<?php
// Exclude Post type 
function claniz_excluded_post_type(){
    $DefaultExcludedPostTypes = [
        'page',
        'attachment',
        'revision',
        'nav_menu_item',
        'vc_grid_item',
        'custom_css',
        'customize_changeset',
        'oembed_cache',
        'cms-mega-menu',
        'elementor_library',
        'e-landing-page'
    ];
    $ExtraExcludedPostTypes = apply_filters('etc_get_post_types', []);
    $excludedPostTypes      = array_merge($DefaultExcludedPostTypes, $ExtraExcludedPostTypes );
    return $excludedPostTypes;
}
/**
 * Get Page List 
 * @return array 
*/
if(!function_exists('claniz_elementor_list_page_opts')){
    function claniz_elementor_list_page_opts($post_type = 'page', $default = ['value' => '', 'label' => 'None'] ){
        $page_list = array();
        if(!empty($default))
            $page_list[$default['value']] = $default['label'];
        $pages = get_pages(array('post_type' => $post_type, 'hierarchical' => 0, 'posts_per_page' => '-1'));
        foreach($pages as $page){
            $page_list[$page->ID] = $page->post_title;
        }
        return $page_list;
    }
}
/**
 * Get post List 
 * @return array 
*/
if(!function_exists('claniz_elementor_list_post_opts')){
    function claniz_elementor_list_post_opts($post_type = 'post', $default = []){
        $page_list = array();
        if(!empty($default))
            $page_list[$default['value']] = $default['label'];
        $pages = get_posts(array('post_type' => $post_type, 'hierarchical' => 0, 'posts_per_page' => '-1'));
        foreach($pages as $page){
            $page_list[$page->ID] = $page->post_title;
        }
        return $page_list;
    }
}
/**
 * Term option for post type
 * make option for elementor element option 
*/
if(!function_exists('etc_get_grid_term_by_post_type_options')){
    function etc_get_grid_term_by_post_type_options($args=[]){
        $args = wp_parse_args($args, ['condition' => 'post_type', 'custom_condition' => []]);
        $post_types = get_post_types([
            'public'   => true,
            //'_builtin' => false
        ], 'objects');
        $excludedPostTypes      = claniz_excluded_post_type();
        $result = [];
        if (!is_array($post_types))
            return $result;
        foreach ($post_types as $post_type) {
            if (!$post_type instanceof WP_Post_Type)
                continue;
            if (in_array($post_type->name, $excludedPostTypes))
                continue;
            $result[] = array(
                'name'     => 'source_'.$post_type->name,
                'label'    => sprintf(esc_html__( 'Select Term of %s', 'claniz' ), $post_type->labels->singular_name),
                'type'     => \Elementor\Controls_Manager::SELECT2,
                'multiple' => true,
                'options'  => etc_get_grid_term_options($post_type->name),
                'condition' => array_merge(
                    [
                        $args['condition'] => [$post_type->name]
                    ],
                    $args['custom_condition']
                )
            );
        }
        return $result;
    }
}

/**
 * Custom link a post opts
 * make option for elementor element option 
    array(
        'name'        => $args['prefix'].'link_page',
        'label'       => esc_html__( 'Page Link', 'claniz' ),
        'type'        => \Elementor\Controls_Manager::SELECT,
        'default'     => '',
        'options'     => claniz_elementor_list_page_opts(),
        'condition'   => array_merge($args['condition'], [$args['prefix'].'link_type' => 'page']),
    )
*/

if(!function_exists('clarora_elementor_link_to_post_opts')){
    function clarora_elementor_link_to_post_opts($args=[]){
        $args = wp_parse_args($args, [
            'prefix'           => '',
            'condition'        => '',
            'custom_condition' => []
        ]);
        $post_types = get_post_types([
            'public'   => true,
            //'_builtin' => false
        ], 'objects');
        $excludedPostTypes = claniz_excluded_post_type();
        $result = [];
        if (!is_array($post_types))
            return $result;
        foreach ($post_types as $post_type) {
            if (!$post_type instanceof WP_Post_Type)
                continue;
            if (in_array($post_type->name, $excludedPostTypes))
                continue;
            $result[] = array(
                'name'     => $args['prefix'].'link_'.$post_type->name,
                'label'    => sprintf(esc_html__( '%s Link', 'claniz' ), $post_type->labels->singular_name),
                'type'     => \Elementor\Controls_Manager::SELECT,
                'options'  => claniz_elementor_list_post_opts($post_type->name),
                'condition' => array_merge(
                    [
                        $args['condition'] => [$post_type->name]
                    ],
                    $args['custom_condition']
                )
            );
        }
        return $result;
    }
}
/**
 * Extra Elementor Icons
*/
if(!function_exists('claniz_register_custom_icon_library')){
    add_filter('elementor/icons_manager/native', 'claniz_register_custom_icon_library');
    function claniz_register_custom_icon_library($tabs){
        $custom_tabs = [
            'cmsi_icon' => [
                'name'          => 'cmsi',
                'label'         => esc_html__( 'CMS Icons', 'claniz' ),
                'url'           => get_template_directory_uri() . '/assets/fonts/font-cmsi/style.css',
                'enqueue'       => [],
                'prefix'        => 'cmsi-',
                'displayPrefix' => '',
                'labelIcon'     => 'cmsi-arrow-circle-right',
                'ver'           => '1.0.0',
                'fetchJson'     => get_template_directory_uri() . '/assets/fonts/font-cmsi.js',
                'native'        => true,
            ],
            'claniz_icon' => [
                'name'          => 'claniz-icon',
                'label'         => esc_html__( 'Claniz Icon', 'claniz' ),
                'url'           => get_template_directory_uri() . '/assets/fonts/font-theme/style.css',
                'enqueue'       => [],
                'prefix'        => 'claniz-',
                'displayPrefix' => '',
                'labelIcon'     => 'claniz-dishwasher',
                'ver'           => '1.0.0',
                'fetchJson'     => get_template_directory_uri() . '/assets/fonts/font-theme.js',
                'native'        => true,
            ],
        ];
        $tabs = array_merge($custom_tabs, $tabs);
        return $tabs;
    }
}

// Elementor Post layout
if(!function_exists('claniz_elementor_post_layout')){
    function claniz_elementor_post_layout(){
        return [
            '1' => [
                'label' => esc_html__( 'Layout 1', 'claniz' ),
                'image' => get_template_directory_uri() . '/elementor/templates/layouts/posts/1.png'
            ],
            '2' => [
                'label' => esc_html__( 'Layout 2', 'claniz' ),
                'image' => get_template_directory_uri() . '/elementor/templates/layouts/posts/2.png'
            ],
            '3' => [
                'label' => esc_html__( 'Layout 3', 'claniz' ),
                'image' => get_template_directory_uri() . '/elementor/templates/layouts/posts/3.jpg'
            ],
            '4' => [
                'label' => esc_html__( 'Layout 4', 'claniz' ),
                'image' => get_template_directory_uri() . '/elementor/templates/layouts/posts/4.jpg'
            ],
            '5' => [
                'label' => esc_html__( 'Layout 5', 'claniz' ),
                'image' => get_template_directory_uri() . '/elementor/templates/layouts/posts/5.jpg'
            ],
            '6' => [
                'label' => esc_html__( 'Layout 6', 'claniz' ),
                'image' => get_template_directory_uri() . '/elementor/templates/layouts/posts/6.jpg'
            ],
            '7' => [
                'label' => esc_html__( 'Layout 7', 'claniz' ),
                'image' => get_template_directory_uri() . '/elementor/templates/layouts/posts/7.jpg'
            ],
            '8' => [
                'label' => esc_html__( 'Layout 8', 'claniz' ),
                'image' => get_template_directory_uri() . '/elementor/templates/layouts/posts/8.jpg'
            ]
        ];
    }
}

/**
 * Elementor Default Image
*/
function claniz_elementor_opt_default_image($name){
    return get_template_directory_uri() .'/assets/images/'.$name;
}
/**
 * Elementor Text Settings
*/
function claniz_elementor_text_settings($args){
    $args = wp_parse_args($args, [
        'label'        => esc_html__( 'Heading', 'claniz' ),
        'name'         => 'text',
        'selector'     => '.text',
        'separator'    => '',
        'default'      => __('Your Heading','claniz'),
        'effect'       => true,
        'border'       => false,    
        'condition'    => [],
        'css_tag'      => 'color',
        'custom_style' => [],
        'custom_width' => false
    ]);
    $default = array(
        array(
            'name'      => $args['name'].'_heading_label_title',
            'label'     => $args['label'],
            'type'      => \Elementor\Controls_Manager::HEADING,
            'separator' => $args['separator'],
            'condition' => $args['condition']
        ),
        array(
            'name'        => $args['name'],
            'label'       => '',
            'type'        => \Elementor\Controls_Manager::TEXTAREA,
            'placeholder' => esc_html__( 'Enter your text', 'claniz' ),
            'default'     => $args['default'],
            'description' => __('Enter "-1" to hide', 'claniz'),
            'label_block' => true,
            //'separator'   => $args['separator'],
            'dynamic' => [
                'active' => true,
            ],
            'condition' => $args['condition']
        ),
        array(
            'name'        => $args['name'].'_tag',
            'label'       => $args['label'].' '.__('Tag','claniz'),
            'type'        => \Elementor\Controls_Manager::SELECT,
            'options'     => [
                'h1'   => 'H1',
                'h2'   => 'H2',
                'h3'   => 'H3',
                'h4'   => 'H4',
                'h5'   => 'H5',
                'h6'   => 'H6',
                'div'  => 'div',
                'span' => 'span',
                'p'    => 'p',
                ''     => __('Default','claniz')
            ],  
            'description' => esc_html__( 'Choose HTML tag use for this element', 'claniz' ),
            'default'     => '',  
            'label_block' => true,
            'separator'   => $args['separator'],
            'condition' => array_merge( 
                $args['condition'],
                [
                    $args['name'].'!' => ['','-1']
                ]
            )
        ),
        array(
            'name'         => $args['name'].'_typo',
            'type'         => \Elementor\Group_Control_Typography::get_type(),
            'control_type' => 'group',
            'selector'     => '{{WRAPPER}} '.$args['selector'],
            'condition'    => array_merge( 
                $args['condition'],
                [
                    $args['name'].'!' => ['','-1']
                ]
            )
        ),
        array(
            'name'         => $args['name'].'_shadow',
            'type'         => \Elementor\Group_Control_Text_Shadow::get_type(),
            'control_type' => 'group',
            'selector'     => '{{WRAPPER}} '.$args['selector'],
            'condition'    => array_merge( 
                $args['condition'],
                [
                    $args['name'].'!' => ['','-1']
                ]
            )
        ),
        array(
            'name'        => $args['name'].'_color',
            'label'       => esc_html__( 'Color', 'claniz' ),
            'type'        => \Elementor\Controls_Manager::SELECT,
            'options'     => claniz_elementor_theme_color_opts(),  
            'default'     => '',
            'condition'   => array_merge( 
                $args['condition'],
                [
                   $args['name'].'!' => ['','-1']
                ]
            )
        ),
        array(
            'name'        => $args['name'].'_custom_color',
            'label'       => esc_html__( 'Custom Color', 'claniz' ),
            'type'        => \Elementor\Controls_Manager::COLOR,
            'condition'   => array_merge( 
                $args['condition'],
                [
                    $args['name'].'!' => ['','-1'],
                    $args['name'].'_color' => 'custom'
                ]
            ),
            'selectors'  => array_merge(
                [
                    '{{WRAPPER}} '.$args['selector'] => $args['css_tag'].':{{VALUE}};'
                ],
                $args['custom_style']
            )
        ),
        array(
            'name'      => $args['name'].'_extra_space',
            'label'     => esc_html__( 'Extra bottom Space', 'claniz' ),
            'type'      => \Elementor\Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'min' => -300,
                    'max' => 300,
                ]
            ],
            'selectors'  => [
                '{{WRAPPER}} '.$args['selector'].' .extra-space' => 'display:block;margin-bottom:{{SIZE}}{{UNIT}};'
            ],
            'condition' => array_merge( 
                $args['condition'],
                [
                    $args['name'].'!' => ['','-1']
                ]
            )
        )
    );
    $custom_width = $effect = $border = [];
    if($args['custom_width']){
        $custom_width = [
            array(
                'name'         => $args['name'].'_custom_width',
                'label'        => __( 'Custom content width (%)', 'claniz' ),
                'type'         => \Elementor\Controls_Manager::SLIDER,
                'control_type' => 'responsive',
                'tablet_default' => [
                    'size' => 100,
                ],
                'mobile_default' => [
                    'size' => 100,
                ],
                'selectors'    => [
                    '{{WRAPPER}} '.$args['selector'] => 'width:{{SIZE}}%;'
                ],
                'condition' => array_merge( 
                    $args['condition'],
                    [
                        $args['name'].'!' => ['','-1']
                    ]
                )
            ),
        ];
    }
    if($args['effect']){
        $effect = [
            array(
                'name'      => $args['name'].'_animation',
                'label'     => esc_html__( 'Motion Effect', 'claniz' ),
                'type'      => \Elementor\Controls_Manager::ANIMATION,
                'condition' => array_merge( 
                    $args['condition'],
                    [
                        $args['name'].'!' => ['-1']
                    ]
                )
            ),
            array(
                'name'    => $args['name'].'_animation_duration', 
                'label'   => __( 'Animation Duration', 'claniz' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => 'normal',
                'options' => [
                    'slow'   => __( 'Slow', 'claniz' ),
                    'normal' => __( 'Normal', 'claniz' ),
                    'fast'   => __( 'Fast', 'claniz' ),
                ],
                'condition' => [
                    $args['name'].'_animation!' => '',
                ]
            ),
            array(
                'name'      => $args['name'].'_animation_delay',
                'label'     => esc_html__( 'Animation Delay', 'claniz' ),
                'type'      => \Elementor\Controls_Manager::NUMBER,
                'min'       => 0,
                'step'      => 100,
                'condition' => [
                    $args['name'].'_animation!' => ''
                ]
            )
        ];
    }
    if($args['border']){
        $border = [
            array(
                'name'      => $args['name'].'_border_heading',
                'label'     => esc_html__( 'Border', 'claniz' ),
                'type'      => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ),
            array(
                'name'    => $args['name'].'_border_width',
                'label'   => esc_html__( 'Border Width', 'claniz' ),
                'type'    => \Elementor\Controls_Manager::SLIDER,
                'default' => [],
                'range'   => [
                    'px' => [
                        'min' => 0,
                        'max' => 10,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} '.$args['selector'] => 'border-width: {{SIZE}}{{UNIT}};',
                ],
            ),
            array(
                'name'        => $args['name'].'_border_color',
                'label'       => esc_html__( 'Border Color', 'claniz' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
                'options'     => claniz_elementor_theme_color_opts(),  
                'default'     => '',
                'condition'   => array_merge( 
                    $args['condition'],
                    [
                        $args['name'].'!' => '',
                        $args['name'].'!' => '-1'
                    ]
                )
            ),
            array(
                'name'        => $args['name'].'_border_custom_color',
                'label'       => esc_html__( 'Custom Border Color', 'claniz' ),
                'type'        => \Elementor\Controls_Manager::COLOR,
                'condition'   => array_merge( 
                    $args['condition'],
                    [
                        $args['name'].'!' => '',
                        $args['name'].'!' => '-1',
                        $args['name'].'_border_color' => 'custom'
                    ]
                ),
                'selectors'  => [
                    '{{WRAPPER}} '.$args['selector'] => 'border-color:{{VALUE}};'
                ]
            )
        ];
    }
    return array_merge($default, $border, $custom_width, $effect);
}
/**
 * Elementor Text Render
*/
function claniz_elementor_text_render($args = [], $widget = [], $settings = []){
    $args = wp_parse_args($args, [
        'name'         => 'text',
        'tag'          => 'div',
        'color'        => 'body',
        'class'        => '', 
        'selector'     => '',
        'render_attrs' => '',
        'before'       => '', 
        'after'        => '',
        'wrap_before'  => '', 
        'wrap_after'   => '',
        'autop'        => false,
        'default'      => '' 
    ]);
    if( empty($widget->get_setting($args['name'],$args['default'])) || $widget->get_setting($args['name']) === '-1' ) return;
    if(empty($args['render_attrs'])) $args['render_attrs'] = $args['name'];
    // Heading
    $text_tag = $widget->get_setting($args['name'].'_tag', $args['tag']);
    $widget->add_render_attribute( $args['render_attrs'], 'class', $args['class']);
    $widget->add_render_attribute( $args['render_attrs'], 'class', $args['selector']);
    $widget->add_render_attribute( $args['render_attrs'], 'class', 'text-'.$widget->get_setting($args['name'].'_color', $args['color']));
    $widget->add_render_attribute( $args['render_attrs'], 'class', 'empty-none');
    
    if ( isset($settings[$args['name'].'_animation']) && $settings[$args['name'].'_animation'] ) {
        $widget->add_render_attribute( $args['render_attrs'], 'class', 'elementor-invisible');
        $widget->add_render_attribute( $args['render_attrs'], 'class', 'animated-'.$widget->get_setting($args['name'].'_animation_duration', ''));
        $widget->add_render_attribute( $args['render_attrs'], 'data-settings', json_encode([
            '_animation'      => $widget->get_setting($args['name'].'_animation', ''),
            'animation_delay' => $widget->get_setting($args['name'].'_animation_delay', '')
        ]));
    }
    if($args['autop']){
        $text = nl2br($widget->get_setting($args['name'], $args['default']));
    } else {
        $text = $widget->get_setting($args['name'], $args['default']);
    }
    printf('%s', $args['wrap_before']);
?>
    <<?php etc_print_html($text_tag);?> <?php etc_print_html($widget->get_render_attribute_string( $args['render_attrs'] )); ?>><?php
        etc_print_html($args['before'].$text.$args['after']);
    ?><span class="extra-space clearfix"></span></<?php etc_print_html($text_tag);?>>
<?php
    printf('%s', $args['wrap_after']);
}
/**
 * Elementor Typo Settings
*/
function claniz_elementor_typo_settings($args=[]){
    $args = wp_parse_args($args, [
        'name'     => 'typo_text',
        'selector' => '.typo-text',
        'condition'=> [],
        'label'    => __('Typography Settings','claniz'),
        'color'    => true
    ]);
    $default = array(
        array(
            'name'      => $args['name'].'_notice',
            'type'      => \Elementor\Controls_Manager::RAW_HTML,
            'raw'       => $args['label'],
            'condition' => $args['condition'],
            'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning'
        ),
        array(
            'name'         => $args['name'].'_typo',
            'type'         => \Elementor\Group_Control_Typography::get_type(),
            'control_type' => 'group',
            'selector'     => '{{WRAPPER}} '.$args['selector'],
            'condition'    => $args['condition']
        ),
        array(
            'name'         => $args['name'].'_shadow',
            'type'         => \Elementor\Group_Control_Text_Shadow::get_type(),
            'control_type' => 'group',
            'selector'     => '{{WRAPPER}} '.$args['selector'],
            'condition'    => $args['condition']
        )
    );
    if($args['color']){
        $default[] = array(
            'name'        => $args['name'].'_color',
            'label'       => esc_html__( 'Text Color', 'claniz' ),
            'type'        => \Elementor\Controls_Manager::SELECT,
            'options'     => claniz_elementor_theme_color_opts(),
            'condition'    => $args['condition'] 
        );
        $default[] = array(
            'name'        => $args['name'].'_custom_color',
            'label'       => esc_html__( 'Custom Text Color', 'claniz' ),
            'type'        => \Elementor\Controls_Manager::COLOR,
            'condition'   => array_merge(
                [
                    $args['name'].'_color'      => 'custom'
                ],
                $args['condition']
            ),
            'selectors'  => [
                '{{WRAPPER}} '.$args['selector'] => 'color:{{VALUE}};'
            ]
        );
    }
    return $default;
}
if(!function_exists('claniz_elementor_typo_render')){
    function claniz_elementor_typo_render($args = [], $widget= [], $settings= []){
        $args = wp_parse_args($args, [
            'content'      => '',
            'name'         => 'text',
            'tag'          => 'div',
            'color'        => 'body',
            'class'        => '', 
            'selector'     => '',
            'render_attrs' => '',
            'before'       => '', 
            'after'        => '',
            'wrap_before'  => '', 
            'wrap_after'   => ''
        ]);

        if(empty($args['content'])) return;

        if(empty($args['render_attrs'])) $args['render_attrs'] = $args['name'];
        // Heading
        $text_tag = $widget->get_setting($args['name'].'_tag', $args['tag']);
        $widget->add_render_attribute( $args['render_attrs'], 'class', $args['class']);
        $widget->add_render_attribute( $args['render_attrs'], 'class', $args['selector']);
        $widget->add_render_attribute( $args['render_attrs'], 'class', 'text-'.$widget->get_setting($args['name'].'_color', $args['color']));
        $widget->add_render_attribute( $args['render_attrs'], 'class', 'empty-none');
        printf('%s', $args['wrap_before']);
    ?>
    <<?php etc_print_html($text_tag);?> <?php etc_print_html($widget->get_render_attribute_string( $args['render_attrs'] )); ?>><?php
        etc_print_html($args['before'].$args['content'].$args['after']);
    ?></<?php etc_print_html($text_tag);?>>
    <?php
        printf('%s', $args['wrap_after']);
    }
}

// Theme Colors
if(!function_exists('claniz_elementor_theme_colors')){
    function claniz_elementor_theme_colors($args = []){
        $args = wp_parse_args($args, [
            'name'                => 'main_color',
            'label'               => esc_html__('Main Color', 'claniz'),
            'custom'              => true,
            'custom_selector'     => '',
            'custom_selector_tag' => 'color',
            'prefix_class'        => '',
            'relation'            => '',
            'condition'           => [],
            'default'             => '',
            'output'              => true     
        ]);
        $custom_selector = [];
        if(!empty($args['custom_selector']) && $args['output'] === true){
            if($args['relation'] === 'and'){
                $custom_selector = [
                    '{{WRAPPER}}'.$args['custom_selector'] => $args['custom_selector_tag'].': {{VALUE}};' //$custom_selector
                ];
            } else {
                $custom_selector = [
                    '{{WRAPPER}} '.$args['custom_selector'] => $args['custom_selector_tag'].': {{VALUE}};' //$custom_selector
                ];
            }
        } 
        $color = [
            [
                'name'        => $args['name'],
                'label'       => $args['label'],
                'type'        => \Elementor\Controls_Manager::SELECT,
                'options'     => claniz_elementor_theme_color_opts(),  
                'default'     => $args['default'],
                'prefix_class'=> $args['prefix_class'],
                'condition'   => $args['condition']
            ]
        ];
        if($args['custom']){
            $color[] = [
                'name'        => 'custom_'.$args['name'],
                'label'       => __('Custom','claniz'). ' '.$args['label'],
                'type'        => \Elementor\Controls_Manager::COLOR,
                'condition'   => [
                    $args['name'] => 'custom'
                ],
                'selectors'    => $custom_selector,
            ];
        }
        return  $color;
    }
}

// Alignment options
if(!function_exists('claniz_elementor_text_align')){
    function claniz_elementor_text_align($args = []) {
        $args = wp_parse_args($args, [
            'prefix'      => '',
            'name'        => 'text-align',   
            'default'     => '',
            'label'       => esc_html__( 'Content Alignment', 'claniz' ),
            'label_block' => false,
            'condition'   => []
        ]);
        return array(
            'name'         => $args['prefix'].$args['name'],
            'label'        => $args['label'],
            'label_block'  => $args['label_block'],
            'type'         => \Elementor\Controls_Manager::CHOOSE,
            'control_type' => 'responsive',
            'options'      => claniz_text_align_opts(),
            'default'      => $args['default'],
            'condition'    => $args['condition']
        );
    }
}
if(!function_exists('claniz_text_align_opts')){
    function claniz_text_align_opts($args = []){
        $args = wp_parse_args($args, [
            'default' => '',
        ]);
        return [
            'start' => [
                'title' => esc_html__( 'Start', 'claniz' ),
                'icon' => 'eicon-text-align-left',
            ],
            'center' => [
                'title' => esc_html__( 'Center', 'claniz' ),
                'icon' => 'eicon-text-align-center',
            ],
            'end' => [
                'title' => esc_html__( 'End', 'claniz' ),
                'icon' => 'eicon-text-align-right',
            ],
            'justify' => [
                'title' => esc_html__( 'Justified', 'claniz' ),
                'icon' => 'eicon-text-align-justify',
            ],
        ];
    }
}
// Alignment css class
// Text Align
if(!function_exists('claniz_elementor_align_class')){
    function claniz_elementor_align_class($settings =[], $args = []){
        $args = wp_parse_args($args, [
            'id'          => 'text-align',
            'extra_class' => '',
            'default'     => '',
            'prefix_name' => '',
            'prefix'      => 'text-'  
        ]);
        if(empty($args['default'])) $args['default'] = $settings[$args['prefix_name'].$args['id']];
        $align_class = [];
        $align_class[] = empty($settings[$args['id'].'_mobile']) ? $args['prefix'].$args['default'] : $args['prefix'].$settings[$args['id'].'_mobile'];
        $align_class[] = empty($settings[$args['id'].'_tablet']) ? '' : $args['prefix'].'md-'.$settings[$args['id'].'_tablet'];
        $align_class[] = empty($settings[$args['id']]) ? '' : $args['prefix'].'lg-'.$settings[$args['id']];
        
        $align_class[] = $args['extra_class'];
        return trim(implode(' ', $align_class));
    }
}
// Row content align
if(!function_exists('claniz_elementor_row_align')){
    function claniz_elementor_row_align($args = []) {
        $args = wp_parse_args($args, [
            'prefix'    => '',
            'name'      => 'row-align',  
            'label'     => esc_html__( 'Justify Content', 'claniz' ),    
            'default'   => '',
            'condition' => [],
            'prefix_class' => ''
        ]);
        return array(
            'name'         => $args['prefix'].$args['name'],
            'label'        => $args['label'],
            'type'         => \Elementor\Controls_Manager::CHOOSE,
            'control_type' => 'responsive',
            'options'      => [
                'start' => [
                    'title' => esc_html__( 'Start', 'claniz' ),
                    'icon' => 'eicon-h-align-left',
                ],
                'center' => [
                    'title' => esc_html__( 'Center', 'claniz' ),
                    'icon' => 'eicon-h-align-center',
                ],
                'end' => [
                    'title' => esc_html__( 'End', 'claniz' ), 
                    'icon' => 'eicon-h-align-right',
                ],
                'around' => [
                    'title' => esc_html__( 'Around', 'claniz' ),
                    'icon' => 'eicon-h-align-center',
                ],
                'between' => [
                    'title' => esc_html__( 'Between', 'claniz' ),
                    'icon' => 'eicon-h-align-stretch',
                ],
            ],
            'default'      => $args['default'],
            'condition'    => $args['condition'],
            'prefix_class' => $args['prefix_class']
        );
    }
}
// Row Content Alignment
if(!function_exists('claniz_elementor_row_justify_class')){
    function claniz_elementor_row_justify_class($settings=[], $args = []){
        $args = wp_parse_args($args, [
            'id'          => 'row-align',
            'default'     => '',
            'extra_class' => '',
            'prefix'      => 'justify-content-'
        ]);

        if(empty($args['default'])) $args['default'] = $settings[$args['id']];

        $align_class = [];
        $align_class[] = empty($settings[$args['id'].'_mobile']) ? $args['prefix'].$args['default'] : $args['prefix'].$settings[$args['id'].'_mobile'];
        $align_class[] = empty($settings[$args['id'].'_tablet']) ? '' : $args['prefix'].'md-'.$settings[$args['id'].'_tablet'];
        $align_class[] = empty($settings[$args['id']]) ? '' : $args['prefix'].'lg-'.$settings[$args['id']];
        if(empty($align_class)){
            return;
        } else {
            $align_class[] = $args['extra_class'];
            return trim(implode(' ', $align_class));
        }
    }
}

// Swiper Slider Settings
if(!function_exists('claniz_elementor_swiper_slider_settings')){
    function claniz_elementor_swiper_slider_settings($args = []){
        $args = wp_parse_args($args, [
            'name'                 => 'section_swiper_slider_settings',
            'label'                => __('Carousel Settings', 'claniz'),
            'tab'                  => \Elementor\Controls_Manager::TAB_LAYOUT,
            'prefix'               => '',
            'condition'            => [],
            'slide_to_show'        => 3,
            'slide_to_show_tablet' => 2,
            'slide_to_show_mobile' => 1, 
        ]);
        $slides_to_show = range( 1, 10 );
        $slides_to_show = array_combine( $slides_to_show, $slides_to_show );
        return array(
            'name'     => $args['name'],
            'label'    => $args['label'],
            'tab'      => $args['tab'],
            'controls' => array_merge(
                array(
                    array(
                        'name'        => $args['prefix'].'slide_direction',
                        'label'       => esc_html__('Slides Direction', 'claniz'),
                        'description' => esc_html__('Defines how slides Direction, \'horizontal\' | \'vertical\'', 'claniz'),
                        'type'        => \Elementor\Controls_Manager::SELECT,
                        'options'     => [
                            'horizontal' => __('Horizontal', 'claniz'),
                            'vertical'   => __('Vertical', 'claniz')
                        ],
                        'default'      => 'horizontal',
                        'condition' => [
                            'slide_to_show' => '1',
                        ],
                    ),
                    array(
                        'name'    => $args['prefix'].'slide_mode',
                        'label'   => esc_html__('Slide Effect', 'claniz'),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'options' => [
                            'slide'     => esc_html__('Slide', 'claniz'),
                            'fade'      => esc_html__('Fade', 'claniz'),
                            'cube'      => esc_html__('Cube', 'claniz'),
                            'flip'      => esc_html__('Flip', 'claniz'),
                            //'coverflow' => esc_html__('Coverflow', 'claniz'),
                        ],
                        'default' => 'slide',
                    ),
                    array(
                        'name'            => $args['prefix'].'slide_to_show',
                        'label'           => esc_html__('Slides to Show', 'claniz'),
                        'type'            => \Elementor\Controls_Manager::SELECT,
                        'control_type'    => 'responsive',
                        'desktop_default' => 3,
                        'tablet_default'  => 2,
                        'mobile_default'  => 1,
                        'options'         => [
                                '' => esc_html__('Default', 'claniz' ),
                            ] + $slides_to_show,
                        'condition' => [
                            'slide_mode' => ['slide']
                        ]
                    ),
                    array(
                        'name'         => $args['prefix'].'slide_to_scroll',
                        'label'        => esc_html__('Slides to Scroll', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'control_type' => 'responsive',
                        'default'      => '',
                        'options'      => [
                                '' => esc_html__('Default', 'claniz' ),
                            ] + $slides_to_show,
                        'condition' => [
                            'slide_mode'      => ['slide'],
                            'slide_to_show!' => '1',
                        ],
                    ),
                    array(
                        'name'        => $args['prefix'].'slide_percolumn',
                        'label'       => esc_html__('Slides Per Column', 'claniz'),
                        'description' => esc_html__('Number of slides per column, for multirow layout', 'claniz'),
                        'type'        => \Elementor\Controls_Manager::SELECT,
                        'options'     => [
                            '1' => '1',
                            '2' => '2',
                            '3' => '3',
                            '4' => '4'
                        ],
                        'default'      => '1',
                        'condition'    => [
                            'slide_mode'       => 'slide',
                            'slide_to_show!'   => '1',
                            'slide_to_scroll!' => '1' 
                        ] 
                    ),
                    array(
                        'name'        => $args['prefix'].'slide_percolumnfill',
                        'label'       => esc_html__('Slides Per Column Fill', 'claniz'),
                        'description' => esc_html__('Defines how slides should fill rows, by column or by row', 'claniz'),
                        'type'        => \Elementor\Controls_Manager::SELECT,
                        'options'     => [
                            'row'    => __('Row', 'claniz'),
                            'column' => __('Column', 'claniz')
                        ],
                        'default'      => 'column',
                        'condition'    => [
                            'slide_mode'       => 'slide',
                            'slide_to_show!'   => '1',
                            'slide_to_scroll!' => '1',
                            'slide_percolumn!' => '1'
                        ]
                    ),
                    array(
                        'name'        => $args['prefix'].'gap',
                        'label'       => __('Gap', 'claniz'),
                        'description' => __('Distance between slides in px', 'claniz'),
                        'type'        => \Elementor\Controls_Manager::NUMBER,
                        'default'     => 40
                    ),
                    array(
                        'name'         => $args['prefix'].'gap_extra',
                        'label'        => esc_html__( 'Extra Gap Bottom', 'claniz' ),
                        'description'  => esc_html__( 'Add extra space at bottom of each items','claniz'),
                        'type'         => \Elementor\Controls_Manager::NUMBER,
                        'default'      => 0,
                    ),
                    array(
                        'name'         => $args['prefix'].'full_width',
                        'label'        => esc_html__( 'Full Width', 'claniz' ),
                        'description'  => esc_html__( 'Make Slider Full Width','claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => 'full-no',
                        'options'      => [
                            'full-no'    => __('No', 'claniz'),
                            'full-end'   => __('Full To End', 'claniz'),
                            'full-start' => __('Full To Start', 'claniz'),
                        ],
                        'prefix_class' => 'cms-sliders-'
                    ),
                    array(
                        'name'         => $args['prefix'].'arrows',
                        'label'        => esc_html__('Show Arrows', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'options' => [
                            'true'  => __('Yes', 'claniz'),
                            'false' => __('No', 'claniz')
                        ],
                        'default'      => 'true', 
                        'control_type' => 'responsive',
                        'separator'    => 'before',
                        'prefix_class' => 'cms-swiper-arrows%s-'
                    ),
                    array(
                        'name'         => $args['prefix'].'arrows_icon',
                        'label'        => esc_html__('Arrows Icon', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'options' => [
                            'default' => __('Default', 'claniz'),
                            'chevron' => __('Chevron', 'claniz'),
                            'arrow'   => __('Arrow', 'claniz')
                        ],
                        'default'      => 'default',
                        'separator'    => 'before',
                        'prefix_class' => 'cms-swiper-arrows-icon-'
                    ),
                    array(
                        'name'         => $args['prefix'].'arrows_pos',
                        'label'        => esc_html__('Arrows Position', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => 'in-vertical',
                        'options'      => [
                            'in-vertical'   => esc_html__('Inside Vertical','claniz'),
                            'out-vertical'  => esc_html__('Outside Vertical','claniz'),
                            'top-left'      => esc_html__('Top Left','claniz'),
                            'top-right'     => esc_html__('Top Right','claniz'),
                            'top-center'    => esc_html__('Top Center','claniz'),
                            'bottom-left'   => esc_html__('Bottom Left','claniz'),
                            'bottom-right'  => esc_html__('Bottom Right','claniz'),
                            'bottom-center' => esc_html__('Bottom Center','claniz'),
                            'left-side'     => esc_html__('Left Side','claniz'),
                            'right-side'    => esc_html__('Right Side','claniz')
                        ],
                        'prefix_class' => 'cms-swiper-nav-',
                    ),
                    array(
                        'name'         => $args['prefix'].'arrows_style',
                        'label'        => esc_html__('Arrows Size', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => 'default',
                        'options'      => [
                            'default'  => __('Default','claniz'),
                            'size-58'  => __('Size 58','claniz'),
                            'size-44'  => __('Size 44','claniz'),
                            'size-48'  => __('Size 48','claniz'),
                            'size-34'  => __('Size 34','claniz'),
                        ],
                        'prefix_class' => 'cms-swiper-nav-',
                    ),
                    array(
                        'name'         => $args['prefix'].'arrows_shape',
                        'label'        => esc_html__('Arrows Shape', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => 'default',
                        'options'      => [
                            'default' => __('Default','claniz'),
                            'square'  => __('Square','claniz'),
                            'rounded' => __('Rounded','claniz'),
                            'circle'  => __('Circle','claniz'),
                        ],
                        'prefix_class' => 'cms-swiper-nav-shape-',
                    ),
                    array(
                        'name'         => $args['prefix'].'arrows_outline',
                        'label'        => esc_html__('Arrows Outline', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => 'no',
                        'options'      => [
                            'yes' => __('Yes','claniz'),
                            'no'  => __('No','claniz')
                        ],
                        'prefix_class' => 'cms-swiper-nav-outline-',
                    ),
                    array(
                        'name'         => $args['prefix'].'arrows_color',
                        'label'        => esc_html__('Arrows Color', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => '',
                        'options'      => claniz_elementor_theme_color_opts(['custom' =>  false]),
                        'prefix_class' => 'cms-swiper-nav-color-',
                    ),
                    array(
                        'name'         => $args['prefix'].'arrows_color_hover',
                        'label'        => esc_html__('Arrows Color Hover', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => '',
                        'options'      => claniz_elementor_theme_color_opts(['custom' =>  false]),
                        'prefix_class' => 'cms-swiper-nav-color-hover-',
                    ),
                    array(
                        'name'         => $args['prefix'].'arrows_bg_color',
                        'label'        => esc_html__('Arrows Background Color', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => '',
                        'options'      => claniz_elementor_theme_color_opts(['custom' =>  false]),
                        'prefix_class' => 'cms-swiper-nav-bg-color-',
                    ),
                    array(
                        'name'         => $args['prefix'].'arrows_bg_color_hover',
                        'label'        => esc_html__('Arrows Background Color Hover', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => '',
                        'options'      => claniz_elementor_theme_color_opts(['custom' =>  false]),
                        'prefix_class' => 'cms-swiper-nav-bg-color-hover-',
                    ),
                    array(
                        'name'    => $args['prefix'].'arrow_link',
                        'label'   => esc_html__('Additional arrow link?','claniz'),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'options' => [  
                            ''          => __('None', 'claniz'),
                            'text_link' => __('Text Link','claniz'),
                            'button'    => __('Button','claniz'),
                        ],
                        'default' => '',
                        'condition' => [
                            'arrows_pos' =>  ['left-side', 'right-side']
                        ],
                        'separator'   => 'before',
                        'label_block' => true
                    )
                ),
                claniz_elementor_hyperlink_settings([
                    'prefix'    => $args['prefix'].'arrow_hyperlink',
                    'condition' => [
                        'arrow_link' => 'text_link',
                        'arrows_pos' =>  ['left-side', 'right-side']                         
                    ]
                ]),
                claniz_elementor_button_settings([
                    'prefix'   => $args['prefix'].'arrow_btnlink',
                    'btn_text' => 'Read More',
                    'condition' => [
                        'arrow_link' => 'button',
                        'arrows_pos' =>  ['left-side', 'right-side']                            
                    ]
                ]),
                array(
                    array(
                        'name'         => $args['prefix'].'dots',
                        'label'        => esc_html__('Show Dots', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'control_type' => 'responsive',
                        'options' => [
                            'true'  => __('Yes', 'claniz'),
                            'false' => __('No', 'claniz')
                        ],
                        'default'      => 'true',
                        'separator'    => 'before',
                        'prefix_class' => 'cms-swiper-dots%s-'
                    ),
                    array(
                        'name'         => $args['prefix'].'dots_style',
                        'label'        => esc_html__('Dots Style', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => 'bullets',
                        'options'      => [
                            'bullets'     => __('Bullets','claniz'),
                            //'dynamic'   => __('Dynamic','claniz'),
                            'progressbar' => __('Progressbar','claniz'),
                            'fraction'    => __('Fraction','claniz'),
                            //'custom'    => __('Custom','claniz')
                        ]
                    ),
                    array(
                        'name'         => $args['prefix'].'dots_layout',
                        'label'        => esc_html__('Dots Layout', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => 'divider',
                        'options'      => [
                            'circle'   => __('Circle','claniz'),
                            'divider'  => __('Divider','claniz'),
                            'custom'   => __('Custom','claniz'),
                        ],
                        'prefix_class' => 'cms-swiper-dots-',
                        'condition' => [
                            'dots_style'  => 'bullets'
                        ]
                    ),
                    array(
                        'name'      => $args['prefix'].'dots_style_notice',
                        'type'      => \Elementor\Controls_Manager::RAW_HTML,
                        'raw'       => sprintf( __( 'How to custom pagination, readmore at <a href="%s" target="_blank">swiper.js</a>', 'claniz' ), 'https://swiperjs.com/swiper-api#pagination' ),
                        'condition' => [
                            'dots_style'  => 'custom'
                        ],
                        'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning'
                    ),
                    array(
                        'name'      => $args['prefix'].'dots_style_custom',
                        'type'      => \Elementor\Controls_Manager::TEXTAREA,
                        'label'     => esc_html__('Enter your code here','claniz'),
                        'condition' => [
                            'dots_style'  => 'custom'
                        ],
                        'description' => __('Default','claniz').': function (swiper, current, total) { return current + \' of \' + total;}'
                    ),

                    array(
                        'name'         => $args['prefix'].'dots_in_nav',
                        'label'        => esc_html__('Dots In Nav', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SWITCHER,
                        'default'      => '',
                        'separator'    => 'before',
                        'condition'    => [
                            'arrows'     => 'true',
                            'arrows_pos' => ['top-left', 'top-right', 'top-center','bottom-left', 'bottom-right', 'bottom-center']
                        ] 
                    ),
                    array(
                        'name'         => $args['prefix'].'dots_pos',
                        'label'        => esc_html__('Dots Position', 'claniz'),
                        'type'         => \Elementor\Controls_Manager::SELECT,
                        'default'      => 'out',
                        'options'      => [
                            'in'  => esc_html__('Inside','claniz'),
                            'out' => esc_html__('Outside','claniz')
                        ],
                        'condition' => [
                            'dots_in_nav' => ''
                        ],
                        'prefix_class' => 'cms-swiper-dots-'
                    )
                ),
                claniz_elementor_theme_colors([
                    'name'                => $args['prefix'].'dots_color',
                    'label'               => esc_html__('Dots Color', 'claniz'),
                    'custom_label'        => esc_html__('Custom Dots Color', 'claniz'),
                    'custom_selector'     => '.cms-swiper-dots-color-custom ul.cms-swiper-dot li:not(.slick-active):not(:hover) button:before',
                    'custom_selector_tag' => 'background',
                    'prefix_class'        => 'cms-swiper-dots-color-',
                    'relation'            => 'and'
                ]),
                claniz_elementor_theme_colors([
                    'name'                => $args['prefix'].'dots_color_hover',
                    'label'               => esc_html__('Dots Color Hover', 'claniz'),
                    'custom_label'        => esc_html__('Custom Dots Color Hover', 'claniz'),
                    'custom_selector'     => '.cms-swiper-dots-color-hover-custom ul.cms-swiper-dot li.slick-active button:before, .cms-swiper-dots-color-hover-custom ul.cms-swiper-dot li:hover button:before',
                    'custom_selector_tag' => 'background',
                    'prefix_class'        => 'cms-swiper-dots-color-hover-',
                    'relation'            => 'and'
                ]),
                array(
                    claniz_elementor_row_align([
                        'name'      => $args['prefix'].'dots_align',
                        'label'     => esc_html__('Dots Align', 'claniz'),
                        'prefix_class' => 'cms-swiper-dots-align%s-'
                    ]),
                    array(
                        'name'      => $args['prefix'].'autoplay',
                        'label'     => esc_html__('Autoplay', 'claniz'),
                        'type'      => \Elementor\Controls_Manager::SELECT,
                        'options'   => [
                            'true' => __('Yes','claniz'),
                            'false' => __('No', 'claniz')
                        ],
                        'default'   => 'false',
                        'separator' => 'before'
                    ),
                    array(
                        'name'    => $args['prefix'].'pause_on_hover',
                        'label'   => esc_html__('Pause on Hover', 'claniz'),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'options'   => [
                            'true' => __('Yes','claniz'),
                            'false' => __('No', 'claniz')
                        ],
                        'default' => 'true',
                        'condition' => [
                            'autoplay' => 'true'
                        ]
                    ),
                    array(
                        'name'      => $args['prefix'].'pause_on_interaction',
                        'label'     => esc_html__('Pause on Interaction', 'claniz'),
                        'type'      => \Elementor\Controls_Manager::SELECT,
                        'options'   => [
                            'true' => __('Yes','claniz'),
                            'false' => __('No', 'claniz')
                        ],
                        'default'   => 'true',
                        'condition' => [
                            'autoplay' => 'true'
                        ]
                    ),
                    array(
                        'name'      => $args['prefix'].'autoplay_speed',
                        'label'     => esc_html__('Autoplay Speed', 'claniz'),
                        'type'      => \Elementor\Controls_Manager::NUMBER,
                        'default'   => 5000,
                        'condition' => [
                            'autoplay' => 'true'
                        ]
                    ),
                    array(
                        'name'    => $args['prefix'].'loop',
                        'label'   => esc_html__('Infinite Loop', 'claniz'),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'options'   => [
                            'true'  => __('Yes','claniz'),
                            'false' => __('No', 'claniz')
                        ],
                        'default' => 'false',
                    ),
                    array(
                        'name'    => $args['prefix'].'speed',
                        'label'   => esc_html__('Animation Speed', 'claniz'),
                        'type'    => \Elementor\Controls_Manager::NUMBER,
                        'default' => 300,
                    )
                )
            ),
            'condition' => $args['condition']
        );
    }
}
if(!function_exists('claniz_swiper_slider_arrows')){
    function claniz_swiper_slider_arrows($settings=[]){
        if(in_array($settings['arrows_pos'], ['in-vertical', 'out-vertical'])): ?>
            <div class="cms-swiper-arrow cmsi-icon rtl-flip cms-swiper-arrow-prev"></div>
            <div class="cms-swiper-arrow cmsi-icon rtl-flip cms-swiper-arrow-next"></div>
        <?php endif;
    }
}
if(!function_exists('claniz_swiper_slider_arrows_side')){
    function claniz_swiper_slider_arrows_side($settings=[]){
        if(in_array($settings['arrows_pos'], ['left-side', 'right-side'])): 
        ?>
            <div class="cms-swiper-arrows">
                <div class="cms-swiper-arrows-arrow">
                    <div class="cms-swiper-arrow cmsi-icon rtl-flip cms-swiper-arrow-prev"></div>
                    <div class="cms-swiper-arrow cmsi-icon rtl-flip cms-swiper-arrow-next"></div>
                </div>
                <div class="cms-swiper-arrows-additional empty-none"><?php
                        // Link
                        if($settings['arrow_link'] === 'button'){
                            // Button
                            claniz_elementor_button_render($widget,$settings,[
                                'prefix'     => 'arrow_link',
                                'icon_class' => '',
                                'class'      => ''
                            ]);
                        } elseif($settings['arrow_link'] === 'text_link') {
                            // Custom Link 
                             claniz_elementor_hyperlink_render($widget,$settings,[
                                'prefix'           => 'arrow_link', 
                                'link_type'        => $settings['arrow_link'],
                                'wrap_class'       => '',
                                'class'            => '',
                                'link_color'       => '',
                                'link_hover_color' => '',
                                'default_icon'     => [],
                                'icon_class'       => ''
                            ]);
                        }
                ?></div>
            </div>
            <?php
        endif;
    }
}
if(!function_exists('claniz_swiper_slider_arrows_side2')){
    function claniz_swiper_slider_arrows_side2($settings=[]){
        if(in_array($settings['arrows_pos'], ['left-side2', 'right-side2'])): 
        ?>
            <div class="cms-swiper-arrows">
                <div class="cms-swiper-arrow cmsi-icon rtl-flip cms-swiper-arrow-prev"></div>
                <?php  claniz_swiper_slider_dots_in_nav($settings); ?>
                <div class="cms-swiper-arrow cmsi-icon rtl-flip cms-swiper-arrow-next"></div>
            </div>
        <?php
        endif;
    }
}
if(!function_exists('claniz_swiper_slider_arrows_top')){
    function claniz_swiper_slider_arrows_top($settings=[], $args = []){
        $args = wp_parse_args($args, [
            'class'  => '',
            'before' => '',
            'after'  => ''
        ]);
        $classes = claniz_nice_class(['cms-swiper-arrows', $args['class']]);
        if(in_array($settings['arrows_pos'], ['top-left', 'top-right'])): ?>
            <div class="<?php echo esc_attr($classes); ?>">
                <div class="cms-swiper-arrow cmsi-icon rtl-flip cms-swiper-arrow-prev"></div>
                <?php  claniz_swiper_slider_dots_in_nav($settings); ?>
                <div class="cms-swiper-arrow cmsi-icon rtl-flip cms-swiper-arrow-next"></div>
            </div>
        <?php endif;
    }
}
if(!function_exists('claniz_swiper_slider_arrows_bottom')){
    function claniz_swiper_slider_arrows_bottom($settings=[], $args = []){
        if(!in_array($settings['arrows_pos'], ['bottom-left', 'bottom-right'])) return;
        $args = wp_parse_args($args, [
            'class'     => '',
            'icon_prev' => '',
            'icon_next' => '',
            'before'    => '',
            'after'     => ''
        ]);
        $classes = ['cms-swiper-arrows', $args['class'], str_replace('bottom-', 'order-',$settings['arrows_pos']) ];
        printf('%s', $args['before']);
    ?>
        <div class="<?php echo implode(' ', $classes);?>">
            <div class="<?php echo implode(' ', ['cms-swiper-arrow cmsi-icon rtl-flip cms-swiper-arrow-prev', $args['icon_prev']]);?>"></div>
            <?php  claniz_swiper_slider_dots_in_nav($settings); ?>
            <div class="<?php echo implode(' ', ['cms-swiper-arrow cmsi-icon rtl-flip cms-swiper-arrow-next', $args['icon_next']]); ?>"></div>
        </div>
    <?php
        printf('%s', $args['after']);
    }
}
if(!function_exists('claniz_swiper_slider_dots')){
    function claniz_swiper_slider_dots($settings=[], $args=[]){
        $args = wp_parse_args($args, [
            'class' => ''
        ]); 
        $classes = ['cms-swiper-dots empty-none', $args['class']];
        ?>
            <div class="<?php echo implode(' ', $classes)?>"></div>
        <?php
    }
}
if(!function_exists('claniz_swiper_slider_dots_in_nav')){
    function claniz_swiper_slider_dots_in_nav($settings=[]){
        if( $settings['dots_in_nav'] === 'true') {
        ?>
            <div class="cms-swiper-dots empty-none"></div>
        <?php
        }
    }
}
if(!function_exists('claniz_swiper_slider_settings')){

    function claniz_swiper_slider_settings($widget=[], $args = []){
        $args = wp_parse_args($args, [
            'swiper_container' => 'cms-swiper-container',
            'class'            => ''
        ]);
        $slide_direction         = $widget->get_setting('slide_direction', 'horizontal');
        $slide_percolumn         = (int) $widget->get_setting('slide_percolumn', '1');
        $slide_percolumnfill     = $widget->get_setting('slide_percolumnfill', 'column');
        $slide_mode              = $widget->get_setting('slide_mode', 'slide');
        
        $slides_to_show          = (int) $widget->get_setting('slide_to_show', '3');
        $slides_to_show_tablet   = (int) $widget->get_setting('slide_to_show_tablet', '2');
        $slides_to_show_mobile   = (int) $widget->get_setting('slide_to_show_mobile', '1');
        $slides_to_scroll        = (int) $widget->get_setting('slide_to_scroll', $slides_to_show );
        $slides_to_scroll_tablet = (int) $widget->get_setting('slide_to_scroll_tablet', $slides_to_show_tablet);
        $slides_to_scroll_mobile = (int) $widget->get_setting('slide_to_scroll_mobile', $slides_to_show_mobile);

        // show one item
        if(in_array($slide_mode, ['fade', 'cube', 'flip'])){
            $slides_to_show = $slides_to_show_tablet = $slides_to_show_mobile = $slides_to_scroll = $slides_to_scroll_tablet = $slides_to_scroll_mobile = 1;
        } elseif($slide_mode === 'coverflow'){
            $slides_to_show = $slides_to_show_tablet = $slides_to_show_mobile = $slides_to_scroll = $slides_to_scroll_tablet = $slides_to_scroll_mobile = 'auto';
        }

        $slides_gutter        = $widget->get_setting('gap');
        $arrows               = $widget->get_setting('arrows', 'true');
        $arrows_tablet        = $widget->get_setting('arrows_tablet', $arrows);
        $arrows_mobile        = $widget->get_setting('arrows_mobile', $arrows_tablet);
        $dots                 = $widget->get_setting('dots');
        $dots_tablet          = $widget->get_setting('dots_tablet', $dots);
        $dots_mobile          = $widget->get_setting('dots_mobile', $dots);
        $dots_style           = $widget->get_setting('dots_style', 'bullets');
        $dots_style_custom    = $widget->get_setting('dots_style_custom', 'function (swiper, current, total) { return current + \' of \' + total;}');
        $dots_pos             = $widget->get_setting('dots_pos','out');
        $autoplay             = $widget->get_setting('autoplay', 'false');
        $pause_on_hover       = $widget->get_setting('pause_on_hover', 'true');
        $pause_on_interaction = $widget->get_setting('pause_on_interaction', 'true');
        $autoplay_speed       = $widget->get_setting('autoplay_speed', 500);
        $loop                 = $widget->get_setting('loop', 'false');
        $speed                = $widget->get_setting('speed', 300);
        $titlenext            = $widget->get_setting('nav_title_next', 'Next');
        $titleprev            = $widget->get_setting('nav_title_prev', 'Prev');
        $opts = [
            'slide_direction'         => $slide_direction,
            'slide_percolumn'         => $slide_percolumn, 
            'slide_percolumnfill'     => $slide_percolumnfill, 
            'slide_mode'              => $slide_mode, 
            'slides_to_show'          => $slides_to_show, 
            'slides_to_show_tablet'   => $slides_to_show_tablet, 
            'slides_to_show_mobile'   => $slides_to_show_mobile, 
            'slides_to_scroll'        => $slides_to_scroll, 
            'slides_to_scroll_tablet' => $slides_to_scroll_tablet, 
            'slides_to_scroll_mobile' => $slides_to_scroll_mobile, 
            'slides_gutter'           => (int) $slides_gutter, 
            'arrow'                   => $arrows,
            'arrow_tablet'            => $arrows_tablet,
            'arrow_mobile'            => $arrows_mobile,
            'dots'                    => $dots,
            'dots_tablet'             => $dots_tablet,
            'dots_mobile'             => $dots_mobile,
            'dots_style'              => $dots_style,
            'dots_style_custom'       => $dots_style_custom,
            'autoplay'                => $autoplay,
            'pause_on_hover'          => $pause_on_hover,
            'pause_on_interaction'    => $pause_on_interaction,
            'delay'                   => $autoplay_speed,
            'loop'                    => $loop,
            'speed'                   => $speed,
        ];
        $widget->add_render_attribute( 'cms-swiper-settings', [
            'class'         => implode(' ', [$args['swiper_container'], $args['class']]),
            'dir'           => is_rtl() ? 'rtl' : 'ltr',
            'data-settings' => wp_json_encode($opts),
            'data-customdot' => $dots_style_custom
        ]);
        etc_print_html($widget->get_render_attribute_string( 'cms-swiper-settings' ));
        //echo 'data-settings='.wp_json_encode($opts).'';
    }
}
// Grid settings
if(!function_exists('claniz_column_settings')){
    function claniz_column_settings(){
        $options = [
            '12' => '12',
            '6'  => '6',
            '3'  => '3',
            '4'  => '4',
            '2'  => '2',
            '1'  => '1'
        ];
        return array(
            array(
                'name'    => 'col_sm',
                'label'   => esc_html__( 'Mobile', 'claniz' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => '1',
                'options' => $options
            ),
            array(
                'name'    => 'col_md',
                'label'   => esc_html__( 'Table', 'claniz' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => '2',
                'options' => $options
            ),
            array(
                'name'    => 'col_lg',
                'label'   => esc_html__( 'Small Desktop', 'claniz' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => '3',
                'options' => $options
            ),
            array(
                'name'    => 'col_xl',
                'label'   => esc_html__( 'Large Desktop', 'claniz' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'default' => '3',
                'options' => $options
            ),
            array(
                'name'         => 'gap',
                'label'        => esc_html__( 'Item Gap', 'claniz' ),
                'type'         => \Elementor\Controls_Manager::NUMBER,
                'control_type' => 'responsive',
                'default'      => 40,
            ),
            array(
                'name'         => 'gap_extra',
                'label'        => esc_html__( 'Extra Gap Bottom', 'claniz' ),
                'description'  => esc_html__( 'Add extra space at bottom of each items','claniz'),
                'type'         => \Elementor\Controls_Manager::NUMBER,
                'default'      => 0,
            )
        );
    }
}
if(!function_exists('claniz_grid_column_settings')){
    function claniz_grid_column_settings($args = []){
        $args = wp_parse_args($args, [
            'tab'       => \Elementor\Controls_Manager::TAB_LAYOUT,
            'condition' => [],
            'extra'     => []    
        ]);
        return array(
            'name'     => 'section_grid_settings',
            'label'    => esc_html__('Grid Columns Settings', 'claniz'),
            'tab'      => $args['tab'],
            'controls' => array_merge(
                claniz_column_settings(),
                $args['extra']
            ),
            'condition' => $args['condition']
        );
    }
}
// get column width
if(!function_exists('claniz_elementor_grid_column_class')){
    function claniz_elementor_grid_column_class($widget=[], $settings=[]){
        $class = [];
        $class[] = 'col-xl-'.round(12/$settings['col_xl']);
        $class[] = 'col-lg-'.round(12/$settings['col_lg']);
        $class[] = 'col-md-'.round(12/$settings['col_md']);
        $class[] = 'col-sm-'.round(12/$settings['col_sm']);

        echo trim(implode(' ', $class));
    }
}

/**
 * Masonry Settings
*/
if(!function_exists('claniz_elementor_masonry_settings')){
    function claniz_elementor_masonry_settings($args = []){
        $args = wp_parse_args($args, [
            'tab'       => \Elementor\Controls_Manager::TAB_LAYOUT,
            'condition' => []
        ]);
        
        return array(
            'name'      => 'section_masonry_settings',
            'label'     => esc_html__('Masonry Settings', 'claniz'),
            'tab'       => $args['tab'],
            'condition' => $args['condition'],
            'controls'  => array_merge(
                array(
                    array(
                        'name'    => 'masonry_mode',
                        'label'   => esc_html__( 'Masonry Mode', 'claniz' ),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'options' => [
                            'fitRows' => esc_html__( 'Basic Grid', 'claniz' ),
                            'masonry' => esc_html__( 'Masonry Grid', 'claniz' ),
                        ],
                        'default'   => 'fitRows'
                    )
                )
            )
        );
    }
}
if(!function_exists('claniz_elementor_masonry_filter_settings')){
    function claniz_elementor_masonry_filter_settings($args = []){
        $args = wp_parse_args($args, [
            'tab'       => \Elementor\Controls_Manager::TAB_LAYOUT,
            'condition' => []
        ]);
        return array(
            'name'      => 'section_filter_settings',
            'label'     => esc_html__('Filter Settings', 'claniz'),
            'tab'       => $args['tab'],
            'condition' => $args['condition'],
            'controls'  => array_merge(
                array(
                    array(
                        'name'    => 'filter',
                        'label'   => esc_html__( 'Show Filter', 'claniz' ),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'default' => 'false',
                        'options' => [
                            'true'  => esc_html__( 'Enable', 'claniz' ),
                            'false' => esc_html__( 'Disable', 'claniz' ),
                        ]
                    ),
                    array(
                        'name'      => 'filter_default_title',
                        'label'     => esc_html__( 'Default Title', 'claniz' ),
                        'type'      => \Elementor\Controls_Manager::TEXT,
                        'default'   => esc_html__( 'All', 'claniz' ),
                        'condition' => [
                            'filter' => 'true',
                        ],
                    ),
                    array(
                        'name'    => 'filter_alignment',
                        'label'   => esc_html__( 'Alignment', 'claniz' ),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'default' => 'center',
                        'options' => [
                            'start'  => esc_html__( 'Start', 'claniz' ),
                            'center' => esc_html__( 'Center', 'claniz' ),
                            'end'    => esc_html__( 'End', 'claniz' ),
                        ],
                        'condition' => [
                            'filter' => 'true',
                        ],
                    )
                )
            )
        );
    }
}
if(!function_exists('claniz_elementor_masonry_pagination_settings')){
    function claniz_elementor_masonry_pagination_settings($args = []){
        $args = wp_parse_args($args, [
            'tab'       => \Elementor\Controls_Manager::TAB_LAYOUT,
            'condition' => []
        ]);
        
        return array(
            'name'      => 'section_pagination_settings',
            'label'     => esc_html__('Pagination Settings', 'claniz'),
            'tab'       => $args['tab'],
            'condition' => $args['condition'],
            'controls'  => array_merge(
                array(
                    array(
                        'name'    => 'pagination_type',
                        'label'   => esc_html__( 'Pagination Type', 'claniz' ),
                        'type'    => \Elementor\Controls_Manager::SELECT,
                        'default' => 'false',
                        'options' => [
                            'pagination' => esc_html__( 'Pagination', 'claniz' ),
                            'loadmore'   => esc_html__( 'Loadmore', 'claniz' ),
                            'false'      => esc_html__( 'Disable', 'claniz' ),
                        ]
                    ),
                    array(
                        'name'      => 'loadmore_text',
                        'label'     => esc_html__( 'Load More text', 'claniz' ),
                        'type'      => \Elementor\Controls_Manager::TEXT,
                        'default'   => esc_html__('Load More','claniz'),
                        'condition' => [
                            'pagination_type' => 'loadmore'
                        ]
                    ),
                )
            )
        );
    }
}
if(!function_exists('claniz_elementor_masonry_column_settings')){
    function claniz_elementor_masonry_column_settings($args = []){
        $args = wp_parse_args($args, [
            'tab'       => \Elementor\Controls_Manager::TAB_LAYOUT,
            'condition' => []
        ]);
        return  claniz_grid_column_settings([
            'tab'       => $args['tab'],
            'condition' => $args['condition']
        ]);
    }
}

if(!function_exists('claniz_elementor_masonry_settings_render_attrs')){
    function claniz_elementor_masonry_settings_render_attrs($widget=[], $settings=[], $_args = []){
        $_args = wp_parse_args($_args,[
            'post_type' => 'post',
            'class'     => ''
        ]);
        $html_id   = etc_get_element_id($settings);
        extract(etc_get_posts_of_grid($_args['post_type'], [
            'source'   => $widget->get_setting('source_'.$_args['post_type'], ''),
            'orderby'  => $widget->get_setting('orderby', 'date'),
            'order'    => $widget->get_setting('order', 'desc'),
            'limit'    => $widget->get_setting('limit', 6),
            'post_ids' => $widget->get_setting('post_ids', ''),
        ]));
        $widget->add_render_attribute( 'wrapper', [
            'id'              => $html_id,
            'class'           => trim('cms-grid '.$_args['class']),
            'data-layoutmode' => $settings['masonry_mode'],
            'data-layout'     => 'masonry',
            'data-start-page' => $paged,
            'data-max-pages'  => $max,
            'data-total'      => $total,
            'data-perpage'    => $widget->get_setting('limit', 6),
            'data-next-link'  => $next_link
        ]);
        etc_print_html($widget->get_render_attribute_string( 'wrapper' ));
    }
}
/**
 * Hyperlink Settings
**/
if(!function_exists('claniz_elementor_hyperlink_settings')){
    function claniz_elementor_hyperlink_settings($args = []){
        $args = wp_parse_args($args, [
            'options'           => [],
            'condition'         => [],
            'prefix'            => '',
            'link_type'         => '',
            'link_type_default' => 'custom',
            'link_page'         => true,
            'link_post'         => true,
            'link_text'         => __('Read More','claniz'),
            'default_icon'      => [
                'library' => 'cmsi',
                'value'   => 'cmsi-arrow-right'
            ],
            'default_icon_align' => 'left',
            'effect'             => false
        ]);
        $_link_type = [
            'custom'   => esc_html__('Custom','claniz')
        ];  
        if($args['link_page']){
            $_link_type['page'] =  esc_html__('Internal Page','claniz');
        }
        if($args['link_post']){
            $_link_type = array_merge($_link_type, etc_get_post_type_options());
        }
        $post_type_link_opts = [];

        $default = array_merge(
            array(
                array(
                    'name'        => $args['prefix'].'link_type',
                    'label'       => esc_html__( 'Link Type', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'default'     => $args['link_type_default'],
                    'options'     => array_merge(
                        $_link_type, 
                        $args['options']
                    ),
                    'condition'   => array_merge($args['condition']),
                ),
                array(
                    'name'        => $args['prefix'].'link_page',
                    'label'       => esc_html__( 'Page Link', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'default'     => '',
                    'options'     => claniz_elementor_list_page_opts(),
                    'condition'   => array_merge($args['condition'], [$args['prefix'].'link_type' => 'page']),
                ), 
                array(
                    'name'        => $args['prefix'].'hyper_link',
                    'label'       => esc_html__( 'Custom Link', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'claniz' ),
                    'default'     => [
                        'url'         => '#',
                        'is_external' => 'on'
                    ],
                    'condition'   => array_merge($args['condition'], [$args['prefix'].'link_type' => 'custom']),
                )
            ),
            clarora_elementor_link_to_post_opts([
                'prefix'    => $args['prefix'],
                'condition' => $args['prefix'].'link_type'
            ]),
            array(
                array(
                    'name'        => $args['prefix'].'link_text',
                    'label'       => __( 'Link Text', 'claniz' ),
                    'description' => __( 'Enter "-1" to hide', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'condition'   => array_merge($args['condition']),
                    'dynamic'     => [
                        'active' => true,
                    ],
                    'default'    => $args['link_text']
                ),
                array(
                    'name'      => $args['prefix'].'show_link_text',
                    'label'     => __( 'Show Link Text', 'claniz' ),
                    'type'      => \Elementor\Controls_Manager::SELECT,
                    'options'   => [
                        ''    => __('Default', 'claniz'),
                        'yes' => __('Yes', 'claniz'),
                        'no'  => __('No', 'claniz')
                    ],
                    'condition' => array_merge($args['condition']),
                    'dynamic'   => [
                        'active' => true,
                    ],
                    'default'    => ''
                ),
                array(
                    'name'        => $args['prefix'].'link_color',
                    'label'       => __( 'Color', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'options'     => claniz_elementor_theme_color_opts(['custom' =>  false]),
                    'condition'   => array_merge($args['condition']),
                ),
                array(
                    'name'        => $args['prefix'].'link_hover_color',
                    'label'       => __( 'Hover Color', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'options'     => claniz_elementor_theme_color_opts(['custom' =>  false]),
                    'condition'   => array_merge($args['condition']),
                ),
                array(
                    'name'         => $args['prefix'].'link_align',
                    'label'        => __( 'Alignment', 'claniz' ),
                    'type'         => \Elementor\Controls_Manager::CHOOSE,
                    'control_type' => 'responsive',
                    'options'      => claniz_text_align_opts(),
                    'condition'    => array_merge($args['condition'])
                ),
                array(
                    'name'        => $args['prefix'].'link_icon',
                    'label'       => __( 'Icon', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::ICONS,
                    'label_block' => true,
                    'default'     => $args['default_icon'], 
                    'condition'   => array_merge($args['condition'])
                ),
                array(
                    'name'        => $args['prefix'].'link_icon_color',
                    'label'       => __( 'Icon Color', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'options'     => claniz_elementor_theme_color_opts(['custom' =>  false]), 
                    'condition'   => array_merge([
                            $args['prefix'].'link_icon[value]!' => ''
                        ],
                        $args['condition'])
                ),
                array(
                    'name'    => $args['prefix'].'link_icon_outline',
                    'label'   => __( 'Icon Outline', 'claniz' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'default' => 'no',
                    'options' => [
                        'yes'  => __( 'Yes', 'claniz' ),
                        'no'  => __( 'No', 'claniz' ),
                    ],
                    'condition' => array_merge([
                            $args['prefix'].'link_icon[value]!' => ''
                        ],
                        $args['condition']
                    )
                ),
                array(
                    'name'    => $args['prefix'].'link_icon_align',
                    'label'   => __( 'Icon Position', 'claniz' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'default' => $args['default_icon_align'],
                    'options' => [
                        'left'  => __( 'Before', 'claniz' ),
                        'right' => __( 'After', 'claniz' ),
                    ],
                    'condition' => array_merge([
                            $args['prefix'].'link_icon[value]!' => ''
                        ],
                        $args['condition']
                    )
                ),
                array(
                    'name'  => $args['prefix'].'link_icon_size',
                    'label' => __( 'Icon Size', 'claniz' ),
                    'type'  => \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => 5,
                            'max' => 200,
                        ],
                    ],
                    'condition' => array_merge(
                        [
                            $args['prefix'].'link_icon[value]!' => ''
                        ],
                        $args['condition']
                    ),
                    'selectors' => [
                        '{{WRAPPER}} .cms-link.'.$args['prefix'].' .cms-icon' => 'font-size: {{SIZE}}{{UNIT}};'
                    ]
                ),
                array(
                    'name'  => $args['prefix'].'link_icon_indent',
                    'label' => esc_html__( 'Icon Spacing', 'claniz' ),
                    'type'  => \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => 5,
                            'max' => 200,
                        ],
                    ],
                    'condition' => array_merge(
                        [
                            $args['prefix'].'link_icon[value]!' => ''
                        ],
                        $args['condition']
                    ),
                    'selectors' => [
                        '{{WRAPPER}} .cms-link.'.$args['prefix'].' .cms-align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
                        '{{WRAPPER}} .cms-link.'.$args['prefix'].' .cms-align-icon-left' => 'margin-right: {{SIZE}}{{UNIT}};',
                    ]
                )
            )
        );
        return wp_parse_args($args['options'], $default);
    }
}
/**
 * Hyperlink Settings
**/
if(!function_exists('claniz_elementor_hyperlink_settings2')){
    function claniz_elementor_hyperlink_settings2($args = []){
        $args = wp_parse_args($args, [
            'options'           => [],
            'condition'         => [],
            'prefix'            => '',
            'link_type'         => '',
            'link_type_default' => 'custom',
            'link_page'         => true,
            'link_post'         => true,
            'link_text'         => 'Read More',
            'effect'            => false
        ]);
        $_link_type = [
            'custom'   => esc_html__('Custom','claniz')
        ];  
        if($args['link_page']){
            $_link_type['page'] =  esc_html__('Internal Page','claniz');
        }
        if($args['link_post']){
            $_link_type = array_merge($_link_type, etc_get_post_type_options());
        }
        $post_type_link_opts = [];

        $default = array_merge(
            array(
                array(
                    'name'      => $args['prefix'].'link_text',
                    'label'     => __( 'Link Text', 'claniz' ),
                    'type'      => \Elementor\Controls_Manager::TEXT,
                    'condition' => array_merge($args['condition']),
                    'dynamic'   => [
                        'active' => true,
                    ],
                    'default'    => $args['link_text']
                ),
                array(
                    'name'        => $args['prefix'].'link_type',
                    'label'       => esc_html__( 'Link Type', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'default'     => $args['link_type_default'],
                    'options'     => array_merge(
                        $_link_type, 
                        $args['options']
                    ),
                    'condition'   => array_merge(
                        $args['condition'],
                        [
                            $args['prefix'].'link_text!' => ''
                        ]
                    ),
                ),
                array(
                    'name'        => $args['prefix'].'link_page',
                    'label'       => esc_html__( 'Page Link', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'default'     => '',
                    'options'     => claniz_elementor_list_page_opts(),
                    'condition'   => array_merge(
                        $args['condition'], 
                        [$args['prefix'].'link_type' => 'page'], 
                        [$args['prefix'].'link_text!' => '']
                    ),
                ), 
                array(
                    'name'        => $args['prefix'].'hyper_link',
                    'label'       => esc_html__( 'Custom Link', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => esc_html__( 'https://your-link.com', 'claniz' ),
                    'default'     => [
                        'url'         => '#',
                        'is_external' => 'on'
                    ],
                    'condition'   => array_merge($args['condition'], [$args['prefix'].'link_type' => 'custom']),
                )
            ),
            clarora_elementor_link_to_post_opts([
                'prefix'    => $args['prefix'],
                'condition' => $args['prefix'].'link_type'
            ])
        );
        return wp_parse_args($args['options'], $default);
    }
}
if(!function_exists('claniz_elementor_custom_link_attrs____old')){
    function claniz_elementor_custom_link_attrs____old($settings=[], $args = []){
        $args = wp_parse_args($args, [
            'name'   => 'hyper_link',
            'prefix' => '',
            'class'  => '',
            'echo'   => false
        ]);
        if(empty($settings[$args['prefix'].$args['name']]['url'])) return;
        
        $settings[$args['prefix'].$args['name']]['custom_attributes'] =  empty($settings[$args['prefix'].$args['name']]['custom_attributes']) ? 'class|' : $settings[$args['prefix'].$args['name']]['custom_attributes'];

        $link_attrs = [];
        if ( ! empty( $settings[$args['prefix'].$args['name']]['url'] ) ) {
            $link_attrs[] = 'href="'.$settings[$args['prefix'].$args['name']]['url'].'"';
        }
        if ( ! empty($settings[$args['prefix'].$args['name']]['is_external'] )) {
            $link_attrs[] = 'target="_blank"';
        }
        if ( ! empty($settings[$args['prefix'].$args['name']]['nofollow'] )) {
            $link_attrs[] = 'rel="nofollow"';
        }
        if( ! empty($settings[$args['prefix'].$args['name']]['custom_attributes'])){
            $custom_attributes = explode(',', $settings[$args['prefix'].$args['name']]['custom_attributes']);
            foreach ($custom_attributes as $atts_value) {
                $_custom_attributes = explode('|', $atts_value);
                if($_custom_attributes[0] === 'class') $_custom_attributes[1] .= ' '.$args['class'];
                $link_attrs[] = $_custom_attributes[0].'="'.$_custom_attributes[1].'"';
            }
        }
        if($args['echo']){
            return trim(implode(' ', $link_attrs));
        } else {
            return $link_attrs;
        }
    }
}
if(!function_exists('claniz_elementor_custom_link_attrs')){
    function claniz_elementor_custom_link_attrs($settings=[], $args = []){
        $args = wp_parse_args($args, [
            'name'   => 'hyper_link',
            'prefix' => '',
            'class'  => '',
            'echo'   => false
        ]);
        $key = $settings[$args['prefix'].$args['name']];
        
        if(empty($key['url'])) return;

        if ( ! empty( $key['url'] ) ) {
            $attributes['href'] = esc_url( $key['url'] );
        }

        if ( ! empty( $key['is_external'] ) ) {
            $attributes['target'] = '_blank';
        }

        if ( ! empty( $key['nofollow'] ) ) {
            $attributes['rel'] = 'nofollow'; 
        }
        
        if ( ! empty( $key['custom_attributes'] ) ) {
            // Custom URL attributes should come as a string of comma-delimited key|value pairs
            $attributes = array_merge( $attributes, claniz_parse_custom_attributes( $key['custom_attributes'] ) );
        }
        $attributes = claniz_array_merge_recursive($attributes, ['class' => $args['class']]);
        if($args['echo']){
            return trim(implode(' ', $attributes ));
        } else {
            return $attributes;
        }
    }
}
if(!function_exists('claniz_elementor_page_link_attrs')){
    function claniz_elementor_page_link_attrs($settings=[], $args = []){
        $args = wp_parse_args($args, [
            'prefix'    => '',
            'class'     => '',
            'echo'      => false,
            'post_type' => 'page'
        ]);
        $page_link_attrs = [];
        $page_link_attrs[] = 'href="'.get_permalink($settings[$args['prefix'].'link_'.$args['post_type']]).'"';
        //$page_link_attrs[] = 'target="_blank"';
        $page_link_attrs[] = 'class="'.$args['class'].'"';
        if($args['echo']){
            return trim(implode(' ',$page_link_attrs));
        } else {
            return $page_link_attrs;
        }
    }
}

if(!function_exists('claniz_elementor_hyperlink_render')){
    function claniz_elementor_hyperlink_render($widget=[],$settings=[], $args = []){
        $args = wp_parse_args($args, [
            'prefix'           => '',
            'tag'              => 'div',
            'link_type'        => 'custom',
            'link_text'        => '', //esc_html__('Read More','claniz'),
            'link_color'       => '',
            'link_hover_color' => '',
            'wrap_class'       => '',    
            'class'            => '',
            'default_icon'     => [],
            'icon_color'       => '', 
            'icon_class'       => 'text-10',
            'icon_align'       => 'left', 
            'before'           => '',
            'after'            => '',
            'echo'             => true,
            'show_link_text'   => 'yes'
        ]);
        $link_text = !empty($settings[$args['prefix'].'link_text']) ? $settings[$args['prefix'].'link_text'] : $args['link_text'];
        if(empty($link_text) || $link_text === '-1') return;

        $show_link_text = !empty($settings[$args['prefix'].'show_link_text']) ?  $settings[$args['prefix'].'show_link_text'] : $args['show_link_text'];

        $link_attrs = '';
        $link_color = !empty($settings[$args['prefix'].'link_color']) ? $settings[$args['prefix'].'link_color'] : $args['link_color'];
        $link_hover_color = !empty($settings[$args['prefix'].'link_hover_color']) ? $settings[$args['prefix'].'link_hover_color'] : $args['link_hover_color'];
        $args['class'] = claniz_nice_class(['cms--link', 'd-inline-block', 'text-'.$link_color, 'text-hover-'.$link_hover_color, $args['class']]);

        if($settings[$args['prefix'].'link_type'] === 'custom'){
            $link_attrs = claniz_elementor_custom_link_attrs($settings, $args);
        } else {
            $link_attrs = claniz_elementor_page_link_attrs($settings, array_merge($args, ['post_type' => $settings[$args['prefix'].'link_type']]));
        }
        if(empty($link_attrs)) return;

        $settings[$args['prefix'].'link_icon_align'] = empty($settings[$args['prefix'].'link_icon_align']) ? $args['icon_align'] : $settings[$args['prefix'].'link_icon_align'];

        // icon class
        $link_icon_color = !empty($settings[$args['prefix'].'link_icon_color']) ? $settings[$args['prefix'].'link_icon_color'] : $args['icon_color'];
        $icon_class = ['cms-btn-icon', 'cms-link-icon', 'cms-align-icon-'.$settings[$args['prefix'].'link_icon_align'], $args['icon_class'], 'icon-outline-'.$settings[$args['prefix'].'link_icon_outline'], 'rtl-flip'];
        if($settings[$args['prefix'].'link_icon_align'] === 'left'){
            $icon_class[] = 'order-first';
        } else {
            $icon_class[] = 'order-last';
        }

        if(is_array($link_attrs) ) $link_attrs = implode(' ', $link_attrs);

        $wrap_class = claniz_elementor_align_class($settings, ['id' => $args['prefix'].'link_align']);
        ob_start();
        ?>
            <<?php printf('%s', $args['tag']);?> class="<?php echo claniz_nice_class(['cms-link', $args['prefix'], $wrap_class, $args['wrap_class']]);?>">
                <?php printf('%s', $args['before']); ?>
                <a <?php printf('%s', $link_attrs) ;?>>
                    <span class="cms-btn-content"><?php 
                        claniz_elementor_icon_render($widget,$settings, [
                            'id'           => $args['prefix'].'link_icon',
                            'loop'         => false,
                            'tag'          => 'span',   
                            'wrap_class'   => '',
                            'class'        => claniz_nice_class($icon_class),
                            'style'        => '',
                            'before'       => '',
                            'after'        => '',
                            'atts'         => [],
                            'color'        => $link_icon_color,
                            'color_hover'  => 'inherit',
                            'default_icon' => $args['default_icon']
                        ]);
                        if( $show_link_text === 'yes'){
                            printf('%s', '<span class="cms-btn-text">'.$link_text.'</span>');
                        }
                    ?></span>
                </a>
                <?php printf('%s', $args['after']); ?>
            </<?php printf('%s', $args['tag']);?>>
        <?php
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
if(!function_exists('claniz_elementor_hyperlink_render2')){
    function claniz_elementor_hyperlink_render2($widget=[], $settings=[], $args = []){
        $args = wp_parse_args($args, [
            'prefix'           => '',
            'tag'              => 'div',
            'link_type'        => 'custom',
            'link_text'        => '', //esc_html__('Read More','claniz'),
            'wrap_class'       => '',    
            'class'            => '',
            'text_class'       => '', 
            'before'           => '',
            'after'            => '',
            'echo'             => true
        ]);
        $link_text = $args['link_text'];
        if(empty($link_text)) return;
        $link_attrs = '';
        if($settings[$args['prefix'].'link_type'] === 'custom'){
            $link_attrs = claniz_elementor_custom_link_attrs($settings, $args);
        } else {
            $link_attrs = claniz_elementor_page_link_attrs($settings, array_merge($args, ['post_type' => $settings[$args['prefix'].'link_type']]));
        }
        if(empty($link_attrs)) return;
        if(is_array($link_attrs) ) $link_attrs = implode(' ', $link_attrs);

        ob_start();
        ?>
            <<?php printf('%s', $args['tag']);?> class="<?php echo claniz_nice_class(['cms-link', $args['wrap_class']]);?>">
                <a <?php printf('%s', $link_attrs) ;?>><?php 
                    printf('%s', $args['before']); 
                    printf('%s', '<span class="'.claniz_nice_class(['cms-link-text', $args['text_class']]).'">'.$link_text.'</span>');
                    printf('%s', $args['after']); 
                ?></a>
            </<?php printf('%s', $args['tag']);?>>
        <?php
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
if(!function_exists('claniz_elementor_hyperlink_render_url_open')){
    function claniz_elementor_hyperlink_render_url_open($widget=[],$settings=[], $args = []){
        $args = wp_parse_args($args, [
            'prefix'           => '',
            'link_type'        => 'custom',
            'class'            => '',
            'before'           => '',
            'after'            => '',
            'echo'             => true
        ]);
        $link_attrs = '';
        $args['class'] = claniz_nice_class([$args['class']]);
        if($settings[$args['prefix'].'link_type'] === 'custom'){
            $link_attrs = claniz_elementor_custom_link_attrs($settings, $args);
        } else {
            $link_attrs = claniz_elementor_page_link_attrs($settings, array_merge($args, ['post_type' => $settings[$args['prefix'].'link_type']]));
        }
        if(empty($link_attrs)) return;
        if(is_array($link_attrs) ) $link_attrs = implode(' ', $link_attrs);
        ob_start();
        ?>
           <a <?php printf('%s', $link_attrs) ;?>>
        <?php if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
if(!function_exists('claniz_elementor_hyperlink_render_url_close')){
    function claniz_elementor_hyperlink_render_url_close($widget=[],$settings=[], $args=[]){
        $args = wp_parse_args($args, [
            'prefix'    => '',
            'link_type' => 'custom',
            'echo'      => true
        ]);
        $link_attrs = '';
        if($settings[$args['prefix'].'link_type'] === 'custom'){
            $link_attrs = claniz_elementor_custom_link_attrs($settings, $args);
        } else {
            $link_attrs = claniz_elementor_page_link_attrs($settings, array_merge($args, ['post_type' => $settings[$args['prefix'].'link_type']]));
        }
        if(empty($link_attrs)) return;

        ob_start();
        ?>
           </a>
        <?php if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}

/**
 * Buttons Settings
**/
if(!function_exists('claniz_elementor_button_settings')){
    function claniz_elementor_button_settings($args = []){
        $args = wp_parse_args($args, [
            'options'               => [],
            'condition'             => [],
            'prefix'                => '',
            'btn_text'              => '',
            'btn_type'              => [],
            'btn_type_default'      => 'btn btn-fill',
            'btn_link_type'         => [],
            'btn_link_type_default' => 'custom',
            'btn_color'             => 'accent',
            'btn_hover_color'       => 'primary',
            'btn_size'              => '',
            'btn_align'             => '',
            'icon_default'          => [
                'value'             => 'cmsi-arrow-circle-right',
                'library'           => 'cmsi'
            ],
            'icon_align'            => 'left',
            'separator'             => '',
            'effect'                => true
        ]);
        $default = array_merge(
            array(
                array(
                    'name'        => $args['prefix'].'btn_text',
                    'label'       => __( 'Button Text', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'default'     => $args['btn_text'],
                    'placeholder' => __('Your Text', 'claniz'),
                    'condition'   => $args['condition'],
                    'separator'   => $args['separator']
                ),
                array(
                    'name'        => $args['prefix'].'show_btn_text',
                    'label'       => __( 'Show Button Text', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SWITCHER,
                    'default'     => 'true',
                    'condition'   => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition']),
                ),
                array(
                    'name'        => $args['prefix'].'btn_link_type',
                    'label'       => __( 'Link Type', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'default'     => $args['btn_link_type_default'],
                    'options'     => array_merge(
                        [
                            'custom'   => __('Custom','claniz'),
                            'page'     => __('Internal Page','claniz'),
                        ],
                        etc_get_post_type_options(),
                        $args[ 'btn_link_type']
                    ),
                    'condition' => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition']),
                ),
                array(
                    'name'        => $args['prefix'].'link_page',
                    'label'       => __( 'Page Link', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'default'     => '',
                    'options'     => claniz_elementor_list_page_opts(),
                    'condition'   => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition'], [$args['prefix'].'btn_link_type' => 'page'])
                ),
                array(
                    'name'        => $args['prefix'].'btn_link',
                    'label'       => __( 'Custom Link', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::URL,
                    'placeholder' => __( 'https://your-link.com', 'claniz' ),
                    'default'     => [
                        'url' => '#',
                    ],
                    'condition' => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition'], [$args['prefix'].'btn_link_type' => 'custom'])
                )
            ),
            clarora_elementor_link_to_post_opts([
                'prefix'           => $args['prefix'],
                'condition'        => $args['prefix'].'btn_link_type',
                'custom_condition' => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition'])
            ]),
            array(
                array(
                    'name'        => $args['prefix'].'btn_type',
                    'label'       => __( 'Mode', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'default'     => $args['btn_type_default'],
                    'options'     => array_merge(
                        [
                            'btn btn-fill'    => esc_html__('Fill','claniz'),
                            'btn btn-outline' => esc_html__('Outline','claniz')
                        ],
                        $args['btn_type']
                    ),
                    'condition' => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition'])
                ),
                array(
                    'name'        => $args['prefix'].'btn_style',
                    'label'       => __( 'Style', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'default'     => 'btn-style-3',
                    'options'     => [
                        'btn-style-1'    => __('Style 1','claniz'),
                        'btn-style-2'    => __('Style 2','claniz'),
                        'btn-style-3'    => __('Style 3','claniz'),
                        'btn-style-4'    => __('Style 4','claniz')
                    ],
                    'condition' => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition'])
                ),
                array(
                    'name'        => $args['prefix'].'btn_color',
                    'label'       => __( 'Color', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'default'     => $args['btn_color'],
                    'options'     => claniz_elementor_theme_color_opts(['custom' =>  false]),
                    'condition'   => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition'])
                ),
                array(
                    'name'        => $args['prefix'].'btn_hover_color',
                    'label'       => __( 'Hover Color', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'default'     => $args['btn_hover_color'],
                    'options'     => claniz_elementor_theme_color_opts(['custom' =>  false]),
                    'condition'   => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition']),
                ),
                array(
                    'name'        => $args['prefix'].'btn_size',
                    'label'       => __( 'Size', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SELECT,
                    'default'     => $args['btn_size'],
                    'options'     => [
                        'xs'  => __('Extra Small','claniz'),  
                        'sm'  => __('Small','claniz'),  
                        ''    => __('Default','claniz'),
                        'md'  => __('Medium','claniz'),
                        'mdl' => __('Medium Large','claniz'),
                        'lg'  => __('Large','claniz'),
                        'xl'  => __('Extra Large','claniz'),
                    ],
                    'condition' => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition'],[$args['prefix'].'btn_type!' => ['btn-overlay', 'btn-text', 'just-link']]), 
                ),
                array(
                    'name'         => $args['prefix'].'align',
                    'label'        => __( 'Button Alignment', 'claniz' ),
                    'type'         => \Elementor\Controls_Manager::CHOOSE,
                    'control_type' => 'responsive',
                    'options'      => claniz_text_align_opts(),
                    'default'      => $args['btn_align'],
                    'condition'    => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition'])
                ),
                array(
                    'name'             => $args['prefix'].'btn_icon',
                    'label'            => __( 'Icon', 'claniz' ),
                    'type'             => \Elementor\Controls_Manager::ICONS,
                    'label_block'      => true,
                    'fa4compatibility' => 'icon',
                    'condition'        => array_merge([$args['prefix'].'btn_text!' => ''], $args['condition']),
                    'default'          => $args['icon_default']
                ),
                array(
                    'name'        => $args['prefix'].'show_btn_icon',
                    'label'       => __( 'Show Button Icon', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::SWITCHER,
                    'default'     => 'true',
                    'condition' =>  array_merge([
                            $args['prefix'].'btn_text!' => '',
                            $args['prefix'].'btn_icon[value]!' => ''
                        ],
                        $args['condition']
                    ),
                ),
                array(
                    'name'    => $args['prefix'].'icon_outline',
                    'label'   => __( 'Icon Outline', 'claniz' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'default' => 'no',
                    'options' => [
                        'yes'  => __( 'Yes', 'claniz' ),
                        'no'  => __( 'No', 'claniz' ),
                    ],
                    'condition' =>  array_merge([
                            $args['prefix'].'btn_text!'        => '',
                            $args['prefix'].'btn_icon[value]!' => ''
                        ],
                        $args['condition']
                    ),
                ),
                array(
                    'name'    => $args['prefix'].'icon_align',
                    'label'   => __( 'Icon Position', 'claniz' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'default' => $args['icon_align'],
                    'options' => [
                        'left'  => __( 'Before', 'claniz' ),
                        'right' => __( 'After', 'claniz' ),
                    ],
                    'condition' => array_merge([
                            $args['prefix'].'btn_text!'        => '',
                            $args['prefix'].'btn_icon[value]!' => '',
                            $args['prefix'].'show_btn_icon'    => 'true'
                        ],
                        $args['condition']
                    )
                ),
                array(
                    'name'  => $args['prefix'].'btn_icon_size',
                    'label' => __( 'Icon Size', 'claniz' ),
                    'type'  => \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 200,
                        ],
                    ],
                    'condition' => array_merge([
                            $args['prefix'].'btn_text!'        => '',
                            $args['prefix'].'btn_icon[value]!' => '',
                            $args['prefix'].'show_btn_icon'    => 'true'
                        ],
                        $args['condition']
                    ),
                    'selectors' => [
                        '{{WRAPPER}} .cms-btn-content-'.$args['prefix'].' .cms-btn-icon' => 'font-size: {{SIZE}}{{UNIT}};'
                    ]
                ),
                array(
                    'name'  => $args['prefix'].'icon_indent',
                    'label' => __( 'Icon Spacing', 'claniz' ),
                    'type'  => \Elementor\Controls_Manager::SLIDER,
                    'control_type' => 'responsive',
                    'range' => [
                        'px' => [
                            'min' => 5,
                            'max' => 200,
                        ],
                    ],
                    'condition' => array_merge([
                            $args['prefix'].'btn_text!'        => '',
                            $args['prefix'].'btn_icon[value]!' => '',
                            $args['prefix'].'show_btn_icon'    => 'true'
                        ],
                        $args['condition']
                    ),
                    'selectors' => [
                        '{{WRAPPER}} .cms-btn-content-'.$args['prefix'].' .cms-btn-icon.cms-align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
                        '{{WRAPPER}} .cms-btn-content-'.$args['prefix'].' .cms-btn-icon.cms-align-icon-left' => 'margin-right: {{SIZE}}{{UNIT}};',
                    ]
                ),
                array(
                    'name'        => $args['prefix'].'btn_css_class',
                    'label'       => __( 'Custom CSS Class', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::TEXT,
                    'condition' => array_merge([
                            $args['prefix'].'btn_text!' => ''
                        ],
                        $args['condition']
                    )
                )
            )
        );
        $effect = [];
        if($args['effect']){
            $effect = [
                array(
                    'name'      => $args['prefix'].'btn_animation',
                    'label'     => esc_html__( 'Button Motion Effect', 'claniz' ),
                    'type'      => \Elementor\Controls_Manager::ANIMATION,
                    'condition' => [
                        $args['prefix'].'btn_text!' => ''
                    ]
                ),
                array(
                    'name'    => $args['prefix'].'btn_animation_duration', 
                    'label'   => __( 'Animation Duration', 'claniz' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'default' => 'normal',
                    'options' => [
                        'slow'   => __( 'Slow', 'claniz' ),
                        'normal' => __( 'Normal', 'claniz' ),
                        'fast'   => __( 'Fast', 'claniz' ),
                    ],
                    'condition' => [
                        $args['prefix'].'btn_animation!' => '',
                    ]
                ),
                array(
                    'name'      => $args['prefix'].'btn_animation_delay',
                    'label'     => esc_html__( 'Animation Delay', 'claniz' ),
                    'type'      => \Elementor\Controls_Manager::NUMBER,
                    'min'       => 0,
                    'step'      => 100,
                    'default'   => 300,
                    'condition' => [
                        $args['prefix'].'btn_animation!' => ''
                    ]
                )
            ];
        }
        $default = wp_parse_args($args['options'], $default);
        return array_merge($default, $effect);
    }
}
// Button Render
if(!function_exists('claniz_elementor_button_render')){
    function claniz_elementor_button_render($widget=[], $settings=[], $args = []){
        $args = wp_parse_args($args, [
            'post_id'           => '',
            'tag'               => 'div',
            'overwrite'         => false,
            'prefix'            => '',
            'wrap'              => true,
            'class'             => '',
            'btn_class'         => '',
            'btn_content_class' => '',
            'icon_before'       => '',
            'icon_after'        => '',
            'icon_class'        => '',
            'icon_color'        => '',
            'custom_link'       => '',
            'default'     => [
                'btn_text' => '',
                'btn_type' => '',
                'btn_size' => '',
                'btn_icon' => []
            ],
            'align'        => '',
            'attrs'        => ''  
        ]);
        $btn_text =  !empty($settings[$args['prefix'].'btn_text']) ? $settings[$args['prefix'].'btn_text'] : $args['default']['btn_text']; 
        if(empty($btn_text)) return;

        $button_attrs = [];
        $button_class = [$settings[$args['prefix'].'btn_type'], $settings[$args['prefix'].'btn_style']];

        if(empty($settings[$args['prefix'].'btn_type'])) $settings[$args['prefix'].'btn_type'] = $args['default']['btn_type'];
        if( !in_array($settings[$args['prefix'].'btn_type'], ['just-link','btn-overlay']) ){
            if ( ! empty( $settings[$args['prefix'].'btn_color'] ) ) {
                $button_class[] = 'btn-' . $settings[$args['prefix'].'btn_color'];
            }
            if ( ! empty( $settings[$args['prefix'].'btn_hover_color'] ) ) {
                $button_class[] = 'btn-hover-' . $settings[$args['prefix'].'btn_hover_color'];
            }
            if ( ! empty( $settings[$args['prefix'].'btn_size'] ) ) {
                $button_class[] = 'btn-' . $settings[$args['prefix'].'btn_size'];
            }
        } else {
            if ( ! empty( $settings[$args['prefix'].'btn_color'] ) ) {
                $button_class[] = 'text-' . $settings[$args['prefix'].'btn_color'];
            }
            if ( ! empty( $settings[$args['prefix'].'btn_hover_color'] ) ) {
                $button_class[] = 'text-hover-' . $settings[$args['prefix'].'btn_hover_color'];
            }
            $button_class[] = 'btn-' . $widget->get_setting($args['prefix'].'btn_size', $args['default']['btn_size']);
        }
        //$button_class[] = 'text-'.$settings[$args['prefix'].'align'];
        $btn_align = isset( $settings[$args['prefix'].'align'] ) ? $settings[$args['prefix'].'align'] : '';
        $btn_align_tablet = isset($settings[$args['prefix'].'align_tablet']) ? $settings[$args['prefix'].'align_tablet'] : '';
        $btn_align_mobile = isset($settings[$args['prefix'].'align_mobile']) ? $settings[$args['prefix'].'align_mobile'] : '';

        if( !empty($btn_align_mobile) && $btn_align_mobile === 'justify' ){
            $button_class[] = 'd-sm-block';
        }
        if( !empty($btn_align_tablet) && $btn_align_tablet === 'justify' ){
            $button_class[] = 'd-md-block';
        }
        if( !empty($btn_align) && $btn_align === 'justify' && ( $btn_align_mobile !== 'justify' && $btn_align_tablet !== 'justify' ) ) {
            $button_class[] = 'd-block';
        } elseif( !empty($btn_align) && $btn_align === 'justify'){
            $button_class[] = 'd-lg-block';
        }

        $button_class[] = $args['btn_class'];
        if(empty($settings[$args['prefix'].'btn_icon']['value']) || $settings[$args['prefix'].'show_btn_icon'] !== 'true' ) {
            $button_class[] = 'btn-no-icon';
        }
        $button_class[] = $settings[$args['prefix'].'btn_css_class'];
        
        // Button Animation
        if(isset($settings[$args['prefix'].'btn_animation']) && $settings[$args['prefix'].'btn_animation'] !== ''){
            $button_class[] = 'cms-animate elementor-invisible';
        }
        // Button attrs
        if($settings[$args['prefix'].'btn_link_type'] === 'custom'){
            $button_attrs = (array) claniz_elementor_custom_link_attrs($settings,[
                'name'   => 'btn_link',
                'prefix' => $args['prefix'],
                'class'  => claniz_nice_class(implode(' ', $button_class)),
                'echo'   => true
            ]);
        } else {
            $button_attrs = claniz_elementor_page_link_attrs($settings, array_merge($args, [
                'post_type' => $settings[$args['prefix'].'btn_link_type'],
                'class'     => claniz_nice_class(implode(' ', $button_class))
            ]));
        }
        // Button Animation
        if(isset($settings[$args['prefix'].'btn_animation']) && $settings[$args['prefix'].'btn_animation'] !== ''){
            $button_attrs[] = 'data-settings=\''.json_encode([
                '_animation'      => $settings[$args['prefix'].'btn_animation'],
                'animation'       => $settings[$args['prefix'].'btn_animation'],
                'animation_delay' => $settings[$args['prefix'].'btn_animation_delay']
            ]).'\'';
        }
        // custom attributes
        $button_attrs[] = $args['attrs'];
        // button content class 
        $btn_content_class = [
            'cms-btn-content',
            'cms-btn-content-'.$args['prefix'],
            $args['btn_content_class']
        ];
        // button icon class 
        $btn_icon_class = [
            'cms-btn-icon',
            'cms-align-icon-'.$settings[$args['prefix'].'icon_align'],
            $args['icon_class'],
            'icon-outline-'.$settings[$args['prefix'].'icon_outline'],
            'rtl-flip'
        ];
        if($settings[$args['prefix'].'btn_icon']['value'] === 'cmsi-arrow-circle-right'){
            $btn_icon_class[] = 'text-26';
        }
        if($args['wrap'] == true):
    ?>
        <<?php echo esc_html($args['tag']);?> class="cms-btn-wraps <?php echo esc_attr($args['class'].' '.claniz_elementor_align_class($settings, [ 'id' => $args['prefix'].'align', 'default' => $args['align'] ] ) );?>" <?php echo esc_attr($args['attrs']);?>>
    <?php endif; ?>
            <a <?php echo trim(implode(' ', $button_attrs)); ?>>
                <span class="<?php echo claniz_nice_class($btn_content_class);?>">
                    <?php if(!empty($settings[$args['prefix'].'btn_icon']['value']) && $settings[$args['prefix'].'show_btn_icon'] === 'true' ) : ?>
                        <?php 
                            claniz_elementor_icon_render($widget,$settings, [
                                'id'           => $args['prefix'].'btn_icon',
                                'loop'         => false,
                                'tag'          => 'span',   
                                'wrap_class'   => '',
                                'class'        => claniz_nice_class($btn_icon_class),
                                'style'        => '',
                                'before'       => '',
                                'after'        => '',
                                'atts'         => [],
                                'default_icon' => '',
                                'color'        => $args['icon_color']     
                            ]);
                        ?>
                    <?php endif; 
                    if($settings[$args['prefix'].'show_btn_text'] === 'true' || $settings[$args['prefix'].'show_btn_text'] === NULL) {
                    ?>
                    <span class="cms-btn-text"><?php printf('%s', $btn_text); ?></span>
                    <?php } ?>
                </span>
            </a>
        <?php if($args['wrap'] == true): ?>
        </<?php echo esc_html($args['tag']);?>>
    <?php
        endif;
    }
}
// Image Settings
if(!function_exists('claniz_elementor_image_settings')){
    function claniz_elementor_image_settings($args =[]){
        $args = wp_parse_args($args, [
            'name'         => 'image',
            'label'        => __('Select Image','claniz'),
            'default_size' => 'large',
            'condition'    => '' 
        ]);
        return array(
            array(
                'name'        => $args['name'],
                'label'       => $args['label'],
                'type'        => \Elementor\Controls_Manager::MEDIA,
                'label_block' => true,
                'condition'   => $args['condition']
            ),
            array(
                'name'         => $args['name'],// Usage: `{$args['name']}_size` and `{$args['name']}_custom_dimension`, in this case `$args['name']_size` and `$args['name']_custom_dimension`.
                'type'         => \Elementor\Group_Control_Image_Size::get_type(),
                'control_type' => 'group',
                'default'      => $args['default_size'],
                'condition'   => [
                    $args['name'].'[id]!' => ''
                ]
            )
        );
    }
}
// Image Render 
if(!function_exists('claniz_elementor_image_render')){
    function claniz_elementor_image_render($settings=[], $widget=[], $args = [], $data = []){
        $args = wp_parse_args($args, [
            'id'            => 'selected_img',
            'attachment_id' => '',
            'size'          => '',
            'class'         => '',
            'img_class'     => '',
            'before'        => '',
            'after'         => '',
            'echo'          => true,
            'custom_size'   => 'full',
            'default'       => false,
            'as_background' => false,
            'as_background_class' => ''
        ]);
        if(empty($args['size'])) $args['size'] = $args['id'];
        
        $settings[$args['size'].'_size'] = isset($settings[$args['size'].'_size']) ? $settings[$args['size'].'_size'] : 'custom';
        $settings[$args['size'].'_custom_dimension'] = isset($settings[$args['size'].'_custom_dimension']) ? $settings[$args['size'].'_custom_dimension'] : [];
        if(!empty($data)){
            if(!isset($data[$args['size'].'_size'])) $data[$args['size'].'_size'] = $settings[$args['size'].'_size'];
            if(!isset($data[$args['size'].'_custom_dimension'])) $data[$args['size'].'_custom_dimension'] = $settings[$args['size'].'_custom_dimension'];
            $data['custom_size'] = $args['custom_size'];
            
            $settings = !empty($data) ? $data : $settings;
        }
        if ( $args['default'] === false && ( empty( $settings[$args['id']]['url'] ) && empty($args['attachment_id']) ) ) return;
        //if ( $args['default'] === false  ) return;
        $image_attr = [
            'class' => $args['class']
        ];
        $size = isset($settings[$args['size'].'_size']) ? $settings[$args['size'].'_size'] : 'custom'; //$args['custom_size'];
        if($size === 'cms_none') return;

        $custom_size = [];
        if($size === 'custom'){
            $default_custom_size = explode('x', $args['custom_size']);
            if(isset($settings[$args['size'].'_custom_dimension']['width']) && !empty($settings[$args['size'].'_custom_dimension']['width']) ){
                $custom_size[] = $settings[$args['size'].'_custom_dimension']['width'];
            } else {
                $custom_size[] = $default_custom_size[0];
            }
            if(isset($settings[$args['size'].'_custom_dimension']['height']) && !empty($settings[$args['size'].'_custom_dimension']['height']) ){
                $custom_size[] = $settings[$args['size'].'_custom_dimension']['height'];
            } else {
                $custom_size[] = isset($default_custom_size[1]) ? $default_custom_size[1] : $default_custom_size[0];
            }
            $size = implode('x', $custom_size);
        }

        $img_id = !empty($settings[$args['id']]['id']) ? $settings[$args['id']]['id'] : $args['attachment_id'];
        $img_url = !empty($settings[$args['id']]['url']) ? $settings[$args['id']]['url'] : wp_get_attachment_url($args['attachment_id']);
        if($img_url === false){
            // fix for default image
            $img_url = \Elementor\Utils::get_placeholder_image_src();
        }

        $background_image_open = $background_image_close = '';
        if($args['as_background']){
            $background_image_open = '<div class="'.implode(' ',['cms-image-as-bg', $args['as_background_class']]).'" style="background-image: url('.$img_url.')">';
            $background_image_close = '</div>';
        }
        ob_start();
            printf('%s', $args['before']);
                printf('%s', $background_image_open);
                    claniz_image_by_size([
                        'id'         => $img_id, 
                        'size'       => $size, 
                        'class'      => $args['img_class'], 
                        'echo'       => $args['echo'] , 
                        'default'    => $args['default'],
                        'no_image'   => isset($settings[$args['id']]['url']) ? $settings[$args['id']]['url'] : '',
                        'before'     => '',
                        'after'      => '',
                        'show_image' => true
                    ]);
                printf('%s', $background_image_close);
            printf('%s', $args['after']);
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
// Loop Image Render 
if(!function_exists('claniz_elementor_loop_image_render')){
    function claniz_elementor_loop_image_render($settings=[], $widget=[], $args = [], $data = []){
        $args = wp_parse_args($args, [
            'id'            => 'selected_img',
            'attachment_id' => '',
            'size'          => 'thumbnail_size',
            'class'         => '',
            'img_class'     => '',
            'before'        => '',
            'after'         => '',
            'echo'          => true
        ]);
        if(!isset($data[$args['size'].'_size'])) $data[$args['size'].'_size'] = $settings[$args['size'].'_size'];
        if(!isset($data[$args['size'].'_custom_dimension'])) $data[$args['size'].'_custom_dimension'] = $settings[$args['size'].'_custom_dimension'];
        $settings = !empty($data) ? $data : $settings;
        $image_attr = [
            'class' => $args['class']
        ];
        if(!empty($args['attachment_id'])) {
            $image_url = \Elementor\Group_Control_Image_Size::get_attachment_image_src( $args['attachment_id'], $args['size'], $settings );
            $img_alt = trim( strip_tags(get_post_meta( $args['attachment_id'], '_wp_attachment_image_alt', true )));
            $image_html = '<img src="' . esc_attr( $image_url ) . '" alt="' . esc_attr( $img_alt) . '" class="'.esc_attr($args['img_class']).'" />';
        } else {
            $image_html = \Elementor\Group_Control_Image_Size::get_attachment_image_html( $settings, $args['size'], $args['id']);
        }
        ob_start();
            printf('%1$s%2$s%3$s', $args['before'], $image_html, $args['after']);
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
// Image URL Render 
if(!function_exists('claniz_elementor_image_url_render')){
    function claniz_elementor_image_url_render($settings=[], $args = []){
        $args = wp_parse_args($args, [
            'id'            => 'selected_img',
            'size'          => 'thumbnail_size',
            'custom_size'   => '',
            'default_thumb' => false,
            'default_img'   => ''  
        ]); 
        if(empty($settings[$args['id']]) && empty($args['url'])) return;
        if(empty($args['custom_size'])){
            $thumbnail_size_custom = isset($settings[$args['size'].'_custom_dimension']) ? $settings[$args['size'].'_custom_dimension'] : ['width' => '', 'height' => ''];
            if(isset($settings[$args['size'].'_size']) && $settings[$args['size'].'_size'] != 'custom'){
                $img_size = $settings[$args['size'].'_size'];
            }
            elseif(!empty($thumbnail_size_custom['width']) && !empty($thumbnail_size_custom['height'])){
                $img_size = $thumbnail_size_custom['width'] . 'x' . $thumbnail_size_custom['height'];
            }
            else{
                $img_size = 'full';
            }
        } else {
            $img_size = $args['custom_size'];
        }

        return claniz_get_image_url_by_size([
            'id'          => $settings[$args['id']]['id'],
            'size'        => $img_size,
            'default_img' => $args['default_img'],
            'default_thumb' => $args['default_thumb']  
        ]);
    }
}
// Setting Icon
if(!function_exists('claniz_elementor_icon_settings')){
    function claniz_elementor_icon_settings($args = []){
        $args = wp_parse_args($args, [
            'prefix'       => '', 
            'name'         => 'selected_icon',
            'label'        => __('Icon', 'claniz'),
            'default_icon' => [
                'value'   => '',
                'library' => ''
            ],
            'selector' => ''
        ]);
        return array_merge(
            array(
                array(
                    'name'    => $args['prefix'].$args['name'],
                    'label'   => $args['label'],
                    'type'    => \Elementor\Controls_Manager::ICONS,
                    'default' => $args['default_icon'],
                )
            ),
            claniz_elementor_theme_colors([
                'name'                => $args['prefix'].$args['name'].'_color',
                'label'               => esc_html__('Main Color', 'claniz'),
                'custom'              => true,
                'custom_label'        => esc_html__('Custom Main Color', 'claniz'),
                'custom_selector'     => $args['selector'],
                'custom_selector_tag' => 'color',
            ]),
            claniz_elementor_theme_colors([
                'name'                => $args['prefix'].$args['name'].'_hover_color',
                'label'               => esc_html__('Hover Color', 'claniz'),
                'custom'              => true,
                'custom_label'        => esc_html__('Custom Hover Color', 'claniz'),
                'custom_selector'     => $args['selector'].':hover',
                'custom_selector_tag' => 'color',
            ]),
            array(
                array(
                    'name'  => $args['prefix'].$args['name'].'_size',
                    'label' => esc_html__( 'Icon Size', 'claniz' ),
                    'type'  => \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => 15,
                            'max' => 200,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} '.$args['selector'] => 'font-size: {{SIZE}}{{UNIT}};'
                    ]
                ),
                array(
                    'name'  => $args['prefix'].$args['name'].'_spacing',
                    'label' => esc_html__( 'Icon Spacing', 'claniz' ),
                    'type'  => \Elementor\Controls_Manager::SLIDER,
                    'range' => [
                        'px' => [
                            'min' => 5,
                            'max' => 200,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} '.$args['selector'] => 'margin-right: {{SIZE}}{{UNIT}};',
                    ]
                )
            )
        );
    }
}
// Render icon 
if(!function_exists('claniz_elementor_icon_render')){
    function claniz_elementor_icon_render( $widget=[], $settings=[], $args = [], $data=[]){
        $args = wp_parse_args($args, [
            'prefix'     => '',   
            'id'         => 'selected_icon',
            'loop'       => false,
            'tag'        => 'div',
            'color'      => 'accent',
            'color_hover'=> '',
            'wrap_class' => '',
            'class'      => '',
            'style'      => '',
            'before'     => '',
            'after'      => '',
            'atts'       => [],
            'default_icon'    => [
                'value'   => '',
                'library' => ''
            ],
            'echo' => true
        ]);
        if($args['loop']) {
            $icon = $args['id'];
            $settings = $data;
        } else {
            if(!isset($settings[$args['id']])) return;
            $icon = $settings[$args['id']];
        }
        if(empty($icon['value'])) $icon = $args['default_icon'];
        if(empty($icon['value'])) return;
        $classes = [
            'cms-icon',
            $args['class'],
            $args['wrap_class']
        ];
        if($args['color']!='none'){ 
            $icon_color = $widget->get_setting($args['prefix'].$args['id'].'_color', $args['color']);
            $icon_color_hover = $widget->get_setting($args['prefix'].$args['id'].'_hover_color', $args['color_hover']);
            if(!empty($icon_color)) $classes[] = 'text-'.$icon_color;
            if(!empty($icon_color_hover)) $classes[] = 'text-hover-'.$icon_color_hover;
        }
        
        ob_start();
        printf('%s', $args['before']);
        ?>
        <?php \Elementor\Icons_Manager::render_icon( $icon, array_merge(
                [ 
                    'aria-hidden' => 'true', 
                    'class'       => trim(implode(' ', $classes)),
                    'style'       => $args['style']  
                ],
                $args['atts']
            ), $args['tag']); ?>
        <?php
        printf('%s', $args['after']);
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}

// Render link options
if(!function_exists('claniz_elementor_link_render')){
    function claniz_elementor_link_render($key, $args =[]){
        $attributes = $atts = [];
        if ( ! empty( $key['url'] ) ) {
            $attributes['href'] = esc_url( $key['url'] );
        }

        if ( ! empty( $key['is_external'] ) ) {
            $attributes['target'] = '_blank';
        }

        if ( ! empty( $key['nofollow'] ) ) {
            $attributes['rel'] = 'nofollow';
        }
        
        if ( ! empty( $key['custom_attributes'] ) ) {
            // Custom URL attributes should come as a string of comma-delimited key|value pairs
            $attributes = array_merge( $attributes, claniz_parse_custom_attributes( $key['custom_attributes'] ) );
        }

        $attributes = claniz_array_merge_recursive($attributes, $args);
        
        echo trim(implode(' ', $attributes));
    }
}

// Get Excerpt
if(!function_exists('claniz_elementor_excerpt')){
    function claniz_elementor_excerpt($post, $num_words, $more ){
        if(!empty($post->post_excerpt)){
            echo wp_trim_words( $post->post_excerpt, $num_words, $more = null );
        } else {
            $content = strip_shortcodes( $post->post_content );
            $content = apply_filters( 'the_content', $content );
            $content = str_replace(']]>', ']]&gt;', $content);
            echo wp_trim_words( $content, $num_words, '' );
        }
    }
}
// Custom Attributes 
if(!function_exists('claniz_parse_custom_attributes')){
    function claniz_parse_custom_attributes( $attributes_string, $delimiter = ',' ) {
        $attributes = explode( $delimiter, $attributes_string );
        $result = [];

        foreach ( $attributes as $attribute ) {
            $attr_key_value = explode( '|', $attribute );

            $attr_key = mb_strtolower( $attr_key_value[0] );

            // Remove any not allowed characters.
            preg_match( '/[-_a-z0-9]+/', $attr_key, $attr_key_matches );

            if ( empty( $attr_key_matches[0] ) ) {
                continue;
            }

            $attr_key = $attr_key_matches[0];

            // Avoid Javascript events and unescaped href.
            if ( 'href' === $attr_key || 'on' === substr( $attr_key, 0, 2 ) ) {
                continue;
            }

            if ( isset( $attr_key_value[1] ) ) {
                $attr_value = trim( $attr_key_value[1] );
            } else {
                $attr_value = '';
            }

            $result[ $attr_key ] = $attr_value;
        }

        return $result;
    }
}
// Badge
if(!function_exists('claniz_elementor_badge_render')){
    function claniz_elementor_badge_render($settings, $args = []){
        $args = wp_parse_args($args, [
            'show_badge' => 'show_badge',
            'badge_text' => 'badge_text',
            'class'      => '',
            'style'      => '1',
            'before'     => '',
            'after'      => ''        
        ]);
        if($settings[$args['show_badge']] === 'true'){
            printf('%s', $args['before']);
            ?>
            <div class="cms-badge cms-badge-<?php echo esc_attr($args['style']);?> <?php echo esc_attr($args['class']);?>">
                <div class="cms-badge-text empty-none"><?php if(!empty($settings[$args['badge_text']])) echo esc_html($settings[$args['badge_text']]); ?></div>
            </div>
        <?php
            printf('%s', $args['after']);
        }
    }
}

// Newsletter Extension
if(!function_exists('claniz_element_newsletter_form_list')){
    function claniz_element_newsletter_form_list(){
        if(class_exists('Newsletter')) {
            $forms = array_filter( (array) get_option( 'newsletter_forms', array() ) );

            $newsletter_forms = array(
                'default' => esc_html__( 'Default Form', 'claniz' )
            );

            if ( $forms )
            {
                $index = 1;
                foreach ( $forms as $key => $form )
                {
                    $newsletter_forms[$key] = sprintf( esc_html__( 'Form %s', 'claniz' ), $index );
                    $index ++;
                }
            }
        } else {
            $newsletter_forms = [];
        }
    }
}
// Button Video Settings
if(!function_exists('claniz_elementor_button_video_settings')){
    function claniz_elementor_button_video_settings ($args = []){
        $args = wp_parse_args($args, [
            'prefix'    => '',
            'separator' => '',
            'effect'    => false,
            'default'   => true
        ]);
        $url = '';
        if($args['default']) $url = 'https://www.youtube.com/watch?v=SF4aHwxHtZ0';
        $default = array(
            array(
                'name'        => $args['prefix'].'video_link',
                'label'       => __( 'Video URL', 'claniz' ),
                'type'        => \Elementor\Controls_Manager::URL,
                'default'     => [
                    'url'         => $url,
                    'is_external' => 'on'
                ],
                'separator' => $args['separator'],
                'description' => 'https://www.youtube.com/watch?v=SF4aHwxHtZ0'
            ),
            array(
                'name'        =>  $args['prefix'].'video_play_color',
                'label'       => __( 'Play Background Color', 'claniz' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
                'options'     => claniz_elementor_theme_color_opts(['custom' =>  false]),
                'default'     => 'accent'  
            ),
            array(
                'name'        =>  $args['prefix'].'video_play_color_hover',
                'label'       => __( 'Play Background Color Hover', 'claniz' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
                'options'     => claniz_elementor_theme_color_opts(['custom' =>  false]),
                'default'     => 'secondary'  
            ),
            array(
                'name'        =>  $args['prefix'].'video_icon_color',
                'label'       => __( 'Video Icon Color', 'claniz' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
                'options'     => claniz_elementor_theme_color_opts(['custom' =>  false]),
                'default'     => 'white'  
            ),
            array(
                'name'        =>  $args['prefix'].'video_icon_color_hover',
                'label'       => __( 'Video Icon Color Hover', 'claniz' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
                'options'     => claniz_elementor_theme_color_opts(['custom' =>  false]),
                'default'     => 'primary'  
            ),
            array(
                'name'        =>  $args['prefix'].'video_text',
                'label'       => __( 'Video Text', 'claniz' ),
                'type'        => \Elementor\Controls_Manager::TEXT,
                'default'     => __('Our Video','claniz')
            ),
            array(
                'name'        =>  $args['prefix'].'video_text_color',
                'label'       => __( 'Text Color', 'claniz' ),
                'type'        => \Elementor\Controls_Manager::SELECT,
                'options'     => claniz_elementor_theme_color_opts(['custom' =>  false]),
                'condition'   => [
                     $args['prefix'].'video_text!' => ''
                ],
                'default'     => 'accent'  
            )
        );
        $effect = [];
        if($args['effect'] === true){
            $effect = [
                array(
                    'name'      => $args['prefix'].'video_animation',
                    'label'     => esc_html__( 'Button Video Effect', 'claniz' ),
                    'type'      => \Elementor\Controls_Manager::ANIMATION,
                    'condition' => [
                        $args['prefix'].'video_link[url]!' => ''
                    ]
                ),
                array(
                    'name'    => $args['prefix'].'video_animation_duration', 
                    'label'   => __( 'Animation Duration', 'claniz' ),
                    'type'    => \Elementor\Controls_Manager::SELECT,
                    'default' => 'normal',
                    'options' => [
                        'slow'   => __( 'Slow', 'claniz' ),
                        'normal' => __( 'Normal', 'claniz' ),
                        'fast'   => __( 'Fast', 'claniz' ),
                    ],
                    'condition' => [
                        $args['prefix'].'video_link[url]!' => '',
                        $args['prefix'].'video_animation!' => '',
                    ]
                ),
                array(
                    'name'      => $args['prefix'].'video_animation_delay',
                    'label'     => esc_html__( 'Animation Delay', 'claniz' ),
                    'type'      => \Elementor\Controls_Manager::NUMBER,
                    'min'       => 0,
                    'step'      => 100,
                    'condition' => [
                        $args['prefix'].'video_link[url]!' => '',
                        $args['prefix'].'video_animation!' => ''
                    ]
                )
            ];
        } 
        return  array_merge($default, $effect);
    }
}
// Render popup video attrs
if(!function_exists('claniz_elementor_render_lightbox_video_atts')){
    function claniz_elementor_render_lightbox_video_atts($widget, $settings, $args= []){
        $args = wp_parse_args($args, [
            'prefix'    => '',
            'video_url' => '',
            'animation' => 'fadeInUp',
            'ratio'     => '169'
        ]);
        $embed_params = [
            'loop'           => '0',
            'controls'       => '1',
            'mute'           => '0',
            'rel'            => '0',
            'modestbranding' => '0'
        ];
        $embed_options = [];
        $widget->add_render_attribute( 'video_atts', 'data-elementor-open-lightbox', 'yes');
        $widget->add_render_attribute( 'video_atts', 'data-elementor-lightbox', wp_json_encode([
            'type'         => 'video',
            'videoType'    => 'youtube',
            'url'          => \Elementor\Embed::get_embed_url( $args['video_url'], $embed_params, $embed_options ),
            'modalOptions' => [
                'id'                       => 'cms-lightbox-'.$settings['element_id'],
                'entranceAnimation'        => $args['animation'],
                'entranceAnimation_tablet' => '',
                'entranceAnimation_mobile' => '',
                'videoAspectRatio'         => $args['ratio']
            ]
        ]));
        //etc_print_html($widget->get_render_attribute_string( 'video_atts' ));
        $widget->print_render_attribute_string( 'video_atts' );
    }
}
// render popup video html
if(!function_exists('claniz_elementor_render_lightbox_video_button')){
    function claniz_elementor_render_lightbox_video_button($widget, $settings, $args= []){
        $args = wp_parse_args($args, [
            'prefix'     => '',
            'animation'  => 'slideInUp',
            'ratio'      => '169',
            'class'      => '',
            'row'        => '',
            'icon_class' => '',
            'before'     => '',
            'after'      => '',
            'outline'    => true,
            'shadow'     => false,
            'video_text' => '',
            'video_text_color' => 'text-accent',
            'video_text_class' => '',
            'row_class'  => ''
        ]);
        if(empty($settings[$args['prefix'].'video_link']['url']) || $settings[$args['prefix'].'video_link']['url'] === null) return;

        $lightbox_id = isset($settings['_id']) ? $settings['_id'] : $settings['element_id'];
        $embed_params = [
            'loop'           => '0',
            'controls'       => '1',
            'mute'           => '0',
            'rel'            => '0',
            'modestbranding' => '0'
        ];
        $video_atts = $embed_options = $animation = [];
        $classes = ['cms-video-lightbox', $args['class']];
        $classes[] = isset($settings[$args['prefix'].'video_animation_duration']) ? 'animated-'.$settings[$args['prefix'].'video_animation_duration'] : '';
        if(!empty($settings[$args['prefix'].'video_animation'])){
            $classes[] = 'cms-animate elementor-invisible';
            $animation  = [
                'animation'       => $settings[$args['prefix'].'video_animation'],
                '_animation'       => $settings[$args['prefix'].'video_animation'],
                'animation_delay' => $settings[$args['prefix'].'video_animation_delay']
            ];
        }
        $lightbox_options = [
            'type'         => 'video',
            'videoType'    => 'youtube',
            'url'          => \Elementor\Embed::get_embed_url( $settings[$args['prefix'].'video_link']['url'], $embed_params, $embed_options ),
            'modalOptions' => [
                'id'                       => 'cms-lightbox-'.$lightbox_id,
                'entranceAnimation'        => $args['animation'],
                'entranceAnimation_tablet' => '',
                'entranceAnimation_mobile' => '',
                'videoAspectRatio'         => $args['ratio']
            ]
        ];
        //$widget->add_render_attribute('video-atts', [
            $video_atts[] = 'class="'.trim(implode(' ', $classes)).'"';
            $video_atts[] = 'data-settings="'.esc_attr(wp_json_encode($animation)).'"';
            $video_atts[] = 'data-elementor-open-lightbox="yes"';
            $video_atts[] = 'data-elementor-lightbox="'.esc_attr(wp_json_encode( $lightbox_options )).'"';
        //]);
        // play video button
        $video_button = [
            'cms-video-btn',
            'text-center',
            !empty($settings[$args['prefix'].'video_play_color']) ? 'bg-'.$settings[$args['prefix'].'video_play_color'] : 'bg-accent',
            !empty($settings[$args['prefix'].'video_play_color_hover']) ? 'bg-hover-'.$settings[$args['prefix'].'video_play_color_hover'] : 'bg-hover-primary',
            !empty($settings[$args['prefix'].'video_icon_color']) ? 'text-'.$settings[$args['prefix'].'video_icon_color'] : 'text-white',
            !empty($settings[$args['prefix'].'video_icon_color_hover']) ? 'text-hover-'.$settings[$args['prefix'].'video_icon_color_hover'] : 'text-hover-accent',
            $args['icon_class']
        ];
        if($args['outline']) $video_button[] = 'has-outline';
        if($args['shadow']) $video_button[] = 'has-shadow';
        // play video text 
        $video_text_class = [
            $args['video_text_class'],
            'col empty-none font-700 lh-1',
            !empty($settings[$args['prefix'].'video_text_color']) ? 'text-'.$settings[$args['prefix'].'video_text_color'] : $args['video_text_color'] 
        ];
        $row_classes = ['row align-items-center gutters-30', $args['row_class']];
        printf('%s', $args['before']);
        ?>
        <div <?php echo trim(implode(' ', $video_atts)); ?>>
            <div class="<?php echo trim(implode(' ', $row_classes)); ?>">
                <div class="col-auto">
                    <div class="<?php echo implode(' ', $video_button); ?>"><?php 
                        if($args['outline']) echo  '<div class="cms-video-btn-outline"></div>';
                        if($args['shadow']) echo  '<div class="cms-video-btn-shadow"></div>';
                    ?><span class="cmsi cmsi-play"></span></div>
                </div>
                <div class="<?php echo implode(' ',$video_text_class); ?>"><?php 
                    etc_print_html($widget->get_setting($args['prefix'].'video_text', $args['video_text'])); 
                ?></div>
            </div>
        </div>
        <?php
        printf('%s', $args['after']);
    }
}

// Overlay options
if(!function_exists('claniz_elementor_overlay_settings')){
    function claniz_elementor_overlay_settings($args = []){
        $args = wp_parse_args($args, [
            'prefix'   => '',
            'name'     => 'cms_gradient',
            'label'    => __('Gradient', 'claniz'), 
            'selector' => '.cms-gradient',
            'condition'=> []
        ]);
        $default = array(
            array(
                'name'           => $args['prefix'].$args['name'].'_gradient',
                'label'          => $args['label'].' '.__( 'Color','claniz' ),
                'type'           => \Elementor\Group_Control_Background::get_type(),
                'control_type'   => 'group',
                'types'          => [ 'gradient' ],
                'fields_options' => [
                    'background' => [
                        'frontend_available' => true,
                    ],
                ],
                'selector'  => '{{WRAPPER}} '.$args['selector'].':after',
                'condition' => $args['condition']
            ),
            array(
                'name'      => $args['prefix'].$args['name'].'_color',
                'label'     => $args['label'].' '.__( 'Background Color','claniz' ),
                'type'      => \Elementor\Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} '.$args['selector'].':before' => 'background-color: {{VALUE}};',
                ],
                'condition' => $args['condition']
            ),
            array(
                'name'         => $args['prefix'].$args['name'].'_background',
                'title'        => $args['label'].' '.__( 'Background Image', 'claniz' ),
                'type'         => \Elementor\Group_Control_Background::get_type(),
                'control_type' => 'group',
                'types'        => [ 'classic' ],
                'fields_options' => [
                    'background' => [
                        'frontend_available' => true,
                    ],
                ],
                'selector'  => '{{WRAPPER}} '.$args['selector'],
                'condition' => $args['condition']
            )
        );
        return $default;
    }
}
// Responsive option 
if(!function_exists('claniz_elementor_responsive_settings')){
    function claniz_elementor_responsive_settings($args = []){
        $args = wp_parse_args($args, [
            'prefix' => 'cms',
            'prefix_class' => ''
        ]);
        $default = [
            [
                'name'            => $args['prefix'].'responsive_description',
                'raw'             => __( 'Responsive visibility will take effect only on preview or live page, and not while editing in Elementor.', 'claniz' ),
                'type'            => \Elementor\Controls_Manager::RAW_HTML,
                'content_classes' => 'elementor-descriptor',
            ],
            [
                'name'         => $args['prefix'].'hide_desktop',
                'label'        => __( 'Hide On Desktop', 'claniz' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'default'      => '',
                'label_on'     => 'Hide',
                'label_off'    => 'Show',
                'return_value' => 'elementor-hidden-desktop',
            ],
            [
                'name'         => $args['prefix'].'hide_tablet',
                'label'        => __( 'Hide On Tablet', 'claniz' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'default'      => '',
                'label_on'     => 'Hide',
                'label_off'    => 'Show',
                'return_value' => 'elementor-hidden-tablet',
            ],
            [
                'name'         => $args['prefix'].'hide_mobile',
                'label'        => __( 'Hide On Mobile', 'claniz' ),
                'type'         => \Elementor\Controls_Manager::SWITCHER,
                'default'      => '',
                'label_on'     => 'Hide',
                'label_off'    => 'Show',
                'return_value' => 'elementor-hidden-phone',
            ]
        ];
        return $default;
    }
}
if(!function_exists('claniz_elementor_responsive_render')){
    function claniz_elementor_responsive_render($settings, $args = []){
        $args = wp_parse_args($args, [
            'prefix' => 'cms'
        ]);
        $hidden = [
            $settings[$args['prefix'].'hide_desktop'],
            $settings[$args['prefix'].'hide_tablet'],
            $settings[$args['prefix'].'hide_mobile'],
        ];
        return implode(' ',$hidden);
    }
}

// Testinomial Rating
if(!function_exists('claniz_star_rating')){
    function claniz_star_rating($args = []){
        $args = wp_parse_args($args, [
            'rated'       => '100',
            'rated_w'     => 'auto', 
            'text'        => '',
            'class'       => '',
            'star_class'  => '',
            'rated_class' => '',
            'text_class'  => ''   
        ]);
        if($args['rated'] === 'none') return;
        $text_class = !empty($args['text_class']) ? $args['text_class'] : 'text-16 font-700';
    ?>
        <div class="cms-star-ratings row align-items-center gutters-20 <?php echo esc_attr($args['class']);?>">
            <?php if($args['rated'] !== 'none') : ?>
                <div class="col-<?php echo esc_attr($args['rated_w']);?>">
                    <div class="cms-star-rating relative <?php echo esc_attr($args['star_class']);?>">
                        <div class="cms-star-rated absolute <?php echo esc_attr($args['rated_class']);?>" data-width="<?php echo esc_attr($args['rated']);?>" style = "width:<?php echo esc_attr($args['rated'].'%');?>"></div>
                    </div>
                </div>
            <?php endif; ?>
            <div class="col empty-none <?php echo esc_attr($text_class);?>"><?php
                echo etc_print_html($args['text']);
            ?></div>
        </div>
    <?php
    }
}

if(!function_exists('claniz_swiper_chart_data_settings')){

    function claniz_swiper_chart_data_settings($widget, $settings, $args = []){
        $args = wp_parse_args($args, [
            'name'            => 'cms_chart',
            'chart_container' => 'cms-charts',
            'class'           => ''
        ]);
        $charts = $widget->get_settings($args['name']);
        $chart_title = $chart_main_title = $chart_value = $chart_color = [];
        foreach ($charts as $key => $value) {
            $chart_title[] = $value['chart_title'];
            $chart_main_title[] = $value['chart_main_title'];
            $chart_value[] = $value['chart_value'];
            $chart_color[] = $value['chart_color'];
        }
        /*$charts_data = [
            'labels' => $chart_title,
            'value'  => implode(',', $chart_value),
            'colors' => implode(',', $chart_color)
        ];*/
        $opts = [
            'type'            => $settings['cms_chart_type'],   
            'labels'          => $chart_title,
            'value'           => $chart_value,
            'colors'          => $chart_color,
            'legend_display'  => $settings['legend_display'],
            'legend_position' => $settings['legend_position'],
            'title_display'   => $settings['title_display'],
            'title_position'  => $settings['title_position'],
            'title_text'      => $settings['title_text']
        ];
        $widget->add_render_attribute( 'cms-chart-settings', [
            'id'            => etc_get_element_id($settings),
            'class'         => claniz_nice_class( implode( ' ', [$args['chart_container'], $args['class']] ) ),
            'data-settings' => wp_json_encode($opts)
        ]);
        etc_print_html($widget->get_render_attribute_string( 'cms-chart-settings' ));
    }
}
if(!function_exists('claniz_elementor_element_heading_settings')) {
    function claniz_elementor_element_heading_settings() {
        return array_merge(
            array(
                claniz_elementor_text_align([
                    'prefix'    => 'heading_desc_layout_',
                    'default' => '',
                    'condition' => [
                        'heading_desc_layout' => ['1']
                    ]
                ]),
                array(
                    'name'         => 'heading_desc_width',
                    'label'        => __('Width', 'claniz'),
                    'type'         => \Elementor\Controls_Manager::SLIDER,
                    'control_type' => 'responsive',
                    'selectors'    => [
                        '{{WRAPPER}} .cms-posts-heading' => 'width:{{SIZE}}%;flex: 0 0 {{SIZE}}%;'
                    ],
                    'condition' => [
                        'heading_desc_layout' => ['1','3']
                    ]
                )
            ),
            array(
                array(
                    'name'    => 'heading_desc_layout',
                    'label'   => esc_html__( 'Heading & Description Layout', 'claniz' ),
                    'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                    'default' => '1',
                    'options' => [
                        '1' => [
                            'label'      => esc_html__( 'Layout 1', 'claniz' ),
                            'image'      => get_template_directory_uri() . '/elementor/templates/layouts/posts/heading/1.png'
                        ],
                        '2' => [
                            'label'      => esc_html__( 'Layout 2', 'claniz' ),
                            'image'      => get_template_directory_uri() . '/elementor/templates/layouts/posts/heading/2.png'
                        ],
                        '3' => [
                            'label'      => esc_html__( 'Layout 3', 'claniz' ),
                            'image'      => get_template_directory_uri() . '/elementor/templates/layouts/posts/heading/3.png'
                        ],
                    ]
                ),
                array(
                    'name'             => 'selected_icon',
                    'label'            => esc_html__( 'Icon', 'claniz' ),
                    'type'             => \Elementor\Controls_Manager::ICONS,
                    'fa4compatibility' => 'icon',
                    'default'          => [
                        'value'     => '',
                        'library'   => '',
                    ],
                    'condition' => [],
                )
            ),
            claniz_elementor_text_settings([
                'name'     => 'smallheading_text',
                'label'    => __('Small Heading','claniz'), 
                'default'  => '',
                'selector' => '.cms-smallheading'
            ]),
            claniz_elementor_text_settings([
                'name'     => 'heading_text',
                'label'    => __('Large Heading','claniz'),
                'default'  => '',
                'selector' => '.cms-mainheading'
            ]),
            claniz_elementor_text_settings([
                'name'     => 'description_text',
                'label'    => __('Description','claniz'),
                'default'  => '',
                'selector' => '.cms-desc'
            ])
        );
    }
}
if(!function_exists('claniz_elementor_element_heading')){
    function claniz_elementor_element_heading($widget, $settings, $args = []){
        if(empty($settings['smallheading_text']) && empty($settings['heading_text']) && empty($settings['description_text'])) return;

        $args = wp_parse_args($args, [
            'before' => '',
            'after'  => '',
            'class'  => 'pb-60',
            'echo'   => true,
            'desc_class' => ''
        ]);
        ob_start();
            printf('%s', $args['before']);
            switch ($settings['heading_desc_layout']) {
                case '3': 
            ?><div class="d-flex <?php echo claniz_elementor_align_class($settings, ['prefix_name'=> 'heading_desc_layout_','prefix' => 'justify-content-']).' '.claniz_elementor_align_class($settings, ['prefix_name'=> 'heading_desc_layout_','prefix' => 'text-']);?>">
                <div class="<?php echo claniz_nice_class(['cms-posts-heading w-100', $args['class']]); ?>">
                    <?php 
                        // icon
                        claniz_elementor_icon_render($widget,$settings,[
                            'class'  => '',
                            'before' => '<div class="cms-heading-icon text-64">',
                            'after'  =>'</div>'
                        ]);
                        // Small Heading 
                        claniz_elementor_text_render([
                            'name'        => 'smallheading_text',
                            'tag'         => 'div',
                            'color'       => 'heading',
                            'class'       => 'cms-smallheading text-16 font-700 mt-n5 pb-15'  
                        ], $widget, $settings);
                        // Heading 
                        claniz_elementor_text_render([
                            'name'        => 'heading_text',
                            'tag'         => 'h2',
                            'color'       => 'heading',
                            'class'       => 'cms-mainheading cms-heading text-24 mt-n5 pb-27'  
                        ], $widget, $settings);
                        // Description
                        claniz_elementor_text_render([
                            'name'        => 'description_text',
                            'tag'         => 'div',
                            'color'       => 'body',
                            'class'       => 'cms-desc text-16 mb-n7 pb-35 '.$args['desc_class'],
                            'autop'       => true, 
                        ], $widget, $settings);
                    ?>
                </div></div>
            <?php
                break;
                case '2':
            ?>
                <div class="<?php echo claniz_nice_class(['cms-posts-heading row gutters-grid', $args['class']]); ?>">
                    <div class="col-lg-6 empty-none"><?php 
                        //Icon
                        claniz_elementor_icon_render($widget,$settings,[
                            'class'  => '',
                            'before' => '<div class="cms-heading-icon text-64">',
                            'after'  =>'</div>'
                        ]);
                        // Small Heading 
                        claniz_elementor_text_render([
                            'name'        => 'smallheading_text',
                            'tag'         => 'div',
                            'color'       => 'heading',
                            'class'       => 'cms-smallheading text-16 font-700 mt-n5 mb-10'  
                        ], $widget, $settings);
                        // Heading 
                        claniz_elementor_text_render([
                            'name'        => 'heading_text',
                            'tag'         => 'h2',
                            'color'       => 'heading',
                            'class'       => 'cms-mainheading cms-heading text-24 text-lg-37 font-700 mt-n5',
                        ], $widget, $settings);
                    ?></div>
                    <?php
                        // Description
                        claniz_elementor_text_render([
                            'name'        => 'description_text',
                            'tag'         => 'div',
                            'color'       => 'body',
                            'class'       => 'cms-desc text-16 mb-n7 '.$args['desc_class'],
                            'autop'       => true,  
                            'wrap_before' => '<div class="col-lg-6">',
                            'wrap_after'  => '</div>'   
                        ], $widget, $settings);
                    ?>
                </div>
            <?php
                    break;
                default:
            ?><div class="d-flex <?php echo claniz_elementor_align_class($settings, ['prefix_name'=> 'heading_desc_layout_','prefix' => 'justify-content-']).' '.claniz_elementor_align_class($settings, ['prefix_name'=> 'heading_desc_layout_','prefix' => 'text-']);?>">
                <div class="<?php echo claniz_nice_class(['cms-posts-heading w-100', $args['class']]); ?>">
                    <?php 
                        //Icon
                        claniz_elementor_icon_render($widget,$settings,[
                            'class'  => '',
                            'before' => '<div class="cms-heading-icon text-64">',
                            'after'  =>'</div>'
                        ]);
                        // Small Heading 
                        claniz_elementor_text_render([
                            'name'        => 'smallheading_text',
                            'tag'         => 'div',
                            'color'       => 'heading',
                            'class'       => 'cms-smallheading text-16 font-700 mt-n5 mb-15'  
                        ], $widget, $settings);
                        // Heading 
                        claniz_elementor_text_render([
                            'name'        => 'heading_text',
                            'tag'         => 'h2',
                            'color'       => 'heading',
                            'class'       => 'cms-mainheading cms-heading text-24 text-lg-37 font-700 mt-n5'  
                        ], $widget, $settings);
                        // Description
                        claniz_elementor_text_render([
                            'name'        => 'description_text',
                            'tag'         => 'div',
                            'color'       => 'body',
                            'class'       => 'cms-desc text-16 mb-n7 pt-10 '.$args['desc_class'],
                            'autop'       => true, 
                        ], $widget, $settings);
                    ?>
                </div></div>
            <?php
                    break;
            }
            printf('%s', $args['after']);
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
// Zocdoc rating 
if(!function_exists('claniz_elementor_zocdoc_settings')){
    function claniz_elementor_zocdoc_settings($args = []){
        $args = wp_parse_args($args, [
            'show_rating'  => 'yes',
            'rating_rated' => '4.9',
            'rating_total' => '7541',
            'rating_text1' => 'Zocdoc',
            'rating_text2' => 'Overall Rating',
            'rating_text3' => ', based on.',
            'rating_text4' => 'reviews.',
            'rated_color'  => 'body',
            'text_color'   => 'accent',
            'text1_color'  => 'accent',
            'tabs'         => \Elementor\Controls_Manager::TAB_CONTENT,
            'condition'    => []   
        ]);
        return [
            'name'     => 'zocdoc_section',
            'label'    => esc_html__( 'Zocdoc Options', 'claniz' ),
            'tab'      => $args['tabs'],
            'controls' => [
                [
                    'name'     => 'show_rating',
                    'label'    => esc_html__( 'Show Zocdoc', 'claniz' ),
                    'type'     => \Elementor\Controls_Manager::SELECT,
                    'options'  => [
                        'yes' => __('Yes','claniz'), 
                        'no' => __('No','claniz') 
                    ],
                    'default'  => $args['show_rating']
                ],
                [
                    'name'     => 'rating_rated',
                    'label'    => esc_html__( 'Rated', 'claniz' ),
                    'type'     => \Elementor\Controls_Manager::TEXT,
                    'default'  => $args['rating_rated'],
                    'condition'=>[
                        'show_rating' => 'yes'
                    ]
                ],
                [
                    'name'     => 'rating_total',
                    'label'    => esc_html__( 'Rate Total', 'claniz' ),
                    'type'     => \Elementor\Controls_Manager::TEXT,
                    'default'  => $args['rating_total'],
                    'condition'=>[
                        'show_rating' => 'yes'
                    ]
                ],
                [
                    'name'     => 'rating_text1',
                    'label'    => esc_html__( 'Text', 'claniz' ),
                    'type'     => \Elementor\Controls_Manager::TEXT,
                    'default'  => $args['rating_text1'],
                    'condition'=>[
                        'show_rating' => 'yes'
                    ]
                ],
                [
                    'name'     => 'rating_text2',
                    'label'    => esc_html__( 'Overall Text', 'claniz' ),
                    'type'     => \Elementor\Controls_Manager::TEXT,
                    'default'  => $args['rating_text2'],
                    'condition'=>[
                        'show_rating' => 'yes'
                    ]
                ],
                [
                    'name'     => 'rating_text3',
                    'label'    => esc_html__( 'Base Text', 'claniz' ),
                    'type'     => \Elementor\Controls_Manager::TEXT,
                    'default'  => $args['rating_text3'],
                    'condition'=>[
                        'show_rating' => 'yes'
                    ]
                ],
                [
                    'name'     => 'rating_text4',
                    'label'    => esc_html__( 'Review Text', 'claniz' ),
                    'type'     => \Elementor\Controls_Manager::TEXT,
                    'default'  => $args['rating_text4'],
                    'condition'=>[
                        'show_rating' => 'yes'
                    ]
                ],
                [
                    'name'     => 'rated_color',
                    'label'    => esc_html__( 'Rated Color', 'claniz' ),
                    'type'     => \Elementor\Controls_Manager::SELECT,
                    'options'  => claniz_elementor_theme_color_opts(),
                    'default'  => $args['rated_color'],
                    'condition'=>[
                        'show_rating' => 'yes'
                    ]
                ],
                [
                    'name'        => 'rated_custom_color',
                    'label'       => esc_html__( 'Rated Custom Color', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::COLOR,
                    'condition'   => [
                        'rated_color' => 'custom'
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .cms-zodoc-rating .cms-zodoc-rated' => 'color:{{VALUE}};'
                    ]
                ],
                [
                    'name'     => 'text_color',
                    'label'    => esc_html__( 'Text Color', 'claniz' ),
                    'type'     => \Elementor\Controls_Manager::SELECT,
                    'options'  => claniz_elementor_theme_color_opts(),
                    'default'  => $args['text1_color'],
                    'condition'=>[
                        'show_rating' => 'yes'
                    ]
                ],
                [
                    'name'        => 'text_custom_color',
                    'label'       => esc_html__( 'Text Custom Color', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::COLOR,
                    'condition'   => [
                        'text_color' => 'custom'
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .cms-zodoc-rating .cms-zocdoc-text1 ' => 'color:{{VALUE}};'
                    ]
                ],
                [
                    'name'     => 'text1_color',
                    'label'    => esc_html__( 'Text1 Color', 'claniz' ),
                    'type'     => \Elementor\Controls_Manager::SELECT,
                    'options'  => claniz_elementor_theme_color_opts(),
                    'default'  => $args['text1_color'],
                    'condition'=>[
                        'show_rating' => 'yes'
                    ]
                ],
                [
                    'name'        => 'text1_custom_color',
                    'label'       => esc_html__( 'Text1 Custom Color', 'claniz' ),
                    'type'        => \Elementor\Controls_Manager::COLOR,
                    'condition'   => [
                        'text1_color' => 'custom'
                    ],
                    'selectors'  => [
                        '{{WRAPPER}} .cms-zodoc-rating .cms-zocdoc-text1 ' => 'color:{{VALUE}};'
                    ]
                ]
            ],
            'condition' => $args['condition']
        ];
    }
}
if(!function_exists('claniz_zocdoc_rating')){
    function claniz_zocdoc_rating($widget, $settings, $args = []){
        $args = wp_parse_args($args, [
            'show_rating'  => $widget->get_setting('show_rating', ''),
            'rating_rated' => $widget->get_setting('rating_rated', '4.9'),
            'rating_total' => $widget->get_setting('rating_total', '7541'),
            'rating_text1' => $widget->get_setting('rating_text1', __('Zocdoc', 'claniz')),
            'rating_text2' => $widget->get_setting('rating_text2', __('Overall Rating', 'claniz')),
            'rating_text3' => $widget->get_setting('rating_text3', __(', based on.', 'claniz')),
            'rating_text4' => $widget->get_setting('rating_text4', __('reviews.', 'claniz')),
            'rated_color'  => $widget->get_setting('rated_color', 'body'),
            'text_color'   => $widget->get_setting('text_color', 'body'),
            'text1_color'  => $widget->get_setting('text1_color', 'accent'),
            'wrap_class'   => '',
            'before'       => '',
            'after'        => ''   
        ]);
        if($args['show_rating'] !== 'yes') return;
        printf('%s', $args['before']);
        ?>
            <div class="<?php echo trim(implode(' ', ['cms-zodoc-rating row align-items-center gutters-20', $args['wrap_class'], 'text-'.$args['text_color'] ]));?>">
                <div class="cms-zodoc-rated col-auto cms-heading text-37 text-<?php echo esc_attr($args['rated_color']);?>"><?php 
                    echo esc_html($args['rating_rated']);
                ?></div>
                <div class="cms-zodoc-text col">
                    <span class="text-13"><span class="text-border-bottom"><span class="cms-zocdoc-text1 text-14 font-700 text-<?php echo esc_attr($args['text1_color']);?>"><?php echo esc_html($args['rating_text1']);?></span> <?php echo esc_html($args['rating_text2']);?></span><?php echo nl2br($args['rating_text3']);?> <?php echo esc_html($args['rating_total']);?> <?php echo esc_html($args['rating_text4']);?></span>
                </div>
            </div>
        <?php
        printf('%s', $args['after']);
    }
}
// Element Width
if(!function_exists('claniz_elementor_element_width_settings')){
    function claniz_elementor_element_width_settings($args = []){
        $args = wp_parse_args($args, [
            'name' => 'element_w',
            'label' => __('Element Width','claniz'),
            'default' => ''
        ]);
        return array(
            'name'          => $args['name'],
            'label'         => $args['label'],
            'type'          => \Elementor\Controls_Manager::SELECT,
            'control_type'  => 'responsive',
            'options'       => [
                ''     => __( 'Default', 'claniz' ),
                'auto' => __( 'Auto', 'claniz' ),
                'col'  => __('Base on other','claniz'),
            ] + array_combine(range(1, 12),range(1, 12)),
            'default'       => $args['default']
        );
    }
}
if(!function_exists('claniz_elementor_element_width_render')){
    function claniz_elementor_element_width_render($widget, $settings, $args = []){
        $args = wp_parse_args($args, [
            'name'    => 'element_w',
            'default' => ''
        ]);
        $default = $widget->get_setting($args['name'], $args['default']);
    }
}

// Elementor Wave
if(!function_exists('claniz_elementor_waves_settings')){
    function claniz_elementor_waves_settings($args = []){
        $args = wp_parse_args($args, [
            'prefix' => '' 
        ]);
        /*foreach ( [
            'top' => esc_html__( 'Top', 'claniz' ),
            'bottom' => esc_html__( 'Bottom', 'claniz' ),
        ] as $side => $side_label ) {
            $base_control_key = "cms_waves_$side";
            [
                'name' => $args['prefix'].'tab_'.$base_control_key,
                'label' => $args['prefix'].$side_label
            ],
            [
                'name'               => $args['prefix'].$base_control_key,
                'label'              => esc_html__( 'Type', 'claniz' ),
                'type'               => \Elementor\Controls_Manager::SELECT,
                'options'            => [
                    ''  => esc_html__('None','claniz'),
                    'waves' => esc_html__('Waves', 'claniz')
                ],
                'render_type'        => 'none',
                'frontend_available' => true,
            ],
            [
                'name'  => $args['prefix'].$base_control_key . '_color',
                'label' => esc_html__( 'Color', 'claniz' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'condition' => [
                    "shape_divider_$side!" => '',
                ],
                'selectors' => [
                    "{{WRAPPER}} > .elementor-shape-$side .elementor-shape-fill" => 'fill: {{UNIT}};',
                ],
            ],
            [
                'name'  => $args['prefix'].$base_control_key . '_width',
                'label' => esc_html__( 'Width', 'elementor' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'default' => [
                    'unit' => '%',
                ],
                'tablet_default' => [
                    'unit' => '%',
                ],
                'mobile_default' => [
                    'unit' => '%',
                ],
                'range' => [
                    '%' => [
                        'min' => 100,
                        'max' => 300,
                    ],
                ],
                'condition' => [
                    "shape_divider_$side" => array_keys( Shapes::filter_shapes( 'height_only', Shapes::FILTER_EXCLUDE ) ),
                ],
                'selectors' => [
                    "{{WRAPPER}} > .elementor-shape-$side svg" => 'width: calc({{SIZE}}{{UNIT}} + 1.3px)',
                ],
            ],
            [
                'name' => $args['prefix'].$base_control_key . '_height',
                'label' => esc_html__( 'Height', 'elementor' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'condition' => [
                    "shape_divider_$side!" => '',
                ],
                'selectors' => [
                    "{{WRAPPER}} > .elementor-shape-$side svg" => 'height: {{SIZE}}{{UNIT}};',
                ],
            ],
            [
                'name' => $args['prefix'].$base_control_key . '_flip',
                'label' => esc_html__( 'Flip', 'elementor' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'condition' => [
                    "shape_divider_$side" => array_keys( Shapes::filter_shapes( 'has_flip' ) ),
                ],
                'selectors' => [
                    "{{WRAPPER}} > .elementor-shape-$side svg" => 'transform: translateX(-50%) rotateY(180deg)',
                ],
            ],
            [
                'name' => $args['prefix'].$base_control_key . '_negative',
                'label' => esc_html__( 'Invert', 'elementor' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'frontend_available' => true,
                'condition' => [
                    "shape_divider_$side" => array_keys( Shapes::filter_shapes( 'has_negative' ) ),
                ],
                'render_type' => 'none',
            ]
        }*/
    }
}
if(!function_exists('claniz_elementor_waves_render')){
    function claniz_elementor_waves_render($widget=[], $settings=[], $args=[]){
        $args = wp_parse_args($args, [
            'prefix' => '',
            'class'  => '',
            'before' => '',
            'after'  => '',
            'echo'   => true,
            'colors' => [
                'accent',
                'lighten-accent',
                'darken-accent',
                'primary'
            ]
        ]);
        $classes = ['cms-waves', $args['class']];
        ob_start();
            printf('%s', $args['before']);

        ?>
        <svg class="<?php echo claniz_nice_class($classes); ?>"
             xmlns="http://www.w3.org/2000/svg"
             xmlns:xlink="http://www.w3.org/1999/xlink"
             viewBox="0 24 150 28 "
             preserveAspectRatio="none">
            <defs>
                <path id="cms-wave"
                d="M-160 44c30 0 
                58-18 88-18s
                58 18 88 18 
                58-18 88-18 
                58 18 88 18
                v44h-352z" />
            </defs>
            <g class="cms-wave1">
                <use xlink:href="#cms-wave" x="50" y="3" fill="<?php echo esc_attr($args['colors'][0]) ?>"/>
            </g>
            <g class="cms-wave2">
                <use xlink:href="#cms-wave" x="50" y="0" fill="<?php echo esc_attr($args['colors'][1]) ?>"/>
            </g>
            <g class="cms-wave3">
                <use xlink:href="#cms-wave" x="50" y="9" fill="<?php echo esc_attr($args['colors'][2]) ?>"/>
            </g>
            <g class="cms-wave4">
                <use xlink:href="#cms-wave" x="50" y="6" fill="<?php echo esc_attr($args['colors'][3]) ?>"/>  
            </g>
        </svg>
        <?php
        printf('%s', $args['after']);

        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}

// Rate setting 
if(!function_exists('claniz_elementor_rate_settings')){
    function claniz_elementor_rate_settings($args =[]){
        $args = wp_parse_args($args, [
            'name'      => 'cms_rate',
            'label'     => __('Rate','claniz'),
            'tab'       => \Elementor\Controls_Manager::TAB_CONTENT,
            'default'   => '100',
            'condition' => []
        ]);
        return array(
            'name'     => $args['name'].'_section',
            'label'    => $args['label'].' '.__('Settings','claniz'),
            'tab'      => $args['tab'],
            'controls' => array_merge(
                array(
                    array(
                        'name'        => $args['name'],
                        'label'       => $args['label'].' '.__('Rated', 'claniz'),
                        'type'        => \Elementor\Controls_Manager::SELECT,
                        'options'     => [
                            'none'=> 'none',  
                            '0'   => 0,
                            '20'  => 1,
                            '40'  => 2,
                            '60'  => 3,
                            '80'  => 4,
                            '100' => 5
                        ],
                        'default'     => $args['default'],
                        'separator'   => 'before'
                    )
                ),
                claniz_elementor_theme_colors([
                    'name'            => $args['name'].'rate_color',
                    'label'           => __('Color','claniz'),
                    'custom_selector' => '.cms-star-rating'
                ]),
                claniz_elementor_theme_colors([
                    'name' => $args['name'].'rated_color',
                    'label' => __('Rated Color','claniz'),
                    'custom_selector' => '.cms-star-rating .cms-star-rated'
                ]),
                claniz_elementor_text_settings([
                    'name'        => $args['name'].'_text_bold',
                    'label'       => $args['label'].' '.__('Heading','claniz'), 
                    'default'     => '',
                    'separator'   => 'before',
                    'default'     => '',
                    'extra_space' =>  false,
                    'selector'    => '.cms-rate-text-bold',
                    'border'      => true
                ]),
                claniz_elementor_text_settings([
                    'name'        => $args['name'].'_text_desc',
                    'label'       => $args['label'].' '.__('Description','claniz'), 
                    'default'     => '',
                    'separator'   => 'before',
                    'default'     => '',
                    'extra_space' =>  false,
                    'selector'    => '.cms-rate-text'
                ]),
            ),
            'condition' => $args['condition']
        );
    }
}
if(!function_exists('claniz_elementor_rate_render')){
    function claniz_elementor_rate_render($widget= [], $settings = [], $args =[]){
        $args = wp_parse_args($args, [
            'name'        => 'cms_rate',
            'rated'       => '100',
            'rated_w'     => 'auto',
            'rate_color'  => 'body',
            'rated_color' => 'accent',
            'rated_class' => '',
            'rated_before'=> '',
            'rated_after' => '',
            'class'       => '',
            'star_class'  => '',
            'text_bold'   => '97% Customer Satisfaction', 
            'text'        => 'based on 750+ reviews from our beloved customers and 20,000 natural products!',
            'before'      => '',  
            'after'       => ''  
        ]);
        if($args['rated'] === 'none') return;
        
        $wrap_classes = ['cms-ratings', 'row', $args['class']];
        // star color
        $star_color   = 'text-'.$widget->get_setting($args['name'].'rate_color', $args['rate_color']);
        $star_classes = ['cms-star-rating relative', $star_color, $args['star_class']];
        // rated color
        if($settings[$args['name']] != '0'){
            $rated = $widget->get_setting($args['name'], $args['rated']);
        } else {
            $rated = '0';
        }
        $rated_color = 'text-'.$widget->get_setting($args['name'].'rated_color', $args['rated_color']);
        $rated_classes     = ['cms-star-rated absolute', $rated_color, $args['rated_class']];
        printf($args['before']);
    ?>
        <div class="<?php echo claniz_nice_class($wrap_classes);?>">
            <?php if($rated != 'none'): ?>
                <div class="col-mobile-12 col-<?php echo esc_attr($args['rated_w']);?>">
                    <?php etc_print_html($args['rated_before']); ?>
                    <div class="<?php echo claniz_nice_class($star_classes);?>">
                        <div class="<?php echo claniz_nice_class($rated_classes);?>" data-width="<?php echo esc_attr($rated);?>" style = "width:<?php echo esc_attr($rated.'%');?>"></div>
                    </div>
                    <?php etc_print_html($args['rated_after']); ?>
                </div>
            <?php endif; ?>
            <div class="col cms-rate-text"><?php
                claniz_elementor_text_render([
                    'name'         => $args['name'].'_text_bold',
                    'tag'          => 'span',
                    'color'        => 'accent',
                    'class'        => 'font-700', 
                    'selector'     => 'cms-rate-text-bold',
                    'render_attrs' => '',
                    'before'       => '', 
                    'after'        => '',
                    'wrap_before'  => '', 
                    'wrap_after'   => '',
                    'autop'        => true,
                    'default'      => $args['text_bold'],
                    'extra_space'  => false,
                    'border'       => true 
                ], $widget, $settings);
                claniz_elementor_text_render([
                    'name'         => $args['name'].'_text_desc',
                    'tag'          => 'span',
                    'color'        => 'body',
                    'class'        => '', 
                    'selector'     => 'cms-rate-text',
                    'render_attrs' => '',
                    'before'       => '', 
                    'after'        => '',
                    'wrap_before'  => '', 
                    'wrap_after'   => '',
                    'autop'        => true,
                    'default'      => $args['text'],
                    'extra_space'  => false 
                ], $widget, $settings);
            ?></div>
        </div>
    <?php
        printf($args['after']);
    }
}

if(!function_exists('claniz_elementor_rate_render2')){
    function claniz_elementor_rate_render2($widget= [], $settings = [], $args =[]){
        $args = wp_parse_args($args, [
            'name'        => 'cms_rate',
            'rated'       => '100',
            'rated_w'     => '12',
            'rate_color'  => 'body',
            'rated_color' => 'rating',
            'rated_class' => '',
            'class'       => '',
            'star_class'  => '',
            'text_bold'   => 'Check out our reviews on Google', 
            'text'        => '',
            'before'      => '',  
            'after'       => ''  
        ]);
        if($args['rated'] === 'none') return;
        
        $wrap_classes = ['cms-ratings', 'row align-items-center', $args['class']];
        // star color
        $star_color   = 'text-'.$widget->get_setting($args['name'].'rate_color', $args['rate_color']);
        $star_classes = ['cms-star-rating relative', $star_color, $args['star_class']];
        // rated color
        if($settings[$args['name']] != '0'){
            $rated = $widget->get_setting($args['name'], $args['rated']);
        } else {
            $rated = '0';
        }
        $rated_color = 'text-'.$widget->get_setting($args['name'].'rated_color', $args['rated_color']);
        $rated_classes     = ['cms-star-rated absolute', $rated_color, $args['rated_class']];
        printf($args['before']);
    ?>
        <div class="<?php echo claniz_nice_class($wrap_classes);?>">
            <div class="col cms-rate-text"><?php
                claniz_elementor_text_render([
                    'name'         => $args['name'].'_text_bold',
                    'tag'          => 'div',
                    'color'        => 'primary',
                    'class'        => 'font-700', 
                    'selector'     => 'cms-rate-text-heading lh-1/3',
                    'render_attrs' => '',
                    'before'       => '', 
                    'after'        => '',
                    'wrap_before'  => '', 
                    'wrap_after'   => '',
                    'autop'        => true,
                    'default'      => $args['text_bold'],
                    'extra_space'  => false
                ], $widget, $settings);
                claniz_elementor_text_render([
                    'name'         => $args['name'].'_text_desc',
                    'tag'          => 'span',
                    'color'        => 'body',
                    'class'        => '', 
                    'selector'     => 'cms-rate-text',
                    'render_attrs' => '',
                    'before'       => '', 
                    'after'        => '',
                    'wrap_before'  => '', 
                    'wrap_after'   => '',
                    'autop'        => true,
                    'default'      => $args['text'],
                    'extra_space'  => false 
                ], $widget, $settings);
            ?></div>
            <?php if($rated != 'none'): ?>
                <div class="col-12 col-md-<?php echo esc_attr($args['rated_w']);?> pt-5">
                    <div class="<?php echo claniz_nice_class($star_classes);?>">
                        <div class="<?php echo claniz_nice_class($rated_classes);?>" data-width="<?php echo esc_attr($rated);?>" style = "width:<?php echo esc_attr($rated.'%');?>"></div>
                    </div>
                </div>
            <?php endif; ?>
            
        </div>
    <?php
        printf($args['after']);
    }
}

// Scan element (need add to bottom of this file)
$files = scandir(get_template_directory() . '/elementor/core/register');
foreach ($files as $file){
    $pos = strrpos($file, ".php");
    if($pos !== false){
        require_once get_template_directory() . '/elementor/core/register/' . $file;
    }
}



