<?php
// Register Chart Widget
etc_add_custom_widget(
    array(
        'name'       => 'cms_chart',
        'title'      => esc_html__( 'CMS Chart', 'claniz' ),
        'icon'       => 'eicon-circle-o',
        'categories' => array( Elementor_Theme_Core::ETC_CATEGORY_NAME ),
        'scripts'    => array(
            'chartjs',
            'cms-chartjs',
            'cms-animation'
        ),
        'params' => array(
            'sections' => array(
                array(
                    'name'     => 'layout_section',
                    'label'    => esc_html__( 'Layout', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_LAYOUT,
                    'controls' => array(
                        array(
                            'name'    => 'layout',
                            'label'   => esc_html__( 'Templates', 'claniz' ),
                            'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                            'default' => '1',
                            'options' => [
                                '1' => [
                                    'label' => esc_html__( 'Layout 1', 'claniz' ),
                                    'image' => get_template_directory_uri() . '/elementor/templates/widgets/cms_accordion/layout-images/1.png'
                                ]
                            ],
                            'prefix_class' => 'cms-charts cms-chart-layout-'
                        ),
                    ),
                ),
                array(
                    'name'     => 'heading_section',
                    'label'    => esc_html__( 'Heading Settings', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        array(
                            claniz_elementor_text_align([
                                'name'    => 'heading_align', 
                                'default' => '',
                                'label'   => __( 'Heading Alignment', 'claniz' ),
                            ])
                        ),
                        claniz_elementor_text_settings([
                            'name'     => 'smallheading_text',
                            'label'    => __('Small Heading','claniz'),
                            'default'  => '',
                            'selector' => '.cms-smallheading'
                        ]),
                        claniz_elementor_text_settings([
                            'name'     => 'heading_text',
                            'default'  => '',
                            'selector' => '.cms-mainheading',
                            'separator' => 'before'
                        ]),
                        claniz_elementor_text_settings([
                            'name'      => 'description_text',
                            'label'     => __('Description','claniz'),
                            'default'   => '',
                            'selector'  => '.cms-desc',
                            'separator' => 'before'
                        ]),
                    )
                ),
                array(
                    'name'     => 'chart_section',
                    'label'    => esc_html__( 'Chart Content', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        array(
                            array(
                                'name'    => 'cms_chart',
                                'label'   => esc_html__( 'Chart Items', 'claniz' ),
                                'type'    => \Elementor\Controls_Manager::REPEATER,
                                'controls' => array(
                                    array(
                                        'name'  => 'chart_title',
                                        'label' => esc_html__( 'Title', 'claniz' ),
                                        'type'  => \Elementor\Controls_Manager::TEXT,
                                    ),
                                    array(
                                        'name'  => 'chart_main_title',
                                        'label' => esc_html__( 'Main Title', 'claniz' ),
                                        'type'  => \Elementor\Controls_Manager::TEXT,
                                    ),
                                    array(
                                        'name'  => 'chart_value',
                                        'label' => esc_html__( 'Value', 'claniz' ),
                                        'type'  => \Elementor\Controls_Manager::NUMBER,
                                    ),
                                    array(
                                        'name'  => 'chart_color',
                                        'label' => esc_html__( 'Color', 'claniz' ),
                                        'type'  => \Elementor\Controls_Manager::COLOR,
                                    ),
                                    
                                ),
                                'default' => [
                                    [
                                        'chart_title'      => 'Retail',
                                        'chart_main_title' => 'Retail & Consumer',
                                        'chart_value'      => 40,
                                        'chart_color'      => '#9bcb3b',
                                    ],
                                    [
                                        'chart_title'      => 'Sciences',
                                        'chart_main_title' => 'Sciences & Healthcare',
                                        'chart_value'      => 20,
                                        'chart_color'      => '#5553ce',
                                    ],
                                    [
                                        'chart_title'      => 'Industrial',
                                        'chart_main_title' => 'Industrial & Chemical',
                                        'chart_value'      => 15,
                                        'chart_color'      => '#f13a30',
                                    ],
                                    [
                                        'chart_title'      => 'Power',
                                        'chart_main_title' => 'Power Generation',
                                        'chart_value'      => 15,
                                        'chart_color'      => '#f8a137',
                                    ],
                                    [
                                        'chart_title'      => 'Oil & Gas',
                                        'chart_main_title' => 'Oil & Gas',
                                        'chart_value'      => 10,
                                        'chart_color'      => '#1875f0',
                                    ]
                                ],
                                'title_field' => '{{{ chart_title }}} ({{{ chart_value }}})',
                                'separator'   => 'after',
                            ),
                            array(
                                'name'         => 'cms_chart_dimensions',
                                'label'        => esc_html__( 'Chart Dimensions', 'claniz' ),
                                'type'         => \Elementor\Controls_Manager::SLIDER,
                                'control_type' => 'responsive',
                                'range' => [
                                    'px' => [
                                        'min' => 100,
                                        'max' => 1000,
                                    ]
                                ],
                                'default' => [
                                    'size' => 400
                                ],
                                'selectors' => [
                                    '{{WRAPPER}} .cms-charts-chart' => 'max-width:{{SIZE}}px;max-height:{{SIZE}}px;'
                                ],
                                'separator' => 'before'
                            )
                        )
                    )
                ),
                array(
                    'name'     => 'style_section',
                    'label'    => esc_html__( 'Style Settings', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_STYLE,
                    'controls' => [
                        array(
                            'name'    => 'cms_chart_type',
                            'label'   => esc_html__( 'Chart Type', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => array(
                                'doughnut'  => __('Doughnut','claniz'),
                                'pie'       => __('Pie','claniz'),
                                'polarArea' => __('Polar Area','claniz'),
                                //'line'      => __('line','claniz')
                            ),
                            'default' => 'doughnut'
                        ),
                        array(
                            'name'    => 'legend_display',
                            'label'   => esc_html__( 'Show Legend', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => array(
                                'true'  => __('Yes','claniz'),
                                'false' => __('No','claniz')
                            ),
                            'default' => 'false'
                        ),
                        array(
                            'name'    => 'legend_position',
                            'label'   => esc_html__( 'Legend Position', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => array(
                                'top'    => __('Top','claniz'),
                                'right'  => __('Right','claniz'),
                                'bottom' => __('Bottom','claniz'),
                                'left'   => __('Left','claniz')
                            ),
                            'default' => 'top',
                            'condition' => [
                                'legend_display' => 'true'
                            ]
                        ),
                        array(
                            'name'    => 'title_display',
                            'label'   => esc_html__( 'Show Title', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => array(
                                'true'  => __('Yes','claniz'),
                                'false' => __('No','claniz')
                            ),
                            'default' => 'false'
                        ),
                        array(
                            'name'    => 'title_text',
                            'label'   => esc_html__( 'Title', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::TEXTAREA,
                            'default' => 'Your Title',
                            'condition' => [
                                'title_display' => 'true'
                            ]
                        ),
                        array(
                            'name'    => 'title_position',
                            'label'   => esc_html__( 'Title Position', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => array(
                                'top'    => __('Top','claniz'),
                                'right'  => __('Right','claniz'),
                                'bottom' => __('Bottom','claniz'),
                                'left'   => __('Left','claniz')
                            ),
                            'default' => 'top',
                            'condition' => [
                                'title_display' => 'true'
                            ]
                        )
                    ]
                )
            )
        )
    ),
    get_template_directory() . '/elementor/core/widgets/'
);