<?php
// Register Page Title Widget
etc_add_custom_widget(
    array(
        'name'       => 'cms_page_title',
        'title'      => esc_html__( 'CMS Page Title', 'claniz' ),
        'icon'       => 'eicon-archive-title',
        'categories' => array( Elementor_Theme_Core::ETC_CATEGORY_NAME ),
        'scripts'    => array(),
        'params'     => array(
            'sections' => array(
                array(
                    'name'     => 'layout_section',
                    'label'    => esc_html__( 'Layout', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_LAYOUT,
                    'controls' => array(
                        array(
                            'name'    => 'layout',
                            'label'   => esc_html__( 'Templates', 'claniz' ),
                            'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                            'default' => '1',
                            'options' => [
                                '1' => [
                                    'label'      => esc_html__( 'Layout 1', 'claniz' ),
                                    'image'      => get_template_directory_uri() . '/elementor/templates/widgets/cms_page_title/layout-images/1.jpg'
                                ],
                                '2' => [
                                    'label'      => esc_html__( 'Layout 2', 'claniz' ),
                                    'image'      => get_template_directory_uri() . '/elementor/templates/widgets/cms_page_title/layout-images/2.jpg'
                                ]
                            ],
                            'prefix_class' => 'cms-page-title-layout-'
                        )
                    ),
                ),
                array(
                    'name'     => 'settings_section',
                    'label'    => esc_html__( 'Setting', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' =>  array(
                        array(
                            'name'         => 'content_col',
                            'type'         => \Elementor\Controls_Manager::SELECT,
                            'label'        => esc_html__('Content Width','claniz'),  
                            'options'      => 
                                [ '' => __('Default','claniz')] 
                                + array_combine(range(1, 12), range(1, 12))
                                + ['custom' => __('Custom', 'claniz')]
                            ,
                            'control_type' => 'responsive'
                        ),
                        array(
                            'name'          => 'content_custom_width',
                            'label'         => __('Custom Content Width', 'claniz'),
                            'type'          => \Elementor\Controls_Manager::SLIDER,
                            'control_type'  => 'responsive',
                            'selectors'     => [
                                '{{WRAPPER}} .cms-page-title-content-col' => 'flex:0 0 {{SIZE}}%; width: {{SIZE}}%;'
                            ],
                            'condition' => [
                                'content_col' => ['custom']
                            ],
                            'tablet_default' => [
                                'size' => 100,
                            ],
                            'mobile_default' => [
                                'size' => 100,
                            ],
                        ),
                        claniz_elementor_row_align(),
                        claniz_elementor_text_align([
                            'label' => __('Text Alignment','claniz')
                        ])
                    )
                ),
                array(
                    'name'     => 'subheading_section',
                    'label'    => esc_html__( 'Small Heading', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        claniz_elementor_text_settings([
                            'name'     => 'subheading_text',
                            'label'    => '',
                            'selector' => '.cms-subheading',
                            'effect'   => true,
                            'default'  => '',
                            'custom_width' => true 
                        ])
                    )
                ),
                array(
                    'name'     => 'heading_section',
                    'label'    => esc_html__( 'Large Heading', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        claniz_elementor_text_settings([
                            'name'     => 'heading_text',
                            'label'    => '',
                            'selector' => '.cms-mainheading',
                            'effect'   => true,
                            'default'  => '',
                            'custom_width' => true  
                        ]),
                        array(
                            array(
                                'name'               => 'heading_spacing',
                                'label'              => esc_html__( 'Spacing', 'claniz' ),
                                'type'               => \Elementor\Controls_Manager::DIMENSIONS,
                                'size_units'         => [ 'px'],
                                'allowed_dimensions' => 'vertical',
                                'placeholder'        => [
                                    'top'    => '',
                                    'right'  => 'auto',
                                    'bottom' => '',
                                    'left'   => 'auto',
                                ],
                                'control_type' => 'responsive',
                                'selectors'    => [
                                    '{{WRAPPER}} .cms-mainheading' => 'padding-top: {{TOP}}{{UNIT}}; padding-bottom: {{BOTTOM}}{{UNIT}};',
                                ]
                            )
                        )
                    )
                ),
                array(
                    'name'     => 'desc_section',
                    'label'    => esc_html__( 'Description', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        claniz_elementor_text_settings([
                            'name'         => 'description_text',
                            'label'        => '',
                            'selector'     => '.cms-desc',
                            'effect'       => true,
                            'default'      => '',
                            'custom_width' => true 
                        ])
                    )
                ),
                claniz_elementor_zocdoc_settings([
                    'condition' => [
                        'layout' => ['2']
                    ]
                ]),
                array(
                    'name'     => 'button_section',
                    'label'    => esc_html__( 'Button 01', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        claniz_elementor_button_settings()
                    )
                ),
                array(
                    'name'     => 'button_section2',
                    'label'    => esc_html__( 'Button 02', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        claniz_elementor_button_settings([
                            'prefix'           => 'btn2',
                            'btn_type_default' => 'btn btn-outline',
                            'btn_color'        => 'white',
                            'btn_hover_color'  => 'white'
                        ])
                    )
                ),
                array(
                    'name'     => 'button_section3',
                    'label'    => esc_html__( 'Buttons 03', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        claniz_elementor_button_settings([
                            'prefix'           => 'btn3',
                            'btn_color'        => 'white',
                            'btn_hover_color'  => 'accent'
                        ]) 
                    )
                ),
                array(
                    'name'     => 'video_section',
                    'label'    => esc_html__( 'Button Video', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        claniz_elementor_button_video_settings([
                            'default'   => false,
                            'separator' => '',
                            'effect'    => true,

                        ]), 
                    )
                ),
                array(
                    'name'      => 'icon_section',
                    'tab'       => \Elementor\Controls_Manager::TAB_CONTENT,
                    'label'     => esc_html__('Icon Settings', 'claniz'),
                    'controls' => array(
                        array(
                            'name'    => 'show_icon',
                            'label'   => esc_html__( 'Show Icon', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => [
                                'yes' => esc_html__('Yes', 'claniz'),
                                'no' => esc_html__('No', 'claniz')
                            ],
                            'default' => 'no'
                        ),
                        array(
                            'name'     => 'multi_icons',
                            'label'    => esc_html__('Icons', 'claniz'),
                            'type'     => \Elementor\Controls_Manager::REPEATER,
                            'controls' => array(
                                array(
                                    'name'  => 'multi_icon',
                                    'label' => esc_html__('Icon', 'claniz'),
                                    'type'  => \Elementor\Controls_Manager::ICONS,
                                )
                            ),
                            'default' => [
                                'multi_icon' => [
                                    'value'   => 'claniz-icon-default',
                                    'library' => 'cmsi-claniz'
                                ]
                            ],
                            'condition' => [
                                'show_icon' => ['yes']
                            ],
                            'title_field' => '{{{ elementor.helpers.renderIcon( this, multi_icon, {}, "i", "panel" ) || \'<i class="{{ icon }}" aria-hidden="true"></i>\' }}}'
                        )
                    )
                ),
                array(
                    'name'     => 'breadcrumb_section',
                    'label'    => esc_html__( 'Breadcrumb', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array(
                        array(
                            'name'    => 'show_breadcrumb',
                            'label'   => esc_html__( 'Show Breadcrumb', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => [
                                '' => esc_html__('Default', 'claniz'),
                                '1' => esc_html__('Yes', 'claniz'),
                                'no' => esc_html__('No', 'claniz')
                            ]    
                        ),
                        array(
                            'name'        => 'breadcrumb_link_color',
                            'label'       => esc_html__( 'Breadcrumb Link Color', 'claniz' ),
                            'type'        => \Elementor\Controls_Manager::SELECT,
                            'options'     => claniz_elementor_theme_color_opts(),  
                            'default'     => '',
                            'label_block' => true,
                            'condition'   => [
                                'show_breadcrumb'      => ['', '1']
                            ],
                            'separator'     => 'before'
                        ),
                        array(
                            'name'        => 'breadcrumb_link_custom_color',
                            'label'       => esc_html__( 'Custom Breadcrumb Color', 'claniz' ),
                            'type'        => \Elementor\Controls_Manager::COLOR,
                            'condition'   => [
                                'breadcrumb_link_color'      => 'custom'
                            ],
                        ),
                        array(
                            'name'        => 'breadcrumb_color',
                            'label'       => esc_html__( 'Breadcrumb Color', 'claniz' ),
                            'type'        => \Elementor\Controls_Manager::SELECT,
                            'options'     => claniz_elementor_theme_color_opts(),  
                            'default'     => '',
                            'label_block' => true,
                            'condition'   => [
                                'show_breadcrumb'      => ['','1']
                            ],
                            'separator'     => 'before'
                        ),
                        array(
                            'name'        => 'breadcrumb_custom_color',
                            'label'       => esc_html__( 'Custom Breadcrumb Color', 'claniz' ),
                            'type'        => \Elementor\Controls_Manager::COLOR,
                            'condition'   => [
                                'breadcrumb_color'      => 'custom'
                            ],
                        ),
                    )
                ),
                array(
                    'name'     => 'background_section',
                    'label'    => esc_html__( 'Background', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array(
                        array(
                            'name'        => 'background',
                            'label'       => esc_html__( 'Background Image', 'claniz' ),
                            'description' => esc_html__( 'Choose Background. Default is post feature image', 'claniz' ),
                            'type'        => \Elementor\Controls_Manager::MEDIA ,
                            'default'     => ['url' => '']  
                        ),
                        array(
                            'name'       => 'background_xpos',
                            'label'      => esc_html__( 'Background Left Position (%)', 'claniz' ),
                            'type'       => \Elementor\Controls_Manager::SLIDER,
                            'size_units' => ['%'],
                            'range'      => [
                                '%' => [
                                    'min' => -100,
                                    'max' => 100,
                                ]
                            ],
                            'default'   => [
                                'unit' => '%'
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .cms-page-title-wrapper' => 'background-position-x:{{SIZE}}%'
                            ] 
                        ),
                        array(
                            'name'        => 'background_ypos',
                            'label'       => esc_html__( 'Background Top Position (%)', 'claniz' ),
                            'type'        => \Elementor\Controls_Manager::SLIDER,
                            'size_units' => ['%'],
                            'range'      => [
                                '%' => [
                                    'min' => -100,
                                    'max' => 100,
                                ]
                            ],
                            'default'   => [
                                'unit' => '%'
                            ],
                            'selectors'   => [
                                '{{WRAPPER}} .cms-page-title-wrapper' => 'background-position-y:{{SIZE}}%'
                            ] 
                        ),
                        array(
                            'name'        => 'bg_overlay',
                            'label'       => esc_html__( 'Background Overlay', 'claniz' ),
                            'type'        => \Elementor\Controls_Manager::SELECT,
                            'label_block' => true,
                            'options'     => [
                                ''       => esc_html__('Default', 'claniz'),
                                'none'   => esc_html__('None', 'claniz'),
                                'custom' => esc_html__('Custom', 'claniz')
                            ]
                        ),
                        array(
                            'name'        => 'bg_overlay_color',
                            'label'       => esc_html__( 'Background Overlay Color', 'claniz' ),
                            'type'        => \Elementor\Controls_Manager::COLOR,
                            'options'     => '',  
                            'default'     => '',
                            'condition'   => [
                                'bg_overlay!' => 'none'
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .cms-page-title-gradient' => 'background-color: {{VALUE}};'
                            ]
                        ),
                        array(
                            'name'       => 'bg_overlay_color_stop',
                            'label'      => _x( 'Location', 'Background Control', 'claniz' ),
                            'type'       => \Elementor\Controls_Manager::SLIDER,
                            'size_units' => [ '%' ],
                            'default'    => [
                                'unit' => '%',
                                'size' => 0,
                            ],
                            'render_type' => 'ui',
                            'of_type'     => 'gradient',
                            'condition'   => [
                                'bg_overlay' => ['custom']
                            ],
                        ),
                        array(
                            'name'        => 'bg_overlay_color_b',
                            'label'       => _x( 'Second Color', 'Background Control', 'claniz' ),
                            'type'        => \Elementor\Controls_Manager::COLOR,
                            'default'     => '#f2295b',
                            'render_type' => 'ui',
                            'condition'   => [
                                'bg_overlay' => ['custom']
                            ],
                            'of_type' => 'gradient',
                        ),
                        array(
                            'name'       => 'bg_overlay_color_b_stop',
                            'label'      => _x( 'Location', 'Background Control', 'claniz' ),
                            'type'       => \Elementor\Controls_Manager::SLIDER,
                            'size_units' => [ '%' ],
                            'default'    => [
                                'unit' => '%',
                                'size' => 100,
                            ],
                            'render_type' => 'ui',
                            'condition'   => [
                                'bg_overlay'      => [ 'custom' ],
                            ],
                            'of_type' => 'gradient',
                        ),
                        array(
                            'name'    => 'bg_overlay_type',
                            'label'   => _x( 'Type', 'Background Control', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => [
                                'linear' => _x( 'Linear', 'Background Control', 'claniz' ),
                                'radial' => _x( 'Radial', 'Background Control', 'claniz' ),
                            ],
                            'default'     => 'linear',
                            'render_type' => 'ui',
                            'condition'   => [
                                'bg_overlay'      => [ 'custom' ],
                            ],
                            'of_type' => 'gradient',
                        ),
                        array(
                            'name'       => 'bg_overlay_angle',
                            'label'      => _x( 'Angle', 'Background Control', 'claniz' ),
                            'type'       => \Elementor\Controls_Manager::SLIDER,
                            'size_units' => [ 'deg' ],
                            'default'    => [
                                'unit' => 'deg',
                                'size' => 180,
                            ],
                            'range' => [
                                'deg' => [
                                    'step' => 10,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .cms-page-title-gradient' => 'background-color: transparent; background-image: linear-gradient({{SIZE}}{{UNIT}}, {{bg_overlay_color.VALUE}} {{bg_overlay_color_stop.SIZE}}{{bg_overlay_color_stop.UNIT}}, {{bg_overlay_color_b.VALUE}} {{bg_overlay_color_b_stop.SIZE}}{{bg_overlay_color_b_stop.UNIT}})',
                            ],
                            'condition' => [
                                'bg_overlay'      => [ 'custom' ],
                                'bg_overlay_type' => 'linear',
                            ],
                            'of_type' => 'gradient',
                        ),
                        array(
                            'name'    => 'bg_overlay_position',
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => [
                                'center center' => _x( 'Center Center', 'Background Control', 'claniz' ),
                                'center left'   => _x( 'Center Left', 'Background Control', 'claniz' ),
                                'center right'  => _x( 'Center Right', 'Background Control', 'claniz' ),
                                'top center'    => _x( 'Top Center', 'Background Control', 'claniz' ),
                                'top left'      => _x( 'Top Left', 'Background Control', 'claniz' ),
                                'top right'     => _x( 'Top Right', 'Background Control', 'claniz' ),
                                'bottom center' => _x( 'Bottom Center', 'Background Control', 'claniz' ),
                                'bottom left'   => _x( 'Bottom Left', 'Background Control', 'claniz' ),
                                'bottom right'  => _x( 'Bottom Right', 'Background Control', 'claniz' ),
                            ],
                            'default'   => 'center center',
                            'selectors' => [
                                '{{WRAPPER}} .cms-page-title-gradient' => 'background-color: transparent; background-image: radial-gradient(at {{VALUE}}, {{bg_overlay_color.VALUE}} {{bg_overlay_color_stop.SIZE}}{{bg_overlay_color_stop.UNIT}}, {{bg_overlay_color_b.VALUE}} {{bg_overlay_color_b_stop.SIZE}}{{bg_overlay_color_b_stop.UNIT}})',
                            ],
                            'condition' => [
                                'bg_overlay'      => [ 'custom' ],
                                'bg_overlay_type' => 'radial',
                            ],
                            'of_type' => 'gradient',
                        ),
                    )
                )
            )
        )
    ),
    get_template_directory() . '/elementor/core/widgets/'
);