<?php
// Register Post Grid Widget
etc_add_custom_widget(
    array(
        'name'       => 'cms_post_carousel',
        'title'      => esc_html__( 'CMS Post Carousel', 'claniz' ),
        'icon'       => 'eicon-posts-carousel',
        'categories' => array( Elementor_Theme_Core::ETC_CATEGORY_NAME ),
        'scripts'    => [
            'swiper',
            'cms-swiper',
            'cms-animation'
        ],
        'params' => array(
            'sections' => array(
                claniz_elementor_swiper_slider_settings([
                    'tab' => \Elementor\Controls_Manager::TAB_SETTINGS
                ]),
                array(
                    'name'     => 'layout_section',
                    'label'    => esc_html__( 'Item(s) Layout', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_LAYOUT,
                    'controls' => array(
                        array(
                            'name'    => 'layout',
                            'type'    => Elementor_Theme_Core::LAYOUT_CONTROL,
                            'default' => '1',
                            'options' => claniz_elementor_post_layout(),
                            'prefix_class' => 'cms-post-layout-'
                        ),
                    ),
                ),
                array(
                    'name'     => 'heading_desc_section',
                    'label'    => esc_html__( 'Heading Settings', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        array(
                            //claniz_elementor_text_align(['default' => '']),
                            array(
                                'name'         => 'heading_desc_width_',
                                'label'        => __('Element Heading Width', 'claniz'),
                                'type'         => \Elementor\Controls_Manager::SLIDER,
                                'control_type' => 'responsive',
                                'selectors'    => [
                                    '{{WRAPPER}} .cms-heading-wrap' => 'width:{{SIZE}}{{UNIT}};flex: 0 0 {{SIZE}}{{UNIT}};',
                                    '{{WRAPPER}} .cms-content-wrap' => 'width:calc(100% - {{SIZE}}{{UNIT}});flex: 0 0 calc(100% - {{SIZE}}{{UNIT}});'
                                ],
                                'range' => [
                                    'px' => [
                                        'min' => 0,
                                        'max' => 1920,
                                    ],
                                    '%' => [
                                        'min' => 0,
                                        'max' => 100,
                                    ],
                                ],
                                'size_units' => [ 'px', '%'],
                            ),
                            array(
                                'name'  => 'heading_custom_class',
                                'label' => __('Custom CSS class', 'claniz'),
                                'type'  => \Elementor\Controls_Manager::TEXT,
                            )
                        ),
                        claniz_elementor_element_heading_settings()
                    )
                ),
                array(
                    'name'     => 'source_section',
                    'label'    => esc_html__( 'Source Options', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        array(
                            array(
                                'name'     => 'post_type',
                                'label'    => esc_html__( 'Select Post Type', 'claniz' ),
                                'type'     => \Elementor\Controls_Manager::SELECT,
                                'multiple' => true,
                                'options'  => etc_get_post_type_options(),
                                'default'  => 'post'
                            )
                        ),
                        etc_get_grid_term_by_post_type_options(),
                        array(
                            array(
                                'name'    => 'orderby',
                                'label'   => esc_html__( 'Order By', 'claniz' ),
                                'type'    => \Elementor\Controls_Manager::SELECT,
                                'default' => 'date',
                                'options' => [
                                    'date'   => esc_html__( 'Date', 'claniz' ),
                                    'ID'     => esc_html__( 'ID', 'claniz' ),
                                    'author' => esc_html__( 'Author', 'claniz' ),
                                    'title'  => esc_html__( 'Title', 'claniz' ),
                                    'rand'   => esc_html__( 'Random', 'claniz' ),
                                ],
                            ),
                            array(
                                'name'    => 'order',
                                'label'   => esc_html__( 'Sort Order', 'claniz' ),
                                'type'    => \Elementor\Controls_Manager::SELECT,
                                'default' => 'desc',
                                'options' => [
                                    'desc' => esc_html__( 'Descending', 'claniz' ),
                                    'asc'  => esc_html__( 'Ascending', 'claniz' ),
                                ],
                            ),
                            array(
                                'name'    => 'limit',
                                'label'   => esc_html__( 'Items to show', 'claniz' ),
                                'type'    => \Elementor\Controls_Manager::NUMBER,
                                'default' => '6',
                            )
                        )
                    )
                ),
                array(
                    'name'     => 'thumbnail_section',
                    'label'    => esc_html__( 'Thumbnail Settings', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array(
                        array(
                            'name'         => 'thumbnail',
                            'type'         => \Elementor\Group_Control_Image_Size::get_type(),
                            'control_type' => 'group',
                            'default'      => 'large',
                        )
                    )
                ),
                array(
                    'name' => 'sale_section',
                    'label' => __('Sale Options','claniz'),
                    'tab'  => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array(
                        array(
                            'name' => 'sale_value',
                            'label' => __('Sale Value','claniz'),
                            'type' => \Elementor\Controls_Manager::TEXTAREA,
                            'default' => '25% off',
                        )
                    ),
                    'condition' => [
                        'layout' => ['7']
                    ]
                ),
                array(
                    'name'     => 'excerpt_section',
                    'label'    => esc_html__( 'Excerpt Options', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array(
                        array(
                            'name'      => 'excerpt_lenght',
                            'label'     => esc_html__( 'Excerpt lenght', 'claniz' ),
                            'type'      => \Elementor\Controls_Manager::NUMBER,
                            'default'   => 180,
                            'separator' => 'after',
                        ),
                        array(
                            'name'      => 'excerpt_more_text',
                            'label'     => esc_html__( 'Excerpt more text', 'claniz' ),
                            'type'      => \Elementor\Controls_Manager::TEXT,
                            'default'   => '...',
                            'separator' => 'after',
                        )
                    ),
                ),
                array(
                    'name'     => 'readmore_section',
                    'label'    => esc_html__( 'Read More Options', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => [
                        array(
                            'name'      => 'readmore_text',
                            'label'     => esc_html__( 'Read More Text', 'claniz' ),
                            'type'      => \Elementor\Controls_Manager::TEXT,
                            'default'   => esc_html__('Read More','claniz'),
                            'separator' => 'after',
                        ),
                    ],
                ),
                array(
                    'name'     => 'other_section',
                    'label'    => esc_html__( 'Other Info', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        [
                            array(
                                'name'      => 'other_text',
                                'label'     => esc_html__( 'Text', 'claniz' ),
                                'type'      => \Elementor\Controls_Manager::TEXTAREA,
                            ),
                            array(
                                'name'         => 'other_text_typo',
                                'type'         => \Elementor\Group_Control_Typography::get_type(),
                                'control_type' => 'group',
                                'default'      => '',
                                'selector'     => '{{WRAPPER}} .other-text',
                                'condition' => [
                                    'other_text!' => ''
                                ]
                            ),
                            array(
                                'name'        => 'other_text_color',
                                'label'       => esc_html__( 'Text Color', 'claniz' ),
                                'type'        => \Elementor\Controls_Manager::SELECT,
                                'options'     => claniz_elementor_theme_color_opts(['custom' => false]),  
                                'default'     => '',
                                'selector'     => '{{WRAPPER}} .other-text',
                                'condition'   => [
                                    'other_text!' => ''
                                ]
                            ),
                            array(
                                'name'  => 'other_text_link_desc',
                                'label' => esc_html__( 'Other Info Link', 'claniz' ),
                                'type'  => \Elementor\Controls_Manager::HEADING,
                                'condition' => [
                                    'other_text!' => ''                   
                                ]
                            )
                        ],
                        claniz_elementor_hyperlink_settings([
                            'condition' => [
                                'other_text!' => '',                           
                            ],
                            'prefix'             => 'other_link_',
                            'default_icon_align' => 'right'
                        ])
                    )
                ),
                array(
                    'name'     => 'button_section',
                    'label'    => esc_html__( 'Explore Button', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_CONTENT,
                    'controls' => array_merge(
                        array(
                            array(
                                'name'    => 'explode_button',
                                'label'   => esc_html__('Hyperlink As','claniz'),
                                'type'    => \Elementor\Controls_Manager::SELECT,
                                'options' => [
                                    'text_link' => esc_html__('Text Link','claniz'),
                                    'button'    => esc_html__('Button','claniz')
                                ],
                                'default' => 'button'
                            )
                        ),
                        claniz_elementor_hyperlink_settings([
                            'condition' => [
                                'explode_button' => 'text_link',                           
                            ],
                            'prefix'             => 'explode_button',
                            'default_icon_align' => 'right'
                        ]),
                        claniz_elementor_button_settings([
                            'condition' => [
                                'explode_button'    => 'button'                            
                            ]
                        ])
                    )
                )
            )
        )
    ),
    get_template_directory() . '/elementor/core/widgets/'
);