<?php
/**
 * Functions and definitions
 *
 * @package claniz
 */

if(!function_exists('claniz_require_folder')){
    function claniz_require_folder($foldername,$path = '')
    {
        if($path === '') $path = get_template_directory();
        $dir = $path . DIRECTORY_SEPARATOR . $foldername;
        if (!is_dir($dir)) {
            return;
        }
        $files = array_diff(scandir($dir), array('..', '.'));
        foreach ($files as $file) {
            $patch = $dir . DIRECTORY_SEPARATOR . $file;
            if (file_exists($patch) && strpos($file, ".php") !== false) {
                require_once $patch;
            }
        }
    }
}
claniz_require_folder('inc');
claniz_require_folder('inc/theme-configs');
claniz_require_folder('inc/extends');
if ( ! function_exists( 'claniz_setup' ) ) {
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
    add_action( 'after_setup_theme', 'claniz_setup' );
	function claniz_setup() {
        if(class_exists('Elementor_Theme_Core') || class_exists('Theme_Core_Options')){
            remove_theme_support('widgets-block-editor');
        }
		// Make theme available for translation.
		load_theme_textdomain( 'claniz', get_template_directory() . '/languages' );
		// Custom Header
		add_theme_support( "custom-header" );
		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );
		// Let WordPress manage the document title.
		add_theme_support( 'title-tag' );
		/*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support( 'post-thumbnails' );
        add_image_size( 'cms_none', 0, 0, true );
        // Set post thumbnail size.
        set_post_thumbnail_size( claniz_configs('thumbnail')['post_thumbnail_size_w'], claniz_configs('thumbnail')['post_thumbnail_size_h'] );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'claniz Primary', 'claniz' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
            'script',
            'style'
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'claniz_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for core custom logo.
		add_theme_support( 'custom-logo', array(
			'height'      => claniz_configs('logo')['width'],
			'width'       => claniz_configs('logo')['height'],
			'flex-width'  => true,
			'flex-height' => true,
		) );
		add_theme_support( 'post-formats', array(
			'gallery',
			'video',
		) );
        // Add support for full and wide align images.
        add_theme_support( 'align-wide' );
        // Enable support for WooCommerce.
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );
	}
}
/* Display Custom Image Sizes */
if(!function_exists('claniz_custom_sizes')){
    add_filter('image_size_names_choose','claniz_custom_sizes');
    function claniz_custom_sizes($sizes){
        return array_merge($sizes, array(
            'medium_large' => esc_html__('Medium Large', 'claniz')
        ));
    }
}
if(!function_exists('claniz_update')){
    add_action('after_switch_theme', 'claniz_update');
    function claniz_update(){
        /** Change default image thumbnail sizes in wordpress
         *  'uploads_use_yearmonth_folders' => 0,
         *  'posts_per_page'                => 3
         * 
        */
        $thumbnail_size = array(
            'large_size_w'        => claniz_configs('thumbnail')['large_size_w'],
            'large_size_h'        => claniz_configs('thumbnail')['large_size_h'],
            'large_crop'          => 1, 
            'medium_large_size_w' => claniz_configs('thumbnail')['medium_large_size_w'],
            'medium_large_size_h' => claniz_configs('thumbnail')['medium_large_size_h'],
            'medium_large_crop'   => 1, 
            'medium_size_w'       => claniz_configs('thumbnail')['medium_size_w'],
            'medium_size_h'       => claniz_configs('thumbnail')['medium_size_h'],
            'medium_crop'         => 1, 
            'thumbnail_size_w'    => claniz_configs('thumbnail')['thumbnail_size_w'],
            'thumbnail_size_h'    => claniz_configs('thumbnail')['thumbnail_size_h'],
            'thumbnail_crop'      => 1
        );
        foreach ($thumbnail_size as $option => $value) {
            if (get_option($option, '') != $value)
                update_option($option, $value);
        }
    }
}
/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 */
// Set up the content width value based on the theme's design and stylesheet.
if(!function_exists('claniz_content_width')){
    add_action('after_setup_theme', 'claniz_content_width', 0);
    if (!isset($content_width))
        $content_width = apply_filters('claniz_content_width', claniz_configs('content_width'));
    function claniz_content_width()
    {
        $GLOBALS['content_width'] = apply_filters('claniz_content_width', claniz_configs('content_width'));
    }
}

// Add new menu Locations
add_action( 'cms_locations', function ( $cms_locations ) {
    //$cms_locations['cms-test'] ='Test Menu';
	return $cms_locations;
} );
/**
 * Register widget area.
 */
if(!function_exists('claniz_widgets_init')){
    add_action( 'widgets_init', 'claniz_widgets_init' );
    function claniz_widgets_init() {
    	if(class_exists('Elementor_Theme_Core')){
            $all_post_type = claniz_all_post_types();
            foreach ($all_post_type as $key => $value) {
                register_sidebar( array(
                    'name'          => sprintf( esc_html__( '%s Sidebar', 'claniz' ), $value ),
                    'id'            => 'sidebar-'.$key,
                    'description'   => sprintf(esc_html__( 'Add widgets here to show in %1$s archive page and single %2$s page', 'claniz' ), strtoupper(str_replace('-', ' ', $key)), $value),
                    'class'         => 'cms-post-type-widget',
                    'title_class'   => ''
                ) );
            }
            // Hidden sidebar
            register_sidebar( array(
                'name'          => esc_html__( 'Hidden Sidebar', 'claniz' ),
                'id'            => 'sidebar-hidden',
                'description'   => esc_html__( 'Add widgets here.', 'claniz' ),
                'class'         => 'cms-hidden-widget',
                'title_class'   => ''
            ) );
        } else {
            register_sidebar( array(
                'name'          => esc_html__( 'Blog Widgets', 'claniz' ),
                'id'            => 'sidebar-post',
                'description'   => esc_html__( 'Add widgets here to show on blog/archives/single post page', 'claniz' ),
                'class'         => 'cms-blog-widget',
                'title_class'   => ''
            ) );
            if(class_exists('WooCommerce')){
                register_sidebar( array(
                    'name'          => esc_html__( 'WooCommerce Widgets', 'claniz' ),
                    'id'            => 'sidebar-product',
                    'description'   => esc_html__( 'Add widgets here to show on woocommerce page', 'claniz' ),
                    'class'         => 'cms-blog-widget',
                    'title_class'   => ''
                ) );
            }
        }
    }
}
/**
 * Change default widget title structure
*/
if(!function_exists('claniz_widgets_title')){
    add_filter('widget_display_callback', 'claniz_widgets_structure');
    add_filter('register_sidebar_defaults', 'claniz_widgets_structure');
    function claniz_widgets_structure($args){
        $args = wp_parse_args($args, [
            'title_class' => ''
        ]);
        $widget_title_tag = 'h4';
        $title_class = [
            'cms-widget-title',
            'cms-heading',
            isset($args['title_class']) ? $args['title_class'] : ''
        ];
        $args['before_widget'] = '<div id="%1$s" class="cms-widget cms-radius-7 widget %2$s"><div class="cms-widget-inner">';
        $args['after_widget']  = '</div></div>';
        $args['before_title']  = '<'.$widget_title_tag.' class="'.trim(implode(' ', $title_class)).'">';
        $args['after_title']   = '</'.$widget_title_tag.'>';
        return $args;
    }
}
/**
 * Enqueue scripts and styles.
 */
if(!function_exists('claniz_scripts')){
    add_action( 'wp_enqueue_scripts', 'claniz_scripts');
    function claniz_scripts() {
    	$theme = wp_get_theme( get_template() );
        //var_dump(claniz_get_theme_opt('dev_mode'));
        $dev_mode   = claniz_get_theme_opt('dev_mode', false);
        $speed_up   = claniz_get_theme_opt('speed_up', '1');
        if($dev_mode === '' || $dev_mode === '0' || $dev_mode === false){
            $min = '.min';
        } else {
            $min = '';
        }
        if($speed_up === '1'){
            // theme style
            wp_enqueue_style( 'claniz', get_template_directory_uri() . '/assets/css/theme.all'.$min.'.css', array(), $theme->get( 'Version' ) );
        } else {
            // WooCommerce
            if(class_exists('WooCommerce')){
                wp_enqueue_style( 'claniz-woocommerce', get_template_directory_uri() . '/assets/css/woocommerce'.$min.'.css', array(), $theme->get( 'Version' ) );
            }
            // Elementor 
            if(class_exists('\Elementor\Plugin')){
                wp_enqueue_style( 'claniz-elementor', get_template_directory_uri() . '/assets/css/elementor'.$min.'.css', array(), $theme->get( 'Version' ) );
            }
            // Nomaly
            wp_enqueue_style( 'claniz-normalize', get_template_directory_uri() . '/assets/css/normalize'.$min.'.css', array(), $theme->get( 'Version' ) );   
            // theme boostrap
            wp_enqueue_style( 'claniz-bootstrap', get_template_directory_uri() . '/assets/css/boostrap_theme'.$min.'.css', array(), $theme->get( 'Version' ) );
            // theme style
            wp_enqueue_style( 'claniz', get_template_directory_uri() . '/assets/css/theme'.$min.'.css', array(), $theme->get( 'Version' ) );

             // theme font icon
            wp_enqueue_style( 'font-cmsi', get_template_directory_uri() . '/assets/fonts/font-cmsi/style.css', array(), $theme->get( 'Version' ) );
            wp_enqueue_style( 'font-theme', get_template_directory_uri() . '/assets/fonts/font-theme/style.css', array('claniz'), $theme->get( 'Version' ) );
        }
        wp_add_inline_style( 'claniz', claniz_inline_styles() );

        // WP Comment
        if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
            wp_enqueue_script( 'comment-reply' );
        }
        // Theme JS
        wp_enqueue_script( 'claniz', get_template_directory_uri() . '/assets/js/main'.$min.'.js', array( 'jquery' ), $theme->get( 'Version' ), true );
    	wp_localize_script( 'claniz', 'main_data', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
        
        /*
         * Elementor Widget JS
         */
        // Animation
        wp_enqueue_script('cms-animation', get_template_directory_uri() . '/elementor/js/cms-animation'.$min.'.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        // Accordion
        wp_register_script('cms-accordion', get_template_directory_uri() . '/elementor/js/cms-accordion'.$min.'.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        // Counter
        wp_register_script('cms-counter', get_template_directory_uri() . '/elementor/js/cms-counter'.$min.'.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        // Countdown
        wp_register_script('cms-countdown', get_template_directory_uri() . '/elementor/js/cms-countdown'.$min.'.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        // Post Grid Widget
        wp_register_script('cms-post-grid', get_template_directory_uri() . '/elementor/js/cms-post-grid'.$min.'.js', [ 'isotope', 'jquery' ], $theme->get( 'Version' ), true);
        // Progress Bar Widget
        wp_register_script( 'cms-progressbar', get_template_directory_uri() . '/elementor/js/cms-progressbar'.$min.'.js', [ 'jquery' ], $theme->get( 'Version' ) );
         // Swiper Slider
        wp_enqueue_script('swiper', get_template_directory_uri() . '/elementor/js/swiper/swiper'.$min.'.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        wp_enqueue_script('cms-swiper', get_template_directory_uri() . '/elementor/js/cms-swiper'.$min.'.js', [ 'jquery','swiper' ], $theme->get( 'Version' ), true);
        // Tabs
        wp_register_script('cms-tabs', get_template_directory_uri() . '/elementor/js/cms-tabs'.$min.'.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        // Galleries
        wp_register_script('cms-galleries', get_template_directory_uri() . '/elementor/js/cms-galleries'.$min.'.js', [ 'jquery' ], $theme->get( 'Version' ), true);
        // Chartjs
        wp_register_script( 'chartjs', get_template_directory_uri() . '/elementor/js/chart.min.js', array( 'jquery' ), $theme->get( 'Version' ), true );
        wp_register_script( 'cms-chartjs', get_template_directory_uri() . '/elementor/js/cms-chart'.$min.'.js', array( 'chartjs' ), $theme->get( 'Version' ), true );
        //GSAP
        wp_register_script('gsap', get_template_directory_uri() . '/elementor/js/gsap/gsap.min.js', [ 'jquery' ], '3.11.3', true);
        wp_register_script('gsap-scrolltrigger', get_template_directory_uri() . '/elementor/js/gsap/ScrollTrigger.min.js', [ 'gsap' ], '3.11.3', true);
        wp_register_script('cms-gsap', get_template_directory_uri() . '/elementor/js/cms-gsap'.$min.'.js', [ 'gsap' ], $theme->get( 'Version' ), true);
        // Elementor Custom
        wp_enqueue_script('cms-elementor-custom-js', get_template_directory_uri() . '/elementor/js/elementor-custom'.$min.'.js', [ 'jquery' ], $theme->get( 'Version' ), true);
    }
}

if(!function_exists('claniz_admin_enqueue')){
    add_action('admin_enqueue_scripts', 'claniz_admin_enqueue');
    function claniz_admin_enqueue(){
        $theme = wp_get_theme(get_template());
        // theme font icon
        wp_enqueue_style( 'font-cmsi', get_template_directory_uri() . '/assets/fonts/font-cmsi/style.css', array(), $theme->get( 'Version' ) );
        wp_enqueue_style( 'font-theme', get_template_directory_uri() . '/assets/fonts/font-theme/style.css', array(), $theme->get( 'Version' ) );
        //Get Start
        wp_enqueue_style('claniz-get-started-css', get_template_directory_uri() . '/assets/admin/get-started.css');
        wp_enqueue_script('claniz-get-started-js', get_template_directory_uri() . '/assets/admin/get-started.js', ['jquery'], $theme->get('Version'), true);
        wp_localize_script('claniz-get-started-js', 'main_data', array('ajax_url' => admin_url('admin-ajax.php')));
    }
}

// Custom Elementor Editor
add_action( 'elementor/editor/before_enqueue_scripts', function() {
    wp_enqueue_style( 'claniz-elementor-custom-editor', get_template_directory_uri() . '/assets/admin/elementor-custom-editor.css', array(), '1.0.0' );
});

/**
 * Register Google Fonts
 *
 * https://gist.github.com/kailoon/e2dc2a04a8bd5034682c
 * https://themeshaper.com/2014/08/13/how-to-add-google-fonts-to-wordpress-themes/
 *
*/
function claniz_fonts_url() {
    $fonts_url = '';
    $fonts     = array();
    $subsets   = 'latin,latin-ext';
    if ( 'off' !== _x( 'on', 'Barlow font: on or off', 'claniz' ) ) {
        $fonts[] = 'Barlow:wght@100;0,200;0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,100;1,200;1,300;1,400;1,500;1,600;1,700;1,800;1,900';
    }

    if ( 'off' !== _x( 'on', 'Caveat font: on or off', 'claniz' ) ) {
        $fonts[] = 'Caveat:wght@400;500;600;700';
    }
    if ( 'off' !== _x( 'on', 'Roboto font: on or off', 'claniz' ) ) {
        $fonts[] = 'Roboto:ital,wght@0,100;0,300;0,400;0,500;0,700;0,900;1,100;1,300;1,400;1,500;1,700;1,900';
    }
    if ( $fonts ) {
        $fonts_url = add_query_arg( array(
            'family' => urlencode( implode( '|', $fonts ) ),
            //'family' => claniz_configs('google_fonts'),
            'subset' => urlencode( $subsets ),
        ), 'https://fonts.googleapis.com/css2' );
    }
    return $fonts_url;
}
if(!function_exists('claniz_fonts_extra')){
    add_action('wp_footer', 'claniz_fonts_extra', 1, 1);
    function claniz_fonts_extra(){
        ?>
            <link rel="preconnect" href="https://fonts.googleapis.com">
            <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
            <link href="https://fonts.googleapis.com/css2?family=Barlow:wght@400;500;600;700;800&family=Caveat:wght@400;500;600;700&family=Roboto:ital,wght@0,400;0,700;1,400;1,700&display=swap" rel="stylesheet">
        <?php
    }
}
/**
 * Incudes file
 *
*/
claniz_require_folder('assets/fonts'); // theme option icon font
claniz_require_folder('inc/theme-options');
claniz_require_folder('inc/post-type-options');
claniz_require_folder('inc/classes');
/**
 * Additional widgets for the theme
 */
claniz_require_folder('widgets');
/**
 * Custom post type
*/
claniz_require_folder('inc/custom-post');
/**
 * Elementor
*/
claniz_require_folder('inc/elementor');
/**
 *  Woocommerce
 */
if(class_exists('Woocommerce')){
    claniz_require_folder('woocommerce');
}
/**
 * other extensions
*/
claniz_require_folder('inc/extensions');
/**
 * Remove all Font Awesome from 3rd extension 
 * to use only font-awesome latest from our theme
 * //'font-awesome',
 * //'gglcptch',
*/
if(!function_exists('etc_remove_styles')){
    add_action( 'wp_enqueue_scripts', 'etc_remove_styles', 999 );
    add_action( 'wp_footer', 'etc_remove_styles', 999 );
    add_action( 'wp_header', 'etc_remove_styles', 999 );
    function etc_remove_styles() {
        $default = ['gglcptch' ];
        $styles  = apply_filters( 'etc_remove_styles', $default );
        foreach ( $styles as $style ) {
            wp_dequeue_style( $style );
            wp_deregister_style( $style );
        }
    }
}
if(!function_exists('claniz_remove_styles')){
    add_filter('etc_remove_styles', 'claniz_remove_styles');
    function claniz_remove_styles($styles){
        $_styles = [
            // gutenberg
            //'wp-block-library',
            // newsletter
            'newsletter',
            //cf7
            'contact-form-7',
            // elementor
            'elementor-frontend-legacy',
            // woo
            'woocommerce-smallscreen',
            'woocommerce-general',
            'woocommerce-layout',
            'wc-blocks-vendors-style',
            'wc-blocks-style',
            // theme core
            'oc-css',
            'etc-main-css',
            'progressbar-lib-css',
            // language switcher
            'trp-floater-language-switcher-style',
            'trp-language-switcher-style',
            // Elementor Theme Core
            'slick-css',
        ];
        if(!is_user_logged_in()){
            $_styles[] = 'elementor-icons';
        }
        $styles = array_merge($styles, $_styles);
        return $styles;
    }
}
/*
 * Get Started
 */
require_once get_template_directory() . '/inc/get-started.php';
/*
 * Get Started
 */