<?php
if ( ! class_exists( 'Theme_Core_Options' ) ) {
	return;
}

class CSS_Generator {
	/**
     * scssc class instance
     *
     * @access protected
     * @var scssc
     */
    protected $scssc = null;

    /**
     * Debug mode is turn on or not
     *
     * @access protected
     * @var boolean
     */
    protected $dev_mode = true;

    /**
     * opt_name
     *
     * @access protected
     * @var string
     */
    protected $opt_name = '';

	/**
	 * Constructor
	 */
	function __construct() {
		$this->opt_name = claniz_get_theme_opt_name();

		if ( empty( $this->opt_name ) ) {
			return;
		}
		$this->dev_mode = claniz_get_theme_opt( 'dev_mode', '0' ) === '1' ? true : false;
		add_filter( 'cms_scssc_lib', function(){ return 'new';} ); // old => new 
		add_filter( 'cms_scssc_on', '__return_true' );
		add_action( 'init', array( $this, 'init' ) );
	}

	/**
	 * init hook - 10
	 */
	function init() {
		if ( ! class_exists( '\Leafo\ScssPhp\Compiler' ) )
        {
            return;
        }
		add_action( 'wp', array( $this, 'generate_with_dev_mode' ) );
		
	}

	function generate_with_dev_mode() {
		if ( $this->dev_mode === true ) {
			$this->generate_file(); 
			$this->generate_min_file(); 
		}
	}

	/**
	 * Generate options and css files
	 */
	function generate_file() {
        require_once(ABSPATH . 'wp-admin/includes/file.php');
        global $wp_filesystem;
        if ( ! is_a( $wp_filesystem, 'WP_Filesystem_Base') ){
            $creds = request_filesystem_credentials( site_url() );
            wp_filesystem($creds);
        }
        // Main Theme
		$scss_dir = get_template_directory() . '/assets/scss/';
		$css_dir  = get_template_directory() . '/assets/css/';
        // Child Theme
        $child_scss_dir = get_stylesheet_directory() . '/assets/scss/';
        $child_css_dir  = get_stylesheet_directory() . '/assets/css/';
        $child_css_file = $child_css_dir . 'child-theme.css';

        // Build CSS
		$this->scssc = new \Leafo\ScssPhp\Compiler();
		
        if(is_child_theme()){
            $this->scssc->setImportPaths( $child_scss_dir );
        } else {
            $this->scssc->setImportPaths( $scss_dir );
        }
		$_options = $scss_dir . 'theme-options.scss';

        $wp_filesystem->put_contents(
            $_options,
            preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->options_output() ),
            FS_CHMOD_FILE
        );

        $boostrap_css_file = $css_dir . 'boostrap_theme.css';
        $normalize_file    = $css_dir . 'normalize.css';
        $css_file          = $css_dir . 'theme.css';
        $css_all_file      = $css_dir . 'theme.all.css';
        $elementor_file    = $css_dir . 'elementor.css';
        $woocommerce_file  = $css_dir . 'woocommerce.css';

		/**
         * build source map
         * this used for load scss file when dev_mode is on
         * @source: https://github.com/leafo/scssphp/wiki/Source-Maps
        */
        $this->scssc->setFormatter('Leafo\ScssPhp\Formatter\Nested');

        if(is_child_theme()){
            $this->scssc->setSourceMap(\Leafo\ScssPhp\Compiler::SOURCE_MAP_FILE);
            $this->scssc->setSourceMapOptions(array(
                'sourceMapWriteTo'  => $child_css_file . ".map",
                'sourceMapURL'      => "child-theme.css.map",
                'sourceMapFilename' => $child_css_file,
                'sourceMapBasepath' => $child_scss_dir,
                'sourceRoot'        => $child_scss_dir,
            ));
            $wp_filesystem->put_contents(
                $child_css_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "child-theme.scss"' ) ),
                FS_CHMOD_FILE
            );
        } else {
            // Normalize
            $this->scssc->setSourceMap(\Leafo\ScssPhp\Compiler::SOURCE_MAP_FILE);
            $this->scssc->setSourceMapOptions(array(
                'sourceMapWriteTo'  => $normalize_file . ".map",
                'sourceMapURL'      => "normalize.css.map",
                'sourceMapFilename' => $normalize_file,
                'sourceMapBasepath' => $scss_dir,
                'sourceRoot'        => $scss_dir,
            ));
            $wp_filesystem->put_contents(
                $normalize_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "normalize.scss"' ) ),
                FS_CHMOD_FILE
            );
            // Boostrap
            $this->scssc->setSourceMap(\Leafo\ScssPhp\Compiler::SOURCE_MAP_FILE);
            $this->scssc->setSourceMapOptions(array(
                'sourceMapWriteTo'  => $boostrap_css_file . ".map",
                'sourceMapURL'      => "boostrap_theme.css.map",
                'sourceMapFilename' => $boostrap_css_file,
                'sourceMapBasepath' => $scss_dir,
                'sourceRoot'        => $scss_dir,
            ));
            $wp_filesystem->put_contents(
                $boostrap_css_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "_boostrap_theme.scss"' ) ),
                FS_CHMOD_FILE
            );
            // Theme
            $this->scssc->setSourceMap(\Leafo\ScssPhp\Compiler::SOURCE_MAP_FILE);
            $this->scssc->setSourceMapOptions(array(
                'sourceMapWriteTo'  => $css_file . ".map",
                'sourceMapURL'      => "theme.css.map",
                'sourceMapFilename' => $css_file,
                'sourceMapBasepath' => $scss_dir,
                'sourceRoot'        => $scss_dir,
            ));
            $wp_filesystem->put_contents(
                $css_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "theme.scss"' ) ),
                FS_CHMOD_FILE
            );
            // Elementor
            $this->scssc->setSourceMap(\Leafo\ScssPhp\Compiler::SOURCE_MAP_FILE);
            $this->scssc->setSourceMapOptions(array(
                'sourceMapWriteTo'  => $elementor_file . ".map",
                'sourceMapURL'      => "elementor.css.map",
                'sourceMapFilename' => $elementor_file,
                'sourceMapBasepath' => $scss_dir,
                'sourceRoot'        => $scss_dir,
            ));
            $wp_filesystem->put_contents(
                $elementor_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "elementor.scss"' ) ),
                FS_CHMOD_FILE
            );
            // WooCommerce
            $this->scssc->setSourceMap(\Leafo\ScssPhp\Compiler::SOURCE_MAP_FILE);
            $this->scssc->setSourceMapOptions(array(
                'sourceMapWriteTo'  => $woocommerce_file . ".map",
                'sourceMapURL'      => "woocommerce.css.map",
                'sourceMapFilename' => $woocommerce_file,
                'sourceMapBasepath' => $scss_dir,
                'sourceRoot'        => $scss_dir,
            ));
            $wp_filesystem->put_contents(
                $woocommerce_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "woocommerce.scss"' ) ),
                FS_CHMOD_FILE
            );
            // All
            $this->scssc->setSourceMap(\Leafo\ScssPhp\Compiler::SOURCE_MAP_FILE);
            $this->scssc->setSourceMapOptions(array(
                'sourceMapWriteTo'  => $css_all_file . ".map",
                'sourceMapURL'      => "theme.all.css.map",
                'sourceMapFilename' => $css_all_file,
                'sourceMapBasepath' => $scss_dir,
                'sourceRoot'        => $scss_dir,
            ));
            $wp_filesystem->put_contents(
                $css_all_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "theme.all.scss"' ) ),
                FS_CHMOD_FILE
            );
        }
	}
	/**
     * Generate options and css files
     */
    function generate_min_file(){   
        require_once(ABSPATH . 'wp-admin/includes/file.php');
        global $wp_filesystem;
        if ( ! is_a( $wp_filesystem, 'WP_Filesystem_Base') ){
            $creds = request_filesystem_credentials( site_url() );
            wp_filesystem($creds);
        }
        // Theme
        $scss_dir          = get_template_directory() . '/assets/scss/';
        $css_dir           = get_template_directory() . '/assets/css/';
        $normalize_file    = $css_dir . 'normalize.min.css';
        $boostrap_css_file = $css_dir . 'boostrap_theme.min.css';
        $css_file          = $css_dir . 'theme.min.css';
        $css_all_file      = $css_dir . 'theme.all.min.css';
        $elementor_file    = $css_dir . 'elementor.min.css';
        $woocommerce_file  = $css_dir . 'woocommerce.min.css';

        // Child Theme
        $child_scss_dir = get_stylesheet_directory() . '/assets/scss/';
        $child_css_dir  = get_stylesheet_directory() . '/assets/css/';
        $child_css_file = $child_css_dir . 'child-theme.min.css';

        $this->scssc = new \Leafo\ScssPhp\Compiler();
        if(is_child_theme()){
            $this->scssc->setImportPaths( $child_scss_dir );
        } else {
            $this->scssc->setImportPaths( $scss_dir );
        }

        $this->scssc->setFormatter( 'Leafo\ScssPhp\Formatter\Crunched' );
        
        if(is_child_theme()){
            $wp_filesystem->put_contents(
                $child_css_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "child-theme.scss"' ) ),
                FS_CHMOD_FILE
            );
        } else {
            // Normalize
            $wp_filesystem->put_contents(
                $normalize_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "normalize.scss"' ) ),
                FS_CHMOD_FILE
            );
            // Boostrap
            $wp_filesystem->put_contents(
                $boostrap_css_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "_boostrap_theme.scss"' ) ),
                FS_CHMOD_FILE
            );
            // Theme
            $wp_filesystem->put_contents(
                $css_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "theme.scss"' ) ),
                FS_CHMOD_FILE
            );
            // Elementor
            $wp_filesystem->put_contents(
                $elementor_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "elementor.scss"' ) ),
                FS_CHMOD_FILE
            );
            // WooCommerce
            $wp_filesystem->put_contents(
                $woocommerce_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "woocommerce.scss"' ) ),
                FS_CHMOD_FILE
            );
            // Child Theme
            if(is_child_theme()){
                $wp_filesystem->put_contents(
                    $css_file,
                    preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "child-theme.scss"' ) ),
                    FS_CHMOD_FILE
                );
            }
            // All
            $wp_filesystem->put_contents(
                $css_all_file,
                preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "theme.all.scss"' ) ),
                FS_CHMOD_FILE
            );
        }
    }
	/**
	 * Output options to _variables.scss
	 *
	 * @access protected
	 * @return string
	 */
	protected function print_scss_opt($variable){
		if(is_array($variable)){
			$x = [];
			foreach ($variable as $key => $value) {
                if(is_array($value)) $value = $value['value'];
				$x[] =  '\''.$key.'\':\''.$value.'\'';
			}
			return implode(',', $x);
		} else {
			return $variable;
		}
	}
    protected function print_scss_opt_unqoute($variable){
        if(is_array($variable)){
            $x = [];
            foreach ($variable as $key => $value) {
                if(is_array($value)) $value = $value['value'];
                $x[] =  '\''.str_replace('#', '',$key).'\':'.$value;
            }
            return implode(',', $x);
        } else {
            return $variable;
        }
    }
    protected function print_scss_opt_colors($variable){
        if(is_array($variable)){
            $x = [];
            foreach ($variable as $key => $value) {
                if(is_array($value)) $value = $value['value'];
                $x[] =  '\''.str_replace('#', '',$key).'\':var(--color-'.str_replace('#', '',$key).')';
            }
            return implode(',', $x);
        } else {
            return $variable;
        }
    }
    function print_single_scss_opt() {
        ob_start();
        // CSS Variable
        $theme_colors = claniz_theme_colors();
        $link_color   = claniz_get_opts('link_color', claniz_configs('link_color'));
        $body         = claniz_configs('body');
        $heading      = claniz_configs('heading');
        $heading2     = claniz_configs('heading2');
        $button       = claniz_configs('button');
        $meta         = claniz_configs('meta');
        $border       = claniz_configs('border');
        $shadow       = claniz_configs('shadow');
        $gradient     = claniz_configs('gradient');
        $comment      = claniz_configs('comment');
        $header       = claniz_configs('header');
            // color rgb only
            foreach ($theme_colors as $key => $value) {
                printf('$%1$s_color_hex: %2$s;', str_replace(['#',' '], [''], $key), $value); 
            }
            // color
            foreach ($theme_colors as $key => $value) {
                printf('$%1$s_color: %2$s;', str_replace(['#',' '], [''],$key), 'var(--color-'.str_replace(['#',' '], [''],$key).')' );
            }
            // link color
            foreach ($link_color as $key => $value) {
                printf('$link_%1$s_color: %2$s;', $key, 'var(--link-'.$key.'-color)');
            }
            foreach ($body as $key => $value) {
                printf('$body-%1$s: %2$s;', $key, 'var(--body-'.$key.')');
            }
            foreach ($heading as $key => $value) {
                if(!is_array($value)) {
                    printf('$heading-%1$s: var(--heading-%2$s);', $key, $key);
                } else {
                    foreach ($value as $_key => $_value) {
                        printf('$heading-%1$s-%2$s: var(--heading-%1$s-%2$s);', str_replace('_', '-', $key), $_key);
                    }
                }
            }
            foreach ($heading2 as $key => $value) {
                if(!is_array($value)) {
                    printf('$heading2-%1$s: var(--heading2-%2$s);', $key, $key);
                } else {
                    foreach ($value as $_key => $_value) {
                        printf('$heading2-%1$s-%2$s: var(--heading2-%1$s-%2$s);', str_replace('_', '-', $key), $_key);
                    }
                }
            }
            foreach ($button as $key => $value) {
                printf('$button-%1$s: %2$s;', $key, $value);
            }
            foreach ($meta as $key => $value) {
                printf('$meta-%1$s: %2$s;', $key, $value);
            }
            foreach ($border as $key => $value) {
                printf('$border-%1$s: %2$s;', $key, $value);
                if($key === 'color'){
                    printf('$border-%1$s-rgb: %2$s;', $key, $value);
                }
            }
            foreach ($comment as $key => $value) {
                printf('$comment-%1$s: %2$s;', $key, $value);
            }
            foreach ($header as $key => $value) {
                printf('$header-%1$s: %2$s;', $key, 'var(--header-'.$key.')');
            }	
        return ob_get_clean();
    }

	protected function options_output() {
		ob_start();
		// Theme colors
        $theme_colors = wp_parse_args(claniz_theme_colors(), claniz_custom_colors() );
		printf('$cms_theme_colors:(%s);',$this->print_scss_opt_colors($theme_colors));
        // Link colors
        printf('$link_color:(%s);',$this->print_scss_opt(claniz_configs('link_color')));
		// Theme spacings
        printf('$cms_theme_spacings:(%s);',$this->print_scss_opt_unqoute(claniz_configs('theme_spacings')));
        // Gradient
        printf('$cms_theme_gradient:(%s);',$this->print_scss_opt_unqoute(claniz_configs('gradient'), true));
        // Shadow
        printf('$theme_shadow:(%s);',$this->print_scss_opt_unqoute(claniz_configs('shadow')));
        // Radius
        printf('$cms_theme_radius:(%s);',$this->print_scss_opt(claniz_configs('radius')));
        // single css options
        printf('%s', $this->print_single_scss_opt());
		return ob_get_clean();
	}
}

new CSS_Generator();