<?php
/**
 * Get page title and description.
 *
 * @return array Contains 'title'
 */
function claniz_get_page_titles() {
	$title = '';
	// Default titles
	if ( ! is_archive() ) {
		// Posts page view
		if ( is_home() ) {
			// Only available if posts page is set.
			if ( ! is_front_page() && $page_for_posts = get_option( 'page_for_posts' ) ) {
				$title = get_post_meta( $page_for_posts, 'custom_title', true );
				if ( empty( $title ) ) {
					$title = get_the_title( $page_for_posts );
				}
			}
			if ( is_front_page() ) {
				$title = esc_html__( 'Welcome to', 'claniz' ).' '.get_bloginfo('name');
			}
		} elseif ( is_404() ) {
			$title = esc_html__( '404', 'claniz' );
		} elseif ( is_search() ) {
			$title = esc_html__( 'Search results', 'claniz' );
		} else {
			$title = get_post_meta( get_the_ID(), 'custom_title', true );
			if(is_singular('post') && empty($title)) {
				$title = esc_html__('Blog Post', 'claniz'); 
				// get_the_title(); 
			} elseif ( ! $title ) {
				$title = get_the_title();
			} else {
				$title = $title; //get_the_title();
			}
		}
		$sub_title = get_post_meta( get_the_ID(), 'custom_sub_title', true );
	} elseif ( is_author() ) {
		//esc_html__( 'Author:', 'claniz' ) . ' ' .
		$title     = get_the_author();
		$sub_title = claniz_get_opts('custom_sub_title');
	} else {
		$custom_title = claniz_get_opts('custom_title');
		$_title = single_term_title('', false);
		if( (class_exists( 'WooCommerce' ) && is_shop()) ) {
			$_title = esc_html__( 'Our Products', 'claniz' );
		}
		$title = !empty($custom_title) ? $custom_title : $_title;
		$sub_title = claniz_get_opts('custom_sub_title');
	}
	return array(
		'title'     => $title,
		'sub_title' => $sub_title
	);
}

// Remove "Category:", "Tag:", "Author:" from the_archive_title
add_filter( 'get_the_archive_title', function ($title) {    
    if ( is_category() ) {    
            $title = single_cat_title( '', false );    
        } elseif ( is_tag() ) {    
            $title = single_tag_title( '', false );    
        } elseif ( is_author() ) {    
            $title = '<span class="vcard">' . get_the_author() . '</span>' ;    
        } elseif ( is_tax() ) { //for custom post types
            $title = sprintf( '%1$s' , single_term_title( '', false ) );
        } elseif (is_post_type_archive()) {
            $title = post_type_archive_title( '', false );
        }
    return $title;    
});