<?php
if(!function_exists('claniz_add_cpt_support')){
    add_action( 'after_switch_theme', 'claniz_add_cpt_support');
    function claniz_add_cpt_support() {
        $cpt_support = array_merge((array)get_option( 'elementor_cpt_support'), ['cms-footer','cms-header-top', 'cms-mega-menu' ]);
        update_option( 'elementor_cpt_support', $cpt_support );
    }
}
// Add custom field to section
if(!function_exists('claniz_custom_section_params')){
    add_filter('etc-custom-section/custom-params', 'claniz_custom_section_params'); 
    function claniz_custom_section_params(){
        return array(
            'sections' => array(
                array(
                    'name'     => 'cms_custom_layout',
                    'label'    => esc_html__( 'Claniz Custom Settings', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_LAYOUT,
                    'controls' => array(
                        // make section Stretched with Space from Start/End
                        array(
                            'name'         => 'stretched_with_space',
                            'label'        => esc_html__( 'Full Width space from?', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SELECT,
                            'prefix_class' => 'cms-section-stretched-with-space-',
                            'options'      => array(
                                'none'    => esc_html__( 'None', 'claniz'),
                                'start'   => esc_html__( 'Start', 'claniz'),
                                'end'     => esc_html__( 'End', 'claniz')
                            ),
                            'default'      => 'none',
                            'condition' => [
                                'stretch_section' => 'section-stretched'
                            ]
                        ),
                        // make section full content with a space on start / end
                        array(
                            'name'         => 'full_content_with_space',
                            'label'        => esc_html__( 'Full Content with space from?', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SELECT,
                            'prefix_class' => 'cms-full-content-with-space-',
                            'options'      => array(
                                'none'    => esc_html__( 'None', 'claniz' ),
                                'start'   => esc_html__( 'Start', 'claniz' ),
                                'end'     => esc_html__( 'End', 'claniz' ),
                                'start-wide'   => esc_html__( 'Start (Container Wide)', 'claniz' ),
                                'end-wide'     => esc_html__( 'End (Container Wide)', 'claniz' ),
                            ),
                            'default'      => 'none',
                            'condition' => [
                                'layout' => 'full_width'
                            ]
                        ),
                        // this field hasn't config prefix_class
                        // its value will be handled at claniz_custom_section_classes function
                        // screen shot - http://prntscr.com/tjco9g
                        array(
                            'name'    => 'column_hori_align',
                            'label'   => esc_html__( 'Horizontal Align', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::SELECT,
                            'options' => array(
                                ''        => esc_html__( 'Default', 'claniz' ),
                                'start'   => esc_html__( 'Start', 'claniz' ),
                                'center'  => esc_html__( 'Center', 'claniz' ),
                                'end'     => esc_html__( 'End', 'claniz' ),
                                'around'  => esc_html__( 'Space Around', 'claniz' ),
                                'between' => esc_html__( 'Space Between', 'claniz' )
                            ),
                            'prefix_class' => 'cms-justify-content-',
                            'default'      => '',
                        ),
                        array(
                            'name'         => 'cms_boxed_bg',
                            'label'        => esc_html__( 'Boxed Background', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SWITCHER,
                            'prefix_class' => 'cms-boxed-bg-',
                            'default'      => 'false',
                            'separator'    => 'before'
                        ),
                        array(
                            'name'       => 'cms_boxed_radius',
                            'label'      => esc_html__( 'Boxed Radius', 'claniz' ),
                            'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%' ],
                            'selectors'  => [
                                '{{WRAPPER}}.cms-boxed-bg-true > .cms-section-boxed-bg' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                            'condition' => [
                                'cms_boxed_bg' => 'true'
                            ]
                        ),
                        claniz_elementor_overlay([
                            'name'      => 'default_cms_boxed_overlay',
                            'condition' => [
                                'cms_boxed_bg' => 'true'
                            ],
                            'default'      => '2',
                            'prefix_class' => 'cms-boxed-overlay-gradient-'
                        ]),
                        array(
                            'name'      => 'cms_boxed_overlay',
                            'label'     => esc_html__( 'Overlay Color','claniz' ),
                            'type'      => \Elementor\Controls_Manager::COLOR,
                            'default'   => '',
                            'selectors' => [
                                '{{WRAPPER}} > .cms-section-boxed-bg:before' => 'background-color: {{VALUE}};',
                            ],
                            'condition' => [
                                'default_cms_boxed_overlay' => 'custom',
                            ], 
                        ),
                        array(
                            'name'           => 'cms_boxed_overlay_gradient',
                            'label'          => esc_html__( 'Overlay Gradient Color','claniz' ),
                            'type'           => \Elementor\Group_Control_Background::get_type(),
                            'control_type'   => 'group',
                            'types'          => [ 'gradient' ],
                            'fields_options' => [
                                'background' => [
                                    'frontend_available' => true,
                                ],
                            ],
                            'selector' => '{{WRAPPER}} > .cms-section-boxed-bg:after',
                            'condition' => [
                                'default_cms_boxed_overlay' => 'custom',
                            ]
                        ),
                        array(
                            'name'         => 'cms_boxed_bg_background',
                            'title'        => esc_html__( 'Boxed Background', 'claniz' ),
                            'type'         => \Elementor\Group_Control_Background::get_type(),
                            'control_type' => 'group',
                            'types'         => [ 'classic' ],
                            'fields_options' => [
                                'background' => [
                                    'frontend_available' => true,
                                ],
                            ],
                            'selector'  => '{{WRAPPER}} > .cms-section-boxed-bg',
                            'condition'    => [
                                'cms_boxed_bg' => 'true',
                            ]
                        ),
                        array(
                            'name'         => 'cms_boxed_divider',
                            'label'        => esc_html__( 'Divider', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SWITCHER,
                            'prefix_class' => 'cms-section-boxed-divider-',
                            'default'      => 'false',
                            'separator'    => 'before'
                        ),
                        array(
                            'name'         => 'cms_boxed_divider_pos',
                            'label'        => esc_html__( 'Divider Position', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SELECT,
                            'prefix_class' => 'cms-section-boxed-divider-',
                            'options'      => [
                                'top'    => esc_html__('Top', 'claniz'),
                                'bottom' => esc_html__('Bottom', 'claniz')
                            ],
                            'default'      => 'bottom',
                            'condition' => [
                                'cms_boxed_divider' => 'true'
                            ]
                        ),
                        array(
                            'name'         => 'cms_boxed_divider_color',
                            'label'        => esc_html__('Divider Color', 'claniz'),
                            'type'         => \Elementor\Controls_Manager::SELECT,
                            'default'      => '',
                            'options'      => claniz_elementor_theme_color_opts(),
                            'prefix_class' => 'cms-boxed-divider-color-',
                            'condition' => [
                                'cms_boxed_divider'       => 'true'
                            ]
                        ),
                        array(
                            'name'      => 'cms_boxed_divider_color_custom',
                            'label'     => esc_html__( 'Custom Divider Color','claniz' ),
                            'type'      => \Elementor\Controls_Manager::COLOR,
                            'default'   => '',
                            'selectors' => [
                                '{{WRAPPER}} > .cms-section-boxed-divider' => 'background-color: {{VALUE}};',
                            ],
                            'condition' => [
                                'cms_boxed_divider'       => 'true',
                                'cms_boxed_divider_color' => 'custom'
                            ]
                        ),
                        array(
                            'name'         => 'cms_boxed_divider_width',
                            'label'        => esc_html__( 'Divider Width', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SELECT,
                            'prefix_class' => 'cms-section-boxed-divider-width-',
                            'options'      => [
                                'elementor-container' => __('Default', 'claniz'),
                                'boxed'               => __('Boxed', 'claniz'),
                                'full'                => __('Full', 'claniz')
                            ],
                            'default'      => 'elementor-container',
                            'condition' => [
                                'cms_boxed_divider' => 'true'
                            ]
                        ),
                        array(
                            'name'         => 'cms_boxed_divider_h',
                            'label'        => esc_html__( 'Divider Height', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SLIDER,
                            'control_type' => 'responsive',
                            'range'        => [
                                'px' => [
                                    'min'  => 1,
                                    'max'  => 300,
                                    'step' => 1,
                                ],
                            ],
                            'default' => [
                                'size' => '100',
                            ],
                            'size_units' => [ 'px'],
                            'selectors' => [
                                '{{WRAPPER}} > .cms-section-boxed-divider' => 'height: {{SIZE}}{{UNIT}};',
                            ],
                            'condition' => [
                                'cms_boxed_divider' => 'true'
                            ] 
                        ),
                        array(
                            'name'         => 'cms_elementor_corner',
                            'label'        => esc_html__( 'Show Section Corner', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SELECT,
                            'prefix_class' => 'cms-row-corner-',
                            'options'      => array(
                                'yes' => __( 'Yes', 'claniz'),
                                'no'  => __( 'No', 'claniz')
                            ),
                            'default'   => 'no',
                            'separator' => 'before'
                        ),
                        array(
                            'name'         => 'cms_elementor_corner_size',
                            'label'        => esc_html__( 'Section Corner Dimensions', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SLIDER,
                            'size_units' => ['px'],
                            'range' => [
                                'px' => [
                                    'min' => -1000,
                                    'max' => 1000,
                                    'step' => 1,
                                ]
                            ],
                            'default' => [
                                'size' => '80',
                            ],
                            'selectors'  => [
                                '{{WRAPPER}}.cms-row-corner-yes .cms-elementor-section-corner-top' => 'width: {{SIZE}}{{UNIT}}; height:{{SIZE}}{{UNIT}};',
                            ],
                            'separator' => 'before',
                            'condition' => [
                                'cms_elementor_corner' => 'yes',
                            ]
                        ),
                        array(
                            'name'        => 'cms_elementor_corner_color',
                            'label'       => esc_html__( 'Color', 'claniz' ),
                            'type'        => \Elementor\Controls_Manager::SELECT,
                            'options'     => claniz_elementor_theme_color_opts(),
                            'condition'    => [
                                'cms_elementor_corner' => 'yes',
                            ],
                            'prefix_class' => 'cms-elementor-section-corner-'
                        ),  
                        array(
                            'name'        => 'cms_elementor_corner_custom_color',
                            'label'       => esc_html__( 'Custom Color', 'claniz' ),
                            'type'        => \Elementor\Controls_Manager::COLOR,
                            'condition'   => [
                                'cms_elementor_corner_color' => 'custom'
                            ],
                            'selectors'  => [
                                '{{WRAPPER}}.cms-row-corner-yes .cms-elementor-section-corner' => 'background-color:{{VALUE}};'
                            ]
                        ),
                        array(
                            'name'    => 'cms_elementor_corner_offset_orientation_h',
                            'label'   => esc_html__( 'Horizontal Orientation', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::CHOOSE,
                            'toggle'  => false,
                            'default' => 'start',
                            'options' => [
                                'start' => [
                                    'title' => is_rtl() ? esc_html__( 'Right', 'claniz' ) : esc_html__( 'Left', 'claniz' ),
                                    'icon' => 'eicon-h-align-left',
                                ],
                                'end' => [
                                    'title' => ! is_rtl() ? esc_html__( 'Right', 'claniz' ) : esc_html__( 'Left', 'claniz' ),
                                    'icon' => 'eicon-h-align-right',
                                ],
                            ],
                            'classes' => 'elementor-control-start-end',
                            'render_type' => 'ui',
                            'condition' => [
                                'cms_elementor_corner' => 'yes',
                            ],
                        ),
                        [
                            'name'  => 'cms_elementor_corner_offset_x',
                            'label' => esc_html__( 'Offset', 'claniz' ),
                            'type'  => \Elementor\Controls_Manager::SLIDER,
                            'range' => [
                                'px' => [
                                    'min' => -1000,
                                    'max' => 1000,
                                    'step' => 1,
                                ],
                                '%' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                                'vw' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                                'vh' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                            ],
                            'default' => [
                                'size' => '0',
                            ],
                            'size_units' => [ 'px', '%', 'vw', 'vh' ],
                            'selectors' => [
                                'body:not(.rtl) {{WRAPPER}}.cms-row-corner-yes .cms-elementor-section-corner-top' => 'left: {{SIZE}}{{UNIT}}',
                                'body.rtl {{WRAPPER}}.cms-row-corner-yes  .cms-elementor-section-corner-top' => 'right: {{SIZE}}{{UNIT}}',
                            ],
                            'condition' => [
                                'cms_elementor_corner_offset_orientation_h!' => 'end',
                                'cms_elementor_corner' => 'yes',
                            ],
                        ],

                        [
                            'name'  => 'cms_elementor_corner_offset_x_end',
                            'label' => esc_html__( 'Offset', 'claniz' ),
                            'type'  => \Elementor\Controls_Manager::SLIDER,
                            'range' => [
                                'px' => [
                                    'min' => -1000,
                                    'max' => 1000,
                                    'step' => 0.1,
                                ],
                                '%' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                                'vw' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                                'vh' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                            ],
                            'default' => [
                                'size' => '0',
                            ],
                            'size_units' => [ 'px', '%', 'vw', 'vh' ],
                            'selectors' => [
                                'body:not(.rtl) {{WRAPPER}}.cms-row-corner-yes .cms-elementor-section-corner-top' => 'right: {{SIZE}}{{UNIT}}',
                                'body.rtl {{WRAPPER}}.cms-row-corner-yes .cms-elementor-section-corner-top' => 'left: {{SIZE}}{{UNIT}}',
                            ],
                            'condition' => [
                                'cms_elementor_corner_offset_orientation_h' => 'end',
                                'cms_elementor_corner' => 'yes',
                            ],
                        ],

                        [
                            'name'    => 'cms_elementor_corner_offset_orientation_v',
                            'label'   => esc_html__( 'Vertical Orientation', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::CHOOSE,
                            'toggle'  => false,
                            'default' => 'start',
                            'options' => [
                                'start' => [
                                    'title' => esc_html__( 'Top', 'claniz' ),
                                    'icon' => 'eicon-v-align-top',
                                ],
                                'end' => [
                                    'title' => esc_html__( 'Bottom', 'claniz' ),
                                    'icon' => 'eicon-v-align-bottom',
                                ],
                            ],
                            'render_type' => 'ui',
                            'condition' => [
                                'cms_elementor_corner' => 'yes',
                            ],
                        ],
                        [
                            'name'  => 'cms_elementor_corner_offset_y',
                            'label' => esc_html__( 'Offset', 'claniz' ),
                            'type'  => \Elementor\Controls_Manager::SLIDER,
                            'range' => [
                                'px' => [
                                    'min' => -1000,
                                    'max' => 1000,
                                    'step' => 1,
                                ],
                                '%' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                                'vh' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                                'vw' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                            ],
                            'size_units' => [ 'px', '%', 'vh', 'vw' ],
                            'default' => [
                                'size' => '0',
                            ],
                            'selectors' => [
                                '{{WRAPPER}}.cms-row-corner-yes .cms-elementor-section-corner-top' => 'top: {{SIZE}}{{UNIT}}',
                            ],
                            'condition' => [
                                'cms_elementor_corner_offset_orientation_v!' => 'end',
                                'cms_elementor_corner' => 'yes',
                            ],
                        ],
                        [
                            'name'  => 'cms_elementor_corner_offset_y_end',
                            'label' => esc_html__( 'Offset', 'claniz' ),
                            'type'  => \Elementor\Controls_Manager::SLIDER,
                            'range' => [
                                'px' => [
                                    'min' => -1000,
                                    'max' => 1000,
                                    'step' => 1,
                                ],
                                '%' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                                'vh' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                                'vw' => [
                                    'min' => -200,
                                    'max' => 200,
                                ],
                            ],
                            'size_units' => [ 'px', '%', 'vh', 'vw' ],
                            'default' => [
                                'size' => '0',
                            ],
                            'selectors' => [
                                '{{WRAPPER}}.cms-row-corner-yes .cms-elementor-section-corner-top' => 'bottom: {{SIZE}}{{UNIT}}',
                            ],
                            'condition' => [
                                'cms_elementor_corner_offset_orientation_v' => 'end',
                                'cms_elementor_corner' => 'yes',
                            ],
                            'separator' => 'after'
                        ]
                    )
                ),
                array(
                    'name'     => 'cms_custom_layout_background_overlay',
                    'label'    => esc_html__( 'Custom Background Overlay', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_STYLE,
                    'controls' => array(
                        array(
                            'name'         => 'cms_overlay_background_position',
                            'label'        => esc_html__( 'Overlay position', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SELECT,
                            'prefix_class' => 'cms-section-overvlay-with-space cms-section-overvlay-with-space-',
                            'options'      => array(
                                'full'    => esc_html__( 'Full', 'claniz'),
                                'start'   => esc_html__( 'Full - Space Start', 'claniz'),
                                'end'     => esc_html__( 'Full - Space End', 'claniz'),
                                'between' => esc_html__( 'Full - Space Between', 'claniz')
                            ),
                            'default'      => 'full'
                        ),
                        array(
                            'name'      => 'cms_overlay_background_color',
                            'label'     => esc_html__( 'Background Overlay Color','claniz' ),
                            'type'      => \Elementor\Controls_Manager::COLOR,
                            'default'   => '',
                            'selectors' => [
                                '{{WRAPPER}} > .elementor-background-overlay:before' => 'background-color: {{VALUE}};',
                            ]
                        ),
                        array(
                            'name'    => 'cms_overlay_background_color_opacity',
                            'label'   => esc_html__( 'Opacity', 'claniz' ),
                            'type'    => \Elementor\Controls_Manager::SLIDER,
                            'default' => [
                                'size' => 0.85,
                            ],
                            'range' => [
                                'px' => [
                                    'max' => 1,
                                    'step' => 0.01,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} > .elementor-background-overlay:before' => 'opacity: {{SIZE}};',
                            ]
                        ),
                        array(
                            'name'       => 'cms_overlay_background_radius',
                            'label'      => esc_html__( 'Border Radius', 'claniz' ),
                            'type'       => \Elementor\Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%' ],
                            'selectors'  => [
                                '{{WRAPPER}} > .elementor-background-overlay, {{WRAPPER}} > .elementor-background-overlay:before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ]
                        )
                    ),
                    'condition' => [
                        'background_overlay_background' => [ 'classic', 'gradient' ],
                    ]
                ),
                array(
                    'name'     => 'claniz_custom_shapes_top_color',
                    'label'    => esc_html__( 'Custom Shapes Top Color', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_STYLE,
                    'controls' => array(
                        array(
                            'name'         => 'claniz_custom_shapes_color',
                            'label'        => esc_html__( 'Background Color', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-top' => 'background-color: {{VALUE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_color1',
                            'label'        => esc_html__( 'Color #1', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-top .cms-wave1 use' => 'fill: {{VALUE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_color1_opacity',
                            'label'        => esc_html__( 'Color #1 Opacity', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SLIDER,
                            'range'        => [
                                'px' => [
                                    'min'  => 0,
                                    'max'  => 1,
                                    'step' => 0.01,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-top .cms-wave1' => 'opacity: {{SIZE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_color2',
                            'label'        => esc_html__( 'Color #2', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-top .cms-wave2 use' => 'fill: {{VALUE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_color2_opacity',
                            'label'        => esc_html__( 'Color #2 Opacity', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SLIDER,
                            'range'        => [
                                'px' => [
                                    'min'  => 0,
                                    'max'  => 1,
                                    'step' => 0.01,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-top .cms-wave2' => 'opacity: {{SIZE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_color3',
                            'label'        => esc_html__( 'Color #3', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-top .cms-wave3 use' => 'fill: {{VALUE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_color3_opacity',
                            'label'        => esc_html__( 'Color #3 Opacity', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SLIDER,
                            'range'        => [
                                'px' => [
                                    'min'  => 0,
                                    'max'  => 1,
                                    'step' => 0.01,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-top .cms-wave3' => 'opacity: {{SIZE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_color4',
                            'label'        => esc_html__( 'Color #4', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-top .cms-wave4 use' => 'fill: {{VALUE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_color4_opacity',
                            'label'        => esc_html__( 'Color #4 Opacity', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SLIDER,
                            'range'        => [
                                'px' => [
                                    'min'  => 0,
                                    'max'  => 1,
                                    'step' => 0.01,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-top .cms-wave4' => 'opacity: {{SIZE}};',
                            ]
                        )
                    ),
                    'condition' => [
                        'shape_divider_top' => ['cms-waves']
                    ]
                ),
                array(
                    'name'     => 'claniz_custom_shapes_bottom_colors',
                    'label'    => esc_html__( 'Custom Shapes Bottom Color', 'claniz' ),
                    'tab'      => \Elementor\Controls_Manager::TAB_STYLE,
                    'controls' => array(
                        array(
                            'name'         => 'claniz_custom_shapes_bottom_color',
                            'label'        => esc_html__( 'Background Color', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-bottom' => 'background-color: {{VALUE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_bottom_color1',
                            'label'        => esc_html__( 'Color #1', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-bottom .cms-wave1 use' => 'fill: {{VALUE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_bottom_color1_opacity',
                            'label'        => esc_html__( 'Color #1 Opacity', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SLIDER,
                            'range'        => [
                                'px' => [
                                    'min'  => 0,
                                    'max'  => 1,
                                    'step' => 0.01,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-bottom .cms-wave1' => 'opacity: {{SIZE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_bottom_color2',
                            'label'        => esc_html__( 'Color #2', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-bottom .cms-wave2 use' => 'fill: {{VALUE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_bottom_color2_opacity',
                            'label'        => esc_html__( 'Color #2 Opacity', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SLIDER,
                            'range'        => [
                                'px' => [
                                    'min'  => 0,
                                    'max'  => 1,
                                    'step' => 0.01,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-bottom .cms-wave2' => 'opacity: {{SIZE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_bottom_color3',
                            'label'        => esc_html__( 'Color #3', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-bottom .cms-wave3 use' => 'fill: {{VALUE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_bottom_color3_opacity',
                            'label'        => esc_html__( 'Color #3 Opacity', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SLIDER,
                            'range'        => [
                                'px' => [
                                    'min'  => 0,
                                    'max'  => 1,
                                    'step' => 0.01,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-bottom .cms-wave3' => 'opacity: {{SIZE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_bottom_color4',
                            'label'        => esc_html__( 'Color #4', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-bottom .cms-wave4 use' => 'fill: {{VALUE}};',
                            ]
                        ),
                        array(
                            'name'         => 'claniz_custom_shapes_bottom_color4_opacity',
                            'label'        => esc_html__( 'Color #4 Opacity', 'claniz' ),
                            'type'         => \Elementor\Controls_Manager::SLIDER,
                            'range'        => [
                                'px' => [
                                    'min'  => 0,
                                    'max'  => 1,
                                    'step' => 0.01,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .elementor-shape-bottom .cms-wave4' => 'opacity: {{SIZE}};',
                            ]
                        )
                    ),
                    'condition' => [
                        'shape_divider_bottom' => ['cms-waves']
                    ]
                ),
                array(
                    'name'     => 'cms_default_row_overlay',
                    'tab'      => \Elementor\Controls_Manager::TAB_STYLE,
                    'label'    => esc_html__( 'Default Overlay', 'claniz' ),
                    'controls' => array(
                        claniz_elementor_overlay()
                    )
                )
            )
        );
    }
}
function claniz_elementor_overlay($args = []){
    $args = wp_parse_args($args,[
        'name'         => 'cms_overlay_gradient',
        'prefix_class' => 'cms-overlay-gradient-',
        'condition'    => '',
        'default'      => '' 
    ]);
    return array(
        'name'         => $args['name'],
        'label'        => esc_html__( 'Overlay Gradient', 'claniz' ),
        'type'         => \Elementor\Controls_Manager::SELECT,
        'prefix_class' => $args['prefix_class'],
        'options'      => array(
            ''       => __( 'None', 'claniz'),
            '1'      => __( 'Primary', 'claniz'),
            '2'      => __( 'Accent (Top to Bottom)', 'claniz'),
            '2-2'    => __( 'Accent (Bottom to Top)', 'claniz'),
            '3'      => __( 'Lighten Accent', 'claniz'),
            '4'      => __( 'Secondary (Top to Bottom)', 'claniz'),
            '5'      => __( 'Secondary (Bottom to Top)', 'claniz'),
            'custom' => __( 'Custom', 'claniz')
        ),
        'default'   => $args['default'],
        'condition' => $args['condition']
    );
}
// Custom HTML Elementor ROW (Backend)
if(!function_exists('claniz_elementor_section_custom_html')){
    add_filter('etc-custom-section/before-elementor-row', 'claniz_elementor_section_custom_html', 11 , 2);
    function claniz_elementor_section_custom_html( $html, $settings){
        $html .= '<div class="cms-overlay-gradient"></div>';
        $html .= '<div class="cms-section-boxed-bg"></div>';
        $html .= '<div class="cms-section-boxed-divider"></div>';
        $html .= '<div class="cms-elementor-section-corner cms-elementor-section-corner-top"></div>';
        $html .= '<div class="cms-elementor-section-corner cms-elementor-section-corner-bottom"></div>';
        return $html;
    }
}
// Custom HTML Elementor ROW (Frontend)
if(!function_exists('claniz_elementor_section_custom_html_render')){
    add_filter('etc-custom-section/before-elementor-row-render', 'claniz_elementor_section_custom_html_render', 11 , 2);
    function claniz_elementor_section_custom_html_render( $html, $settings){
        // Overlay Gradient
        if($settings['cms_overlay_gradient'] != ''){
            $html .= '<div class="cms-overlay-gradient"></div>';
        }
        // Boxed Background
        if($settings['cms_boxed_bg'] === 'true' || $settings['cms_boxed_bg'] === true){
            $html .= '<div class="cms-section-boxed-bg"></div>';
        }
        // Boxed Divider
        if($settings['cms_boxed_divider'] === 'true'){
            $html .= '<div class="cms-section-boxed-divider"></div>';
        }
        // Corner
        if($settings['cms_elementor_corner'] === 'yes'){
            $html .= '<div class="cms-elementor-section-corner cms-elementor-section-corner-top"></div>';
            $html .= '<div class="cms-elementor-section-corner cms-elementor-section-corner-bottom"></div>';
        }
        // Return
        return $html;
    }
}


// Custom Shape 
if(!function_exists('claniz_elementor_shapes')){
    add_filter('elementor/shapes/additional_shapes', 'claniz_elementor_shapes');
    function claniz_elementor_shapes($shapes){
        $shapes = [
            'cms-waves' => [
                'title'        => _x( 'CMS Waves', 'Shapes', 'claniz' ),
                'has_negative' => true,
                'url'          => get_template_directory_uri().'/assets/svg/cms-waves.svg',
                'path'         => get_template_directory().'/assets/svg/cms-waves.svg'
            ],
            'cms-waves2' => [
                'title'        => _x( 'CMS Waves2', 'Shapes', 'claniz' ),
                'has_negative' => true,
                'url'          => get_template_directory_uri().'/assets/svg/cms-waves2.svg',
                'path'         => get_template_directory().'/assets/svg/cms-waves2.svg'
            ]
        ];
        return $shapes;
    }
}