<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package claniz
 */

/**
 * Setup default image sizes after the theme has been activated
 */
function claniz_after_setup_theme()
{

}
add_action( 'after_setup_theme', 'claniz_after_setup_theme' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function claniz_body_classes( $classes )
{   
    if(claniz_get_opts('body_font','default') !== 'default'){
        $classes[] = 'cms-body-font-'.claniz_get_opts('body_font','default');
    }
    if(claniz_get_opts('heading_font','default') !== 'default'){
        $classes[] = 'cms-heading-font-'.claniz_get_opts('heading_font','default');
    }
    if(claniz_get_opts('sub_heading_font','default') !== 'default'){
        $classes[] = 'cms-subheading-font-'.claniz_get_opts('sub_heading_font','default');
    }
    return $classes;
}
add_filter( 'body_class', 'claniz_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @param array $classes Classes for the post element.
 * @return array
 */
function claniz_posts_classes( $classes )
{
    if(has_post_thumbnail())
        $classes[] = 'cms-has-post-thumbnail';
    else 
        $classes[] = 'cms-no-post-thumbnail';

    return $classes;
}
add_filter( 'post_class', 'claniz_posts_classes' );
/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function claniz_pingback_header()
{
    if ( is_singular() && pings_open() )
    {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'claniz_pingback_header' );