<?php
/**
 * get all post type
 * used for register sidebar for each post type
*/
if(!function_exists('claniz_all_post_types')){
    function claniz_all_post_types(){
        $default_post_type = [
            'post' => esc_html__('Post','claniz'),
            'page' => esc_html__('Page','claniz')
        ];
        $custom_post_type = function_exists('etc_get_post_type_options') ? etc_get_post_type_options() : [];

        if ( class_exists( 'Woocommerce' ) ) {
            $custom_post_type['product'] = esc_html__('WooCommerce','claniz');
        }
        $all_post_type = array_unique(array_merge($default_post_type, $custom_post_type));

        return $all_post_type;
    }
}

if(!function_exists('claniz_etc_get_post_types')){
    add_filter('etc_get_post_types', 'claniz_etc_get_post_types');
    function claniz_etc_get_post_types($exclude_post_type){
        $exclude_post_type = [
            'cms-footer',
            'cms-header-top',
            'e-landing-page'
        ];
        return $exclude_post_type;
    }
}

/**
 * Output html
*/
if(!function_exists('claniz_html')){
    function claniz_html($html){
        return $html;
    }
}

/**
 * Get custom post type taxonomy: TAXONOMIES
 *
 * @since 1.0.0
*/
if(!function_exists('claniz_get_custom_post_taxonomies')){
    function claniz_get_custom_post_taxonomies($post_type, $key)
    {
        $tax_names = get_object_taxonomies($post_type);
        $result    = '';
        if(is_array($tax_names))
        {
            foreach ($tax_names as $name)
                if(strpos($name , $key) !== false)
                {
                    $result = $name;
                    break;
                }
        }
        return $result;
    }
}
/**
 * Get custom post type taxonomy: CAT
 *
 * @since 1.0.0
*/
if(!function_exists('claniz_get_custom_post_cat_taxonomy')){
    function claniz_get_custom_post_cat_taxonomy()
    {
        $post = get_post();
        $tax_names = get_object_taxonomies($post);
        $result = 'category';
        if(is_array($tax_names))
        {
            foreach ($tax_names as $name)
                if(strpos($name,'cat') !== false)
                {
                    $result = $name;
                    break;
                }
        }
        return $result;
    }
}

/**
 * Get custom post type taxonomy: TAGS
 *
 * @since 1.0.0
*/
if(!function_exists('claniz_get_custom_post_tag_taxonomy')){
    function claniz_get_custom_post_tag_taxonomy()
    {
        $post = get_post();
        $tax_names = get_object_taxonomies($post);
        $result = 'post_tag';
        if(is_array($tax_names))
        {
            foreach ($tax_names as $name)
                if(strpos($name,'tag') !== false)
                {
                    $result = $name;
                    break;
                }
        }
        return $result;
    }
}

/**
 * Get post type taxonomies list
*/
function claniz_get_taxo_slug_as_css_class($args = [])
{
    $args = wp_parse_args($args, ['id' => null, 'taxo' => 'category']);
    $post = get_post( $args['id'] );
    $terms = get_terms([
        'taxonomy' => $args['taxo']
    ]);
    $classes = [];
    if ( is_object_in_taxonomy( $post->post_type, $args['taxo'] ) ) {
        foreach ( (array) get_the_terms( $post->ID, $args['taxo'] ) as $term ) {
            if ( empty( $term->slug ) ) {
                     continue;
            }
            $term_class = sanitize_html_class( $term->slug );
            if ( is_numeric( $term_class ) || ! trim( $term_class, '-' ) ) {
                $term_class = $term->term_id;
            }
            $classes[] =  sanitize_html_class($term_class);
        }
    }
    return implode(' ', $classes);
}

/**
 * Terms List
*/
function claniz_terms($args=[]){
    $args = wp_parse_args($args, [
        'id'    => null,
        'link'  => true,
        'taxo'  => 'category',
        'sep'   => ', ',
        'before' => '',
        'after'  => '' 
    ]);
    if(empty($args['id'])) $args['id'] = get_the_ID();
    $term_list = get_the_term_list( $args['id'], $args['taxo'], $args['before'], $args['sep'], $args['after']);
    $term_obj_list = get_the_terms( $args['id'], $args['taxo']);
    if ( is_wp_error( $term_list ) ) {
        return false;
    }

    if($args['link'] === true){
       $terms_string = $term_list;
    } else {
        $terms_string = $args['before'].join($args['sep'], wp_list_pluck($term_obj_list, 'name')).$args['after'];
    }

    echo apply_filters('claniz_terms', $terms_string);
}

/**
 * Get term ID by slug
 * @param $post_type
 * @param $taxo_key, example category -> get: cat , post_tag -> get: tag, portfolio-category -> get: cat
 * @param $term_slugs //string of slug,  separare by comma
 * @return array
 *
*/
function claniz_get_term_id_by_slug($post_type, $taxo_key, $term_slugs){
    if(empty($term_slugs)) return;
    $term_slugs = explode(',', $term_slugs);
    $term_ids = [];
    foreach ($term_slugs as $slug) {
        $term = get_term_by('slug', $slug, claniz_get_custom_post_taxonomies( $post_type , $taxo_key));
        if(isset($term->term_id)) $term_ids[] = $term->term_id;
    }
    return $term_ids;
}

/**
 * Get taxonomy query for post query
 *
*/
function claniz_tax_query($post_type, $taxonomies, $taxonomies_exclude ){
    $tax_query = array();    
    if(!empty($taxonomies) || !empty($taxonomies_exclude)) {
        $terms              = get_object_taxonomies( $post_type );
        if(count($terms) > 1){
            $tax_query['relation'] = 'OR'; 
        }
        foreach ($terms as $term) {
            $real_terms_args = [
                'taxonomy' => claniz_get_custom_post_taxonomies( $post_type , $term), 
                'exclude'  => claniz_get_term_id_by_slug($post_type, $term, $taxonomies_exclude)
            ];
            if(!empty($taxonomies))  $real_terms_args['slug'] = explode(',', $taxonomies);
            $_real_terms = get_terms($real_terms_args);
            $real_terms = [];
            foreach ($_real_terms as $_real_term) {
                $real_terms[] = $_real_term->slug;
            }             
            if(!empty($real_terms) && strpos($term, 'cat') !== false ){
                $tax_query[] = array(
                    'taxonomy' => $term,
                    'field'    => 'slug',
                    'terms'    => $real_terms,
                    'relation' => 'IN',
                );
            }
        }
    }
    return $tax_query;
}
/**
 * Loop Page 
*/
function claniz_is_loop(){
    if(is_home() || is_archive() || is_author() || is_category() || is_post_type_archive() || is_tag() || is_tax() || is_search())
        return true;
    else 
        return false;
}

// Custom Attributes 
if(!function_exists('claniz_parse_custom_attributes')){
    function claniz_parse_custom_attributes( $attributes_string, $delimiter = ',' ) {
        $attributes = explode( $delimiter, $attributes_string );
        $result = [];

        foreach ( $attributes as $attribute ) {
            $attr_key_value = explode( '|', $attribute );

            $attr_key = mb_strtolower( $attr_key_value[0] );

            // Remove any not allowed characters.
            preg_match( '/[-_a-z0-9]+/', $attr_key, $attr_key_matches );

            if ( empty( $attr_key_matches[0] ) ) {
                continue;
            }

            $attr_key = $attr_key_matches[0];

            // Avoid Javascript events and unescaped href.
            if ( 'href' === $attr_key || 'on' === substr( $attr_key, 0, 2 ) ) {
                continue;
            }

            if ( isset( $attr_key_value[1] ) ) {
                $attr_value = trim( $attr_key_value[1] );
            } else {
                $attr_value = '';
            }

            $result[ $attr_key ] = $attr_value;
        }

        return $result;
    }
}

/**
 * Merge array
*/
function claniz_array_merge_recursive($array1, $array2){
    $claniz_array_merge_recursive = array_merge_recursive($array1, $array2);
    $atts = [];
    foreach ($claniz_array_merge_recursive as $key => $value) {
        if(is_array($value)) $value = implode(' ', $value);
        $atts[] = $key.'="'.$value.'"';
    }
    return $atts;
}

/**
 * Nice css class from string 
*/
if(!function_exists('claniz_nice_class')){
    function claniz_nice_class( $class, $fallback = '-' ) {
        if(is_array($class)) $class = implode(' ', $class);
        // Strip out any %-encoded octets.
        $sanitized = preg_replace( '|%[a-fA-F0-9][a-fA-F0-9]|', ' ', $class );
        // Limit to A-Z, a-z, 0-9, '_', '-'.
        $sanitized = preg_replace( '/[^A-Za-z0-9_-]/', ' ', $sanitized );
        // remove multiple space
        $sanitized = preg_replace('/[[:blank:]]+/',' ', $sanitized );
        // remove left/right space
        $sanitized = trim($sanitized);
        // Fallback
        if ( '' === $sanitized && $fallback ) {
            return sanitize_html_class( $fallback );
        }
        /**
         * Filters a sanitized HTML class string.
         *
         * @since 1.0
         *
         * @param string $sanitized The sanitized HTML class.
         * @param string $class     HTML class before sanitization.
         * @param string $fallback  The fallback string.
         */
        return apply_filters( 'claniz_nice_class', $sanitized, $class, $fallback );
    }
}