<?php
/**
 * Ajax paginate links
*/
if(!function_exists('claniz_ajax_paginate_links')){
    function claniz_ajax_paginate_links($link){
        $parts = parse_url($link);
        parse_str($parts['query'], $query);
        if(isset($query['page']) && !empty($query['page'])){
            return '#' . $query['page'];
        }
        else{
            return '#1';
        }
    }
}

/**
 * AJAX HTML for pagination
*/
if(!function_exists('claniz_get_pagination_html')){
    add_action( 'wp_ajax_claniz_get_pagination_html', 'claniz_get_pagination_html' );
    add_action( 'wp_ajax_nopriv_claniz_get_pagination_html', 'claniz_get_pagination_html' );
    function claniz_get_pagination_html(){
        try{
            if(!isset($_POST['query_vars'])){
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'claniz'));
            }
            $query = new WP_Query($_POST['query_vars']);
            ob_start();
           		claniz_posts_pagination( $query,  true );
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status'  => true,
                    'message' => esc_html__('Load Pagination Successfully!', 'claniz'),
                    'data'    => array(
                        'html'       => $html,
                        'query_vars' => $_POST['query_vars'],
                        'post'       => $query->have_posts()
                    ),
                )
            );
        }
        catch (Exception $e){
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}

// Post Layout 
if(!function_exists('claniz_get_post_grid')){
    function claniz_get_post_grid($posts = [], $settings = [], $args = []){
        if(empty($posts) || !is_array($posts) || empty($settings) || !is_array($settings)){
            return false;
        }
        extract($settings);
        if($thumbnail_size != 'custom'){
            $img_size = $thumbnail_size;
        }
        elseif(!empty($thumbnail_custom_dimension['width']) || !empty($thumbnail_custom_dimension['height'])){
            if(empty($thumbnail_custom_dimension['width'])){
                $thumbnail_custom_dimension['width'] = $thumbnail_custom_dimension['height'];
            }
            if(empty($thumbnail_custom_dimension['height'])){
                $thumbnail_custom_dimension['height'] = $thumbnail_custom_dimension['width'];
            }
            $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
        }
        else{
            $img_size = 'full';
        }
        $_col_xl  = isset($settings['col_xl']) ? (12 / intval($settings['col_xl'])) : 4;
        $_col_lg  = isset($settings['col_lg']) ? (12 / intval($settings['col_lg'])) : 3;
        $_col_md  = isset($settings['col_md']) ? (12 / intval($settings['col_md'])) : 2;
        $_col_sm  = isset($settings['col_sm']) ? (12 / intval($settings['col_sm'])) : 1;

        $col_xl  = isset($settings['col_xl']) ? intval($settings['col_xl']) : 4;
        $col_lg  = isset($settings['col_lg']) ? intval($settings['col_lg']) : 3;
        $col_md  = isset($settings['col_md']) ? intval($settings['col_md']) : 2;
        $col_sm  = isset($settings['col_sm']) ? intval($settings['col_sm']) : 1;

        $args = wp_parse_args($args, [
            'item_class' => trim(implode(' ', ['cms-grid-item', 'col-xl-'.$_col_xl, 'col-lg-'.$_col_lg, 'col-md-'.$_col_md, 'col-sm-'.$_col_sm]))
        ]);

        $custom_item_class = isset($args['custom_item_class']) ? $args['custom_item_class'] : '';
        $item_class = trim(implode(' ' , [$args['item_class'], $custom_item_class]));
        $settings['gap_extra'] = empty($settings['gap_extra']) ? '0' : $settings['gap_extra'];
        //style
        $style = 'style="';
        if(isset($settings['masonry_mode']) && !empty($settings['gap'])){
            $style .= 'padding:'.($settings['gap']/2).'px;';
        }
        if($settings['gap_extra']!== '0'){
            $style .= 'margin-bottom:'.$settings['gap_extra'].'px;';
        }
        $style .= '"';

        // Start build post item 
        $count = 0;
        // Media class
        $img_pos_xl = $img_pos_lg = $img_pos_md = $img_pos_sm = '';
        
        foreach ($posts as $post):
            $count ++;
            $last_xl = $last_lg = $last_md = $last_sm = $last = '';
            
            if($count % $col_xl === 0) $last_xl = 'last-xl';
            if($count % $col_lg === 0) $last_lg = 'last-lg';
            if($count % $col_md === 0) $last_md = 'last-md';
            if($count % $col_sm === 0) $last_sm = 'last-sm';
            if($count % $limit === 0) $last = 'last';

            $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));
            ?>
            <div class="<?php echo claniz_nice_class(implode(' ', [$item_class, $filter_class, 'item-'.$count, $last_xl,$last_lg, $last_md, $last_sm, $last])); ?>" <?php etc_print_html($style); ?>>
                <div class="cms-item-content bg-white cms-transition clearfix cms-shadow-2 cms-shadow-hover-1"><?php 
                    claniz_post_media([
                        'post_id'    => $post->ID, 
                        'size'       => $img_size,
                        'class'      => '',
                        'img_class'  => 'w-100',
                        'after'      => claniz_post_category([
                            'post_id'       => $post->ID,
                            'taxo'          => claniz_get_custom_post_taxonomies($post->post_type, 'cat'),
                            'class'         => 'absolute bg-accent text-white text-13 link-white link-hover-white p-tb-10 p-lr-15',
                            'show_icon'     => false,
                            'echo'          => false   
                        ])
                     ]); ?>
                    <div class="cms-item-content-inner p-20 p-xl-50">
                        <div class="cms-post-meta row gutters-10 text-13 text-616161 pt-10 pb-30"><?php
                            claniz_post_date([
                                'post_id'   => $post->ID,
                                'class'     => 'col-auto',
                                'show_icon' => false,
                                'after'     => '<span class="col-auto align-self-center separator"><span class="cms-meta-separator"></span></span>'
                            ]);
                            claniz_post_author([
                                'post_id'       => $post->ID,
                                'class'         => 'col-auto link-accent',
                                'show_icon'     => false    
                            ]);
                        ?></div>
                        <h4 class="cms-item-content-title cms-heading text-primary text-20 lh-29 mb-8 mt-n5">
                            <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                        </h4>
                        <div class="cms-item-content-excerpt mb-35"><?php
                            if(!empty($post->post_excerpt)){
                                claniz_post_excerpt([
                                    'content' => $post->post_excerpt,
                                    'length'  => $settings['excerpt_lenght'],
                                    'more'    => $settings['excerpt_more_text'] 
                                ]);
                                //echo wp_trim_words( $post->post_excerpt, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                            }
                            else{
                                $content = strip_shortcodes( $post->post_content );
                                $content = apply_filters( 'the_content', $content );
                                $content = str_replace(']]>', ']]&gt;', $content);
                                //echo wp_trim_words( $content, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                claniz_post_excerpt([
                                    'content' => $post->post_content,
                                    'length'  => $settings['excerpt_lenght'],
                                    'more'    => $settings['excerpt_more_text']
                                ]);
                            }
                        ?></div>
                        <?php 
                        if(!empty($settings['readmore_text'])){ ?>
                            <div class="cms-btn-wraps cms-post-item-readmore cms-transition">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-readmore btn btn- btn-outline btn-hover-primary text-primary">
                                    <span class="cms-btn-content">
                                        <span class="cms-btn-icon cmsi-arrow-right rtl-flip text-10"></span>
                                        <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                    </span>
                                </a>
                            </div>
                        <?php } ?>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    }
}

if(!function_exists('claniz_get_post_grid4')){  
    function claniz_get_post_grid4($posts = [], $settings = [], $args = []){
        if(empty($posts) || !is_array($posts) || empty($settings) || !is_array($settings)){
            return false;
        }
        extract($settings);
        if($thumbnail_size != 'custom'){
            $img_size = $thumbnail_size;
        }
        elseif(!empty($thumbnail_custom_dimension['width']) || !empty($thumbnail_custom_dimension['height'])){
            if(empty($thumbnail_custom_dimension['width'])){
                $thumbnail_custom_dimension['width'] = $thumbnail_custom_dimension['height'];
            }
            if(empty($thumbnail_custom_dimension['height'])){
                $thumbnail_custom_dimension['height'] = $thumbnail_custom_dimension['width'];
            }
            $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
        }
        else{
            $img_size = 'full';
        }
        $_col_xl  = isset($settings['col_xl']) ? (12 / intval($settings['col_xl'])) : 4;
        $_col_lg  = isset($settings['col_lg']) ? (12 / intval($settings['col_lg'])) : 3;
        $_col_md  = isset($settings['col_md']) ? (12 / intval($settings['col_md'])) : 2;
        $_col_sm  = isset($settings['col_sm']) ? (12 / intval($settings['col_sm'])) : 1;

        $col_xl  = isset($settings['col_xl']) ? intval($settings['col_xl']) : 4;
        $col_lg  = isset($settings['col_lg']) ? intval($settings['col_lg']) : 3;
        $col_md  = isset($settings['col_md']) ? intval($settings['col_md']) : 2;
        $col_sm  = isset($settings['col_sm']) ? intval($settings['col_sm']) : 1;

        $args = wp_parse_args($args, [
            'item_class' => trim(implode(' ', ['cms-grid-item', 'col-xl-'.$_col_xl, 'col-lg-'.$_col_lg, 'col-md-'.$_col_md, 'col-sm-'.$_col_sm]))
        ]);

        $custom_item_class = isset($args['custom_item_class']) ? $args['custom_item_class'] : '';
        $item_class = trim(implode(' ' , [$args['item_class'], $custom_item_class]));
        $settings['gap_extra'] = empty($settings['gap_extra']) ? '0' : $settings['gap_extra'];
        //style
        $style = 'style="';
        if(isset($settings['masonry_mode']) && !empty($settings['gap'])){
            $style .= 'padding:'.($settings['gap']/2).'px;';
        }
        if($settings['gap_extra']!== '0'){
            $style .= 'margin-bottom:'.$settings['gap_extra'].'px;';
        }
        $style .= '"';

        // Start build post item 
        $count = 0;
        // Media class
        $img_pos_xl = $img_pos_lg = $img_pos_md = $img_pos_sm = '';
        // Sale
        $sale_value_html = '';
        if(!empty($sale_value)){
            $sale_value_html = '<span class="cms-ribbon-2 absolute cms-abs-t-30 cms-abs-r-30 bg-yellow text-14 text-custom-3 font-700 text-center lh-1/286">'.$sale_value.'</span>';
        }
        foreach ($posts as $post):
            $count ++;
            $last_xl = $last_lg = $last_md = $last_sm = $last = '';
            
            if($count % $col_xl === 0) $last_xl = 'last-xl';
            if($count % $col_lg === 0) $last_lg = 'last-lg';
            if($count % $col_md === 0) $last_md = 'last-md';
            if($count % $col_sm === 0) $last_sm = 'last-sm';
            if($count % $limit === 0) $last = 'last';

            $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));

            ?>
            <div class="<?php echo claniz_nice_class(implode(' ', [$item_class, $filter_class, 'item-'.$count, $last_xl,$last_lg, $last_md, $last_sm, $last])); ?>" <?php etc_print_html($style); ?>>
                <div class="cms-item-content bg-white cms-transition clearfix cms-shadow-2 cms-shadow-hover-1 cms-radius-8 overflow-hidden row no-gutters">
                    <?php 
                    claniz_post_media([
                        'post_id'    => $post->ID, 
                        'size'       => $img_size,
                        'wrap_class' => 'col-md-5',
                        'class'      => '', 
                        'img_class'  => '',
                        'after'      => $sale_value_html,
                        'as_background' => true
                    ]); ?>
                    <div class="cms-item-content-inners col-md-7 order-md-first">
                        <div class="cms-item-content-inner p-tb-60 p-lr-20 p-lr-lg-50 mr-lg-n20 mt-n10 mt-lg-n0 cms-radius-8 bg-white h-100">
                            <h4 class="cms-item-content-title cms-heading text-primary text-20 lh-29 mb-17 mt-n5">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                            </h4>
                            <div class="cms-item-content-excerpt mb-20 lh-1/67"><?php
                                if(!empty($post->post_excerpt)){
                                    claniz_post_excerpt([
                                        'content' => $post->post_excerpt,
                                        'length'  => $settings['excerpt_lenght'],
                                        'more'    => $settings['excerpt_more_text'] 
                                    ]);
                                }
                                else{
                                    $content = strip_shortcodes( $post->post_content );
                                    $content = apply_filters( 'the_content', $content );
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    claniz_post_excerpt([
                                        'content' => $post->post_content,
                                        'length'  => $settings['excerpt_lenght'],
                                        'more'    => $settings['excerpt_more_text']
                                    ]);
                                }
                            ?></div>
                            <?php 
                            if(!empty($settings['readmore_text'])){ ?>
                                <div class="cms-btn-wraps cms-post-item-readmore cms-transition">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-readmore">
                                        <span class="cms-btn-content">
                                            <span class="cms-btn-icon cmsi-arrow-right rtl-flip text-10"></span>
                                            <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                        </span>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    }
}

if(!function_exists('claniz_get_post_grid3')){   
    function claniz_get_post_grid3($posts = [], $settings = [], $args = []){
        if(empty($posts) || !is_array($posts) || empty($settings) || !is_array($settings)){
            return false;
        }
        extract($settings);
        if($thumbnail_size != 'custom'){
            $img_size = $thumbnail_size;
        }
        elseif(!empty($thumbnail_custom_dimension['width']) || !empty($thumbnail_custom_dimension['height'])){
            if(empty($thumbnail_custom_dimension['width'])){
                $thumbnail_custom_dimension['width'] = $thumbnail_custom_dimension['height'];
            }
            if(empty($thumbnail_custom_dimension['height'])){
                $thumbnail_custom_dimension['height'] = $thumbnail_custom_dimension['width'];
            }
            $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
        }
        else{
            $img_size = 'full';
        }
        $_col_xl  = isset($settings['col_xl']) ? (12 / intval($settings['col_xl'])) : 4;
        $_col_lg  = isset($settings['col_lg']) ? (12 / intval($settings['col_lg'])) : 3;
        $_col_md  = isset($settings['col_md']) ? (12 / intval($settings['col_md'])) : 2;
        $_col_sm  = isset($settings['col_sm']) ? (12 / intval($settings['col_sm'])) : 1;

        $col_xl  = isset($settings['col_xl']) ? intval($settings['col_xl']) : 4;
        $col_lg  = isset($settings['col_lg']) ? intval($settings['col_lg']) : 3;
        $col_md  = isset($settings['col_md']) ? intval($settings['col_md']) : 2;
        $col_sm  = isset($settings['col_sm']) ? intval($settings['col_sm']) : 1;

        $args = wp_parse_args($args, [
            'item_class' => trim(implode(' ', ['cms-grid-item', 'col-xl-'.$_col_xl, 'col-lg-'.$_col_lg, 'col-md-'.$_col_md, 'col-sm-'.$_col_sm]))
        ]);

        $custom_item_class = isset($args['custom_item_class']) ? $args['custom_item_class'] : '';
        $item_class = trim(implode(' ' , [$args['item_class'], $custom_item_class]));
        $settings['gap_extra'] = empty($settings['gap_extra']) ? '0' : $settings['gap_extra'];
        //style
        $style = 'style="';
        if(isset($settings['masonry_mode']) && !empty($settings['gap'])){
            $style .= 'padding:'.($settings['gap']/2).'px;';
        }
        if($settings['gap_extra']!== '0'){
            $style .= 'margin-bottom:'.$settings['gap_extra'].'px;';
        }
        $style .= '"';

        // Start build post item 
        $count = 0;
        // Media class
        $img_pos_xl = $img_pos_lg = $img_pos_md = $img_pos_sm = '';
        
        foreach ($posts as $post):
            $count ++;
            $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));
            ?>
            <div class="<?php echo claniz_nice_class(implode(' ', [$item_class, $filter_class, 'item-'.$count])); ?>" <?php etc_print_html($style); ?>>
                <div class="cms-item-content pb-30 relative cms-radius-7 cms-shadow-5 text-center">
                    <?php 
                        claniz_post_media([
                            'post_id'    => $post->ID, 
                            'size'       => $img_size,
                            'wrap_class' => 'cms-item-content-media absolute w-100',
                            'img_class'  => 'w-100',
                            'after'      => claniz_post_category([
                                'post_id'       => $post->ID,
                                'taxo'          => claniz_get_custom_post_taxonomies($post->post_type, 'cat'),
                                'class'         => 'absolute bg-accent text-white text-13 link-white link-hover-white p-tb-10 p-lr-15',
                                'show_icon'     => false,
                                'echo'          => false   
                            ])
                        ]);
                    ?>
                    <div class="cms-overlay bg-white cms-radius-7 cms-transition mb-30 z-ontop"></div>
                    <div class="cms-item-content-content relative z-ontop relative cms-transition">
                        <div class="icon-service pt-60">
                            <?php 
                                claniz_post_icon([
                                    'id' => $post->ID,
                                    'class' => 'text-80 lh-80 text-1d65b9'
                                ]);
                            ?>
                        </div>
                        <div class="cms-item-content-inner p-lr-20 p-lr-lg-50 pt-24 pb-50">
                            <h4 class="cms-item-content-title cms-heading text-primary text-24 lh-32 mb-27">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                            </h4>
                            <div class="cms-item-content-excerpt lh-25 mb-32"><?php
                                if(!empty($post->post_excerpt)){
                                    claniz_post_excerpt([
                                        'content' => $post->post_excerpt,
                                        'length'  => $settings['excerpt_lenght'],
                                        'more'    => $settings['excerpt_more_text'] 
                                    ]);
                                }
                                else{
                                    $content = strip_shortcodes( $post->post_content );
                                    $content = apply_filters( 'the_content', $content );
                                    $content = str_replace(']]>', ']]&gt;', $content);
                                    claniz_post_excerpt([
                                        'content' => $post->post_content,
                                        'length'  => $settings['excerpt_lenght'],
                                        'more'    => $settings['excerpt_more_text']
                                    ]);
                                }
                            ?></div>
                            <?php if(!empty($settings['readmore_text'])){ ?>
                                <div class="cms-btn-wraps cms-post-item-readmore">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-readmore btn  btn-accent btn-hover-primary">
                                        <span class="cms-btn-content">
                                            <span class="cms-btn-icon cmsi-arrow-circle-right rtl-flip text-26"></span>
                                            <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                        </span>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        endforeach;
    }
}

if(!function_exists('claniz_get_post_grid5')){
    function claniz_get_post_grid5($posts = [], $settings = [], $args = []){
        if(empty($posts) || !is_array($posts) || empty($settings) || !is_array($settings)){
            return false;
        }
        extract($settings);
        if($thumbnail_size != 'custom'){
            $img_size = $thumbnail_size;
        }
        elseif(!empty($thumbnail_custom_dimension['width']) || !empty($thumbnail_custom_dimension['height'])){
            if(empty($thumbnail_custom_dimension['width'])){
                $thumbnail_custom_dimension['width'] = $thumbnail_custom_dimension['height'];
            }
            if(empty($thumbnail_custom_dimension['height'])){
                $thumbnail_custom_dimension['height'] = $thumbnail_custom_dimension['width'];
            }
            $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
        }
        else{
            $img_size = 'full';
        }
        $_col_xl  = isset($settings['col_xl']) ? (12 / intval($settings['col_xl'])) : 4;
        $_col_lg  = isset($settings['col_lg']) ? (12 / intval($settings['col_lg'])) : 3;
        $_col_md  = isset($settings['col_md']) ? (12 / intval($settings['col_md'])) : 2;
        $_col_sm  = isset($settings['col_sm']) ? (12 / intval($settings['col_sm'])) : 1;

        $col_xl  = isset($settings['col_xl']) ? intval($settings['col_xl']) : 4;
        $col_lg  = isset($settings['col_lg']) ? intval($settings['col_lg']) : 3;
        $col_md  = isset($settings['col_md']) ? intval($settings['col_md']) : 2;
        $col_sm  = isset($settings['col_sm']) ? intval($settings['col_sm']) : 1;

        $args = wp_parse_args($args, [
            'item_class' => trim(implode(' ', ['cms-grid-item', 'col-xl-'.$_col_xl, 'col-lg-'.$_col_lg, 'col-md-'.$_col_md, 'col-sm-'.$_col_sm]))
        ]);

        $custom_item_class = isset($args['custom_item_class']) ? $args['custom_item_class'] : '';
        $item_class = trim(implode(' ' , [$args['item_class'], $custom_item_class]));
        $settings['gap_extra'] = empty($settings['gap_extra']) ? '0' : $settings['gap_extra'];
        //style
        $style = 'style="';
        if(isset($settings['masonry_mode']) && !empty($settings['gap'])){
            $style .= 'padding:'.($settings['gap']/2).'px;';
        }
        if($settings['gap_extra']!== '0'){
            $style .= 'margin-bottom:'.$settings['gap_extra'].'px;';
        }
        $style .= '"';

        // Start build post item 
        $count = 0;
        // Media class
        $img_pos_xl = $img_pos_lg = $img_pos_md = $img_pos_sm = '';
        
        foreach ($posts as $post):
            $count ++;
            $last_xl = $last_lg = $last_md = $last_sm = $last = '';
            
            if($count % $col_xl === 0) $last_xl = 'last-xl';
            if($count % $col_lg === 0) $last_lg = 'last-lg';
            if($count % $col_md === 0) $last_md = 'last-md';
            if($count % $col_sm === 0) $last_sm = 'last-sm';
            if($count % $limit === 0) $last = 'last';

            $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));
            ?>
            <div class="<?php echo claniz_nice_class(implode(' ', [$item_class, $filter_class, 'item-'.$count, $last_xl,$last_lg, $last_md, $last_sm, $last])); ?>" <?php etc_print_html($style); ?>>
                <div class="cms-item-content bg-white cms-transition clearfix cms-shadow-2 cms-shadow-hover-1"><?php 
                    claniz_post_media([
                        'post_id'    => $post->ID, 
                        'size'       => $img_size,
                        'class'      => '',
                        'img_class'  => 'w-100',
                        'after'      => claniz_post_category([
                            'post_id'       => $post->ID,
                            'taxo'          => claniz_get_custom_post_taxonomies($post->post_type, 'cat'),
                            'class'         => 'absolute bg-accent text-white text-13 link-white link-hover-white p-tb-10 p-lr-15',
                            'show_icon'     => false,
                            'echo'          => false   
                        ])
                     ]); ?>
                    <div class="cms-item-content-inner p-lr-20 pt-0 p-lr-lg-30 pb-40 pb-xl-50 p-lr-xl-50">
                        <div class="icon-service pb-30">
                            <?php 
                                claniz_post_icon([
                                'id' => $post->ID,
                                'class' => 'text-62 lh-94 text-1d65b9'
                            ]);
                            ?>
                        </div>
                        <h4 class="cms-item-content-title cms-heading text-primary text-20 lh-29 mb-17 mt-n5">
                            <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                        </h4>
                        <div class="cms-item-content-excerpt mb-32"><?php
                            if(!empty($post->post_excerpt)){
                                claniz_post_excerpt([
                                    'content' => $post->post_excerpt,
                                    'length'  => $settings['excerpt_lenght'],
                                    'more'    => $settings['excerpt_more_text'] 
                                ]);
                            }
                            else{
                                $content = strip_shortcodes( $post->post_content );
                                $content = apply_filters( 'the_content', $content );
                                $content = str_replace(']]>', ']]&gt;', $content);
                                claniz_post_excerpt([
                                    'content' => $post->post_content,
                                    'length'  => $settings['excerpt_lenght'],
                                    'more'    => $settings['excerpt_more_text']
                                ]);
                            }
                        ?></div>
                        <?php 
                        if(!empty($settings['readmore_text'])){ ?>
                            <div class="cms-btn-wraps cms-post-item-readmore cms-transition">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-readmore btn btn- btn-outline btn-hover-primary text-primary">
                                    <span class="cms-btn-content">
                                        <span class="cms-btn-icon cmsi-arrow-right rtl-flip text-10"></span>
                                        <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                    </span>
                                </a>
                            </div>
                        <?php } ?>
                    </div>
                </div>
                
            </div>
        <?php
        endforeach;
    }
}

if(!function_exists('claniz_get_post_grid6')){
    function claniz_get_post_grid6($posts = [], $settings = [], $args = []){
        if(empty($posts) || !is_array($posts) || empty($settings) || !is_array($settings)){
            return false;
        }
        extract($settings);
        if($thumbnail_size != 'custom'){
            $img_size = $thumbnail_size;
        }
        elseif(!empty($thumbnail_custom_dimension['width']) || !empty($thumbnail_custom_dimension['height'])){
            if(empty($thumbnail_custom_dimension['width'])){
                $thumbnail_custom_dimension['width'] = $thumbnail_custom_dimension['height'];
            }
            if(empty($thumbnail_custom_dimension['height'])){
                $thumbnail_custom_dimension['height'] = $thumbnail_custom_dimension['width'];
            }
            $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
        }
        else{
            $img_size = 'full';
        }
        $_col_xl  = isset($settings['col_xl']) ? (12 / intval($settings['col_xl'])) : 4;
        $_col_lg  = isset($settings['col_lg']) ? (12 / intval($settings['col_lg'])) : 3;
        $_col_md  = isset($settings['col_md']) ? (12 / intval($settings['col_md'])) : 2;
        $_col_sm  = isset($settings['col_sm']) ? (12 / intval($settings['col_sm'])) : 1;

        $col_xl  = isset($settings['col_xl']) ? intval($settings['col_xl']) : 4;
        $col_lg  = isset($settings['col_lg']) ? intval($settings['col_lg']) : 3;
        $col_md  = isset($settings['col_md']) ? intval($settings['col_md']) : 2;
        $col_sm  = isset($settings['col_sm']) ? intval($settings['col_sm']) : 1;

        $args = wp_parse_args($args, [
            'item_class' => trim(implode(' ', ['cms-grid-item', 'col-xl-'.$_col_xl, 'col-lg-'.$_col_lg, 'col-md-'.$_col_md, 'col-sm-'.$_col_sm]))
        ]);

        $custom_item_class = isset($args['custom_item_class']) ? $args['custom_item_class'] : '';
        $item_class = trim(implode(' ' , [$args['item_class'], $custom_item_class]));
        $settings['gap_extra'] = empty($settings['gap_extra']) ? '0' : $settings['gap_extra'];
        //style
        $style = 'style="';
        if(isset($settings['masonry_mode']) && !empty($settings['gap'])){
            $style .= 'padding:'.($settings['gap']/2).'px;';
        }
        if($settings['gap_extra']!== '0'){
            $style .= 'margin-bottom:'.$settings['gap_extra'].'px;';
        }
        $style .= '"';

        // Start build post item 
        $count = 0;
        // Media class
        $img_pos_xl = $img_pos_lg = $img_pos_md = $img_pos_sm = '';
        
        foreach ($posts as $post):
            $count ++;
            $last_xl = $last_lg = $last_md = $last_sm = $last = '';
            
            if($count % $col_xl === 0) $last_xl = 'last-xl';
            if($count % $col_lg === 0) $last_lg = 'last-lg';
            if($count % $col_md === 0) $last_md = 'last-md';
            if($count % $col_sm === 0) $last_sm = 'last-sm';
            if($count % $limit === 0) $last = 'last';

            $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));

            ob_start();
                claniz_post_icon([
                    'id'         => $post->ID,
                    'class'      => 'cms-overlay d-flex align-items-center justify-content-center cms-transition',
                    'size'       => '64',
                    'icon_color' => 'text-white',
                    'icon_class' => 'z-top'
                ]);
            $media_icon = ob_get_clean();
            ?>
            <div class="<?php echo claniz_nice_class(implode(' ', [$item_class, $filter_class, 'item-'.$count, $last_xl,$last_lg, $last_md, $last_sm, $last])); ?>" <?php etc_print_html($style); ?>>
                <div class="cms-item-content bg-white cms-transition clearfix cms-shadow-2 cms-shadow-hover-1 cms-radius-8 overflow-hidden"><?php 
                    claniz_post_media([
                        'post_id'    => $post->ID, 
                        'size'       => $img_size,
                        'class'      => '',
                        'img_class'  => 'w-100',
                        'after'      => $media_icon
                     ]); ?>
                    <div class="cms-item-content-inner p-tb-50 p-lr-20 p-lr-lg-30 p-lr-xl-50">
                        <h3 class="cms-item-content-title cms-heading text-primary text-24 lh-29 mb-17 mt-n5">
                            <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                        </h3>
                        <div class="cms-item-content-excerpt mb-32"><?php
                            if(!empty($post->post_excerpt)){
                                claniz_post_excerpt([
                                    'content' => $post->post_excerpt,
                                    'length'  => $settings['excerpt_lenght'],
                                    'more'    => $settings['excerpt_more_text'] 
                                ]);
                            }
                            else{
                                $content = strip_shortcodes( $post->post_content );
                                $content = apply_filters( 'the_content', $content );
                                $content = str_replace(']]>', ']]&gt;', $content);
                                claniz_post_excerpt([
                                    'content' => $post->post_content,
                                    'length'  => $settings['excerpt_lenght'],
                                    'more'    => $settings['excerpt_more_text']
                                ]);
                            }
                        ?></div>
                        <?php 
                        if(!empty($settings['readmore_text'])){ ?>
                            <div class="cms-btn-wraps cms-post-item-readmore cms-transition">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-readmore btn btn- btn-outline btn-hover-accent text-primary text-hover-white">
                                    <span class="cms-btn-content">
                                        <span class="cms-btn-icon cmsi-arrow-circle-right rtl-flip text-26"></span>
                                        <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                    </span>
                                </a>
                            </div>
                        <?php } ?>
                    </div>
                </div>
                
            </div>
        <?php
        endforeach;
    }
}

if(!function_exists('claniz_get_post_grid7')){
    function claniz_get_post_grid7($posts = [], $settings = [], $args = []){
        if(empty($posts) || !is_array($posts) || empty($settings) || !is_array($settings)){
            return false;
        }
        extract($settings);
        if($thumbnail_size != 'custom'){
            $img_size = $thumbnail_size;
        }
        elseif(!empty($thumbnail_custom_dimension['width']) || !empty($thumbnail_custom_dimension['height'])){
            if(empty($thumbnail_custom_dimension['width'])){
                $thumbnail_custom_dimension['width'] = $thumbnail_custom_dimension['height'];
            }
            if(empty($thumbnail_custom_dimension['height'])){
                $thumbnail_custom_dimension['height'] = $thumbnail_custom_dimension['width'];
            }
            $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
        }
        else{
            $img_size = 'full';
        }
        $_col_xl  = isset($settings['col_xl']) ? (12 / intval($settings['col_xl'])) : 4;
        $_col_lg  = isset($settings['col_lg']) ? (12 / intval($settings['col_lg'])) : 3;
        $_col_md  = isset($settings['col_md']) ? (12 / intval($settings['col_md'])) : 2;
        $_col_sm  = isset($settings['col_sm']) ? (12 / intval($settings['col_sm'])) : 1;

        $col_xl  = isset($settings['col_xl']) ? intval($settings['col_xl']) : 4;
        $col_lg  = isset($settings['col_lg']) ? intval($settings['col_lg']) : 3;
        $col_md  = isset($settings['col_md']) ? intval($settings['col_md']) : 2;
        $col_sm  = isset($settings['col_sm']) ? intval($settings['col_sm']) : 1;

        $args = wp_parse_args($args, [
            'item_class' => trim(implode(' ', ['cms-grid-item', 'col-xl-'.$_col_xl, 'col-lg-'.$_col_lg, 'col-md-'.$_col_md, 'col-sm-'.$_col_sm]))
        ]);

        $custom_item_class = isset($args['custom_item_class']) ? $args['custom_item_class'] : '';
        $item_class = trim(implode(' ' , [$args['item_class'], $custom_item_class]));
        $settings['gap_extra'] = empty($settings['gap_extra']) ? '0' : $settings['gap_extra'];
        //style
        $style = 'style="';
        if(isset($settings['masonry_mode']) && !empty($settings['gap'])){
            $style .= 'padding:'.($settings['gap']/2).'px;';
        }
        if($settings['gap_extra']!== '0'){
            $style .= 'margin-bottom:'.$settings['gap_extra'].'px;';
        }
        $style .= '"';

        // Start build post item 
        $count = 0;
        // Media class
        $img_pos_xl = $img_pos_lg = $img_pos_md = $img_pos_sm = '';
        // Sale
        $sale_value_html = '';
        if(!empty($sale_value)){
            $sale_value_html = '<span class="cms-ribbon-2 absolute cms-abs-t-30 cms-abs-r-30 bg-yellow text-14 text-custom-3 font-700 text-center lh-1/286">'.$sale_value.'</span>';
        }
        foreach ($posts as $post):
            $count ++;
            $last_xl = $last_lg = $last_md = $last_sm = $last = '';
            
            if($count % $col_xl === 0) $last_xl = 'last-xl';
            if($count % $col_lg === 0) $last_lg = 'last-lg';
            if($count % $col_md === 0) $last_md = 'last-md';
            if($count % $col_sm === 0) $last_sm = 'last-sm';
            if($count % $limit === 0) $last = 'last';

            $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));
            ?>
            <div class="<?php echo claniz_nice_class(implode(' ', [$item_class, $filter_class, 'item-'.$count, $last_xl,$last_lg, $last_md, $last_sm, $last])); ?>" <?php etc_print_html($style); ?>>
                <div class="cms-item-content relative"><?php 
                    claniz_post_media([
                        'post_id'    => $post->ID, 
                        'size'       => $img_size,
                        'class'      => '',
                        'img_class'  => 'w-100 cms-radius-8 mb-30',
                        'after'      => $sale_value_html
                     ]); ?>
                    <div class="cms-item-content-inner p-tb-40 p-lr-20 p-lr-md-40 absolute cms-abs-l-30 cms-abs-r-30 cms-abs-b-0 bg-white cms-radius-8">
                        <h3 class="cms-item-content-title cms-heading font-600 text-primary text-20 lh-29 mb-17 mt-n5">
                            <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                        </h3>
                        <div class="cms-item-content-excerpt"><?php
                            if(!empty($post->post_excerpt)){
                                claniz_post_excerpt([
                                    'content' => $post->post_excerpt,
                                    'length'  => $settings['excerpt_lenght'],
                                    'more'    => $settings['excerpt_more_text'] 
                                ]);
                            }
                            else{
                                $content = strip_shortcodes( $post->post_content );
                                $content = apply_filters( 'the_content', $content );
                                $content = str_replace(']]>', ']]&gt;', $content);
                                claniz_post_excerpt([
                                    'content' => $post->post_content,
                                    'length'  => $settings['excerpt_lenght'],
                                    'more'    => $settings['excerpt_more_text']
                                ]);
                            }
                        ?></div>
                        <?php 
                        if(!empty($settings['readmore_text'])){ ?>
                            <div class="cms-btn-wraps cms-post-item-readmore pt-20">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-readmore text-primary text-hover-accent font-700">
                                    <span class="cms-btn-content">
                                        <span class="cms-btn-icon cmsi-arrow-circle-right rtl-flip text-26 pr-15"></span>
                                        <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                    </span>
                                </a>
                            </div>
                        <?php } ?>
                    </div>
                </div>
                
            </div>
        <?php
        endforeach;
    }
}
if(!function_exists('claniz_get_post_grid8')){
    function claniz_get_post_grid8($posts = [], $settings = [], $args = []){
        if(empty($posts) || !is_array($posts) || empty($settings) || !is_array($settings)){
            return false;
        }
        extract($settings);
        if($thumbnail_size != 'custom'){
            $img_size = $thumbnail_size;
        }
        elseif(!empty($thumbnail_custom_dimension['width']) || !empty($thumbnail_custom_dimension['height'])){
            if(empty($thumbnail_custom_dimension['width'])){
                $thumbnail_custom_dimension['width'] = $thumbnail_custom_dimension['height'];
            }
            if(empty($thumbnail_custom_dimension['height'])){
                $thumbnail_custom_dimension['height'] = $thumbnail_custom_dimension['width'];
            }
            $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
        }
        else{
            $img_size = 'full';
        }
        $_col_xl  = isset($settings['col_xl']) ? (12 / intval($settings['col_xl'])) : 4;
        $_col_lg  = isset($settings['col_lg']) ? (12 / intval($settings['col_lg'])) : 3;
        $_col_md  = isset($settings['col_md']) ? (12 / intval($settings['col_md'])) : 2;
        $_col_sm  = isset($settings['col_sm']) ? (12 / intval($settings['col_sm'])) : 1;

        $col_xl  = isset($settings['col_xl']) ? intval($settings['col_xl']) : 4;
        $col_lg  = isset($settings['col_lg']) ? intval($settings['col_lg']) : 3;
        $col_md  = isset($settings['col_md']) ? intval($settings['col_md']) : 2;
        $col_sm  = isset($settings['col_sm']) ? intval($settings['col_sm']) : 1;

        $args = wp_parse_args($args, [
            'item_class' => trim(implode(' ', ['cms-grid-item', 'col-xl-'.$_col_xl, 'col-lg-'.$_col_lg, 'col-md-'.$_col_md, 'col-sm-'.$_col_sm]))
        ]);

        $custom_item_class = isset($args['custom_item_class']) ? $args['custom_item_class'] : '';
        $item_class = trim(implode(' ' , [$args['item_class'], $custom_item_class]));
        $settings['gap_extra'] = empty($settings['gap_extra']) ? '0' : $settings['gap_extra'];
        //style
        $style = 'style="';
        if(isset($settings['masonry_mode']) && !empty($settings['gap'])){
            $style .= 'padding:'.($settings['gap']/2).'px;';
        }
        if($settings['gap_extra']!== '0'){
            $style .= 'margin-bottom:'.$settings['gap_extra'].'px;';
        }
        $style .= '"';

        // Start build post item 
        $count = 0;
        // Media class
        $img_pos_xl = $img_pos_lg = $img_pos_md = $img_pos_sm = '';
        // Sale
        $sale_value_html = '';
        if(!empty($sale_value)){
            $sale_value_html = '<span class="cms-ribbon-2 absolute cms-abs-t-30 cms-abs-r-30 bg-yellow text-14 text-custom-3 font-700 text-center lh-1/286">'.$sale_value.'</span>';
        }
        foreach ($posts as $post):
            $count ++;
            $last_xl = $last_lg = $last_md = $last_sm = $last = '';
            
            if($count % $col_xl === 0) $last_xl = 'last-xl';
            if($count % $col_lg === 0) $last_lg = 'last-lg';
            if($count % $col_md === 0) $last_md = 'last-md';
            if($count % $col_sm === 0) $last_sm = 'last-sm';
            if($count % $limit === 0) $last = 'last';

            $filter_class = etc_get_term_of_post_to_class($post->ID, array_unique($tax));
            ?>
            <div class="<?php echo claniz_nice_class(implode(' ', [$item_class, $filter_class, 'item-'.$count, $last_xl,$last_lg, $last_md, $last_sm, $last])); ?>" <?php etc_print_html($style); ?>>
                <div class="cms-item-content relative"><?php 
                    claniz_post_media([
                        'post_id'    => $post->ID, 
                        'size'       => $img_size,
                        'class'      => '',
                        'img_class'  => 'w-100 cms-radius-8',
                        'after'      => $sale_value_html
                     ]); ?>
                    <div class="cms-item-content-inner mt-n40 mr-20 mr-xl-40 p-tb-40 p-lr-20 p-lr-md-40 bg-white cms-shadow-1 relative">
                        <h3 class="cms-item-content-title cms-heading font-600 text-primary text-20 lh-29 mb-17 mt-n5">
                            <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                        </h3>
                        <div class="cms-item-content-excerpt"><?php
                            if(!empty($post->post_excerpt)){
                                claniz_post_excerpt([
                                    'content' => $post->post_excerpt,
                                    'length'  => $settings['excerpt_lenght'],
                                    'more'    => $settings['excerpt_more_text'] 
                                ]);
                            }
                            else{
                                $content = strip_shortcodes( $post->post_content );
                                $content = apply_filters( 'the_content', $content );
                                $content = str_replace(']]>', ']]&gt;', $content);
                                claniz_post_excerpt([
                                    'content' => $post->post_content,
                                    'length'  => $settings['excerpt_lenght'],
                                    'more'    => $settings['excerpt_more_text']
                                ]);
                            }
                        ?></div>
                        <?php 
                        if(!empty($settings['readmore_text'])){ ?>
                            <div class="cms-btn-wraps cms-post-item-readmore pt-20">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="cms-readmore text-primary text-hover-accent font-700">
                                    <span class="cms-btn-content">
                                        <span class="cms-btn-icon cmsi-arrow-circle-right rtl-flip text-26 pr-15"></span>
                                        <span class="cms-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                    </span>
                                </a>
                            </div>
                        <?php } ?>
                    </div>
                </div>
                
            </div>
        <?php
        endforeach;
    }
}

// Load More Post
if(!function_exists('claniz_load_more_post_grid')){
    add_action( 'wp_ajax_claniz_load_more_post_grid', 'claniz_load_more_post_grid' );
    add_action( 'wp_ajax_nopriv_claniz_load_more_post_grid', 'claniz_load_more_post_grid' );
    function claniz_load_more_post_grid(){
        try{
            if(!isset($_POST['settings'])){
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'claniz'));
            }
            $settings = $_POST['settings'];
            set_query_var('paged', $settings['paged']);
            extract(etc_get_posts_of_grid($settings['post_type'], [
                'source'   => isset($settings['source'])?$settings['source']:'',
                'orderby'  => isset($settings['orderby'])?$settings['orderby']:'date',
                'order'    => isset($settings['order'])?$settings['order']:'desc',
                'limit'    => isset($settings['limit'])?$settings['limit']:'6',
                'post_ids' => '',
            ]));
            ob_start();
                claniz_get_post_grid($posts, $settings);
                claniz_get_post_grid3($posts, $settings);
                claniz_get_post_grid5($posts, $settings);
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => __('Load Post Grid Successfully!', 'claniz'),
                    'data' => array(
                        'html'  => $html,
                        'paged' => $settings['paged'],
                        'posts' => $posts,
                    ),
                )
            );
        }
        catch (Exception $e){
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}