<?php
/**
 * Helper functions for the theme
 *
 * @package claniz
 */

/**
 * Generates an excerpt from the post content with custom length.
 * Default length is 55 words, same as default the_excerpt()
 *
 * The excerpt words amount will be 55 words and if the amount is greater than
 * that, then the string '&hellip;' will be appended to the excerpt. If the string
 * is less than 55 words, then the content will be returned as it is.
 *
 * @param int $length Optional. Custom excerpt length, default to 55.
 * @param int|WP_Post $post Optional. You will need to provide post id or post object if used outside loops.
 *
 * @return string           The excerpt with custom length.
 */
function claniz_get_the_excerpt( $length = 500, $more = '&hellip;', $post = null ) {
	$post = get_post( $post );

	if ( empty( $post ) || 0 >= $length ) {
		return '';
	}

	if ( post_password_required( $post ) ) {
		return esc_html__( 'Post password required.', 'claniz' );
	}

 	$content = !empty($post->post_excerpt) ? $post->post_excerpt : strip_shortcodes($post->post_content);

	$content = str_replace( ']]>', ']]&gt;', $content );
    $content = preg_replace(" (\[.*?\])",'',$content);
    $content = strip_tags($content);
    $content = substr($content, 0, $length );
    //$content = substr($content, 0, strripos($content, " "));
    $content = trim(preg_replace( '/\s+/', ' ', $content));
    $content = $content.$more;
}

function claniz_custom_excerpt_length( $length ) {
    return 2000;
}
add_filter( 'excerpt_length', 'claniz_custom_excerpt_length', 999 );