<?php
/**
 * Post Thumbnail
 * @since 1.0.0
*/
if(!function_exists('claniz_post_thumbnail')){
    function claniz_post_thumbnail($args=[]){
        $args = wp_parse_args($args,[
            'post_id'        => null,
            'size'           => is_single() ? 'post-thumbnail' : 'large',
            'echo'           => true,
            'class'          => '',
            'img_class'      => '',
            'img_before'     => '',
            'img_after'      => '',
            'before'         => '',
            'after'          => '',
            'show_link'      => is_single() ? false : true,
            'default'        => false,
            'show_thumbnail' => true,
            'as_background'  => false
        ]);
        if(!$args['show_thumbnail']) return;
        if(!$args['default'] && !has_post_thumbnail($args['post_id']) ) return;
        if($args['size'] === 'cms_none') return;
        $thumbnail_atts = [];
        // class
        $thumbnail_atts_class = ['post-image','cms-post-image', $args['class']];
        if($args['as_background']){
            $thumbnail_atts_class[] = 'as-bg h-100';
            $thumbnail_atts[] = 'style="background-image:url('.get_the_post_thumbnail_url($args['post_id'], 'full').');"'; 
        }
        $thumbnail_atts[] = 'class="'.implode(' ', $thumbnail_atts_class).'"';

        ob_start();
            printf('%s', $args['before']);
        ?>
            <div <?php echo implode(' ', $thumbnail_atts);?>>
                <?php if($args['show_link']) : ?><a href="<?php the_permalink($args['post_id']);?>" title="<?php the_title($args['post_id']);?>" rel="nofollow" class="d-block w-100 h-100"><?php endif; 
                    printf('%s', $args['img_before']);
                    claniz_image_by_size([
                        'id'    => get_post_thumbnail_id($args['post_id']),
                        'size'  => $args['size'], 
                        'class' => $args['img_class'],
                        'default' => $args['default']
                    ]);
                    printf('%s', $args['img_after']);
                if($args['show_link']) : ?></a><?php endif; ?>
            </div>
        <?php 
            do_action('claniz_post_thumbnail_content');
            printf('%s', $args['after']);

        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}

/**
 * Post Gallery 
 * @since 1.0.0
*/
if(!function_exists('claniz_post_gallery')){
    function claniz_post_gallery($args=[], $gallery = 'post-gallery-images'){
        $args = wp_parse_args($args, array(
            'post_id'   => null,
            'size'      => is_single() ? 'post-thumbnail' : 'large',
            'echo'      => true,
            'class'     => '',
            'img_class' => [],
            'before'    => '',
            'after'     => '',
            'show_link' => true
        ));
        // Get gallery from option
        $gallery_list = [];
        $post_gallery = claniz_get_post_format_value($args['post_id'], $gallery, []);
        if(!empty($post_gallery)){
            $gallery_list = explode(',', claniz_get_post_format_value($args['post_id'], $gallery, []));
        }
        $lightbox = claniz_get_post_format_value($args['post_id'], 'post-gallery-lightbox', 'yes');

        ob_start();
        if(!empty($gallery_list[0])){
            wp_enqueue_script('swiper');
            printf('%s', $args['before']);
        ?>
            <div class="cms-post-galleries" data-settings='{"slides_to_show":"1","navigation":"arrows","autoplay":"yes","pause_on_hover":"yes","pause_on_interaction":"yes","autoplay_speed":5000,"infinite":"yes","effect":"slide","speed":500}'>
                <div class="swiper-wrapper">
                    <div class="swiper-slide">
                        <?php
                        foreach ($gallery_list as $img_id):
                            ?>
                            <div class="swiper-slide">
                                <a href="<?php echo esc_url(wp_get_attachment_image_url($img_id, 'full'));?>" data-elementor-open-lightbox="<?php echo esc_attr( $lightbox);?>" data-elementor-lightbox-slideshow="<?php echo uniqid('post-'.$args['post_id'].'-');?>" data-elementor-lightbox-title="<?php echo esc_attr(get_post_meta( $img_id, '_wp_attachment_image_alt', true )) ?>" ><?php 
                                    claniz_image_by_size([
                                        'id'    => $img_id,
                                        'size'  => $args['size'],
                                        'class' => $args['img_class']
                                    ]);
                                ?></a>
                            </div>
                            <?php
                        endforeach;
                        ?>
                    </div>
                </div>
            </div>
        <?php 
            printf('%s', $args['after']);
        } elseif(has_post_thumbnail()) {
            claniz_post_thumbnail($args);
        }
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
/**
 * Post Video
 * @since 1.0.0
*/
if(!function_exists('claniz_post_video')){
    function claniz_post_video($args=[]){
        global $wp_embed;
        $args = wp_parse_args($args, [
            'post_id'   => null,
            'size'      => is_single() ? 'post-thumbnail' : 'large',
            'echo'      => true,
            'class'     => '',
            'img_class' => '',
            'before'    => '',
            'after'     => '',
            'show_link' => true
        ]);
        $video_url     = claniz_get_post_format_value($args['post_id'], 'post-video-url', '');
        $video_file    = claniz_get_post_format_value($args['post_id'], 'post-video-file', []);
        $video_file_id = isset($video_file['id']) ? $video_file['id'] : '';
        $video_html    = claniz_get_post_format_value($args['post_id'], 'post-video-html', '');

        // Only get video from the content if a playlist isn't present.
        $_video_in_content = apply_filters( 'the_content', get_the_content('','',$args['post_id']) );
        if ( false === strpos( $_video_in_content, 'wp-playlist-script' ) ) {
            $video_in_content = get_media_embedded_in_content( $_video_in_content, array( 'video', 'object', 'embed', 'iframe' ) );
        }
        $html = $video = '';
        if (!empty($video_url)) {
            $video = do_shortcode($wp_embed->autoembed($video_url));
        } elseif (!empty($video_file_id)) {
            /* Get default video poster */
            $poster = !empty(get_the_post_thumbnail_url($video_file_id)) ? get_the_post_thumbnail_url($video_file_id,'full') : get_the_post_thumbnail_url(get_the_ID(),'full');
            //attachment meta data 
            $att_data = wp_get_attachment_metadata($video_file_id);
            $mime_type = explode('/', $att_data['mime_type']);
            /* Build video */            
            $video_atts = array(
                'src'    => esc_url($video_file['url']),
                'poster' => esc_url($poster),
                'width'  => esc_attr($video_file['width']),
                'height' => esc_attr($video_file['height'])
            );
            switch ($mime_type[0]) {
                case 'audio':
                    $video = do_shortcode($wp_embed->autoembed($video_file['url']));
                    break;
                
                default:
                    if(!empty($poster))
                        $video = wp_video_shortcode($video_atts);
                    else 
                        $video = do_shortcode($wp_embed->autoembed($video_file['url']));
                    break;
            }            
        } elseif ('' != $video_html) {
            $_video_html = explode(',', $video_html);
            foreach ($_video_html as $value) {
                $video .= '<div class="video-item">'.do_shortcode($wp_embed->autoembed($value)).'</div>';
            }
        } elseif(! empty( $video_in_content ) && !is_singular()){
            // If not a single post, highlight the video file.
            foreach ( $video_in_content as $video_in_content_html ) {
                $video .= $video_in_content_html;
            }
        }
        if(!empty($video)){
            $html = $args['before'] . $video . $args['after'];
        } else {
        	$html = claniz_post_thumbnail($args);
        }
        // Show video 
        if($args['echo'])
            echo claniz_html($html);
        else 
            return $html;
    }
}

/**
 * Post Audio
 * @since 1.0.0
*/
if(!function_exists('claniz_post_audio')){
    function claniz_post_audio($args = []){
        $args = wp_parse_args($args, [
            'post_id'   => null,
            'size'      => is_single() ? 'post-thumbnail' : 'large',
            'echo'      => true,
            'class'     => '',
            'img_class' => '',
            'before'    => '',
            'after'     => '',
            'show_link' => is_single() ? false : true,
            'audio_url'  => 'post-audio-url',
            'audio_file' => 'post-audio-file',
        ]);
        global $wp_embed;
        $audio_url = claniz_get_post_format_value($args['post_id'], $args['audio_url'], '');
        $audio_file = claniz_get_post_format_value($args['post_id'], $args['audio_file'], ['id'=>'']);
        if(!empty($audio_file['id'])){
            /* Get default video poster */
            $poster = (is_array($audio_file) && !empty(get_the_post_thumbnail_url($audio_file['id']))) ? get_the_post_thumbnail_url($audio_file['id'],'full') : get_the_post_thumbnail_url(get_the_ID(),'full');
            //attachment meta data 
            $att_data = wp_get_attachment_metadata($audio_file['id']);
            $mime_type = explode('/', $att_data['mime_type']);
            /* Build audio */            
            $audio_atts = array(
                'src'    => esc_url($audio_file['url']),
                'poster' => esc_url($poster),
                'width'  => esc_attr($audio_file['width']),
                'height' => esc_attr($audio_file['height'])
            );
        }
        // get audion in content 
        $_audio_in_content = apply_filters( 'the_content', get_the_content() );
        // Only get audio from the content if a playlist isn't present.
        if ( false === strpos( $_audio_in_content, 'wp-playlist-script' ) ) {
            $audio_in_content = get_media_embedded_in_content( $_audio_in_content, array( 'audio' ) );
        }        
        $audio = '';
        ob_start();
        if(!empty($audio_url)){
            $audio =  do_shortcode($wp_embed->autoembed($audio_url));
        } elseif (!empty($audio_file['id'])) {
            switch ($mime_type[0]) {
                case 'audio':
                    $audio = do_shortcode($wp_embed->autoembed($audio_file['url']));
                    break;
                case 'application':
                    $audio = do_shortcode($wp_embed->autoembed($audio_file['url']));
                    break;
                
                default:
                    if(!empty($poster)){
                        $audio = wp_video_shortcode($audio_atts);
                    } else {
                        $audio = do_shortcode($wp_embed->autoembed($audio_file['url']));
                    }
                    break;
            }            
        } elseif(! empty( $audio_in_content ) && !is_singular()){
            // If not a single post, highlight the audio file.
            foreach ( $audio_in_content as $audio_in_content_html ) {
                $audio .= $audio_in_content_html;
            }
        } elseif ( has_post_thumbnail($args['post_id']) ){
            $audio = claniz_post_thumbnail($args);
        }
        $audio .= ob_get_clean();
        // Show video 
        if($args['echo'])
            echo apply_filters('claniz_post_audio', $audio);
        else 
            return $audio;
    }
}
/**
 * Post Quote
 * @since 1.0.0
*/
if(!function_exists('claniz_post_quote')){
    function claniz_post_quote($args = []){
        $args = wp_parse_args($args, [
            'post_id'   => null,
            'size'      => is_single() ? 'post-thumbnail' : 'large',
            'echo'      => true,
            'class'     => '',
            'img_class' => '',
            'before'    => '',
            'after'     => '',
            'show_link' => true
        ]);
        $text = claniz_get_post_format_value($args['post_id'], 'post-quote-text', '');
        $cite = claniz_get_post_format_value($args['post_id'], 'post-quote-cite', '');
        $quote = '';
        $quote_attrs = $quote_style = [];
        $quote_css_class = ['quote-wrap'];
        
        // Inline Style
        if(has_post_thumbnail($args['post_id'])) {
            $quote_style[] = 'background-image:url('.get_the_post_thumbnail_url($args['post_id']).')';
            $quote_css_class[] = 'has-bg';
        }
        $quote_attrs[] = 'class="'.trim(implode(' ', $quote_css_class)).'"';
        if(!empty($quote_style)) $quote_attrs[] = 'style="'.trim(implode(';', $quote_style)).'"'; 

        ob_start();
            printf('%s', $args['before']);
                if(!empty($text) || !empty($cite)){
                    echo '<div '.trim(implode(' ', $quote_attrs)).'><blockquote><div class="quote-text">'.$text.'</div><cite>'.$cite.'</cite></blockquote></div>';
                } else {
                    claniz_post_thumbnail($args);
                }
            printf('%s', $args['before']);

        if($args['echo'])
            echo ob_get_clean();
        else 
            return ob_get_clean();
    }
}
/**
 * Post Link
 * @since 1.0.0
*/
if(!function_exists('claniz_post_link')){
    function claniz_post_link($args = []){
        $args = wp_parse_args($args, [
            'post_id'   => null,
            'size'      => is_single() ? 'post-thumbnail' : 'large',
            'echo'      => true,
            'class'     => '',
            'img_class' => '',
            'before'    => '',
            'after'     => '',
            'show_link' => is_single() ? false : true,
        ]);

        $title = claniz_get_post_format_value($args['post_id'], 'post-link-title', __('View Our Portfolio','claniz'));
        $link = claniz_get_post_format_value($args['post_id'], 'post-link-url', 'https://themeforest.net/user/cmssuperheroes/portfolio');
        if(empty($link)) return;
        
        // Link attribute
        $link_attrs = $link_style = [];
        $link_css_class = ['link-wrap'];
        // Inline Style
        if(has_post_thumbnail($args['post_id'])) {
            $link_style[] = 'background-image:url('.get_the_post_thumbnail_url($args['post_id']).')';
            $link_css_class[] = 'has-bg';
        }
        $link_attrs[] = 'class="'.trim(implode(' ', $link_css_class)).'"';
        if(!empty($link_style)) $link_attrs[] = 'style="'.trim(implode(';', $link_style)).'"';
        // Build Content
        ob_start();
        printf('%s', $args['before']);
        if(!empty($link)) {
        ?>
            <div class="<?php echo trim(implode(' ', $link_attrs));?>">
                <a href="<?php echo esc_url($link);?>" class="btn btn-fill btn-accent btn-hover-secondary" target="_blank">
                    <span class="btn-title"><?php echo esc_html($title);?></span>
                </a>
            </div>
        <?php } else {
            claniz_post_thumbnail($args);
        }
        printf('%s', $args['before']);

        if($args['echo'])
            echo ob_get_clean();
        else 
            return ob_get_clean();
    }
}

/**
 * Post Image
 * @since 1.0.0
*/
if(!function_exists('claniz_post_image')){
    function claniz_post_image($args = []){
        $args = wp_parse_args($args, [
            'post_id'   => null,
            'size'      => is_single() ? 'post-thumbnail' : 'large',
            'echo'      => true,
            'class'     => '',
            'img_class' => '',
            'before'    => '',
            'after'     => '',
            'show_link' => is_single() ? false : true,
        ]);   
        claniz_post_thumbnail($args);
    }
}
/**
 * Post Media
 * @since 1.0.1
*/
if(!function_exists('claniz_post_media')){
    function claniz_post_media($args = []){
        $args = wp_parse_args($args, [
            'post_id'   => null,
            'size'      => is_single() ? 'post-thumbnail' : 'large',
            'echo'      => true,
            'class'     => '',
            'img_atts'  => [],
            'before'    => '',
            'after'     => '',
            'show_link' => is_single() ? false : true,
            'default'   => false,
            //
            'wrap_class'    => '',
            'media_content' => true,
            'media_before'  => '',
            'media_after'   => '',
            //as background
            'as_background' => false
        ]);
        do_action('claniz_before_post_media');
        $post_format = !empty(get_post_format($args['post_id'])) ? get_post_format($args['post_id']) : 'standard';

        $classes = [
            'cms-featured',
            'cms-post-'.$post_format,
        ];
        $classes[] = claniz_is_loop() ? 'loop' : '';
        if(!empty($args['wrap_class'])) $classes[] = $args['wrap_class'];
    ?>
    <div class="<?php echo trim(implode(' ', $classes));?>"><div class="cms-featured-inner relative h-100"><?php
        printf('%s', $args['media_before']);
            switch (get_post_format($args['post_id'])) {
                case 'gallery':
                    claniz_post_gallery($args);
                    break;
                case 'video':
                    claniz_post_video($args);
                    break;
                case 'audio':
                    claniz_post_audio($args);
                    break;
                case 'quote':
                    claniz_post_quote($args);
                    break;
                case 'link':
                    claniz_post_link($args);
                    break;
                 case 'image':
                    claniz_post_image($args);
                    break;
                default:
                    claniz_post_thumbnail($args);
                    break;
            }
            
        if($args['media_content']) do_action('claniz_post_media_content', $args);

        printf('%s', $args['media_after']);
        
    ?></div></div>
    <?php
        do_action('claniz_after_post_media');
    }
}

/**
 * Post Date on Media
 * action hook: claniz_post_media_content
 * @since 1.0.0
 * add_action('claniz_post_media_content', 'claniz_post_date_on_media', 10);
*/
if(!function_exists('claniz_post_date_on_media')){
    //add_action('claniz_post_media_content', 'claniz_post_date_on_media', 10);
    function claniz_post_date_on_media($args =[]){
        $args = wp_parse_args($args, [
            'show_date' => is_singular() ? claniz_get_opts('post_date_on', '1' ) : claniz_get_opts('archive_date_on', '1' ),
        ]);
        if($args['show_date'] !== '1') return;
        extract($args);
        ob_start();
            echo '<div class="cms-post-date-on-media bg-white cms-radius-tl-br-8 text-616161 text-center text-small">'
            //.'<div class="date text-26 lh-26 font-700">'.get_the_date( 'd', $args['id']).'</div>'
            //.'<div class="month text-13 lh-13">'.get_the_date( 'M', $args['id']).'</div>'
            //.'<div class="year text-13 lh-13">'.get_the_date( 'Y', $args['id']).'</div>'
            .get_the_date( 'M d, Y', $args['id'])
            .'</div>';
        if($args['echo'])
            echo ob_get_clean();
        else 
            return ob_get_clean();
    }
}
/**
 * Post Author's on Media 
 * action hook : claniz_post_thumbnail_content
 * @since 1.0.0
*/
if(!function_exists('claniz_post_author_on_media')){
    function claniz_post_author_on_media($args = []){
        $args = wp_parse_args($args, [
			'echo'        => true,
			'show_author' => is_singular() ? claniz_get_opts('post_author_on','1') : claniz_get_opts('archive_author_on','1')
        ]);
        extract($args);

        if('1' !== $show_author) return;

        ob_start();
            echo '<div class="post-author">'
            .get_avatar(get_the_author_meta('ID'), 30,  '' , get_the_author(), array('class' => 'circle')).'&nbsp;&nbsp;'
            .esc_html__('By','claniz').':&nbsp;'
            .get_the_author_posts_link()
            .'</div>';
        if($args['echo'])
            echo ob_get_clean();
        else 
            return ob_get_clean();
    }
}

/**
 * Post Category on Media
 * action hook: claniz_post_thumbnail_content
 * @since 1.0.0
 * add_action('claniz_post_thumbnail_content', 'claniz_post_category_on_media', 10);
*/
if(!function_exists('claniz_post_category_on_media')){
    function claniz_post_category_on_media($args =[]){
        $args = wp_parse_args($args, [
            'echo'     => true,
            'show_cat' => is_singular() ? claniz_get_opts('post_categories_on','1') : claniz_get_opts('archive_categories_on','1'),
            'taxonomy' => 'category',
            'before'   => '<span class="icon-pencil icon"></span>',
            'sep'      => ' / ',
            'after'    => ''
        ]);
        extract($args);
        if('1' !== $show_cat) return;

        ob_start();
            echo '<div class="post-category badge-info">'
            .get_the_term_list( get_the_ID(), $taxonomy, $before, $sep, $after )
            .'</div>';
        if($args['echo'])
            echo ob_get_clean();
        else 
            return ob_get_clean();
    }
}

/**
 * Read more on media 
 *
*/
if(!function_exists('claniz_post_readmore_on_media')){
    function claniz_post_readmore_on_media($args=[]){
        $args = wp_parse_args($args, [
            'icon' => 'cmsi-plus',
        ]);
        ob_start();
    ?>
        <a class="overlay gradient-btt" href="<?php the_permalink();?>">
            <span class="icon-readmore <?php echo esc_attr($args['icon']);?>"></span>
        </a>
    <?php
        echo ob_get_clean();
    }
}