<?php
/* Meta Post Author */
if(!function_exists('claniz_post_author')){
    function claniz_post_author($args = []){
        $args = wp_parse_args($args,[
            'post_id'      => get_the_ID(),
            'show_author'  => '1',
            'author_title' => '',  
            'author_class' => '',  
            'class'        => '',
            'text'        => esc_html__('By:','claniz'),
            'show_icon'    => true,
            'icon'         => 'cmsi-user',
            'icon_class'   => 'text-accent',
            'echo'         => true
        ]);

        if($args['show_author']!='1') return;
        ob_start();
    ?>
        <span class="<?php echo trim(implode(' ', ['cms-post-author', $args['class']]));?>">
            <span class="meta-inner">
                <?php 
                	if($args['show_icon']){
    	                // author icon
    	                $icon_class = implode(' ', ['meta-icon', $args['icon'], $args['icon_class']]);
    	                if(!empty($args['icon'])) echo '<span class="'.esc_attr($icon_class).'">&nbsp;</span>';
    	            }
                    // Author text
                    if(!empty($args['text'])):  echo '<span>'.esc_html($args['text']).'&nbsp;</span>'; endif; 
                    // Author name
                    $my_post = get_post( $args['post_id'] );
                    $user_id = $my_post->post_author;
                    $author_url = get_author_posts_url($user_id);
                    $author_url2 = get_the_author_meta( 'user_url', $user_id );
                    if(!empty($args['author_title'])) echo '<span class="title">'.$args['author_title'].'</span>';
                ?>
                <a class="<?php echo esc_attr($args['author_class']); ?>" href="<?php echo esc_url($author_url); ?>" title="<?php the_author_meta('display_name', $user_id); ?>"><?php the_author_meta('display_name', $user_id); ?></a>
            </span>
        </span>
    <?php
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
/* Meta Post Category */
if(!function_exists('claniz_get_the_term_list')){
    function claniz_get_the_term_list( $post_id, $taxonomy, $sep = '', $class = '' ) {
        $terms = get_the_terms( $post_id, $taxonomy );
        
        if ( is_wp_error( $terms ) ) {
            return $terms;
        }
     
        if ( empty( $terms ) ) {
            return false;
        }
     
        $links = array();
     
        foreach ( $terms as $term ) {
            $link = get_term_link( $term, $taxonomy );
            if ( is_wp_error( $link ) ) {
                return $link;
            }
            $links[] = '<a href="' . esc_url( $link ) . '" class="'.claniz_nice_class(['cms-term', $class]).'">' . $term->name . '</a>';
        }
     
        /**
         * Filters the term links for a given taxonomy.
         *
         * The dynamic portion of the hook name, `$taxonomy`, refers
         * to the taxonomy slug.
         *
         * Possible hook names include:
         *
         *  - `term_links-category`
         *  - `term_links-post_tag`
         *  - `term_links-post_format`
         *
         * @since 2.5.0
         *
         * @param string[] $links An array of term links.
         */
        $term_links = apply_filters( "cms_term_links-{$taxonomy}", $links );  // phpcs:ignore WordPress.NamingConventions.ValidHookName.UseUnderscores
     
        return implode( $sep, $term_links );
    }
}
if(!function_exists('claniz_the_terms')){
    function claniz_the_terms( $post_id, $taxonomy, $sep = ', ', $class = '' ) {
        $term_list = claniz_get_the_term_list( $post_id, $taxonomy, $sep, $class );
        if ( is_wp_error( $term_list ) ) {
            return false;
        }
     
        /**
         * Filters the list of terms to display.
         *
         * @since 2.9.0
         *
         * @param string $term_list List of terms to display.
         * @param string $taxonomy  The taxonomy name.
         * @param string $sep       String to use between the terms.
         * @param string $class     CSS class to use in the terms.
         */
        echo apply_filters( 'cms_the_terms', $term_list, $taxonomy, $sep, $class );
    }
}
if(!function_exists('claniz_post_category')){
    function claniz_post_category($args = []){
        $args = wp_parse_args($args,[
            'show_cat'         => '1',
            'class'            => '',
            'inner_class'      => '',
            'text'             => '',
            'show_icon'        => true,
            'icon'             => 'cmsi-folder-open1',
            'icon_class'       => 'text-accent',
            'link_class'       => '',
            'taxo'             => 'category',
            'separator'        => ', ',
            'post_id'          => get_the_ID(),
            'echo'             => true,
            'before'           => '',
            'after'            => ''    
        ]);
        if($args['show_cat']!='1' || !get_the_terms($args['post_id'], $args['taxo'])) return;
        ob_start();
        printf('%s', $args['before']);
    ?>
        <span class="<?php echo trim(implode(' ', ['cms-post-cat', $args['class']]));?>">
            <span class="<?php echo claniz_nice_class(['meta-inner', $args['inner_class']]) ?>">
                <?php 
                	if($args['show_icon']){
    	                // cat icon
    	                $icon_class = implode(' ', ['meta-icon',$args['icon'], $args['icon_class']]);
    	                if(!empty($args['icon'])) echo '<span class="'.esc_attr($icon_class).'">&nbsp;</span>';
    	            }
                    // cat text
                    if(!empty($args['text'])):  echo '<span>'.esc_html($args['text']).'&nbsp;</span>'; endif; 
                    // cat list
                    claniz_the_terms( $args['post_id'], $args['taxo'], $args['separator'], $args['link_class'] );
                ?>
            </span>
        </span>
    <?php
        printf('%s', $args['after']);
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
/* Meta Post Comment */
if(!function_exists('claniz_post_comment')){
    function claniz_post_comment($args = []){
        $args = wp_parse_args($args,[
            'post_id'       => get_the_ID(),
			'show_cmt'      => true,
			'text'          => esc_html__('Comments','claniz'),
			'class'         => '',
			'show_icon'     => true,
			'icon'          => 'cmsi-comments1',
			'icon_class'    => 'text-accent',
            'link_class'    => '',
            'number_class'  => '',
			'cmt_with_text' => true,
            'echo'          => true
        ]);

        if($args['show_cmt']!='1') return;
        ob_start();
    ?>
        <span class="<?php echo trim(implode(' ', ['cms-post-cmt', $args['class']]));?>">
            <span class="meta-inner">
                <?php 
                	if($args['show_icon']){
    	                // comment icon
    	                $icon_class = implode(' ', ['meta-icon', $args['icon'], $args['icon_class']]);
    	                if(!empty($args['icon'])) echo '<span class="'.esc_attr($icon_class).'"></span>';
    	            }
                    // comment text
                    if(!empty($args['text'])):  echo '<span>'.esc_html($args['text']).'&nbsp;</span>'; endif; 
                ?>
                <a class="cms-scroll <?php echo esc_attr($args['link_class']); ?>" href="<?php the_permalink();?>#comments"><?php
                    if($args['cmt_with_text']) 
                        echo comments_number(
                            esc_html__('Comments: ', 'claniz').'<span class="cmt-count '.$args['number_class'].'">0</span>',
                            esc_html__('Comment: ', 'claniz').'<span class="cmt-count '.$args['number_class'].'">1</span>',
                            esc_html__('Comments: ', 'claniz').'<span class="cmt-count '.$args['number_class'].'">%</span>',
                            $args['post_id']
                        ); 
                    else 
                        echo comments_number(
                            '<span class="cmt-count '.$args['number_class'].'">0</span>',
                            '<span class="cmt-count '.$args['number_class'].'">1</span>',
                            '<span class="cmt-count '.$args['number_class'].'">%</span>',
                            $args['post_id']
                        );
                ?></a>
            </span>
        </span>
    <?php
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}
/* Meta post author */
if(!function_exists('claniz_post_date')){
    function claniz_post_date($args = []){
        $args = wp_parse_args($args, [
            'post_id'     => get_the_ID(),
			'show_date'   => true,
			'date_format' => get_option('date_format'),
			'class'       => '',
			'show_icon'   => true, 
			'icon'        => 'cmsi-clock',
			'icon_class'  => 'text-accent',
            'echo'        => true  
        ]);
        if($args['show_date']!='1'  || claniz_is_post_type('product', $args['post_id'])) return;
        ob_start();
        ?>
        <span class="<?php echo trim(implode(' ', ['cms-post-date', $args['class']]));?>">
            <span class="meta-inner">
                <?php 
                	if($args['show_icon']){
    	                // date icon
    	                $icon_class = implode(' ', ['meta-icon', $args['icon'], $args['icon_class']]);
    	                if(!empty($args['icon'])) echo '<span class="'.esc_attr($icon_class).'"></span>';
    	            }
                ?>
                <span><?php echo get_the_date($args['date_format'], $args['post_id'] ); ?></span>
            </span>
        </span>
        <?php
        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}

/**
 * Prints post meta
 */
if ( ! function_exists( 'claniz_post_meta' ) ) {
    function claniz_post_meta($args=[]) { 
        $args = wp_parse_args($args,[
            'show_author' => claniz_get_theme_opt( 'archive_author_on', '1' ),
            'author_title' => '',
            'show_cat'    => claniz_get_theme_opt( 'archive_categories_on', '1' ),
            'show_cmt'    => claniz_get_theme_opt( 'archive_comments_on', '1' ),
            'show_date'   => claniz_get_theme_opt( 'archive_date_on', '1' ),
            'show_icon'	  => true, 
            'class'       => '',
            'inner_class' => '',
            'item_class'  => '',
            'post_id'     => get_the_ID(),
            'date_format' => get_option('date_format'),
            'gutters'	  => '20',
            'taxo'        => claniz_get_custom_post_taxonomies(get_post_type(), 'cat'),
            'separator'   => '',
            'echo'        => true
        ]);
       	$inner_class = ['cms-post-meta-inner', 'row gutters-grid align-items-center', 'gutters-'.$args['gutters'], $args['inner_class']];
        $category = $metas = [];
        if($args['show_cat']=='1'){
            $category = claniz_post_category([
                'show_icon'   => $args['show_icon'],
                'show_cat'    => $args['show_cat'],
                'class'       => 'col-auto',
                'inner_class' => 'bg-darken-secondary text-white cms-radius-2 d-block p-tb-10 p-lr-15',
                'link_class'  => 'text-white text-hover-primary',
                'post_id'     => $args['post_id'],
                'text'        =>  '',
                'taxo'        => $args['taxo'],
                'echo'        => false  
            ]);
        }
        if($args['show_date']=='1' || !claniz_is_post_type('product', $args['post_id'])){
            $metas[] = claniz_post_date([
                'post_id'     => $args['post_id'],
                'show_date'   => $args['show_date'],
                'show_icon'   => $args['show_icon'],
                'date_format' => $args['date_format'],
                'class'       => 'col-auto text-custom-4 '.$args['item_class'],
                'echo'        => false
            ]);
        }
        if($args['show_author']=='1'){
            $metas[] = claniz_post_author([
                'post_id'      => $args['post_id'],
                'show_author'  => $args['show_author'],
                'author_title' => '',
                'author_class' => 'text-custom-3 text-hover-secondary', 
                'show_icon'    => $args['show_icon'],
                'class'        => 'col-auto '.$args['item_class'],
                'echo'         => false
            ]);
        }
        if($args['show_cmt']=='1'){    
            $metas[] = claniz_post_comment([
                'post_id'      => $args['post_id'],
                'show_icon'    => $args['show_icon'],
                'show_cmt'     => $args['show_cmt'],
                'class'        => 'col-auto '.$args['item_class'],
                'link_class'   => 'text-body',
                'number_class' => 'text-custom-3 text-hover-secondary',
                'text'         => '',
                'echo'         => false
            ]);
        }
        ob_start();
        if($args['show_author']=='1' || $args['show_cat']=='1' || $args['show_cmt']=='1' || $args['show_date']=='1') : ?>
            <div class="<?php echo implode(' ', ['cms-post-meta', $args['class']]); ?>">
                <div class="<?php echo trim(implode(' ', $inner_class));?>">
                    <?php 
                        printf('%s', $category); 
                        echo '<div class="col-auto"><div class="bg-white cms-shadow-1 cms-radius-2 p-tb-10 p-lr-15"><div class="row gutters-10">'.implode($args['separator'], $metas).'</div></div></div>';
                    ?>
                </div>
            </div>
        <?php endif;

        if( $args['echo'] ){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}

/**
 * Prints tag list
 */
if ( ! function_exists( 'claniz_post_tagged_in' ) ) :
    /**
     * Prints HTML with meta information for the current post-date/time.
     */
    function claniz_post_tagged_in($args = [])
    {
        $args = wp_parse_args($args, [
            'title'    => '',
            'class'    => '',
            'style'    => 'tagcloud',     
            'show_tag' => '1',
            'post_id'  => get_the_ID(),
            'separator' => '',
        ]);
        if($args['show_tag'] !== '1') return;
        $tags_list = get_the_tag_list( '<div class="'.$args['style'].'">', $args['separator'], '</div>', $args['post_id']);
        if ( $tags_list )
        {
            echo '<div class="'.trim(implode(' ', ['cms-post-tags', $args['class']])).'"><div class="row gutters-10 gutters-grid align-items-center">';
                if($args['title'] != '') printf('%s', $args['title']);
                printf('<div class="col">%2$s</div>', '', $tags_list);
            echo '</div></div>';
        }
    }
endif;