<?php
/**
 * Page title layout
 **/
if(!function_exists('claniz_page_title_layout')){
    function claniz_page_title_layout($args = []) {
        if(is_singular('cms-header-top') || is_singular('cms-footer') || is_singular('cms-mega-menu') || is_404()) return;
        $post_type = get_post_type();
        $remove = ['service', 'cms-doctor'];
        if(in_array($post_type, $remove)) return;
        $all = ['page','cms-department', 'service', 'events','cms-doctor'];
        if(!in_array($post_type, $all) && is_singular($post_type)){
            $show_pagetitle  = ( claniz_get_opts( $post_type.'_pagetitle', '1' ) ) === '-1' ? claniz_get_opts( 'pagetitle', '1' ) : claniz_get_opts( $post_type.'_pagetitle', '1' );
            if($show_pagetitle !== '-1'){
                $ptitle_layout = claniz_get_opts( $post_type.'_ptitle_layout', claniz_configs('single_'.$post_type)['title_layout'] );

                $show_title      = ( claniz_get_opts( $post_type.'_ptitle_title_on', '1') ) === '-1' ? claniz_get_opts( 'ptitle_title_on', '1') : claniz_get_opts( $post_type.'_ptitle_title_on', '1');
                $title_position  = ( claniz_get_opts( $post_type.'_ptitle_title_position', '') ) === '-1' ?  claniz_get_opts( 'ptitle_title_position', 'first') :  claniz_get_opts( $post_type.'_ptitle_title_position', 'first');
                $show_breadcrumb = ( claniz_get_opts( $post_type.'_ptitle_breadcrumb_on', '1' ) ) === '-1' ? claniz_get_opts( 'ptitle_breadcrumb_on', '1' ) : claniz_get_opts( $post_type.'_ptitle_breadcrumb_on', '1' );
            }
        } else {
            $show_pagetitle  = claniz_get_opts( 'pagetitle', '1' );
            $ptitle_layout   = claniz_get_opts( 'ptitle_layout', claniz_configs('ptitle')['layout'] );

            $show_title      = claniz_get_opts( 'ptitle_title_on', '1');
            $title_position  = claniz_get_opts( 'ptitle_title_position', 'first');
            $show_breadcrumb = claniz_get_opts( 'ptitle_breadcrumb_on', '1' );
        }
        
    	if($show_pagetitle !== '1' || ($show_title !== '1' && $show_breadcrumb !== '1') ) return;

    	$args = wp_parse_args($args, [
            'class'      => ''
    	]);

        // Wrap 
        $wrap_class = [
            'cms-pagetitle',
            'cms-pagetitle-layout'.$ptitle_layout,
            'relative',
            $args['class']
        ];
        $overlay_class = [
            'cms-page-title-overlay',
            'cms-overlay'
        ];
        
        // Inner 
        $inner_class = ['cms-page-title-inner', 'relative'];
        // Title
        $ptitle_class = [];
        $title_class = ['heading text-30 text-md-50 text-lg-50 text-xl-75'];
        $sub_title_class = ['text-18', 'font-700']; 
        // Breadcrumb
        $breadcrumb_class     = ['cms-pagetitle-breadcrumb'];
        $breadcrumb_item_class = '';

        // 
        if(is_singular() && !in_array($post_type, $all) && in_array($ptitle_layout, ['10'])) {
            $wrap_class[] = 'single';
            $overlay_class[] = 'single';
            $breadcrumb_item_class = 'breadcrumb-item-single';

            // content align
            $ptitle_class[] = claniz_get_opts($post_type.'_ptitle_content_alignment');
            $breadcrumb_class[] = 'p-tb-11 lh-26 justify-content-'.str_replace('text-', '', claniz_get_opts($post_type.'_ptitle_content_alignment'));
        } else {
            $ptitle_class[] = claniz_get_opts('ptitle_content_alignment');
            $breadcrumb_class[] = 'justify-content-'.str_replace('text-', '', claniz_get_opts('ptitle_content_alignment'));
        }

        switch ($ptitle_layout) {
            case '10':
                 //$breadcrumb_class[] = 'p-tb-15 justify-content-'.str_replace('text-', '', claniz_get_opts($post_type.'_ptitle_content_alignment'));
                break;
            case '2':
                $wrap_class[] = 'p-tb-30 p-tb-lg-70 p-tb-xl-120';
                // Title position text align 
                if($title_position === 'last') {
                    $title_class[] = 'text-end';
                } else {
                    $breadcrumb_class[] = 'justify-content-lg-end';
                }
                break;
            case '1':
                $wrap_class[] = 'p-tb-30 p-tb-lg-70 p-tb-xl-120';
                $breadcrumb_class[] = 'mt-n8';
                break;
        }
        $ptitle_class     = implode(' ', $ptitle_class);
        $title_class      = implode(' ', $title_class);
        $sub_title_class  = implode(' ', $sub_title_class);
        $breadcrumb_class = implode(' ', $breadcrumb_class);
     	?>
    	<div id="cms-pagetitle" class="<?php echo trim(implode(' ', $wrap_class));?>">
        	<?php if(!in_array($ptitle_layout, ['10'])): ?>
                <div class="<?php echo trim(implode(' ', $overlay_class));?>"></div>
            <?php endif; ?>
    		<div class="<?php echo claniz_nice_class($inner_class); ?>">
    			<?php
                    switch ($ptitle_layout) {
                        case '10':
                            claniz_breadcrumb([
                                'class'                 => $breadcrumb_class,
                                'breadcrumb_item_class' => $breadcrumb_item_class,
                                'before'                => '<div class="container cms-breadcrumb-container">',
                                'after'                 => '</div>'
                            ]);
                        break;
                        case '2':
                            printf('%s', '<div class="container"><div class="row align-items-center">');
                                claniz_page_title([
                                    'before'      => '<div class="col-lg-6 order-'.$title_position.'">',
                                    'after'       => '</div>',
                                    'class'       => $ptitle_class,
                                    'title_class' => $title_class,
                                    'sub_class'   => $sub_title_class
                                ]);
                                claniz_breadcrumb([
                                    'before'                => '<div class="col-lg-6">',
                                    'after'                 => '</div>',
                                    'class'                 => $breadcrumb_class,
                                    'breadcrumb_item_class' => $breadcrumb_item_class
                                ]);
                            printf('%s', '</div></div>');
                        break;
                        default:
                            claniz_page_title([
                                'class'       => $ptitle_class,
                                'title_class' => $title_class,
                                'sub_class'   => $sub_title_class,
                                'before'  => '<div class="container cms-ptitle-container">',
                                'after'   => '</div>'
                            ]);
                            claniz_breadcrumb([
                                'class'                 => $breadcrumb_class,
                                'breadcrumb_item_class' => $breadcrumb_item_class,
                                'before'                => '<div class="container cms-breadcrumb-container">',
                                'after'                 => '</div>'
                            ]);
                        break;
                    }
                ?>
    		</div>
            <?php //claniz_ptitle_scroll(['layout' => $ptitle_layout, 'exclude' => ['10'], 'class' => 'absolute']); ?>
        </div>
        <?php
    }
}

/**
 * Page Title 
*/
if(!function_exists('claniz_page_title')){
	function claniz_page_title($args = []){
		$show_title = claniz_get_opts('ptitle_title_on', '1');
		if($show_title !== '1') return;
		$args = wp_parse_args($args, [
            'class'      => '',
            'title_class' => 'cms-heading',
            'sub_class'  => '',
            'before'     => '',
            'after'      => ''
		]);
		$titles = claniz_get_page_titles();
		printf('%s', $args['before']);
            printf('<div class="cms-page-title %1$s">', $args['class']);
    			if (!empty($titles['title'])){
    			    printf( '<div class="main-title %1$s">%2$s</div>',$args['title_class'], $titles['title'] );
    			}
    	        if(!empty($titles['sub_title'])) { 
    	        	printf( '<div class="cms-page-sub-title %1$s">%2$s</div>',$args['sub_class'], $titles['sub_title']);
    	        }
                ?>
                <div class="cms-ptitle-buttons row gutters-30 gutters-grid pt-35 empty-none justify-content-<?php echo str_replace('text-', '', claniz_get_opts('ptitle_content_alignment') ); ?>"><?php
                claniz_ptitle_button([
                    'name'     => 'ptitle_btn1',
                    'btn_args' => [
                        'class'     => 'col-auto',
                        'btn_class' => 'btn btn-xl btn-white btn-hover-accent'
                    ]
                ]);
                claniz_ptitle_button([
                    'name'     => 'ptitle_btn2',
                    'btn_args' => [
                        'btn_class' => 'btn btn-xl btn-outline btn-white btn-hover-white',
                        'icon'      => '',
                        'class'     => 'col-auto',
                    ]
                ]);
                ?></div>
                <?php
            printf('%s','</div>');
        printf('%s', $args['after']);
	}
}

/**
 * Prints HTML for breadcrumbs.
 */
if(!function_exists('claniz_breadcrumb')){
    function claniz_breadcrumb($args = []){
        $args = wp_parse_args($args, [
            'show_breadcrumb'       => claniz_get_opts( 'ptitle_breadcrumb_on', '1' ),
            'before'                => '',
            'after'                 => '',
            'show_divider'          => true,
            'divider_icon'          => 'cmsi-chevron-right',
            'divider_class'         => '',
            'class'                 => '',
            'link_class'            => '',
            'text_class'            => '',
            'breadcrumb_item_class' => ''
        ]);
        if ($args['show_breadcrumb'] !== '1' )
        {
            return;
        }

        $breadcrumb = new CMS_Breadcrumb();
        $entries = $breadcrumb->get_entries();
        if ( empty( $entries ) )
        {
            return;
        }
        $divider = '';
        if($args['show_divider']){
            $divider = '<span class="'.implode(' ', ['breadcrumb-divider', $args['divider_class'], $args['divider_icon'], 'rtl-flip']).'"></span>';
        }
        $breadcrumb_item_class = ['breadcrumb-item', 'd-flex', 'align-items-center'];
        $breadcrumb_item_class[] = $args['breadcrumb_item_class'];

        ob_start();
        foreach ( $entries as $entry )
        {
            $entry = wp_parse_args( $entry, array(
                'label' => '',
                'url'   => ''
            ) );

            if ( empty( $entry['label'] ) )
            {
                continue;
            }

            echo '<div class="'.trim(implode(' ', $breadcrumb_item_class)).'">';

            if ( ! empty( $entry['url'] ) )
            {
                printf(
                    '<a class="breadcrumb-link '.$args['link_class'].'" href="%1$s">%2$s</a>%3$s',
                    esc_url( $entry['url'] ),
                    esc_attr( $entry['label'] ),
                    $divider
                );
            }
            else
            {
                printf( '<span class="breadcrumb-text '.$args['text_class'].'" >%s</span>%2$s', $entry['label'], $divider );
            }

            echo '</div>';
        }

        $output = ob_get_clean();

        if ( $output )
        {
        	printf('%s', $args['before']);
            printf( '<div class="cms-breadcrumb %s">%s</div>', $args['class'], $output);
            printf('%s', $args['after']);
        }
    }
}

// Page Title Button 
if(!function_exists('claniz_ptitle_button')){
    function claniz_ptitle_button($args=[]){
        $args = wp_parse_args($args, [
            'prefix'   => '',
            'name'     => 'ptitle_btn1',
            'btn_args' => []
        ]);
        $h_btn_on          = claniz_get_opts( $args['prefix'].$args['name'].'_on', '0' );
        if($h_btn_on == '0') return;
        $h_btn_text        = claniz_get_opts( $args['prefix'].$args['name'].'_text', 'Your Text' );
        $h_btn_link_type   = claniz_get_opts( $args['prefix'].$args['name'].'_link_type', 'page' );
        $h_btn_link        = claniz_get_opts( $args['prefix'].$args['name'].'_link' );
        $h_btn_link_custom = claniz_get_opts( $args['prefix'].$args['name'].'_link_custom' );
        $h_btn_target      = claniz_get_opts( $args['prefix'].$args['name'].'_target', '_self' );
        if($h_btn_link_type == 'page') {
            $h_btn_url = get_permalink($h_btn_link);
        } else {
            $h_btn_url = $h_btn_link_custom;
        }
        $btn_args = wp_parse_args($args['btn_args'],[
            'class'      => '',
            'btn_class'  => 'btn btn-fill btn-xl',
            'icon'       => 'cmsi-arrow-right',
            'icon_size'  => '',
            'icon_class' => '',
            'icon_order' => 'last',
            'btn_text'   => $h_btn_text
        ]);
        $btn_icon = '';
        if(!empty($btn_args['icon'])){
            $btn_icon = '<span class="'.implode(' ', ['cms-btn-icon rtl-flip', 'order-'.$btn_args['icon_order'], $btn_args['icon_class'], $btn_args['icon_size'], $btn_args['icon']]).'"></span>';
        }
        ?>
            <div class="<?php echo trim(implode(' ', ['cms-ptitle-btn', $btn_args['class']])); ?>">
                <a href="<?php echo esc_url( $h_btn_url ); ?>" target="<?php echo esc_attr($h_btn_target); ?>" class="<?php echo trim(implode(' ', ['ptitle-btn', $btn_args['btn_class']])); ?>">
                    <span class="cms-btn-content">
                        <?php printf('%s', $btn_icon); ?>
                        <span class="cms-btn-text empty-none"><?php  echo esc_html( $btn_args['btn_text'] ); ?></span>
                    </span>
                </a>
            </div>
    <?php
    }
}
// Page title Scroll 
if(!function_exists('claniz_ptitle_scroll')){
    function claniz_ptitle_scroll($args = []){
        $args = wp_parse_args($args, [
            'exclude'    => [],
            'layout'     => '',
            'icon'       => 'cmsi-long-arrow-down',
            'icon_class' => 'cms-fade-move-down w-100 text-white',
            'bg'         => 'white',
            'class'      => ''
        ]);
        if(in_array($args['layout'], $args['exclude'])) return;

        $wrap_class = ['cms-ptitle-scroll', 'd-flex', 'w-100', $args['class']];
        $left_class = ['cms-ptitle-scroll-bg', 'bg-'.$args['bg'], 'col'];
        $right_class = ['cms-ptitle-scroll-icons','d-flex','align-items-center', 'text-center'];
        $icon_class = [$args['icon_class'], $args['icon']];
    ?>
        <div class="<?php echo claniz_nice_class($wrap_class); ?>">
            <div class="<?php echo claniz_nice_class($left_class); ?>"></div>
            <a href="#cms-main" class="<?php echo claniz_nice_class($right_class); ?>"><span class="cms-ptitle-scroll-icon w-100"><span class="<?php echo claniz_nice_class($icon_class); ?>"></span></span></a>
        </div>
    <?php
    }
}