<?php
if(!function_exists('claniz_get_sidebar')){
    function claniz_get_sidebar($check = true){
        global $wp_query;
        if ( isset($_GET['post_type'])) {
            $sidebar = 'sidebar-'.$_GET['post_type'];
        } elseif (isset($wp_query->post->post_type) && !is_search()){
            $sidebar = 'sidebar-'.$wp_query->post->post_type;
        } elseif ( is_search() ) {
            $sidebar = 'sidebar-post';
        } elseif ( class_exists('WooCommerce') && is_shop() ) {
            $sidebar = 'sidebar-product';
        } else {
            $sidebar = 'sidebar-post';
        }

        if($check)
            return is_active_sidebar($sidebar);
        else 
            return $sidebar;
    }
}
if(!function_exists('claniz_sidebar_position')){
    function claniz_sidebar_position($args = []){ 
        global $wp_query;
        $args = wp_parse_args($args, [
            'sidebar_pos' => 'archive_sidebar_pos'
        ]);
        $sidebar_pos = claniz_get_opts($args['sidebar_pos'], claniz_configs('blog')['archive_sidebar_pos']);
        return $sidebar_pos;
    }
}
/*
 * Sidebar area css class
*/
function claniz_sidebar_css_class($args=[]){
    $args = wp_parse_args($args, [
        'content_col' => 'archive_content_col',
        'sidebar_pos' => 'archive_sidebar_pos',
        'class'       => ''
    ]);
    $classes = [
        'cms-sidebar-area',
        'cms-sidebar-area-'.claniz_sidebar_position(['sidebar_pos' => $args['sidebar_pos']])
    ];
    $sidebar_position   = claniz_sidebar_position(['sidebar_pos' => $args['sidebar_pos']]);
    if( in_array($sidebar_position, ['0', 'none', 'bottom']) ){
        $classes[] = 'col-12';
    } else {
        $content_grid_class = (int) claniz_get_opts($args['content_col'], claniz_configs('blog')['archive_content_col']);
        $sidebar_grid_class = 12 - $content_grid_class;
        $classes[] = 'col-lg-'.$sidebar_grid_class; 
    }
    $classes[] = $args['class'];
    echo trim(implode(' ', $classes));
}
/**
 * Show Sidebar
*/
function claniz_sidebar($args = []){
    $args = wp_parse_args($args, [
        'content_col' => 'archive_content_col',
        'sidebar_pos' => 'archive_sidebar_pos',
        'class'       => '',
        'inner_class' => ''
    ]);
    $sidebar            = claniz_get_sidebar(false);
    $sidebar_position   = claniz_sidebar_position([
        'sidebar_pos' => $args['sidebar_pos']
    ]);
    $inner_class = implode(' ', ['cms-sidebar-area-inner', $args['inner_class']]);
    if( in_array($sidebar_position, ['0','none']) ) return;
    ?>
    <div id="cms-sidebar-area" class="<?php claniz_sidebar_css_class(['content_col' => $args['content_col'], 'sidebar_pos' => $args['sidebar_pos'],'class' => $args['class']]); ?>">
        <div class="<?php echo esc_attr($inner_class);?>"><?php
            get_sidebar(); 
        ?></div>
    </div>
    <?php
}
/**
 * Sidebar Hidden
 */
if(!function_exists('claniz_sidebar_hidden')){
    add_action('wp_footer', 'claniz_sidebar_hidden');
    function claniz_sidebar_hidden()
    {
        $hidden_sidebar_on = claniz_get_opts( 'hidden_sidebar_on', '0' );
        if($hidden_sidebar_on == '0' || !is_active_sidebar('sidebar-hidden')) return; 
        ?>
            <div class="cms-hidden-sidebar">
                <div class="cms-hidden-close cmsi-remove"></div>
                <div class="cms-hidden-sidebar-inner cms-mousewheel p-30">
                    <div class="cms-hidden-sidebar-inner2 cms-mousewheel-inner">
                        <div class="cms-sidebar-area">
                            <div class="cms-sidebar-area-inner">
                                <?php dynamic_sidebar( 'sidebar-hidden' ); ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
    }
}
if(!function_exists('claniz_hidden_sidebar_icon')){
    function claniz_hidden_sidebar_icon($args = []){
        if(claniz_get_opts( 'hidden_sidebar_on', '0' ) != '1' || !is_active_sidebar('sidebar-hidden')) return;
        $args = wp_parse_args($args, [
            'class' => '',
            'icon'  => 'cmsi-sign-out-alt'
        ]);
    ?>
        <div class="<?php echo trim(implode(' ', ['cms-header-hidden-sidebar header-icon cms-transition', $args['class']]));?>">
            <span class="menu-color <?php echo trim(implode(' ', [$args['icon']]));?>"></span>
        </div>
    <?php
    }
}