<?php
/**
 * Custom template tags for this theme.
 *
 * @package claniz
 */

/**
 * Page loading
 **/
if(!function_exists('claniz_page_loading')){
    function claniz_page_loading()
    {
        $page_loading = claniz_get_theme_opt( 'show_page_loading', false );

        if($page_loading) { ?>
            <div id="cms-loadding" class="cms-loader">
                <div class="loading-spinner">
                    <div class="loading-dot1"></div>
                    <div class="loading-dot2"></div>
                </div>
            </div>
        <?php }
    }
}
/*
 * Content area css class
*/
if(!function_exists('claniz_content_css_class')){
    function claniz_content_css_class($args = []){
        $args = wp_parse_args($args,[
            'content_col'  => 'archive_content_col',
            'sidebar_pos'  => 'archive_sidebar_pos',
            'class'        => ''
        ]);
        $classes = [
            'cms-content-area'
        ];
        $sidebar            = claniz_get_sidebar();
        $sidebar_position   = claniz_sidebar_position(['sidebar_pos' => $args['sidebar_pos']]);
        $content_grid_class = claniz_get_opts($args['content_col'], claniz_configs('blog')['archive_content_col']);

        if( $sidebar_position === 'bottom' || $sidebar_position === '0' ){
            $classes[] = 'col-12';
        } else {
            if($sidebar && ('none' !== $sidebar_position || 'center' == $sidebar_position)){
                $classes[] = 'col-lg-'.$content_grid_class;
                if($sidebar_position == 'left') $classes[] = 'order-lg-last';
                if($sidebar_position == 'center') $classes[] = 'offset-lg-2';
            } else {
                $classes[] = 'col-12';
            }
        }
        $classes[] = $args['class'];
        echo trim(implode(' ', $classes));
    }
}

// Post title
if ( ! function_exists( 'claniz_post_title' ) ) :
    /**
     * Print post title
     *
     * @param  integer $length
     */
    function claniz_post_title($args = []){
        $args = wp_parse_args($args, [
            'tag'         => 'h3',
            'sticky_icon' => '<span class="cmsi-thumbtack"></span>',
            'show_link'   => true,
            'class'       => ''
        ]);
        ?>
        <<?php echo esc_attr($args['tag']); ?> class="<?php echo trim(implode(' ', ['cms-heading cms-post-title', $args['class']]));?>"><?php 
            if($args['show_link'] && !is_single() ) { ?>
                <a href="<?php echo esc_url( get_permalink()); ?>"><?php 
            }
                if(is_sticky()) { echo wp_kses_post($args['sticky_icon']).'&nbsp;&nbsp;'; }
                the_title();
            if($args['show_link']) { ?>
                </a><?php 
            } ?></<?php echo esc_attr($args['tag']); ?>>
    <?php
    }
endif;

if ( ! function_exists( 'claniz_post_excerpt' ) ) :
    /**
     * Print post excerpt based on length.
     *
     * @param  integer $length
     */
    function claniz_post_excerpt($args = []) {
        $args = wp_parse_args($args, [
            'content' => get_the_excerpt(),
            'class'   => '',
            'length'  => claniz_get_theme_opt('archive_excerpt_length', '500'),
            'more'    => '...'
        ]);
        if($args['length'] === '-1' || $args['length'] === -1) return;

        $excerpt = $args['content'];
        $excerpt = preg_replace(" (\[.*?\])",'',$excerpt);
        $excerpt = strip_shortcodes($excerpt);
        $excerpt = strip_tags($excerpt);
        $excerpt = substr($excerpt, 0, $args['length']);
        //$excerpt = substr($excerpt, 0, strripos($excerpt, " "));
        $excerpt = trim(preg_replace( '/\s+/', ' ', $excerpt));
        $excerpt = $excerpt.$args['more'];
    ?>
    <div class="<?php echo trim(implode(' ', ['cms-post-excerpt', $args['class']])) ?>">
        <?php
            if(!empty($args['content'])) {
                printf('%s',  $excerpt);
            } else {
                echo claniz_get_the_excerpt( $args['length'], $args['more']);
            }
        ?>
    </div>
    <?php
    }
endif;

if ( ! function_exists( 'claniz_post_readmore' ) ) :
    /**
     * Print post Readmore.
     *
     * @param 
     */
    function claniz_post_readmore($args = []){
        $args = wp_parse_args($args, [
            'wrap_class' => '',
            'class'      => '',
            'text'       => esc_html__('Read More', 'claniz'),
            'icon'       => 'cmsi-arrow-right',
            'icon_pos'   => 'last'
        ]);
        $readmore_class = ['cms-readmore', 'btn btn-', $args['class']];
        $icon_class = ['cms-btn-icon', 'order-'.$args['icon_pos'], $args['icon'], 'rtl-flip'];
       ?>
       <div class="<?php echo trim(implode(' ', ['cms-post-readmore', $args['wrap_class']]));?>">
            <a href="<?php echo esc_url( get_permalink()); ?>" class="<?php echo trim(implode(' ', $readmore_class ));?>">
                <span class="cms-btn-content">
                    <span class="cms-btn-text"><?php echo esc_html($args['text']); ?></span>
                    <?php if( !empty($args['icon']) ) { ?><span class="<?php echo trim(implode(' ', $icon_class));?>"></span> <?php } ?>
                </span>        
            </a>
        </div>
       <?php 
    }
endif;

/**
 * Prints post edit link when applicable
 */
if(!function_exists('claniz_post_edit_link')){
    function claniz_post_edit_link()
    {
        edit_post_link(
            sprintf(
                wp_kses(
                /* translators: %s: Name of current post. Only visible to screen readers */
                    esc_html__( 'Edit', 'claniz' ),
                    array(
                        'span' => array(
                            'class' => array(),
                        ),
                    )
                ),
                get_the_title()
            ),
            '<div class="cms-post-edit-link"><span class="cmsi-edit"></span>',
            '</div>'
        );
    }
}

// Post link pages
if(!function_exists('claniz_post_link_pages')){
    add_filter('wp_link_pages_args', 'claniz_wp_link_pages_args');
    function claniz_wp_link_pages_args($args){
        $args['before']      = '';
        $args['after']       = '';
        $args['link_before'] = '<span>';
        $args['link_after']  = '</span>';
        return $args;   
    }
    function claniz_post_link_pages($args = []){
        $args = wp_parse_args($args, [
            'class' => ''
        ]);
    ?>
    <div class="<?php echo trim(implode(' ', ['navigation cms-page-links clearfix empty-none', $args['class']])); ?>"><?php 
        wp_link_pages(); 
    ?></div>
    <?php
    }
}

/**
 * Prints posts pagination based on query
 *
 * @param  WP_Query $query     Custom query, if left blank, this will use global query ( current query )
 * @return void
 */
function claniz_posts_pagination( $query = null, $ajax = false )
{
    if($ajax){
        add_filter('paginate_links', 'claniz_ajax_paginate_links');
    }

    $classes = array();

    if ( empty( $query ) )
    {
        $query = $GLOBALS['wp_query'];
    }

    if ( empty( $query->max_num_pages ) || ! is_numeric( $query->max_num_pages ) || $query->max_num_pages < 2 )
    {
        return;
    }

    $paged = $query->get( 'paged', '' );

    if ( ! $paged && is_front_page() && ! is_home() )
    {
        $paged = $query->get( 'page', '' );
    }

    $paged = $paged ? intval( $paged ) : 1;

    $pagenum_link = html_entity_decode( get_pagenum_link() );
    $query_args   = array();
    $url_parts    = explode( '?', $pagenum_link );

    if ( isset( $url_parts[1] ) )
    {
        wp_parse_str( $url_parts[1], $query_args );
    }

    $pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
    $pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

    $paginate_links_args = array(
        'base'     => $pagenum_link,
        'total'    => $query->max_num_pages,
        'current'  => $paged,
        'mid_size' => 1,
        'add_args' => array_map( 'urlencode', $query_args ),
        'prev_text' => claniz_pagination_prev_text(),
        'next_text' => claniz_pagination_next_text(),
    );
    if($ajax){
        $paginate_links_args['format'] = '?page=%#%';
    }
    $links = paginate_links( $paginate_links_args );
    if ( $links ):
    ?>
    <nav class="navigation posts-pagination <?php echo esc_attr($ajax?'ajax':''); ?>">
        <?php
            printf('%s',$links);
        ?>
    </nav>
    <?php
    endif;
}
if(!function_exists('claniz_pagination_prev_text')){
    function claniz_pagination_prev_text(){
        return '<span class="nav-prev-icon"></span>';
    }
}
if(!function_exists('claniz_pagination_next_text')){
    function claniz_pagination_next_text(){
        return '<span class="nav-next-icon"></span>';
    }
}

/**
 * List socials share for post.
 * <a class="pin-social pinterest hover-effect" title="Pinterest" target="_blank" href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode(the_permalink()); ?>&media=<?php echo esc_attr($pinterestimage[0]); ?>&description=<?php the_title(); ?>"><i class="cmsi-pinterest"></i></a><a class="it-social instagram hover-effect" title="Instagram" target="_blank" href="https://instagram.com/<?php echo claniz_get_theme_opt('instagram_user');?>"><i class="cmsi-instagram"></i></a>
 *
*/

if(!function_exists('claniz_socials_share_default')){
    function claniz_socials_share_default($args = []) {
        $args = wp_parse_args($args, [
            'echo'              => true, 
            'show_share'        => '1',
            'class'             => '',
            'title'             => '<div class="cms-post-share-title cms-heading col">'.esc_html__('Share:','claniz').'</div>',
            'social_class'      => '',
            'social_item_class' => '',
            'before'            => '',
            'after'             => '',
            'icon_facebook'     => 'cmsi-facebook-f',
            'icon_twitter'      => 'cmsi-twitter',
            'icon_linkedin'     => 'cmsi-linkedin-in',
            'icon_instagram'    => '',
            'icon_pinterest'    => '',
            'layout'            => '1',
            'gutters'           => '10',
            'row_class'         => ''
        ]);
        if($args['show_share'] != '1') return;
        $pinterestimage = get_the_post_thumbnail_url( get_the_ID(), 'full' );
        $row_class = ['row', 'gutters-grid', 'gutters-'.$args['gutters'], $args['row_class'] ];
        ob_start();
            printf('%s', $args['before']);
        ?>
            <div class="<?php echo trim(implode(' ',['cms-post-share row align-items-center',  $args['class']]));?>">
                <?php if(!empty($args['title'])) printf('%s', $args['title']); ?>
                <div class="<?php echo trim(implode(' ',['col cms-social',  $args['social_class']]));?>">
                    <div class="<?php echo claniz_nice_class($row_class);?>">
                        <?php switch ($args['layout']) {
                            case '2':
                        ?>
                            <?php if(!empty($args['icon_facebook'])) { ?>
                            <div class="cms-social cms-social-item col-auto">
                                <a class="<?php echo esc_attr($args['social_item_class']);?>" title="Facebook" target="_blank" href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode(get_permalink()); ?>">
                                    <span class="<?php echo esc_attr($args['icon_facebook']); ?>"></span>
                                    <?php esc_html_e('Share on Facebook','claniz'); ?>
                                </a>
                            </div>
                            <?php } if(!empty($args['icon_twitter'])) { ?>
                            <div class="cms-social cms-social-item col-auto">
                                <a class="<?php echo esc_attr($args['social_item_class']);?>" title="Twitter" target="_blank" href="https://twitter.com/intent/tweet?original_referer=<?php echo urldecode(home_url('/')); ?>&url=<?php echo urlencode(get_permalink()); ?>&text=<?php the_title();?>&via=<?php echo claniz_get_theme_opt('twitter_user', 'joomskys');?>">
                                    <span class="<?php echo esc_attr($args['icon_twitter']); ?>"></span>
                                    <?php esc_html_e('Share on Twitter','claniz'); ?>
                                </a>
                            </div>
                            <?php } if(!empty($args['icon_linkedin'])) { ?>
                            <div class="cms-social cms-social-item col-auto">
                                <a class="<?php echo esc_attr($args['social_item_class']);?>" title="Linkedin" target="_blank" href="https://www.linkedin.com/cws/share?url=<?php echo urlencode(get_permalink());?>">
                                    <span class="<?php echo esc_attr($args['icon_linkedin']); ?>"></span>
                                    <?php esc_html_e('Share on Linkedin','claniz'); ?>
                                </a>
                            </div>
                            <?php } if(!empty($args['icon_instagram'])) { ?>
                                <div class="cms-social cms-social-item col-auto">
                                    <a class="<?php echo esc_attr($args['social_item_class']);?>" title="Instagram" target="_blank" href="https://instagram.com/<?php echo claniz_get_theme_opt('instagram_user');?>">
                                        <span class="<?php echo esc_attr($args['icon_instagram']); ?>"></span>
                                        <?php esc_html_e('Share on Instagram','claniz'); ?>
                                    </a>
                                </div>
                            <?php } if(!empty($args['icon_pinterest'])) { ?>
                                <div class="cms-social cms-social-item col-auto">
                                    <a class="<?php echo esc_attr($args['social_item_class']);?>" title="Pinterest" target="_blank" href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode(get_permalink()); ?>&media=<?php echo esc_attr($pinterestimage); ?>&description=<?php the_title(); ?>">
                                        <span class="<?php echo esc_attr($args['icon_pinterest']); ?>"></span>
                                        <?php esc_html_e('Share on Twitter','claniz'); ?>
                                    </a>
                                </div>
                            <?php } ?>
                        <?php
                                break;
                            
                            default:

                            $args['social_item_class'] .= ' d-flex align-items-center justify-content-center cms-radius-2';
                        ?>       
                            <?php if(!empty($args['icon_facebook'])) { ?>
                            <div class="cms-social cms-social-item col-auto">
                                <a class="<?php echo esc_attr($args['social_item_class'].' '.$args['icon_facebook']);?>" title="Facebook" target="_blank" href="https://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode(get_permalink()); ?>"></a>
                            </div>
                            <?php } if(!empty($args['icon_twitter'])) { ?>
                            <div class="cms-social cms-social-item col-auto">
                                <a class="<?php echo esc_attr($args['social_item_class'].' '.$args['icon_twitter']);?>" title="Twitter" target="_blank" href="https://twitter.com/intent/tweet?original_referer=<?php echo urldecode(home_url('/')); ?>&url=<?php echo urlencode(get_permalink()); ?>&text=<?php the_title();?>&via=<?php echo claniz_get_theme_opt('twitter_user', 'joomskys');?>"></a>
                            </div>
                            <?php } if(!empty($args['icon_linkedin'])) { ?>
                            <div class="cms-social cms-social-item col-auto">
                                <a class="<?php echo esc_attr($args['social_item_class'].' '.$args['icon_linkedin']);?>" title="Linkedin" target="_blank" href="https://www.linkedin.com/cws/share?url=<?php echo urlencode(get_permalink());?>"></a>
                            </div>
                            <?php } if(!empty($args['icon_instagram'])) { ?>
                                <div class="cms-social cms-social-item col-auto">
                                    <a class="<?php echo esc_attr($args['social_item_class'].' '.$args['icon_instagram']);?>" title="Instagram" target="_blank" href="https://instagram.com/<?php echo claniz_get_theme_opt('instagram_user');?>"></a>
                                </div>
                            <?php } if(!empty($args['icon_pinterest'])) { ?>
                                <div class="cms-social cms-social-item col-auto">
                                    <a class="<?php echo esc_attr($args['social_item_class'].' '.$args['icon_pinterest']);?>" title="Pinterest" target="_blank" href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode(get_permalink()); ?>&media=<?php echo esc_attr($pinterestimage); ?>&description=<?php the_title(); ?>"></a>
                                </div>
                            <?php } ?>
                        <?php 
                        # code...
                                break;
                        } ?>
                    </div>
                </div>
            </div>
            <?php
            printf('%s', $args['after']);

        if($args['echo']){
            echo ob_get_clean();
        } else {
            return ob_get_clean();
        }
    }
}

/**
 * Post Author Info
****/
if(!function_exists('claniz_post_author_info')){
    function claniz_post_author_info($args = []){
        $args = wp_parse_args($args,[
            'class'       => '',
            'avata_size'  => '100',
            'show_author' => claniz_get_theme_opt('post_author_info_on','0'),
            'title_class' => '',
            'desc_class'  => '',
            'social_item_class' => '',
            'before'      => '',
            'after'       => ''  
        ]);
        if($args['show_author'] != '1' || get_the_author_meta( 'description' ) == '' ) return;

        $desc_class = implode(' ', ['cms-post-author-description', $args['desc_class']]);
        printf('%s', $args['before']);
    ?>
        <div class="<?php echo trim(implode(' ', ['cms-author-info', $args['class']]));?>">
            <div class="cms-post-author row gutters-grid text-center text-md-start gutters-30">
                <div class="cms-post-author-avatar col-12 col-md-auto"><?php 
                    echo get_avatar( get_the_author_meta( 'ID' ), $args['avata_size'], '', esc_html__('claniz', 'claniz'), [
                        'width' => $args['avata_size'],
                        'height' => $args['avata_size'],
                        'class'  => 'cms-radius-4'
                    ]); ?></div>
                <div class="cms-post-author-description col"><?php 
                    echo '<div class="cms-post-author-title cms-heading '.$args['title_class'].'">'.get_the_author().'</div>';
                    echo '<div class="'.$desc_class.'">'.get_the_author_meta( 'description' ).'</div>';
                    claniz_get_user_social([
                        'class'             => 'text-20',
                        'row_class'         => 'justify-content-center justify-content-md-start',
                        'social_item_class' => $args['social_item_class']
                    ]); 
                ?></div>
            </div>
        </div>
    <?php 
        printf('%s', $args['after']);
    }
}
/**
 * Single  Next/Prev Link
*/
if(!function_exists('claniz_posts_nav_link')) { 
    function claniz_posts_nav_link($args = []){
        $args = wp_parse_args($args, [
            'show_nav'       => '1',
            'show_thumbnail' => true,
            'thumbnail_size' => 'medium',
            'show_title'     => '1',
            'prev_title'     =>  esc_html__('Previous', 'claniz'). ' ' .get_post_type(),
            'next_title'     =>  esc_html__('Next', 'claniz'). ' ' . get_post_type(),
            'prev_icon'      => 'cmsi-arrow-left',
            'next_icon'      => 'cmsi-arrow-right',
            'class'          => '',
            'img_class'      => '',
            'before'         => '',
            'after'          => ''
        ]);
        if($args['show_nav'] != '1' ) return;
        $next_post = get_next_post();
        $previous_post = get_previous_post();
        if(empty($previous_post) && empty($next_post)) return;
        printf('%s', $args['before']);
    ?>
        <div class="<?php echo trim(implode(' ', ['cms-single-next-prev-navigation row gutters-grid justify-content-between align-items-center', $args['class']])); ?>">
            <?php if(!empty($previous_post)) { ?>
            <div class="cms-single-next-prev cms-single-prev col-sm-6 relative text-start">
                <div class="cms-single-next-prev-inner cms-single-prev-inner cms-single-nav-inner">
                    <?php 
                        // overlay link
                        previous_post_link('%link',''); 
                    ?>
                    <div class="row align-items-center gutters-20 gutters-grid">
                        <?php 
                            claniz_post_thumbnail([
                                'id'             => $previous_post->ID, 
                                'thumbnail_size' => $args['thumbnail_size'], 
                                'class'          => '', 
                                'img_class'      => $args['img_class'],
                                'img_after'      => claniz_posts_nav_icon(['icon' => $args['prev_icon'], 'class' => 'cms-post-nav-img-icon','icon_class' => 'd-block', 'echo' => false]),
                                'before'         => '<div class="col-12">',
                                'after'          => '</div>',
                                'show_thumbnail' => $args['show_thumbnail']
                            ]); 
                        ?>
                        <div class="col"><div class="cms-posts-nav-arrow-title row gutters-0 align-items-center cms-transition"><?php 
                            claniz_posts_nav_icon([
                                'icon'   => $args['prev_icon'],
                                'before' => '<div class="col-auto">',
                                'after'  => '</div>'
                            ]);
                            ?>
                            <div class="col"><div class="p-lr-20"><?php 
                                // label
                                claniz_posts_nav_link_label(['title' => $args['prev_title'] ]);
                                // title
                                claniz_posts_nav_link_title([
                                    'show_title' => $args['show_title'],
                                    'title' => get_the_title($previous_post->ID )
                                ]);
                            ?></div></div>
                        </div></div>
                    </div>
                </div>
            </div>
            <?php } else { 
                echo '<div class="col-sm-6 relative text-start"></div>'; 
            }
            if(!empty($next_post)) : ?>
            <div class="cms-single-next-prev cms-single-next col-sm-6 relative text-end">
                <div class="cms-single-next-prev-inner cms-single-next-inner cms-single-nav-inner">
                    <?php 
                        // overlay link
                        next_post_link('%link','');
                    ?>
                    <div class="row align-items-center gutters-20 gutters-grid">
                        <?php 
                            claniz_post_thumbnail([
                                'id'             => $next_post->ID,
                                'thumbnail_size' => $args['thumbnail_size'], 
                                'class'          => '', 
                                'img_class'      => $args['img_class'],
                                'img_after'      => claniz_posts_nav_icon(['icon' => $args['next_icon'], 'class' => 'cms-post-nav-img-icon','icon_class' => 'd-block', 'echo' => false]),
                                'before'         => '<div class="col-12">',
                                'after'          => '</div>',
                                'show_thumbnail' => $args['show_thumbnail']
                            ]); 
                        ?>
                        <div class="col"><div class="cms-posts-nav-arrow-title row gutters-0 align-items-center cms-transition">
                            <div class="col"><div class="p-lr-20"><?php 
                                // label
                                claniz_posts_nav_link_label(['title' => $args['next_title'] ]);
                                // title
                                claniz_posts_nav_link_title([
                                    'show_title' => $args['show_title'],
                                    'title' => get_the_title($next_post->ID )
                                ]);
                            ?></div></div>
                            <?php 
                            claniz_posts_nav_icon([
                                'icon'   => $args['next_icon'],
                                'before' => '<div class="col-auto">',
                                'after'  => '</div>'
                            ]);
                            ?>
                        </div></div>
                    </div>
                </div>
            </div>
            <?php endif; ?>
        </div>
    <?php 
        printf('%s', $args['after']);
    }
}

if(!function_exists('claniz_posts_nav_link_label')){
    function claniz_posts_nav_link_label($args = []){
        $args = wp_parse_args($args, [
            'title' => '',
            'class' => '',
            'before' => '',
            'after' => ''
        ]);
        if(empty($args['title'])) return;
        $classes = claniz_nice_class(['cms-nav-label', 'font-700', $args['class'] ]);
        printf( '%s<div class="%s">%s</div>%s', $args['before'], $classes, $args['title'], $args['after'] );
    }
}

if(!function_exists('claniz_posts_nav_link_title')){
    function claniz_posts_nav_link_title($args = []){
        $args = wp_parse_args($args, [
            'show_title' => '1',
            'title' => '',
            'class' => '',
            'before' => '',
            'after' => ''
        ]);
        if(empty($args['title']) || $args['show_title'] !== '1' ) return;
        $classes = claniz_nice_class(['cms-nav-title', $args['class'] ]);
        printf( '%s<h4 class="%s">%s</h4>%s', $args['before'], $classes, $args['title'], $args['after'] );
    }
}
if(!function_exists('claniz_posts_nav_icon')){
    function claniz_posts_nav_icon($args= []){
        $args = wp_parse_args($args, [
            'icon'       => '',
            'icon_class' => 'cms-nav-icon',
            'class'      => '',
            'before'     => '',
            'after'      => '',
            'echo'       => true
        ]);
        if(empty($args['icon'])) return;
        $icon_class = claniz_nice_class(['cms-nav-icons cms-transition', $args['class']]);
        $icon = claniz_nice_class([$args['icon_class'], $args['icon'], 'rtl-flip']);
        ob_start();
            printf('%s<span class="%s"><span class="%s"></span></span>%s', $args['before'], $icon_class, $icon, $args['after']);

        if($args['echo'])
            echo ob_get_clean();
        else 
            return ob_get_clean();
    }
}

/**
 * Related Post
 */
if(!function_exists('claniz_related_post')){
    function claniz_related_post($args = [])
    {
        $args = wp_parse_args($args, [
            'class'          => '',
            'show_related'   => claniz_get_theme_opt( 'post_related_on', '0' ),
            'title'          => esc_html__('Related Posts','claniz'),
            'posts_per_page' => '2',
            'post_type'      => 'post',
            'before'         => '',
            'after'          => ''
        ]);

        if($args['show_related'] != '1') return;
        //$args['posts_per_page'] = (int)$args['posts_per_page'] + 1;

        global $post;
        $current_id = $post->ID;
        $posttags = get_the_category($post->ID);
        if (empty($posttags)) return;
        $tags = array();
        foreach ($posttags as $tag) {
            $tags[] = $tag->term_id;
        }
        $query_similar = new WP_Query(array(
            'posts_per_page' => $args['posts_per_page'], 
            'post_type'      => $args['post_type'], 
            'post_status'    => 'publish', 
            'category__in'   => $tags
        ));
        if (count($query_similar->posts) > 1) {
            printf('%s', $args['before']);
            ?>
            <div class="<?php echo trim(implode(' ', ['cms-related-post', $args['class']]));?>">
                <?php if(!empty($args['title'])) echo '<div class="cms-heading cms-related-heading text-24 mb-25">'.esc_html($args['title']).'</div>'; ?>
                <div class="cms-related-post-inner row">
                    <?php foreach ($query_similar->posts as $post):
                        if ($post->ID !== $current_id) : ?>
                            <div class="grid-item col-lg-6 col-12">
                                <div class="grid-item-inner">
                                    <?php 
                                        claniz_post_media([
                                            'id'             => $post->ID,
                                            'thumbnail_size' => 'medium',
                                            'img_class'      => '',
                                            'wrap_class'          => 'mb-25'
                                        ]);
                                    ?>
                                    <h4 class="item-title">
                                        <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                    </h4>
                                </div>
                            </div>
                        <?php endif;
                    endforeach; ?>
                </div>
            </div>
        <?php 
            printf('%s', $args['after']);
        }
        wp_reset_postdata();
    }
}
/* Author Social */
if(!function_exists('tco_get_user_social')){
    function tco_get_user_social($args = []) {
        $args = wp_parse_args($args,[
            'class'             => '',
            'row_class'         => '',    
            'social_item_class' => ''
        ]);
        $user_facebook  = get_user_meta(get_the_author_meta( 'ID' ), 'user_facebook', true);
        $user_twitter   = get_user_meta(get_the_author_meta( 'ID' ), 'user_twitter', true);
        $user_linkedin  = get_user_meta(get_the_author_meta( 'ID' ), 'user_linkedin', true);
        $user_skype     = get_user_meta(get_the_author_meta( 'ID' ), 'user_skype', true);
        $user_google    = get_user_meta(get_the_author_meta( 'ID' ), 'user_google', true);
        $user_youtube   = get_user_meta(get_the_author_meta( 'ID' ), 'user_youtube', true);
        $user_vimeo     = get_user_meta(get_the_author_meta( 'ID' ), 'user_vimeo', true);
        $user_tumblr    = get_user_meta(get_the_author_meta( 'ID' ), 'user_tumblr', true);
        $user_rss       = get_user_meta(get_the_author_meta( 'ID' ), 'user_rss', true);
        $user_pinterest = get_user_meta(get_the_author_meta( 'ID' ), 'user_pinterest', true);
        $user_instagram = get_user_meta(get_the_author_meta( 'ID' ), 'user_instagram', true);
        $user_yelp      = get_user_meta(get_the_author_meta( 'ID' ), 'user_yelp', true);

        ?>
        <div class="<?php echo trim(implode(' ', ['user-social cms-socials', $args['class']]));?>">
            <div class="row gutters-10 gutters-grid <?php echo esc_attr($args['row_class']);?>">
                <?php if(!empty($user_facebook)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-facebook-circle-alt');?>" href="<?php echo esc_url($user_facebook); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_twitter)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-twitter-circle');?>" href="<?php echo esc_url($user_twitter); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_linkedin)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-linkedin-circle');?>" href="<?php echo esc_url($user_linkedin); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_rss)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-rss');?>" href="<?php echo esc_url($user_rss); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_instagram)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-instagram');?>" href="<?php echo esc_url($user_instagram); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_google)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-google');?>" href="<?php echo esc_url($user_google); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_skype)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-skype');?>" href="<?php echo esc_url($user_skype); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_pinterest)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-pinterest');?>" href="<?php echo esc_url($user_pinterest); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_vimeo)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-vimeo');?>" href="<?php echo esc_url($user_vimeo); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_youtube)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-youtube');?>" href="<?php echo esc_url($user_youtube); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_yelp)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-yelp');?>" href="<?php echo esc_url($user_yelp); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_tumblr)) { ?>
                    <div class="cms-social cms-social-item col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-tumblr');?>" href="<?php echo esc_url($user_tumblr); ?>"></a>
                    </div>
                <?php } ?>
            </div>
        </div> <?php
    }
}
/* Author Social */
if(!function_exists('claniz_get_user_social')){
    function claniz_get_user_social($args = []) {
        $args = wp_parse_args($args,[
            'class'             => '',
            'row_class'         => '',    
            'social_item_class' => ''
        ]);
        $user_facebook  = get_user_meta(get_the_author_meta( 'ID' ), 'user_facebook', true);
        $user_twitter   = get_user_meta(get_the_author_meta( 'ID' ), 'user_twitter', true);
        $user_linkedin  = get_user_meta(get_the_author_meta( 'ID' ), 'user_linkedin', true);
        $user_skype     = get_user_meta(get_the_author_meta( 'ID' ), 'user_skype', true);
        $user_google    = get_user_meta(get_the_author_meta( 'ID' ), 'user_google', true);
        $user_youtube   = get_user_meta(get_the_author_meta( 'ID' ), 'user_youtube', true);
        $user_vimeo     = get_user_meta(get_the_author_meta( 'ID' ), 'user_vimeo', true);
        $user_tumblr    = get_user_meta(get_the_author_meta( 'ID' ), 'user_tumblr', true);
        $user_rss       = get_user_meta(get_the_author_meta( 'ID' ), 'user_rss', true);
        $user_pinterest = get_user_meta(get_the_author_meta( 'ID' ), 'user_pinterest', true);
        $user_instagram = get_user_meta(get_the_author_meta( 'ID' ), 'user_instagram', true);
        $user_yelp      = get_user_meta(get_the_author_meta( 'ID' ), 'user_yelp', true);

        ?>
        <div class="<?php echo trim(implode(' ', ['user-social', $args['class']]));?>">
            <div class="row gutters-10 gutters-grid <?php echo esc_attr($args['row_class']);?>">
                <?php if(!empty($user_facebook)) { ?>
                    <div class="cms-social col-auto lh-1">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-facebook-circle-alt');?>" href="<?php echo esc_url($user_facebook); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_twitter)) { ?>
                    <div class="cms-social col-auto lh-1">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-twitter-circle');?>" href="<?php echo esc_url($user_twitter); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_linkedin)) { ?>
                    <div class="cms-social col-auto lh-1">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-linkedin-circle');?>" href="<?php echo esc_url($user_linkedin); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_rss)) { ?>
                    <div class="cms-social col-auto lh-1">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-rss');?>" href="<?php echo esc_url($user_rss); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_instagram)) { ?>
                    <div class="cms-social col-auto lh-1">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-instagram');?>" href="<?php echo esc_url($user_instagram); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_google)) { ?>
                    <div class="cms-social col-auto lh-1">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-google');?>" href="<?php echo esc_url($user_google); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_skype)) { ?>
                    <div class="cms-social col-auto lh-1">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-skype');?>" href="<?php echo esc_url($user_skype); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_pinterest)) { ?>
                    <div class="cms-social col-auto lh-1">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-pinterest');?>" href="<?php echo esc_url($user_pinterest); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_vimeo)) { ?>
                    <div class="cms-social col-auto">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-vimeo');?>" href="<?php echo esc_url($user_vimeo); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_youtube)) { ?>
                    <div class="cms-social col-auto lh-1">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-youtube');?>" href="<?php echo esc_url($user_youtube); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_yelp)) { ?>
                    <div class="cms-social col-auto lh-1">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-yelp');?>" href="<?php echo esc_url($user_yelp); ?>"></a>
                    </div>
                <?php } ?>
                <?php if(!empty($user_tumblr)) { ?>
                    <div class="cms-social col-auto lh-1">
                        <a class="<?php echo esc_attr($args['social_item_class'].' cmsi-tumblr');?>" href="<?php echo esc_url($user_tumblr); ?>"></a>
                    </div>
                <?php } ?>
            </div>
        </div> <?php
    }
}
function claniz_product_nav() {
    global $post;
    $previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );

    if ( ! $next && ! $previous )
        return;
    ?>
    <?php
    $next_post = get_next_post();
    $previous_post = get_previous_post();
    if( !empty($next_post) || !empty($previous_post) ) { ?>
        <div class="product-previous-next">
            <?php if ( is_a( $previous_post , 'WP_Post' ) && get_the_title( $previous_post->ID ) != '') { ?>
                <a class="nav-link-prev" href="<?php echo esc_url(get_permalink( $previous_post->ID )); ?>"><i class="cmsi-long-arrow-left"></i></a>
            <?php } ?>
            <?php if ( is_a( $next_post , 'WP_Post' ) && get_the_title( $next_post->ID ) != '') { ?>
                <a class="nav-link-next" href="<?php echo esc_url(get_permalink( $next_post->ID )); ?>"><i class="cmsi-long-arrow-right"></i></a>
            <?php } ?>
        </div>
    <?php }
}
if(!function_exists('claniz_is_post_type')){
    function claniz_is_post_type($type = 'post', $id = ''){
        if ( $type == get_post_type($id) ) return true;
        return false;
    } 
}