<?php 
/**
 * Get Page List 
 * @return array
*/
if(!function_exists('claniz_list_page')){
    function claniz_list_page($default = []){
        $page_list = array();
        if(!empty($default))
            $page_list[$default['value']] = $default['label'];
        $pages = get_pages(array('hierarchical' => 0, 'posts_per_page' => '-1'));
        foreach($pages as $page){
            $page_list[$page->ID] = $page->post_title;
        }
        return $page_list;
    }
}

/**
 * Get Post List
 * @return array
*/
if(!function_exists('claniz_list_post')){
    function claniz_list_post($post_type = 'post', $default = false){
        $post_list = array();
        if($default){
            $post_list['none'] = esc_html__('None','claniz');
            $post_list['-1']   = esc_html__('Default','claniz');
        }
        $posts = get_posts(array('post_type' => $post_type,'posts_per_page' => '-1'));
        foreach($posts as $post){
            $post_list[$post->ID] = $post->post_title;
        }
        return $post_list;
    }
}

/**
 * Get post thumbnail as image options
 * @return array
 *
*/
function claniz_list_post_thumbnail($post_type = 'post', $default = false, $args = []){
    $layouts = [];
    if($default){
        $layouts['-1'] = get_template_directory_uri() . '/assets/images/default-opt/default.jpg';
        $layouts['none'] = get_template_directory_uri() . '/assets/images/default-opt/none.jpg';
    }
    $layouts = $layouts + $args;
    $posts = get_posts(array('post_type' => $post_type,'posts_per_page' => '-1'));
    
    foreach($posts as $post){
        $layouts[$post->ID] = wp_get_attachment_image_url(get_post_thumbnail_id($post->ID), 'full');
    }
    return $layouts;
}

/**
 * get list menu.
 * @return array
 */
if(!function_exists('claniz_get_nav_menu')){
    function claniz_get_nav_menu($args = []){
        $args = wp_parse_args($args, [
            'default' => false, 
            'none'    => false
        ]);
        $menus = array(
            '0' => esc_html__('Primary Menu','claniz')
        );
        $obj_menus = wp_get_nav_menus();
        if($args['default']) $menus['-1'] = esc_html__('Default','claniz');
        if($args['none']) $menus['none'] = esc_html__('None','claniz');

        foreach ($obj_menus as $obj_menu){
            $menus[$obj_menu->slug] = $obj_menu->name;
        }
        return $menus;
    }
}
/**
 * Get list of user by user role for post options
 * 
 * @param $user_role
*/
function claniz_list_user_by_role_for_opts($args = []){
    $args = wp_parse_args($args, [
        'role'    => 'subcrible',
        'orderby' => 'user_nicename',
        'order'   => 'ASC'
    ]);
    $users = get_users( $args );
    $options = [];
    foreach ( $users as $user ) {
        $options[$user->user_email] = $user->display_name;
    }
    return $options;
}
/**
 * Get RevSlider List 
 * @return array
*/
if(!function_exists('claniz_get_list_rev_slider')){
    function claniz_get_list_rev_slider() {
        if (!class_exists('RevSlider')) return;
        $slider = new RevSlider();
        $arrSliders = $slider->getArrSliders();
        $revsliders = array();
        if ($arrSliders) {
            foreach ($arrSliders as $slider) {
                /* @var $slider RevSlider */
                $revsliders[$slider->getAlias()] = $slider->getTitle();
            }
        }
        return $revsliders;
    }
}

/**
 * Get Contact Form 7 List
 * @return array
*/
if(!function_exists('claniz_get_list_cf7')){
    function claniz_get_list_cf7($defaule = false) {
        if(!class_exists('WPCF7')) return;
        $cf7 = get_posts( 'post_type="wpcf7_contact_form"&numberposts=-1' );
        $contact_forms = array();
        if($defaule){
            $contact_forms['-1'] = esc_html__('Default From Theme Option','claniz');
        }
        foreach ( $cf7 as $cform ) {
            $contact_forms[ $cform->post_title ] = $cform->post_title;
        }
        return $contact_forms;
    }
}
/**
 * Get NewsLetter Form List
 * @return array
*/
if(!function_exists('claniz_list_newsletter_form')){
    function claniz_list_newsletter_form(){
        if(!class_exists('Newsletter'))  return;
        $forms = array_filter( (array) get_option( 'newsletter_forms', array() ) );
        $newsletter_forms = array(
            'default' => esc_html__( 'Default Form', 'claniz' )
        );
        if ( $forms )
        {
            $index = 1;
            foreach ( $forms as $key => $form )
            {
                $newsletter_forms[$key] = sprintf( esc_html__( 'Form %s', 'claniz' ), $index );
                $index ++;
            }
        }
        return  $newsletter_forms;
    }
}