<?php
/**
 * Register metabox for posts based on Redux Framework. Supported methods:
 *     isset_args( $post_type )
 *     set_args( $post_type, $redux_args, $metabox_args )
 *     add_section( $post_type, $sections )
 * Each post type can contains only one metabox. Pease note that each field id
 * leads by an underscore sign ( _ ) in order to not show that into Custom Field
 * Metabox from WordPress core feature.
 *
 * @param  CMS_Post_Metabox $metabox
 */

add_action( 'cms_post_metabox_register', 'claniz_post_options_register' );
function claniz_post_options_register( $metabox ) {
    if ( ! $metabox->isset_args( 'post' ) ) {
        $metabox->set_args( 'post', array(
            'opt_name'            => 'post_option',
            'display_name'        => esc_html__( 'Post Settings', 'claniz' ),
            'show_options_object' => false,
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }
    if ( ! $metabox->isset_args( 'cms_pf_audio' ) ) {
        $metabox->set_args( 'cms_pf_audio', array(
            'opt_name'     => 'post_format_audio',
            'display_name' => esc_html__( 'Audio', 'claniz' ),
            'class'        => 'fully-expanded',
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }
    if ( ! $metabox->isset_args( 'cms_pf_link' ) ) {
        $metabox->set_args( 'cms_pf_link', array(
            'opt_name'     => 'post_format_link',
            'display_name' => esc_html__( 'Link', 'claniz' )
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }
    if ( ! $metabox->isset_args( 'cms_pf_quote' ) ) {
        $metabox->set_args( 'cms_pf_quote', array(
            'opt_name'     => 'post_format_quote',
            'display_name' => esc_html__( 'Quote', 'claniz' )
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }
    if ( ! $metabox->isset_args( 'cms_pf_video' ) ) {
        $metabox->set_args( 'cms_pf_video', array(
            'opt_name'     => 'post_format_video',
            'display_name' => esc_html__( 'Video', 'claniz' ),
            'class'        => 'fully-expanded',
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }
    if ( ! $metabox->isset_args( 'cms_pf_gallery' ) ) {
        $metabox->set_args( 'cms_pf_gallery', array(
            'opt_name'     => 'post_format_gallery',
            'display_name' => esc_html__( 'Gallery', 'claniz' ),
            'class'        => 'fully-expanded',
        ), array(
            'context'  => 'advanced',
            'priority' => 'default'
        ) );
    }

    /**
     * Config post meta options
     *
     */
    $metabox->add_section( 'post', array(
        'title'  => esc_html__( 'Content Settings', 'claniz' ),
        'icon'   => 'el el-refresh',
        'fields' => array(
            array(
                'id'             => 'post_content_padding',
                'type'           => 'spacing',
                'output'         => array( '.single-post #content' ),
                'right'          => false,
                'left'           => false,
                'mode'           => 'padding',
                'units'          => array( 'px' ),
                'units_extended' => 'false',
                'title'          => esc_html__( 'Content Padding', 'claniz' ),
                'subtitle'     => esc_html__( 'Content site paddings.', 'claniz' ),
                'desc'           => esc_html__( 'Default: Theme Option.', 'claniz' ),
                'default'        => array(
                    'padding-top'    => '',
                    'padding-bottom' => '',
                    'units'          => 'px',
                )
            )
        )
    ) );
    // Sidebar
    $metabox->add_section('post', claniz_sidebar_opts(['name' => 'post_sidebar_pos', 'default' => true, 'subsection' => true]));
    // Post title
    $metabox->add_section( 'post', claniz_page_title_opts([
        'default'        => false,
        'default_value'  => '1',
        'default_layout' => claniz_configs('single_post')['title_layout']
    ]));
    /**
     * Config post format meta options
     *
    */
    $metabox->add_section( 'cms_pf_video', array(
        'title'  => esc_html__( 'Video', 'claniz' ),
        'fields' => array(
            array(
                'id'    => 'post-video-url',
                'type'  => 'text',
                'title' => esc_html__( 'Video URL', 'claniz' ),
                'desc'  => esc_html__( 'YouTube or Vimeo video URL', 'claniz' )
            ),

            array(
                'id'    => 'post-video-file',
                'type'  => 'editor',
                'title' => esc_html__( 'Video Upload', 'claniz' ),
                'desc'  => esc_html__( 'Upload video file', 'claniz' )
            ),

            array(
                'id'    => 'post-video-html',
                'type'  => 'textarea',
                'title' => esc_html__( 'Embadded video', 'claniz' ),
                'desc'  => esc_html__( 'Use this option when the video does not come from YouTube or Vimeo', 'claniz' )
            )
        )
    ) );

    $metabox->add_section( 'cms_pf_gallery', array(
        'title'  => esc_html__( 'Gallery', 'claniz' ),
        'fields' => array(
            array(
                'id'       => 'post-gallery-lightbox',
                'type'     => 'switch',
                'title'    => esc_html__( 'Lightbox?', 'claniz' ),
                'subtitle' => esc_html__( 'Enable lightbox for gallery images.', 'claniz' ),
                'default'  => true
            ),
            array(
                'id'       => 'post-gallery-images',
                'type'     => 'gallery',
                'title'    => esc_html__( 'Gallery Images ', 'claniz' ),
                'subtitle' => esc_html__( 'Upload images or add from media library.', 'claniz' )
            )
        )
    ) );

    $metabox->add_section( 'cms_pf_audio', array(
        'title'  => esc_html__( 'Audio', 'claniz' ),
        'fields' => array(
            array(
                'id'          => 'post-audio-url',
                'type'        => 'text',
                'title'       => esc_html__( 'Audio URL', 'claniz' ),
                'description' => esc_html__( 'Audio file URL in format: mp3, ogg, wav.', 'claniz' ),
                'validate'    => 'url',
                'msg'         => 'Url error!'
            )
        )
    ) );

    $metabox->add_section( 'cms_pf_link', array(
        'title'  => esc_html__( 'Link', 'claniz' ),
        'fields' => array(
            array(
                'id'       => 'post-link-url',
                'type'     => 'text',
                'title'    => esc_html__( 'URL', 'claniz' ),
                'validate' => 'url',
                'msg'      => 'Url error!'
            )
        )
    ) );

    $metabox->add_section( 'cms_pf_quote', array(
        'title'  => esc_html__( 'Quote', 'claniz' ),
        'fields' => array(
            array(
                'id'    => 'post-quote-cite',
                'type'  => 'text',
                'title' => esc_html__( 'Cite', 'claniz' )
            )
        )
    ) );
}