<?php
/**
 * Template part for displaying posts in loop
 *
 * @package claniz
 */
$sidebar = claniz_sidebar_position();
$sidebar_name = claniz_get_sidebar();

if($sidebar_name === false || in_array($sidebar, ['0','none', 'bottom'])){
    $thumbnail_size = 'post-thumbnail';
} else {
    $thumbnail_size = 'large';
}

$post_meta_args = [
    'show_date'    => claniz_get_opts('post_date_on','1'),
    'show_cat'     => claniz_get_opts('post_categories_on','1'),
    'show_author'  => claniz_get_opts('post_author_on','1'),
    'author_title' => esc_html__('By:','claniz').' ',
    'show_cmt'     => claniz_get_opts('post_comments_on','1'),
    'show_icon'    => false,
    'gutters'      => 10,  
    'class'        => 'pb-20',
    'separator'    => '<span class="col-auto align-self-center separator"><span class="cms-meta-separator"></span></span>'
];
$content_text_classes = [
    'cms-content-text', 
    'text-16 text-lg-17',
    'p-lr-20 p-lr-md-40 p-lr-lg-50 pb-40'
];

if(has_post_thumbnail()){
    $post_meta_args['class'] .= ' mt-n25';
} else {
    $content_text_classes[] = 'pt-40';
}
$post_content_classes = ['cms-post-content', 'clearfix'];
if(class_exists('\Elementor\Plugin') && \Elementor\Plugin::$instance->documents->get(get_the_ID())->is_built_with_elementor()){
    $post_content_classes[] = 'single-elementor-content m-lr-n20';
}
?>
<div <?php post_class('cms-single-post'); ?>>
    <div class="cms-single-post-inner cms-shadow-6 mb-40 cms-radius-8 overflow-hidden">
        <?php 
            if(claniz_get_opts('post_feature_image_on', '1') === '1'):
                claniz_post_media([  
                    'size' => $thumbnail_size,
                    'class' => 'cms-radius-12 overflow-hidden'
                ]);
            endif;
        ?>
        <div class="<?php echo claniz_nice_class($content_text_classes);?>">
            <?php
                // Meta
                claniz_post_meta($post_meta_args);
                // title
                claniz_post_title(['tag' => 'h3', 'class' => 'text-20 text-lg-24 text-xl-40 pb-35']);
            ?>
            <div class="<?php echo claniz_nice_class($post_content_classes);?>"><?php
                the_content();
            ?></div>
            <?php 
                // post page
                claniz_post_link_pages(['class' => 'pt-35']);
                //
                if(claniz_get_opts('post_tags_on', '0') === '1' || claniz_get_opts('post_social_share_on', '0') === '1' ) :
            ?>
                <div class="cms-post-tags-share row gutters-20 gutters-grid justify-content-between empty-none pt-35"><?php
                    // Post tag
                    // param: show_tag, title
                    claniz_post_tagged_in([
                        'show_tag'  => claniz_get_opts( 'post_tags_on', '1' ), 
                        'title'     => '<div class="tags-title text-heading">Tags: </div>',
                        'style'     => 'tagcloud', 
                        'separator' => '',
                        'class'     => 'col'
                    ]); 
                    // post share
                    // param: show_share, class, title, social_class
                    claniz_socials_share_default([
                        'class'             => 'gutters-10 gutters-grid justify-content-between',
                        'show_share'        => claniz_get_opts( 'post_social_share_on', '0' ),   
                        'title'             => '',
                        'social_class'      => 'cms-socials social-bg-colored',
                        'social_item_class' => 'social-icon',
                        'before'            => '<div class="col-12 col-md-auto">',
                        'after'             => '</div>'
                    ]);
                ?></div>
            <?php endif; ?>
        </div>
    </div>
    <?php
        // Next/Preview Post link
        // param: show_nav, class, prev_title, next_title
        claniz_posts_nav_link([
            'show_nav'       => claniz_get_theme_opt('post_nav_link_on', '1'),
            'show_title'     => false,
            'show_thumbnail' => false,
            'prev_title'     =>  esc_html__('Prev', 'claniz'). ' ' .get_post_type(),
            'next_title'     =>  esc_html__('Next', 'claniz'). ' ' . get_post_type(),
            'before'         => '<div class="pt-40">',
            'after'          => '</div>' 
        ]);
        // Author info
        // param: show_author, class
        claniz_post_author_info([
            'class'       => 'bg-custom-8 p-20 p-lg-40 p-xl-50 mt-40 cms-radius-8',
            'title_class' => 'heading text-20 pb-10 mt-n8 font-600',
            'desc_class'  => 'pb-20 text-custom-3',
            'show_author' => claniz_get_theme_opt('post_author_info_on', '0'),
            'avata_size'  => 120,
            'social_item_class' => 'text-primary text-hover-secondary',
            'before'      => '',
            'after'       => '' 
        ]);
        // Related post
        // param: class, show_related, title, posts_per_page, post_tyle
        claniz_related_post([
            'class'  => 'mt-40',
            'before' => '',
            'after'  => '' 
        ]);
    ?>
</div>