<?php
if ( ! defined( 'ABSPATH' ) )
{
    die();
}
/**
 * Widget Categories
 * Custom HTML output
*/
if(!function_exists('claniz_widget_pages_args')){
    add_filter('widget_pages_args', 'claniz_widget_pages_args');
    function claniz_widget_pages_args($args){
        $args['walker'] = new claniz_Widget_Pages_Walker_Dropdown;
        return $args; 
    }
}

/**
 * claniz_Pages_Walker_Tree
 *
 * @version 1.0
 * @package claniz
 * @since   1.0
 *
 */
class claniz_Widget_Pages_Walker_Tree extends Walker_Page {
     /**
     * Outputs the beginning of the current level in the tree before elements are output.
     *
     * @since 2.1.0
     *
     * @see Walker::start_lvl()
     *
     * @param string $output Used to append additional content (passed by reference).
     * @param int    $depth  Optional. Depth of page. Used for padding. Default 0.
     * @param array  $args   Optional. Arguments for outputting the next level.
     *                       Default empty array.
     */
    public function start_lvl( &$output, $depth = 0, $args = array() ) {
        if ( isset( $args['item_spacing'] ) && 'preserve' === $args['item_spacing'] ) {
            $t = "\t";
            $n = "\n";
        } else {
            $t = '';
            $n = '';
        }
        $indent  = str_repeat( $t, $depth );
        $output .= "{$n}{$indent}<ul class='children cms-tree'>{$n}";
    }
    /**
     * Outputs the beginning of the current element in the tree.
     *
     * @see Walker::start_el()
     * @since 2.1.0
     *
     * @param string  $output       Used to append additional content. Passed by reference.
     * @param WP_Post $page         Page data object.
     * @param int     $depth        Optional. Depth of page. Used for padding. Default 0.
     * @param array   $args         Optional. Array of arguments. Default empty array.
     * @param int     $current_page Optional. Page ID. Default 0.
     */
    public function start_el( &$output, $page, $depth = 0, $args = array(), $current_page = 0 ) {
        if ( isset( $args['item_spacing'] ) && 'preserve' === $args['item_spacing'] ) {
            $t = "\t";
            $n = "\n";
        } else {
            $t = '';
            $n = '';
        }
        if ( $depth ) {
            $indent = str_repeat( $t, $depth );
        } else {
            $indent = '';
        }
 
        $css_class = array( 'cms-list-item page-item', 'page-item-' . $page->ID );
 
        if ( isset( $args['pages_with_children'][ $page->ID ] ) ) {
            $css_class[] = 'page_item_has_children';
        }
 
        if ( ! empty( $current_page ) ) {
            $_current_page = get_post( $current_page );
 
            if ( $_current_page && in_array( $page->ID, $_current_page->ancestors, true ) ) {
                $css_class[] = 'current_page_ancestor';
            }
 
            if ( $page->ID == $current_page ) {
                $css_class[] = 'current_page_item';
            } elseif ( $_current_page && $page->ID === $_current_page->post_parent ) {
                $css_class[] = 'current_page_parent';
            }
        } elseif ( get_option( 'page_for_posts' ) == $page->ID ) {
            $css_class[] = 'current_page_parent';
        }
 
        /**
         * Filters the list of CSS classes to include with each page item in the list.
         *
         * @since 2.8.0
         *
         * @see wp_list_pages()
         *
         * @param string[] $css_class    An array of CSS classes to be applied to each list item.
         * @param WP_Post  $page         Page data object.
         * @param int      $depth        Depth of page, used for padding.
         * @param array    $args         An array of arguments.
         * @param int      $current_page ID of the current page.
         */
        $css_classes = implode( ' ', apply_filters( 'page_css_class', $css_class, $page, $depth, $args, $current_page ) );
        $css_classes = $css_classes ? ' class="' . esc_attr( $css_classes ) . '"' : '';
 
        if ( '' === $page->post_title ) {
            /* translators: %d: ID of a post. */
            $page->post_title = sprintf( esc_html__( '#%d (no title)', 'claniz' ), $page->ID );
        }
 
        $args['link_before'] = empty( $args['link_before'] ) ? '' : $args['link_before'];
        $args['link_after']  = empty( $args['link_after'] ) ? '' : $args['link_after'];
 
        $atts                 = array();
        $atts['href']         = get_permalink( $page->ID );
        $atts['aria-current'] = ( $page->ID == $current_page ) ? 'page' : '';
 
        /**
         * Filters the HTML attributes applied to a page menu item's anchor element.
         *
         * @since 4.8.0
         *
         * @param array $atts {
         *     The HTML attributes applied to the menu item's `<a>` element, empty strings are ignored.
         *
         *     @type string $href         The href attribute.
         *     @type string $aria_current The aria-current attribute.
         * }
         * @param WP_Post $page         Page data object.
         * @param int     $depth        Depth of page, used for padding.
         * @param array   $args         An array of arguments.
         * @param int     $current_page ID of the current page.
         */
        $atts = apply_filters( 'page_menu_link_attributes', $atts, $page, $depth, $args, $current_page );
 
        $attributes = '';
        foreach ( $atts as $attr => $value ) {
            if ( is_scalar( $value ) && '' !== $value && false !== $value ) {
                $value       = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
                $attributes .= ' ' . $attr . '="' . $value . '"';
            }
        }
 
        $output .= $indent . sprintf(
            '<li%s><a%s>%s%s%s</a>',
            $css_classes,
            $attributes,
            $args['link_before'],
            /** This filter is documented in wp-includes/post-template.php */
            '<span class="title">'.apply_filters( 'the_title', $page->post_title, $page->ID ).'</span>',
            $args['link_after']
        );
 
        if ( ! empty( $args['show_date'] ) ) {
            if ( 'modified' === $args['show_date'] ) {
                $time = $page->post_modified;
            } else {
                $time = $page->post_date;
            }
 
            $date_format = empty( $args['date_format'] ) ? '' : $args['date_format'];
            $output     .= ' ' . mysql2date( $date_format, $time );
        }
    }
}

/**
 * claniz_Pages_Walker_Tree_Dropdown
 *
 * @version 1.0
 * @package claniz
 * @since   1.0
 *
 */
class claniz_Widget_Pages_Walker_Dropdown extends Walker_Page {
    /**
     * Outputs the beginning of the current level in the tree before elements are output.
     *
     * @since 2.1.0
     *
     * @see Walker::start_lvl()
     *
     * @param string $output Used to append additional content (passed by reference).
     * @param int    $depth  Optional. Depth of page. Used for padding. Default 0.
     * @param array  $args   Optional. Arguments for outputting the next level.
     *                       Default empty array.
     */
    public function start_lvl( &$output, $depth = 0, $args = array() ) {
        if ( isset( $args['item_spacing'] ) && 'preserve' === $args['item_spacing'] ) {
            $t = "\t";
            $n = "\n";
        } else {
            $t = '';
            $n = '';
        }
        $indent  = str_repeat( $t, $depth );
        $output .= "{$n}{$indent}<ul class='children cms-dropdown'>{$n}";
    }
    /**
     * Outputs the beginning of the current element in the tree.
     *
     * @see Walker::start_el()
     * @since 2.1.0
     *
     * @param string  $output       Used to append additional content. Passed by reference.
     * @param WP_Post $page         Page data object.
     * @param int     $depth        Optional. Depth of page. Used for padding. Default 0.
     * @param array   $args         Optional. Array of arguments. Default empty array.
     * @param int     $current_page Optional. Page ID. Default 0.
     */
    public function start_el( &$output, $page, $depth = 0, $args = array(), $current_page = 0 ) {
        if ( isset( $args['item_spacing'] ) && 'preserve' === $args['item_spacing'] ) {
            $t = "\t";
            $n = "\n";
        } else {
            $t = '';
            $n = '';
        }
        if ( $depth ) {
            $indent = str_repeat( $t, $depth );
        } else {
            $indent = '';
        }
 
        $css_class = array( 'cms-list-item page-item cms-widget-menu-item', 'page-item-' . $page->ID );
        $dropdown = '';
        if ( isset( $args['pages_with_children'][ $page->ID ] ) ) {
            $css_class[] = 'page_item_has_children';
            $css_class[] = 'cms-widget-menu-item-parents';
            $dropdown = '<span class="cms-menu-toggle"></span>';
        }
 
        if ( ! empty( $current_page ) ) {
            $_current_page = get_post( $current_page );
 
            if ( $_current_page && in_array( $page->ID, $_current_page->ancestors, true ) ) {
                $css_class[] = 'current_page_ancestor';
            }
 
            if ( $page->ID == $current_page ) {
                $css_class[] = 'current_page_item';
            } elseif ( $_current_page && $page->ID === $_current_page->post_parent ) {
                $css_class[] = 'current_page_parent';
            }
        } elseif ( get_option( 'page_for_posts' ) == $page->ID ) {
            $css_class[] = 'current_page_parent';
        }
 
        /**
         * Filters the list of CSS classes to include with each page item in the list.
         *
         * @since 2.8.0
         *
         * @see wp_list_pages()
         *
         * @param string[] $css_class    An array of CSS classes to be applied to each list item.
         * @param WP_Post  $page         Page data object.
         * @param int      $depth        Depth of page, used for padding.
         * @param array    $args         An array of arguments.
         * @param int      $current_page ID of the current page.
         */
        $css_classes = implode( ' ', apply_filters( 'page_css_class', $css_class, $page, $depth, $args, $current_page ) );
        $css_classes = $css_classes ? ' class="' . esc_attr( $css_classes ) . '"' : '';
 
        if ( '' === $page->post_title ) {
            /* translators: %d: ID of a post. */
            $page->post_title = sprintf( esc_html__( '#%d (no title)', 'claniz' ), $page->ID );
        }
 
        $args['link_before'] = empty( $args['link_before'] ) ? '' : $args['link_before'];
        $args['link_after']  = empty( $args['link_after'] ) ? '' : $args['link_after'];
 
        $atts                 = array();
        $atts['href']         = get_permalink( $page->ID );
        $atts['aria-current'] = ( $page->ID == $current_page ) ? 'page' : '';
 
        /**
         * Filters the HTML attributes applied to a page menu item's anchor element.
         *
         * @since 4.8.0
         *
         * @param array $atts {
         *     The HTML attributes applied to the menu item's `<a>` element, empty strings are ignored.
         *
         *     @type string $href         The href attribute.
         *     @type string $aria_current The aria-current attribute.
         * }
         * @param WP_Post $page         Page data object.
         * @param int     $depth        Depth of page, used for padding.
         * @param array   $args         An array of arguments.
         * @param int     $current_page ID of the current page.
         */
        $atts = apply_filters( 'page_menu_link_attributes', $atts, $page, $depth, $args, $current_page );
 
        $attributes = '';
        foreach ( $atts as $attr => $value ) {
            if ( is_scalar( $value ) && '' !== $value && false !== $value ) {
                $value       = ( 'href' === $attr ) ? esc_url( $value ) : esc_attr( $value );
                $attributes .= ' ' . $attr . '="' . $value . '"';
            }
        }
 
        $output .= $indent . sprintf(
            '<li%s><a%s>%s%s%s%s</a>',
            $css_classes,
            $attributes,
            $args['link_before'],
            /** This filter is documented in wp-includes/post-template.php */
            '<span class="title">'.apply_filters( 'the_title', $page->post_title, $page->ID ).'</span>',
            $args['link_after'],
            $dropdown
        );
 
        if ( ! empty( $args['show_date'] ) ) {
            if ( 'modified' === $args['show_date'] ) {
                $time = $page->post_modified;
            } else {
                $time = $page->post_date;
            }
 
            $date_format = empty( $args['date_format'] ) ? '' : $args['date_format'];
            $output     .= ' ' . mysql2date( $date_format, $time );
        }
    }
}